@@ -32,16 +32,22 @@ LOG_CONF_FILE="${RSS_CONF_DIR}/log4j.properties"
 LOG_PATH="${RSS_LOG_DIR}/shuffle_server.log"
 OUT_PATH="${RSS_LOG_DIR}/shuffle_server.out"
 
-set +o nounset
-if [ -z "$XMX_SIZE" ]; then
+if [ -z "${XMX_SIZE:-}" ]; then
   echo "No env XMX_SIZE."
   exit 1
 fi
 echo "Shuffle Server JVM XMX size: ${XMX_SIZE}"
-if [ -n "$RSS_IP" ]; then
+if [ -n "${RSS_IP:-}" ]; then
   echo "Shuffle Server RSS_IP: ${RSS_IP}"
 fi
-set -o nounset
+
+# glibc use an arena memory allocator that causes virtual
+# memory usage to explode. This interacts badly
+# with the many threads that we use in rss. Tune the variable
+# down to prevent vmem explosion.
+# glibc's default value of MALLOC_ARENA_MAX is 8 * CORES.
+# After referring to hadoop/presto, the default MALLOC_ARENA_MAX of shuffle server is set to 4.
+export MALLOC_ARENA_MAX=${MALLOC_ARENA_MAX:-4}
 
 MAIN_CLASS="org.apache.uniffle.server.ShuffleServer"
 
@@ -66,9 +72,15 @@ JAVA_LIB_PATH="-Djava.library.path=$HADOOP_HOME/lib/native"
 
 echo "class path is $CLASSPATH"
 
+MAX_DIRECT_MEMORY_OPTS=""
+if [ -n "${MAX_DIRECT_MEMORY_SIZE:-}" ]; then
+  MAX_DIRECT_MEMORY_OPTS="-XX:MaxDirectMemorySize=$MAX_DIRECT_MEMORY_SIZE"
+fi
+
 JVM_ARGS=" -server \
           -Xmx${XMX_SIZE} \
           -Xms${XMX_SIZE} \
+          ${MAX_DIRECT_MEMORY_OPTS} \
           -XX:+UseG1GC \
           -XX:MaxGCPauseMillis=200 \
           -XX:ParallelGCThreads=20 \
@@ -84,6 +96,9 @@ JVM_ARGS=" -server \
           -XX:+PrintGCDetails \
           -Xloggc:${RSS_LOG_DIR}/gc-%t.log"
 
+JAVA11_EXTRA_ARGS=" -XX:+IgnoreUnrecognizedVMOptions \
+          -Xlog:gc:tags,time,uptime,level"
+
 ARGS=""
 
 if [ -f ${LOG_CONF_FILE} ]; then
@@ -93,7 +108,7 @@ else
   exit 1
 fi
 
-$RUNNER $ARGS $JVM_ARGS $JAVA_LIB_PATH -cp $CLASSPATH $MAIN_CLASS --conf "$SHUFFLE_SERVER_CONF_FILE" $@ &> $OUT_PATH &
+$RUNNER $ARGS $JVM_ARGS $JAVA11_EXTRA_ARGS $JAVA_LIB_PATH -cp $CLASSPATH $MAIN_CLASS --conf "$SHUFFLE_SERVER_CONF_FILE" $@ &> $OUT_PATH &
 
 get_pid_file_name shuffle-server
 echo $! >${RSS_PID_DIR}/${pid_file}
