@@ -17,6 +17,7 @@
 
 package org.apache.spark.shuffle.writer;
 
+import java.util.ArrayList;
 import java.util.List;
 
 import org.apache.uniffle.common.ShuffleBlockInfo;
@@ -25,10 +26,25 @@ public class AddBlockEvent {
 
   private String taskId;
   private List<ShuffleBlockInfo> shuffleDataInfoList;
+  private List<Runnable> processedCallbackChain;
 
   public AddBlockEvent(String taskId, List<ShuffleBlockInfo> shuffleDataInfoList) {
     this.taskId = taskId;
     this.shuffleDataInfoList = shuffleDataInfoList;
+    this.processedCallbackChain = new ArrayList<>();
+  }
+
+  public AddBlockEvent(
+      String taskId, List<ShuffleBlockInfo> shuffleBlockInfoList, Runnable callback) {
+    this.taskId = taskId;
+    this.shuffleDataInfoList = shuffleBlockInfoList;
+    this.processedCallbackChain = new ArrayList<>();
+    addCallback(callback);
+  }
+
+  /** @param callback, should not throw any exception and execute fast. */
+  public void addCallback(Runnable callback) {
+    processedCallbackChain.add(callback);
   }
 
   public String getTaskId() {
@@ -39,6 +55,10 @@ public class AddBlockEvent {
     return shuffleDataInfoList;
   }
 
+  public List<Runnable> getProcessedCallbackChain() {
+    return processedCallbackChain;
+  }
+
   @Override
   public String toString() {
     return "AddBlockEvent: TaskId[" + taskId + "], " + shuffleDataInfoList;
