@@ -22,6 +22,10 @@ import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicInteger;
 
+import scala.Product2;
+import scala.collection.Iterator;
+import scala.reflect.ClassTag$;
+
 import com.esotericsoftware.kryo.io.Output;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Sets;
@@ -29,27 +33,23 @@ import org.apache.spark.serializer.SerializationStream;
 import org.apache.spark.serializer.Serializer;
 import org.apache.spark.serializer.SerializerInstance;
 import org.roaringbitmap.longlong.Roaring64NavigableMap;
-import scala.Product2;
-import scala.collection.Iterator;
-import scala.reflect.ClassTag$;
 
 import org.apache.uniffle.client.util.ClientUtils;
 import org.apache.uniffle.common.ShufflePartitionedBlock;
 import org.apache.uniffle.common.compression.Codec;
 import org.apache.uniffle.common.config.RssConf;
 import org.apache.uniffle.common.util.ChecksumUtils;
-import org.apache.uniffle.storage.HdfsTestBase;
+import org.apache.uniffle.storage.HadoopTestBase;
 import org.apache.uniffle.storage.handler.api.ShuffleWriteHandler;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 
-
-public abstract class AbstractRssReaderTest extends HdfsTestBase {
+public abstract class AbstractRssReaderTest extends HadoopTestBase {
 
   private AtomicInteger atomicInteger = new AtomicInteger(0);
 
-  protected void validateResult(Iterator iterator,
-      Map<String, String> expectedData, int recordNum) {
+  protected void validateResult(
+      Iterator iterator, Map<String, String> expectedData, int recordNum) {
     Set<String> actualKeys = Sets.newHashSet();
     while (iterator.hasNext()) {
       Product2 product2 = (Product2) iterator.next();
@@ -70,9 +70,18 @@ public abstract class AbstractRssReaderTest extends HdfsTestBase {
       Roaring64NavigableMap blockIdBitmap,
       String keyPrefix,
       Serializer serializer,
-      int partitionID) throws Exception {
-    writeTestData(handler, blockNum, recordNum, expectedData, blockIdBitmap, keyPrefix, serializer,
-        partitionID, true);
+      int partitionID)
+      throws Exception {
+    writeTestData(
+        handler,
+        blockNum,
+        recordNum,
+        expectedData,
+        blockIdBitmap,
+        keyPrefix,
+        serializer,
+        partitionID,
+        true);
   }
 
   protected void writeTestData(
@@ -84,7 +93,8 @@ public abstract class AbstractRssReaderTest extends HdfsTestBase {
       String keyPrefix,
       Serializer serializer,
       int partitionID,
-      boolean compress) throws Exception {
+      boolean compress)
+      throws Exception {
     List<ShufflePartitionedBlock> blocks = Lists.newArrayList();
     SerializerInstance serializerInstance = serializer.newInstance();
     for (int i = 0; i < blockNum; i++) {
@@ -108,14 +118,15 @@ public abstract class AbstractRssReaderTest extends HdfsTestBase {
     return createShuffleBlock(data, blockId, true);
   }
 
-  protected ShufflePartitionedBlock createShuffleBlock(byte[] data, long blockId, boolean compress) {
+  protected ShufflePartitionedBlock createShuffleBlock(
+      byte[] data, long blockId, boolean compress) {
     byte[] compressData = data;
     if (compress) {
       compressData = Codec.newInstance(new RssConf()).compress(data);
     }
     long crc = ChecksumUtils.getCrc32(compressData);
-    return new ShufflePartitionedBlock(compressData.length, data.length, crc, blockId, 0,
-        compressData);
+    return new ShufflePartitionedBlock(
+        compressData.length, data.length, crc, blockId, 0, compressData);
   }
 
   protected void writeData(SerializationStream serializeStream, String key, String value) {
