@@ -17,16 +17,24 @@
 
 package org.apache.spark.shuffle.writer;
 
+import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.Future;
 import java.util.concurrent.TimeUnit;
 import java.util.function.Function;
 
+import scala.Function1;
+import scala.Option;
+import scala.Product2;
+import scala.collection.Iterator;
+
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
@@ -35,6 +43,7 @@ import com.google.common.util.concurrent.Uninterruptibles;
 import org.apache.spark.Partitioner;
 import org.apache.spark.ShuffleDependency;
 import org.apache.spark.SparkConf;
+import org.apache.spark.TaskContext;
 import org.apache.spark.executor.ShuffleWriteMetrics;
 import org.apache.spark.scheduler.MapStatus;
 import org.apache.spark.scheduler.MapStatus$;
@@ -45,10 +54,6 @@ import org.apache.spark.shuffle.ShuffleWriter;
 import org.apache.spark.storage.BlockManagerId;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import scala.Function1;
-import scala.Option;
-import scala.Product2;
-import scala.collection.Iterator;
 
 import org.apache.uniffle.client.api.ShuffleWriteClient;
 import org.apache.uniffle.common.ShuffleBlockInfo;
@@ -81,9 +86,9 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
   private RssShuffleManager shuffleManager;
   private long sendCheckTimeout;
   private long sendCheckInterval;
-  private long sendSizeLimit;
   private boolean isMemoryShuffleEnabled;
   private final Function<String, Boolean> taskFailureCallback;
+  private final Set<Long> blockIds = Sets.newConcurrentHashSet();
 
   public RssShuffleWriter(
       String appId,
@@ -95,36 +100,33 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
       RssShuffleManager shuffleManager,
       SparkConf sparkConf,
       ShuffleWriteClient shuffleWriteClient,
-      RssShuffleHandle rssHandle) {
+      RssShuffleHandle<K, V, C> rssHandle) {
     this(
         appId,
         shuffleId,
         taskId,
         taskAttemptId,
-        bufferManager,
         shuffleWriteMetrics,
         shuffleManager,
         sparkConf,
         shuffleWriteClient,
         rssHandle,
-        (tid) -> true
-    );
+        (tid) -> true);
+    this.bufferManager = bufferManager;
   }
 
-  public RssShuffleWriter(
+  private RssShuffleWriter(
       String appId,
       int shuffleId,
       String taskId,
       long taskAttemptId,
-      WriteBufferManager bufferManager,
       ShuffleWriteMetrics shuffleWriteMetrics,
       RssShuffleManager shuffleManager,
       SparkConf sparkConf,
       ShuffleWriteClient shuffleWriteClient,
-      RssShuffleHandle rssHandle,
+      RssShuffleHandle<K, V, C> rssHandle,
       Function<String, Boolean> taskFailureCallback) {
     this.appId = appId;
-    this.bufferManager = bufferManager;
     this.shuffleId = shuffleId;
     this.taskId = taskId;
     this.taskAttemptId = taskAttemptId;
@@ -136,29 +138,65 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
     this.shouldPartition = partitioner.numPartitions() > 1;
     this.sendCheckTimeout = sparkConf.get(RssSparkConfig.RSS_CLIENT_SEND_CHECK_TIMEOUT_MS);
     this.sendCheckInterval = sparkConf.get(RssSparkConfig.RSS_CLIENT_SEND_CHECK_INTERVAL_MS);
-    this.sendSizeLimit = sparkConf.getSizeAsBytes(RssSparkConfig.RSS_CLIENT_SEND_SIZE_LIMIT.key(),
-        RssSparkConfig.RSS_CLIENT_SEND_SIZE_LIMIT.defaultValue().get());
     this.bitmapSplitNum = sparkConf.get(RssSparkConfig.RSS_CLIENT_BITMAP_SPLIT_NUM);
     this.partitionToBlockIds = Maps.newHashMap();
     this.shuffleWriteClient = shuffleWriteClient;
     this.shuffleServersForData = rssHandle.getShuffleServersForData();
     this.partitionToServers = rssHandle.getPartitionToServers();
-    this.isMemoryShuffleEnabled = isMemoryShuffleEnabled(
-        sparkConf.get(RssSparkConfig.RSS_STORAGE_TYPE.key()));
+    this.isMemoryShuffleEnabled =
+        isMemoryShuffleEnabled(sparkConf.get(RssSparkConfig.RSS_STORAGE_TYPE.key()));
     this.taskFailureCallback = taskFailureCallback;
   }
 
+  public RssShuffleWriter(
+      String appId,
+      int shuffleId,
+      String taskId,
+      long taskAttemptId,
+      ShuffleWriteMetrics shuffleWriteMetrics,
+      RssShuffleManager shuffleManager,
+      SparkConf sparkConf,
+      ShuffleWriteClient shuffleWriteClient,
+      RssShuffleHandle<K, V, C> rssHandle,
+      Function<String, Boolean> taskFailureCallback,
+      TaskContext context) {
+    this(
+        appId,
+        shuffleId,
+        taskId,
+        taskAttemptId,
+        shuffleWriteMetrics,
+        shuffleManager,
+        sparkConf,
+        shuffleWriteClient,
+        rssHandle,
+        taskFailureCallback);
+    BufferManagerOptions bufferOptions = new BufferManagerOptions(sparkConf);
+    final WriteBufferManager bufferManager =
+        new WriteBufferManager(
+            shuffleId,
+            taskId,
+            taskAttemptId,
+            bufferOptions,
+            rssHandle.getDependency().serializer(),
+            rssHandle.getPartitionToServers(),
+            context.taskMemoryManager(),
+            shuffleWriteMetrics,
+            RssSparkConfig.toRssConf(sparkConf),
+            this::processShuffleBlockInfos);
+    this.bufferManager = bufferManager;
+  }
+
   private boolean isMemoryShuffleEnabled(String storageType) {
     return StorageType.withMemory(StorageType.valueOf(storageType));
   }
 
-  /**
-   * Create dummy BlockManagerId and embed partition->blockIds
-   */
+  /** Create dummy BlockManagerId and embed partition->blockIds */
   private BlockManagerId createDummyBlockManagerId(String executorId, long taskAttemptId) {
     // dummy values are used there for host and port check in BlockManagerId
     // hack: use topologyInfo field in BlockManagerId to store [partition, blockIds]
-    return BlockManagerId.apply(executorId, DUMMY_HOST, DUMMY_PORT, Option.apply(Long.toString(taskAttemptId)));
+    return BlockManagerId.apply(
+        executorId, DUMMY_HOST, DUMMY_PORT, Option.apply(Long.toString(taskAttemptId)));
   }
 
   @Override
@@ -171,25 +209,24 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
     }
   }
 
-  private void writeImpl(Iterator<Product2<K,V>> records) {
+  private void writeImpl(Iterator<Product2<K, V>> records) {
     List<ShuffleBlockInfo> shuffleBlockInfos;
-    Set<Long> blockIds = Sets.newHashSet();
     while (records.hasNext()) {
       Product2<K, V> record = records.next();
       int partition = getPartition(record._1());
       if (shuffleDependency.mapSideCombine()) {
-        Function1 createCombiner = shuffleDependency.aggregator().get().createCombiner();
+        Function1<V, C> createCombiner = shuffleDependency.aggregator().get().createCombiner();
         Object c = createCombiner.apply(record._2());
         shuffleBlockInfos = bufferManager.addRecord(partition, record._1(), c);
       } else {
         shuffleBlockInfos = bufferManager.addRecord(partition, record._1(), record._2());
       }
-      processShuffleBlockInfos(shuffleBlockInfos, blockIds);
+      processShuffleBlockInfos(shuffleBlockInfos);
     }
 
     final long start = System.currentTimeMillis();
     shuffleBlockInfos = bufferManager.clear();
-    processShuffleBlockInfos(shuffleBlockInfos, blockIds);
+    processShuffleBlockInfos(shuffleBlockInfos);
     long s = System.currentTimeMillis();
     checkBlockSendResult(blockIds);
     final long checkDuration = System.currentTimeMillis() - s;
@@ -201,72 +238,78 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
     }
     long writeDurationMs = bufferManager.getWriteTime() + (System.currentTimeMillis() - start);
     shuffleWriteMetrics.incWriteTime(TimeUnit.MILLISECONDS.toNanos(writeDurationMs));
-    LOG.info("Finish write shuffle for appId[" + appId + "], shuffleId[" + shuffleId
-        + "], taskId[" + taskId + "] with write " + writeDurationMs + " ms, include checkSendResult["
-        + checkDuration + "], commit[" + commitDuration + "], " + bufferManager.getManagerCostInfo());
+    LOG.info(
+        "Finish write shuffle for appId["
+            + appId
+            + "], shuffleId["
+            + shuffleId
+            + "], taskId["
+            + taskId
+            + "] with write "
+            + writeDurationMs
+            + " ms, include checkSendResult["
+            + checkDuration
+            + "], commit["
+            + commitDuration
+            + "], "
+            + bufferManager.getManagerCostInfo());
   }
 
   /**
-   * ShuffleBlock will be added to queue and send to shuffle server
-   * maintenance the following information:
-   * 1. add blockId to set, check if it is send later
-   * 2. update shuffle server info, they will be used in commit phase
-   * 3. update [partition, blockIds], it will be set to MapStatus,
+   * ShuffleBlock will be added to queue and send to shuffle server maintenance the following
+   * information: 1. add blockId to set, check if it is send later 2. update shuffle server info,
+   * they will be used in commit phase 3. update [partition, blockIds], it will be set to MapStatus,
    * and shuffle reader will do the integration check with them
    *
    * @param shuffleBlockInfoList
-   * @param blockIds
    */
-  private void processShuffleBlockInfos(List<ShuffleBlockInfo> shuffleBlockInfoList, Set<Long> blockIds) {
+  private List<CompletableFuture<Long>> processShuffleBlockInfos(
+      List<ShuffleBlockInfo> shuffleBlockInfoList) {
     if (shuffleBlockInfoList != null && !shuffleBlockInfoList.isEmpty()) {
-      shuffleBlockInfoList.stream().forEach(sbi -> {
-        long blockId = sbi.getBlockId();
-        // add blockId to set, check if it is send later
-        blockIds.add(blockId);
-        // update [partition, blockIds], it will be sent to shuffle server
-        int partitionId = sbi.getPartitionId();
-        partitionToBlockIds.computeIfAbsent(partitionId, k -> Sets.newHashSet()).add(blockId);
-      });
-      postBlockEvent(shuffleBlockInfoList);
+      shuffleBlockInfoList.stream()
+          .forEach(
+              sbi -> {
+                long blockId = sbi.getBlockId();
+                // add blockId to set, check if it is send later
+                blockIds.add(blockId);
+                // update [partition, blockIds], it will be sent to shuffle server
+                int partitionId = sbi.getPartitionId();
+                partitionToBlockIds
+                    .computeIfAbsent(partitionId, k -> Sets.newHashSet())
+                    .add(blockId);
+              });
+      return postBlockEvent(shuffleBlockInfoList);
     }
+    return Collections.emptyList();
   }
 
-  // don't send huge block to shuffle server, or there will be OOM if shuffle sever receives data more than expected
-  protected void postBlockEvent(List<ShuffleBlockInfo> shuffleBlockInfoList) {
-    long totalSize = 0;
-    List<ShuffleBlockInfo> shuffleBlockInfosPerEvent = Lists.newArrayList();
-    for (ShuffleBlockInfo sbi : shuffleBlockInfoList) {
-      totalSize += sbi.getSize();
-      shuffleBlockInfosPerEvent.add(sbi);
-      // split shuffle data according to the size
-      if (totalSize > sendSizeLimit) {
-        LOG.info("Post event to queue with " + shuffleBlockInfosPerEvent.size()
-            + " blocks and " + totalSize + " bytes");
-        shuffleManager.getEventLoop().post(
-            new AddBlockEvent(taskId, shuffleBlockInfosPerEvent));
-        shuffleBlockInfosPerEvent = Lists.newArrayList();
-        totalSize = 0;
-      }
-    }
-    if (!shuffleBlockInfosPerEvent.isEmpty()) {
-      LOG.info("Post event to queue with " + shuffleBlockInfosPerEvent.size()
-          + " blocks and " + totalSize + " bytes");
-      shuffleManager.getEventLoop().post(
-          new AddBlockEvent(taskId, shuffleBlockInfosPerEvent));
+  // don't send huge block to shuffle server, or there will be OOM if shuffle sever receives data
+  // more than expected
+  protected List<CompletableFuture<Long>> postBlockEvent(
+      List<ShuffleBlockInfo> shuffleBlockInfoList) {
+    List<CompletableFuture<Long>> futures = new ArrayList<>();
+    for (AddBlockEvent event : bufferManager.buildBlockEvents(shuffleBlockInfoList)) {
+      futures.add(shuffleManager.sendData(event));
     }
+    return futures;
   }
 
   @VisibleForTesting
   protected void sendCommit() {
     ExecutorService executor = Executors.newSingleThreadExecutor();
-    Future<Boolean> future = executor.submit(
-        () -> shuffleWriteClient.sendCommit(shuffleServersForData, appId, shuffleId, numMaps));
+    Future<Boolean> future =
+        executor.submit(
+            () -> shuffleWriteClient.sendCommit(shuffleServersForData, appId, shuffleId, numMaps));
     long start = System.currentTimeMillis();
     int currentWait = 200;
     int maxWait = 5000;
     while (!future.isDone()) {
-      LOG.info("Wait commit to shuffle server for task[" + taskAttemptId + "] cost "
-          + (System.currentTimeMillis() - start) + " ms");
+      LOG.info(
+          "Wait commit to shuffle server for task["
+              + taskAttemptId
+              + "] cost "
+              + (System.currentTimeMillis() - start)
+              + " ms");
       Uninterruptibles.sleepUninterruptibly(currentWait, TimeUnit.MILLISECONDS);
       currentWait = Math.min(currentWait * 2, maxWait);
     }
@@ -278,7 +321,7 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
     } catch (InterruptedException ie) {
       LOG.warn("Ignore the InterruptedException which should be caused by internal killed");
     } catch (Exception e) {
-      throw new RuntimeException("Exception happened when get commit status", e);
+      throw new RssException("Exception happened when get commit status", e);
     } finally {
       executor.shutdown();
     }
@@ -293,7 +336,10 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
       // if failed when send data to shuffle server, mark task as failed
       if (failedBlockIds.size() > 0) {
         String errorMsg =
-            "Send failed: Task[" + taskId + "] failed because " + failedBlockIds.size()
+            "Send failed: Task["
+                + taskId
+                + "] failed because "
+                + failedBlockIds.size()
                 + " blocks can't be sent to shuffle server.";
         LOG.error(errorMsg);
         throw new RssException(errorMsg);
@@ -308,8 +354,13 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
       Uninterruptibles.sleepUninterruptibly(sendCheckInterval, TimeUnit.MILLISECONDS);
       if (System.currentTimeMillis() - start > sendCheckTimeout) {
         String errorMsg =
-            "Timeout: Task[" + taskId + "] failed because " + blockIds.size()
-                + " blocks can't be sent to shuffle server in " + sendCheckTimeout + " ms.";
+            "Timeout: Task["
+                + taskId
+                + "] failed because "
+                + blockIds.size()
+                + " blocks can't be sent to shuffle server in "
+                + sendCheckTimeout
+                + " ms.";
         LOG.error(errorMsg);
         throw new RssException(errorMsg);
       }
@@ -320,7 +371,8 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
   public Option<MapStatus> stop(boolean success) {
     try {
       if (success) {
-        // fill partitionLengths with non zero dummy value so map output tracker could work correctly
+        // fill partitionLengths with non zero dummy value so map output tracker could work
+        // correctly
         long[] partitionLengths = new long[partitioner.numPartitions()];
         Arrays.fill(partitionLengths, 1);
         final BlockManagerId blockManagerId =
@@ -331,10 +383,13 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
           ptb.put(entry.getKey(), Lists.newArrayList(entry.getValue()));
         }
         long start = System.currentTimeMillis();
-        shuffleWriteClient.reportShuffleResult(partitionToServers, appId, shuffleId,
-            taskAttemptId, ptb, bitmapSplitNum);
-        LOG.info("Report shuffle result for task[{}] with bitmapNum[{}] cost {} ms",
-            taskAttemptId, bitmapSplitNum, (System.currentTimeMillis() - start));
+        shuffleWriteClient.reportShuffleResult(
+            partitionToServers, appId, shuffleId, taskAttemptId, ptb, bitmapSplitNum);
+        LOG.info(
+            "Report shuffle result for task[{}] with bitmapNum[{}] cost {} ms",
+            taskAttemptId,
+            bitmapSplitNum,
+            (System.currentTimeMillis() - start));
         MapStatus mapStatus = MapStatus$.MODULE$.apply(blockManagerId, partitionLengths);
         return Option.apply(mapStatus);
       } else {
@@ -352,7 +407,7 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
   }
 
   @VisibleForTesting
-  protected <K> int getPartition(K key) {
+  protected <T> int getPartition(T key) {
     int result = 0;
     if (shouldPartition) {
       result = partitioner.getPartition(key);
