@@ -21,8 +21,14 @@ import java.util.Arrays;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.CompletableFuture;
+import java.util.function.Function;
 import java.util.stream.Collectors;
 
+import scala.Product2;
+import scala.Tuple2;
+import scala.collection.mutable.MutableList;
+
 import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
 import com.google.common.collect.Sets;
@@ -38,11 +44,7 @@ import org.apache.spark.serializer.Serializer;
 import org.apache.spark.shuffle.RssShuffleHandle;
 import org.apache.spark.shuffle.RssShuffleManager;
 import org.apache.spark.shuffle.RssSparkConfig;
-import org.apache.spark.util.EventLoop;
 import org.junit.jupiter.api.Test;
-import scala.Product2;
-import scala.Tuple2;
-import scala.collection.mutable.MutableList;
 
 import org.apache.uniffle.client.api.ShuffleWriteClient;
 import org.apache.uniffle.common.ShuffleBlockInfo;
@@ -51,7 +53,6 @@ import org.apache.uniffle.common.config.RssConf;
 import org.apache.uniffle.storage.util.StorageType;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.ArgumentMatchers.anyLong;
@@ -84,8 +85,8 @@ public class RssShuffleWriterTest {
     Serializer kryoSerializer = new KryoSerializer(conf);
     ShuffleWriteClient mockShuffleWriteClient = mock(ShuffleWriteClient.class);
     Partitioner mockPartitioner = mock(Partitioner.class);
-    ShuffleDependency mockDependency = mock(ShuffleDependency.class);
-    RssShuffleHandle mockHandle = mock(RssShuffleHandle.class);
+    ShuffleDependency<String, String, String> mockDependency = mock(ShuffleDependency.class);
+    RssShuffleHandle<String, String, String> mockHandle = mock(RssShuffleHandle.class);
     when(mockHandle.getDependency()).thenReturn(mockDependency);
     when(mockDependency.partitioner()).thenReturn(mockPartitioner);
     when(mockPartitioner.numPartitions()).thenReturn(2);
@@ -93,15 +94,31 @@ public class RssShuffleWriterTest {
     TaskMemoryManager mockTaskMemoryManager = mock(TaskMemoryManager.class);
 
     BufferManagerOptions bufferOptions = new BufferManagerOptions(conf);
-    WriteBufferManager bufferManager = new WriteBufferManager(
-        0, 0, bufferOptions, kryoSerializer,
-        Maps.newHashMap(), mockTaskMemoryManager, new ShuffleWriteMetrics(), new RssConf());
+    WriteBufferManager bufferManager =
+        new WriteBufferManager(
+            0,
+            0,
+            bufferOptions,
+            kryoSerializer,
+            Maps.newHashMap(),
+            mockTaskMemoryManager,
+            new ShuffleWriteMetrics(),
+            new RssConf());
     WriteBufferManager bufferManagerSpy = spy(bufferManager);
     doReturn(1000000L).when(bufferManagerSpy).acquireMemory(anyLong());
 
-    RssShuffleWriter rssShuffleWriter = new RssShuffleWriter("appId", 0, taskId, 1L,
-        bufferManagerSpy, (new TaskMetrics()).shuffleWriteMetrics(),
-        manager, conf, mockShuffleWriteClient, mockHandle);
+    RssShuffleWriter<?, ?, ?> rssShuffleWriter =
+        new RssShuffleWriter<>(
+            "appId",
+            0,
+            taskId,
+            1L,
+            bufferManagerSpy,
+            (new TaskMetrics()).shuffleWriteMetrics(),
+            manager,
+            conf,
+            mockShuffleWriteClient,
+            mockHandle);
 
     // case 1: all blocks are sent successfully
     manager.addSuccessBlockIds(taskId, Sets.newHashSet(1L, 2L, 3L));
@@ -111,8 +128,10 @@ public class RssShuffleWriterTest {
     // case 2: partial blocks aren't sent before spark.rss.writer.send.check.timeout,
     // Runtime exception will be thrown
     manager.addSuccessBlockIds(taskId, Sets.newHashSet(1L, 2L));
-    Throwable e2 = assertThrows(RuntimeException.class, () ->
-        rssShuffleWriter.checkBlockSendResult(Sets.newHashSet(1L, 2L, 3L)));
+    Throwable e2 =
+        assertThrows(
+            RuntimeException.class,
+            () -> rssShuffleWriter.checkBlockSendResult(Sets.newHashSet(1L, 2L, 3L)));
     assertTrue(e2.getMessage().startsWith("Timeout:"));
 
     manager.clearTaskMeta(taskId);
@@ -120,21 +139,54 @@ public class RssShuffleWriterTest {
     // case 3: partial blocks are sent failed, Runtime exception will be thrown
     manager.addSuccessBlockIds(taskId, Sets.newHashSet(1L, 2L));
     manager.addFailedBlockIds(taskId, Sets.newHashSet(3L));
-    Throwable e3 = assertThrows(RuntimeException.class, () ->
-        rssShuffleWriter.checkBlockSendResult(Sets.newHashSet(1L, 2L, 3L)));
+    Throwable e3 =
+        assertThrows(
+            RuntimeException.class,
+            () -> rssShuffleWriter.checkBlockSendResult(Sets.newHashSet(1L, 2L, 3L)));
     assertTrue(e3.getMessage().startsWith("Send failed:"));
     manager.clearTaskMeta(taskId);
     assertTrue(manager.getSuccessBlockIds(taskId).isEmpty());
     assertTrue(manager.getFailedBlockIds(taskId).isEmpty());
-    assertNull(manager.getTaskToBufferManager().get(taskId));
 
     sc.stop();
   }
 
+  static class FakedDataPusher extends DataPusher {
+    private final Function<AddBlockEvent, CompletableFuture<Long>> sendFunc;
+
+    FakedDataPusher(Function<AddBlockEvent, CompletableFuture<Long>> sendFunc) {
+      this(null, null, null, null, 1, 1, sendFunc);
+    }
+
+    private FakedDataPusher(
+        ShuffleWriteClient shuffleWriteClient,
+        Map<String, Set<Long>> taskToSuccessBlockIds,
+        Map<String, Set<Long>> taskToFailedBlockIds,
+        Set<String> failedTaskIds,
+        int threadPoolSize,
+        int threadKeepAliveTime,
+        Function<AddBlockEvent, CompletableFuture<Long>> sendFunc) {
+      super(
+          shuffleWriteClient,
+          taskToSuccessBlockIds,
+          taskToFailedBlockIds,
+          failedTaskIds,
+          threadPoolSize,
+          threadKeepAliveTime);
+      this.sendFunc = sendFunc;
+    }
+
+    @Override
+    public CompletableFuture<Long> send(AddBlockEvent event) {
+      return sendFunc.apply(event);
+    }
+  }
+
   @Test
   public void writeTest() throws Exception {
     SparkConf conf = new SparkConf();
-    conf.setAppName("testApp").setMaster("local[2]")
+    conf.setAppName("testApp")
+        .setMaster("local[2]")
         .set(RssSparkConfig.RSS_TEST_FLAG.key(), "true")
         .set(RssSparkConfig.RSS_TEST_MODE_ENABLE.key(), "true")
         .set(RssSparkConfig.RSS_WRITER_BUFFER_SIZE.key(), "32")
@@ -149,26 +201,26 @@ public class RssShuffleWriterTest {
     RssShuffleManager manager = new RssShuffleManager(conf, false);
     List<ShuffleBlockInfo> shuffleBlockInfos = Lists.newArrayList();
 
-    manager.setEventLoop(new EventLoop<AddBlockEvent>("test") {
-      @Override
-      public void onReceive(AddBlockEvent event) {
-        assertEquals("taskId", event.getTaskId());
-        shuffleBlockInfos.addAll(event.getShuffleDataInfoList());
-        Set<Long> blockIds = event.getShuffleDataInfoList().parallelStream()
-            .map(sdi -> sdi.getBlockId()).collect(Collectors.toSet());
-        manager.addSuccessBlockIds(event.getTaskId(), blockIds);
-      }
-
-      @Override
-      public void onError(Throwable e) {
-      }
-    });
-    manager.getEventLoop().start();
+    DataPusher dataPusher =
+        new FakedDataPusher(
+            event -> {
+              assertEquals("taskId", event.getTaskId());
+              shuffleBlockInfos.addAll(event.getShuffleDataInfoList());
+              Set<Long> blockIds =
+                  event
+                      .getShuffleDataInfoList()
+                      .parallelStream()
+                      .map(sdi -> sdi.getBlockId())
+                      .collect(Collectors.toSet());
+              manager.addSuccessBlockIds(event.getTaskId(), blockIds);
+              return CompletableFuture.completedFuture(0L);
+            });
+    manager.setDataPusher(dataPusher);
 
     Partitioner mockPartitioner = mock(Partitioner.class);
-    ShuffleDependency mockDependency = mock(ShuffleDependency.class);
+    ShuffleDependency<String, String, String> mockDependency = mock(ShuffleDependency.class);
     final ShuffleWriteClient mockShuffleWriteClient = mock(ShuffleWriteClient.class);
-    RssShuffleHandle mockHandle = mock(RssShuffleHandle.class);
+    RssShuffleHandle<String, String, String> mockHandle = mock(RssShuffleHandle.class);
     when(mockHandle.getDependency()).thenReturn(mockDependency);
     Serializer kryoSerializer = new KryoSerializer(conf);
     when(mockDependency.serializer()).thenReturn(kryoSerializer);
@@ -176,14 +228,20 @@ public class RssShuffleWriterTest {
     when(mockPartitioner.numPartitions()).thenReturn(2);
 
     Map<Integer, List<ShuffleServerInfo>> partitionToServers = Maps.newHashMap();
-    List<ShuffleServerInfo> ssi12 = Arrays.asList(new ShuffleServerInfo("id1", "0.0.0.1", 100),
-        new ShuffleServerInfo("id2", "0.0.0.2", 100));
+    List<ShuffleServerInfo> ssi12 =
+        Arrays.asList(
+            new ShuffleServerInfo("id1", "0.0.0.1", 100),
+            new ShuffleServerInfo("id2", "0.0.0.2", 100));
     partitionToServers.put(0, ssi12);
-    List<ShuffleServerInfo> ssi34 = Arrays.asList(new ShuffleServerInfo("id3", "0.0.0.3", 100),
-        new ShuffleServerInfo("id4", "0.0.0.4", 100));
+    List<ShuffleServerInfo> ssi34 =
+        Arrays.asList(
+            new ShuffleServerInfo("id3", "0.0.0.3", 100),
+            new ShuffleServerInfo("id4", "0.0.0.4", 100));
     partitionToServers.put(1, ssi34);
-    List<ShuffleServerInfo> ssi56 = Arrays.asList(new ShuffleServerInfo("id5", "0.0.0.5", 100),
-        new ShuffleServerInfo("id6", "0.0.0.6", 100));
+    List<ShuffleServerInfo> ssi56 =
+        Arrays.asList(
+            new ShuffleServerInfo("id5", "0.0.0.5", 100),
+            new ShuffleServerInfo("id6", "0.0.0.6", 100));
     partitionToServers.put(2, ssi56);
     when(mockPartitioner.getPartition("testKey1")).thenReturn(0);
     when(mockPartitioner.getPartition("testKey2")).thenReturn(1);
@@ -199,34 +257,52 @@ public class RssShuffleWriterTest {
 
     ShuffleWriteMetrics shuffleWriteMetrics = new ShuffleWriteMetrics();
     BufferManagerOptions bufferOptions = new BufferManagerOptions(conf);
-    WriteBufferManager bufferManager = new WriteBufferManager(
-        0, 0, bufferOptions, kryoSerializer,
-        partitionToServers, mockTaskMemoryManager, shuffleWriteMetrics, new RssConf());
+    WriteBufferManager bufferManager =
+        new WriteBufferManager(
+            0,
+            "taskId",
+            0,
+            bufferOptions,
+            kryoSerializer,
+            partitionToServers,
+            mockTaskMemoryManager,
+            shuffleWriteMetrics,
+            new RssConf(),
+            null);
     WriteBufferManager bufferManagerSpy = spy(bufferManager);
     doReturn(1000000L).when(bufferManagerSpy).acquireMemory(anyLong());
 
-    RssShuffleWriter rssShuffleWriter = new RssShuffleWriter("appId", 0, "taskId", 1L,
-        bufferManagerSpy, shuffleWriteMetrics, manager, conf, mockShuffleWriteClient, mockHandle);
+    RssShuffleWriter<String, String, String> rssShuffleWriter =
+        new RssShuffleWriter<>(
+            "appId",
+            0,
+            "taskId",
+            1L,
+            bufferManagerSpy,
+            shuffleWriteMetrics,
+            manager,
+            conf,
+            mockShuffleWriteClient,
+            mockHandle);
 
     RssShuffleWriter<String, String, String> rssShuffleWriterSpy = spy(rssShuffleWriter);
     doNothing().when(rssShuffleWriterSpy).sendCommit();
 
     // case 1
-    MutableList<Product2<String, String>> data = new MutableList();
-    data.appendElem(new Tuple2("testKey1", "testValue1"));
-    data.appendElem(new Tuple2("testKey2", "testValue2"));
-    data.appendElem(new Tuple2("testKey3", "testValue3"));
-    data.appendElem(new Tuple2("testKey4", "testValue4"));
-    data.appendElem(new Tuple2("testKey5", "testValue5"));
-    data.appendElem(new Tuple2("testKey6", "testValue6"));
+    MutableList<Product2<String, String>> data = new MutableList<>();
+    data.appendElem(new Tuple2<>("testKey1", "testValue1"));
+    data.appendElem(new Tuple2<>("testKey2", "testValue2"));
+    data.appendElem(new Tuple2<>("testKey3", "testValue3"));
+    data.appendElem(new Tuple2<>("testKey4", "testValue4"));
+    data.appendElem(new Tuple2<>("testKey5", "testValue5"));
+    data.appendElem(new Tuple2<>("testKey6", "testValue6"));
     rssShuffleWriterSpy.write(data.iterator());
 
     assertTrue(rssShuffleWriterSpy.getShuffleWriteMetrics().shuffleWriteTime() > 0);
     assertEquals(6, rssShuffleWriterSpy.getShuffleWriteMetrics().shuffleRecordsWritten());
     assertEquals(
         shuffleBlockInfos.stream().mapToInt(ShuffleBlockInfo::getLength).sum(),
-        rssShuffleWriterSpy.getShuffleWriteMetrics().shuffleBytesWritten()
-    );
+        rssShuffleWriterSpy.getShuffleWriteMetrics().shuffleBytesWritten());
 
     assertEquals(6, shuffleBlockInfos.size());
     for (ShuffleBlockInfo shuffleBlockInfo : shuffleBlockInfos) {
@@ -253,37 +329,69 @@ public class RssShuffleWriterTest {
 
   @Test
   public void postBlockEventTest() throws Exception {
-    final WriteBufferManager mockBufferManager = mock(WriteBufferManager.class);
     final ShuffleWriteMetrics mockMetrics = mock(ShuffleWriteMetrics.class);
-    ShuffleDependency mockDependency = mock(ShuffleDependency.class);
+    ShuffleDependency<String, String, String> mockDependency = mock(ShuffleDependency.class);
     Partitioner mockPartitioner = mock(Partitioner.class);
-    final RssShuffleManager mockShuffleManager = mock(RssShuffleManager.class);
     when(mockDependency.partitioner()).thenReturn(mockPartitioner);
     when(mockPartitioner.numPartitions()).thenReturn(2);
     List<AddBlockEvent> events = Lists.newArrayList();
 
-    EventLoop<AddBlockEvent> eventLoop = new EventLoop<AddBlockEvent>("test") {
-      @Override
-      public void onReceive(AddBlockEvent event) {
-        events.add(event);
-      }
-
-      @Override
-      public void onError(Throwable e) {
-      }
-    };
-    eventLoop.start();
-
-    when(mockShuffleManager.getEventLoop()).thenReturn(eventLoop);
-    RssShuffleHandle mockHandle = mock(RssShuffleHandle.class);
-    when(mockHandle.getDependency()).thenReturn(mockDependency);
-    ShuffleWriteClient mockWriteClient = mock(ShuffleWriteClient.class);
     SparkConf conf = new SparkConf();
-    conf.set(RssSparkConfig.RSS_CLIENT_SEND_SIZE_LIMIT.key(), "64")
+    conf.setAppName("postBlockEventTest")
+        .setMaster("local[2]")
+        .set(RssSparkConfig.RSS_TEST_FLAG.key(), "true")
+        .set(RssSparkConfig.RSS_TEST_MODE_ENABLE.key(), "true")
+        .set(RssSparkConfig.RSS_WRITER_BUFFER_SIZE.key(), "32")
+        .set(RssSparkConfig.RSS_WRITER_SERIALIZER_BUFFER_SIZE.key(), "32")
+        .set(RssSparkConfig.RSS_WRITER_BUFFER_SEGMENT_SIZE.key(), "64")
+        .set(RssSparkConfig.RSS_WRITER_BUFFER_SPILL_SIZE.key(), "128")
+        .set(RssSparkConfig.RSS_CLIENT_SEND_CHECK_INTERVAL_MS.key(), "1000")
+        .set(RssSparkConfig.RSS_STORAGE_TYPE.key(), StorageType.LOCALFILE.name())
+        .set(RssSparkConfig.RSS_COORDINATOR_QUORUM.key(), "127.0.0.1:12345,127.0.0.1:12346")
+        .set(
+            RssSparkConfig.SPARK_RSS_CONFIG_PREFIX
+                + RssSparkConfig.RSS_CLIENT_SEND_SIZE_LIMITATION.key(),
+            "64")
         .set(RssSparkConfig.RSS_STORAGE_TYPE.key(), StorageType.LOCALFILE.name());
 
-    RssShuffleWriter writer = new RssShuffleWriter("appId", 0, "taskId", 1L,
-        mockBufferManager, mockMetrics, mockShuffleManager, conf, mockWriteClient, mockHandle);
+    TaskMemoryManager mockTaskMemoryManager = mock(TaskMemoryManager.class);
+    BufferManagerOptions bufferOptions = new BufferManagerOptions(conf);
+    WriteBufferManager bufferManager =
+        new WriteBufferManager(
+            0,
+            0,
+            bufferOptions,
+            new KryoSerializer(conf),
+            Maps.newHashMap(),
+            mockTaskMemoryManager,
+            new ShuffleWriteMetrics(),
+            RssSparkConfig.toRssConf(conf));
+
+    RssShuffleManager manager = new RssShuffleManager(conf, false);
+    DataPusher dataPusher =
+        new FakedDataPusher(
+            event -> {
+              events.add(event);
+              return CompletableFuture.completedFuture(0L);
+            });
+    manager.setDataPusher(dataPusher);
+
+    RssShuffleHandle<String, String, String> mockHandle = mock(RssShuffleHandle.class);
+    when(mockHandle.getDependency()).thenReturn(mockDependency);
+    ShuffleWriteClient mockWriteClient = mock(ShuffleWriteClient.class);
+
+    RssShuffleWriter<String, String, String> writer =
+        new RssShuffleWriter<>(
+            "appId",
+            0,
+            "taskId",
+            1L,
+            bufferManager,
+            mockMetrics,
+            manager,
+            conf,
+            mockWriteClient,
+            mockHandle);
     List<ShuffleBlockInfo> shuffleBlockInfoList = createShuffleBlockList(1, 31);
     writer.postBlockEvent(shuffleBlockInfoList);
     Thread.sleep(500);
@@ -355,9 +463,18 @@ public class RssShuffleWriterTest {
         Lists.newArrayList(new ShuffleServerInfo("id", "host", 0));
     List<ShuffleBlockInfo> shuffleBlockInfoList = Lists.newArrayList();
     for (int i = 0; i < blockNum; i++) {
-      shuffleBlockInfoList.add(new ShuffleBlockInfo(
-          0, 0, 10, blockLength, 10, new byte[]{1},
-          shuffleServerInfoList, blockLength, 10, 0));
+      shuffleBlockInfoList.add(
+          new ShuffleBlockInfo(
+              0,
+              0,
+              10,
+              blockLength,
+              10,
+              new byte[] {1},
+              shuffleServerInfoList,
+              blockLength,
+              10,
+              0));
     }
     return shuffleBlockInfoList;
   }
