@@ -18,16 +18,26 @@
 package org.apache.spark.shuffle.writer;
 
 import java.io.IOException;
+import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.BlockingQueue;
+import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.Future;
+import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.TimeUnit;
 import java.util.function.Function;
 
+import scala.Function1;
+import scala.Option;
+import scala.Product2;
+import scala.collection.Iterator;
+
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
@@ -36,6 +46,7 @@ import com.google.common.util.concurrent.Uninterruptibles;
 import org.apache.spark.Partitioner;
 import org.apache.spark.ShuffleDependency;
 import org.apache.spark.SparkConf;
+import org.apache.spark.TaskContext;
 import org.apache.spark.executor.ShuffleWriteMetrics;
 import org.apache.spark.scheduler.MapStatus;
 import org.apache.spark.shuffle.RssShuffleHandle;
@@ -45,10 +56,6 @@ import org.apache.spark.shuffle.ShuffleWriter;
 import org.apache.spark.storage.BlockManagerId;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import scala.Function1;
-import scala.Option;
-import scala.Product2;
-import scala.collection.Iterator;
 
 import org.apache.uniffle.client.api.ShuffleWriteClient;
 import org.apache.uniffle.common.ShuffleBlockInfo;
@@ -64,27 +71,34 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
 
   private final String appId;
   private final int shuffleId;
-  private final WriteBufferManager bufferManager;
+  private WriteBufferManager bufferManager;
   private final String taskId;
-  private final long taskAttemptId;
   private final int numMaps;
   private final ShuffleDependency<K, V, C> shuffleDependency;
-  private final ShuffleWriteMetrics shuffleWriteMetrics;
   private final Partitioner partitioner;
   private final RssShuffleManager shuffleManager;
   private final boolean shouldPartition;
   private final long sendCheckTimeout;
   private final long sendCheckInterval;
-  private final long sendSizeLimit;
   private final int bitmapSplitNum;
   private final Map<Integer, Set<Long>> partitionToBlockIds;
   private final ShuffleWriteClient shuffleWriteClient;
   private final Map<Integer, List<ShuffleServerInfo>> partitionToServers;
-  private final Set shuffleServersForData;
+  private final Set<ShuffleServerInfo> shuffleServersForData;
   private final long[] partitionLengths;
-  private boolean isMemoryShuffleEnabled;
   private final Function<String, Boolean> taskFailureCallback;
+  private final Set<Long> blockIds = Sets.newConcurrentHashSet();
 
+  /** used by columnar rss shuffle writer implementation */
+  protected final long taskAttemptId;
+
+  protected final ShuffleWriteMetrics shuffleWriteMetrics;
+  protected final boolean isMemoryShuffleEnabled;
+
+  private final BlockingQueue<Object> finishEventQueue = new LinkedBlockingQueue<>();
+
+  // Only for tests
+  @VisibleForTesting
   public RssShuffleWriter(
       String appId,
       int shuffleId,
@@ -95,38 +109,35 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
       RssShuffleManager shuffleManager,
       SparkConf sparkConf,
       ShuffleWriteClient shuffleWriteClient,
-      RssShuffleHandle rssHandle) {
+      RssShuffleHandle<K, V, C> rssHandle) {
     this(
         appId,
         shuffleId,
         taskId,
         taskAttemptId,
-        bufferManager,
         shuffleWriteMetrics,
         shuffleManager,
         sparkConf,
         shuffleWriteClient,
         rssHandle,
-        (tid) -> true
-    );
+        (tid) -> true);
+    this.bufferManager = bufferManager;
   }
 
-  public RssShuffleWriter(
+  private RssShuffleWriter(
       String appId,
       int shuffleId,
       String taskId,
       long taskAttemptId,
-      WriteBufferManager bufferManager,
       ShuffleWriteMetrics shuffleWriteMetrics,
       RssShuffleManager shuffleManager,
       SparkConf sparkConf,
       ShuffleWriteClient shuffleWriteClient,
-      RssShuffleHandle rssHandle,
+      RssShuffleHandle<K, V, C> rssHandle,
       Function<String, Boolean> taskFailureCallback) {
     LOG.warn("RssShuffle start write taskAttemptId data" + taskAttemptId);
     this.shuffleManager = shuffleManager;
     this.appId = appId;
-    this.bufferManager = bufferManager;
     this.shuffleId = shuffleId;
     this.taskId = taskId;
     this.taskAttemptId = taskAttemptId;
@@ -137,8 +148,6 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
     this.shouldPartition = partitioner.numPartitions() > 1;
     this.sendCheckTimeout = sparkConf.get(RssSparkConfig.RSS_CLIENT_SEND_CHECK_TIMEOUT_MS);
     this.sendCheckInterval = sparkConf.get(RssSparkConfig.RSS_CLIENT_SEND_CHECK_INTERVAL_MS);
-    this.sendSizeLimit = sparkConf.getSizeAsBytes(RssSparkConfig.RSS_CLIENT_SEND_SIZE_LIMIT.key(),
-        RssSparkConfig.RSS_CLIENT_SEND_SIZE_LIMIT.defaultValue().get());
     this.bitmapSplitNum = sparkConf.get(RssSparkConfig.RSS_CLIENT_BITMAP_SPLIT_NUM);
     this.partitionToBlockIds = Maps.newHashMap();
     this.shuffleWriteClient = shuffleWriteClient;
@@ -146,11 +155,50 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
     this.partitionLengths = new long[partitioner.numPartitions()];
     Arrays.fill(partitionLengths, 0);
     partitionToServers = rssHandle.getPartitionToServers();
-    this.isMemoryShuffleEnabled = isMemoryShuffleEnabled(
-        sparkConf.get(RssSparkConfig.RSS_STORAGE_TYPE.key()));
+    this.isMemoryShuffleEnabled =
+        isMemoryShuffleEnabled(sparkConf.get(RssSparkConfig.RSS_STORAGE_TYPE.key()));
     this.taskFailureCallback = taskFailureCallback;
   }
 
+  public RssShuffleWriter(
+      String appId,
+      int shuffleId,
+      String taskId,
+      long taskAttemptId,
+      ShuffleWriteMetrics shuffleWriteMetrics,
+      RssShuffleManager shuffleManager,
+      SparkConf sparkConf,
+      ShuffleWriteClient shuffleWriteClient,
+      RssShuffleHandle<K, V, C> rssHandle,
+      Function<String, Boolean> taskFailureCallback,
+      TaskContext context) {
+    this(
+        appId,
+        shuffleId,
+        taskId,
+        taskAttemptId,
+        shuffleWriteMetrics,
+        shuffleManager,
+        sparkConf,
+        shuffleWriteClient,
+        rssHandle,
+        taskFailureCallback);
+    BufferManagerOptions bufferOptions = new BufferManagerOptions(sparkConf);
+    final WriteBufferManager bufferManager =
+        new WriteBufferManager(
+            shuffleId,
+            taskId,
+            taskAttemptId,
+            bufferOptions,
+            rssHandle.getDependency().serializer(),
+            rssHandle.getPartitionToServers(),
+            context.taskMemoryManager(),
+            shuffleWriteMetrics,
+            RssSparkConfig.toRssConf(sparkConf),
+            this::processShuffleBlockInfos);
+    this.bufferManager = bufferManager;
+  }
+
   private boolean isMemoryShuffleEnabled(String storageType) {
     return StorageType.withMemory(StorageType.valueOf(storageType));
   }
@@ -165,11 +213,10 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
     }
   }
 
-  private void writeImpl(Iterator<Product2<K,V>> records) {
+  protected void writeImpl(Iterator<Product2<K, V>> records) throws IOException {
     List<ShuffleBlockInfo> shuffleBlockInfos;
-    Set<Long> blockIds = Sets.newHashSet();
     boolean isCombine = shuffleDependency.mapSideCombine();
-    Function1 createCombiner = null;
+    Function1<V, C> createCombiner = null;
     if (isCombine) {
       createCombiner = shuffleDependency.aggregator().get().createCombiner();
     }
@@ -187,16 +234,16 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
         shuffleBlockInfos = bufferManager.addRecord(partition, record._1(), record._2());
       }
       if (shuffleBlockInfos != null && !shuffleBlockInfos.isEmpty()) {
-        processShuffleBlockInfos(shuffleBlockInfos, blockIds);
+        processShuffleBlockInfos(shuffleBlockInfos);
       }
     }
     final long start = System.currentTimeMillis();
     shuffleBlockInfos = bufferManager.clear();
     if (shuffleBlockInfos != null && !shuffleBlockInfos.isEmpty()) {
-      processShuffleBlockInfos(shuffleBlockInfos, blockIds);
+      processShuffleBlockInfos(shuffleBlockInfos);
     }
     long checkStartTs = System.currentTimeMillis();
-    checkBlockSendResult(blockIds);
+    internalCheckBlockSendResult();
     long commitStartTs = System.currentTimeMillis();
     long checkDuration = commitStartTs - checkStartTs;
     if (!isMemoryShuffleEnabled) {
@@ -204,83 +251,125 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
     }
     long writeDurationMs = bufferManager.getWriteTime() + (System.currentTimeMillis() - start);
     shuffleWriteMetrics.incWriteTime(TimeUnit.MILLISECONDS.toNanos(writeDurationMs));
-    LOG.info("Finish write shuffle for appId[" + appId + "], shuffleId[" + shuffleId
-        + "], taskId[" + taskId + "] with write " + writeDurationMs + " ms, include checkSendResult["
-        + checkDuration + "], commit[" + (System.currentTimeMillis() - commitStartTs) + "], "
-        + bufferManager.getManagerCostInfo());
+    LOG.info(
+        "Finish write shuffle for appId["
+            + appId
+            + "], shuffleId["
+            + shuffleId
+            + "], taskId["
+            + taskId
+            + "] with write "
+            + writeDurationMs
+            + " ms, include checkSendResult["
+            + checkDuration
+            + "], commit["
+            + (System.currentTimeMillis() - commitStartTs)
+            + "], "
+            + bufferManager.getManagerCostInfo());
   }
 
-  // only push-based shuffle use this interface, but rss won't be used when push-based shuffle is enabled.
+  // only push-based shuffle use this interface, but rss won't be used when push-based shuffle is
+  // enabled.
   public long[] getPartitionLengths() {
     return new long[0];
   }
 
-  private void processShuffleBlockInfos(List<ShuffleBlockInfo> shuffleBlockInfoList, Set<Long> blockIds) {
+  @VisibleForTesting
+  protected List<CompletableFuture<Long>> processShuffleBlockInfos(
+      List<ShuffleBlockInfo> shuffleBlockInfoList) {
     if (shuffleBlockInfoList != null && !shuffleBlockInfoList.isEmpty()) {
-      shuffleBlockInfoList.forEach(sbi -> {
-        long blockId = sbi.getBlockId();
-        // add blockId to set, check if it is sent later
-        blockIds.add(blockId);
-        // update [partition, blockIds], it will be sent to shuffle server
-        int partitionId = sbi.getPartitionId();
-        partitionToBlockIds.computeIfAbsent(partitionId, k -> Sets.newHashSet()).add(blockId);
-        partitionLengths[partitionId] += sbi.getLength();
-      });
-      postBlockEvent(shuffleBlockInfoList);
+      shuffleBlockInfoList.forEach(
+          sbi -> {
+            long blockId = sbi.getBlockId();
+            // add blockId to set, check if it is sent later
+            blockIds.add(blockId);
+            // update [partition, blockIds], it will be sent to shuffle server
+            int partitionId = sbi.getPartitionId();
+            partitionToBlockIds.computeIfAbsent(partitionId, k -> Sets.newHashSet()).add(blockId);
+            partitionLengths[partitionId] += sbi.getLength();
+          });
+      return postBlockEvent(shuffleBlockInfoList);
     }
+    return Collections.emptyList();
   }
 
-  protected void postBlockEvent(List<ShuffleBlockInfo> shuffleBlockInfoList) {
-    long totalSize = 0;
-    List<ShuffleBlockInfo> shuffleBlockInfosPerEvent = Lists.newArrayList();
-    for (ShuffleBlockInfo sbi : shuffleBlockInfoList) {
-      totalSize += sbi.getSize();
-      shuffleBlockInfosPerEvent.add(sbi);
-      // split shuffle data according to the size
-      if (totalSize > sendSizeLimit) {
-        LOG.info("Post event to queue with " + shuffleBlockInfosPerEvent.size()
-            + " blocks and " + totalSize + " bytes");
-        shuffleManager.postEvent(
-            new AddBlockEvent(taskId, shuffleBlockInfosPerEvent));
-        shuffleBlockInfosPerEvent = Lists.newArrayList();
-        totalSize = 0;
-      }
-    }
-    if (!shuffleBlockInfosPerEvent.isEmpty()) {
-      LOG.info("Post event to queue with " + shuffleBlockInfosPerEvent.size()
-          + " blocks and " + totalSize + " bytes");
-      shuffleManager.postEvent(
-          new AddBlockEvent(taskId, shuffleBlockInfosPerEvent));
+  protected List<CompletableFuture<Long>> postBlockEvent(
+      List<ShuffleBlockInfo> shuffleBlockInfoList) {
+    List<CompletableFuture<Long>> futures = new ArrayList<>();
+    for (AddBlockEvent event : bufferManager.buildBlockEvents(shuffleBlockInfoList)) {
+      event.addCallback(
+          () -> {
+            boolean ret = finishEventQueue.add(new Object());
+            if (!ret) {
+              LOG.error("Add event " + event + " to finishEventQueue fail");
+            }
+          });
+      futures.add(shuffleManager.sendData(event));
     }
+    return futures;
+  }
+
+  protected void internalCheckBlockSendResult() {
+    checkBlockSendResult(blockIds);
   }
 
   @VisibleForTesting
   protected void checkBlockSendResult(Set<Long> blockIds) {
-    long start = System.currentTimeMillis();
-    while (true) {
-      checkIfBlocksFailed();
-      Set<Long> successBlockIds = shuffleManager.getSuccessBlockIds(taskId);
-      blockIds.removeAll(successBlockIds);
-      if (blockIds.isEmpty()) {
-        break;
+    boolean interrupted = false;
+
+    try {
+      long remainingMs = sendCheckTimeout;
+      long end = System.currentTimeMillis() + remainingMs;
+
+      while (true) {
+        try {
+          finishEventQueue.clear();
+          checkIfBlocksFailed();
+          Set<Long> successBlockIds = shuffleManager.getSuccessBlockIds(taskId);
+          blockIds.removeAll(successBlockIds);
+          if (blockIds.isEmpty()) {
+            break;
+          }
+          if (finishEventQueue.isEmpty()) {
+            remainingMs = Math.max(end - System.currentTimeMillis(), 0);
+            Object event = finishEventQueue.poll(remainingMs, TimeUnit.MILLISECONDS);
+            if (event == null) {
+              break;
+            }
+          }
+        } catch (InterruptedException e) {
+          interrupted = true;
+        }
       }
-      LOG.info("Wait " + blockIds.size() + " blocks sent to shuffle server");
-      Uninterruptibles.sleepUninterruptibly(sendCheckInterval, TimeUnit.MILLISECONDS);
-      if (System.currentTimeMillis() - start > sendCheckTimeout) {
-        String errorMsg = "Timeout: Task[" + taskId + "] failed because " + blockIds.size()
-            + " blocks can't be sent to shuffle server in " + sendCheckTimeout + " ms.";
+      if (!blockIds.isEmpty()) {
+        String errorMsg =
+            "Timeout: Task["
+                + taskId
+                + "] failed because "
+                + blockIds.size()
+                + " blocks can't be sent to shuffle server in "
+                + sendCheckTimeout
+                + " ms.";
         LOG.error(errorMsg);
         throw new RssException(errorMsg);
       }
+    } finally {
+      if (interrupted) {
+        Thread.currentThread().interrupt();
+      }
     }
   }
 
   private void checkIfBlocksFailed() {
     Set<Long> failedBlockIds = shuffleManager.getFailedBlockIds(taskId);
     if (!failedBlockIds.isEmpty()) {
-      String errorMsg = "Send failed: Task[" + taskId + "]"
-          + " failed because " + failedBlockIds.size()
-          + " blocks can't be sent to shuffle server.";
+      String errorMsg =
+          "Send failed: Task["
+              + taskId
+              + "]"
+              + " failed because "
+              + failedBlockIds.size()
+              + " blocks can't be sent to shuffle server.";
       LOG.error(errorMsg);
       throw new RssException(errorMsg);
     }
@@ -289,14 +378,19 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
   @VisibleForTesting
   protected void sendCommit() {
     ExecutorService executor = Executors.newSingleThreadExecutor();
-    Future<Boolean> future = executor.submit(
-        () -> shuffleWriteClient.sendCommit(shuffleServersForData, appId, shuffleId, numMaps));
+    Future<Boolean> future =
+        executor.submit(
+            () -> shuffleWriteClient.sendCommit(shuffleServersForData, appId, shuffleId, numMaps));
     int maxWait = 5000;
     int currentWait = 200;
     long start = System.currentTimeMillis();
     while (!future.isDone()) {
-      LOG.info("Wait commit to shuffle server for task[" + taskAttemptId + "] cost "
-          + (System.currentTimeMillis() - start) + " ms");
+      LOG.info(
+          "Wait commit to shuffle server for task["
+              + taskAttemptId
+              + "] cost "
+              + (System.currentTimeMillis() - start)
+              + " ms");
       Uninterruptibles.sleepUninterruptibly(currentWait, TimeUnit.MILLISECONDS);
       currentWait = Math.min(currentWait * 2, maxWait);
     }
@@ -307,14 +401,14 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
     } catch (InterruptedException ie) {
       LOG.warn("Ignore the InterruptedException which should be caused by internal killed");
     } catch (Exception e) {
-      throw new RuntimeException("Exception happened when get commit status", e);
+      throw new RssException("Exception happened when get commit status", e);
     } finally {
       executor.shutdown();
     }
   }
 
   @VisibleForTesting
-  protected <K> int getPartition(K key) {
+  protected <T> int getPartition(T key) {
     int result = 0;
     if (shouldPartition) {
       result = partitioner.getPartition(key);
@@ -331,15 +425,21 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
           ptb.put(entry.getKey(), Lists.newArrayList(entry.getValue()));
         }
         long start = System.currentTimeMillis();
-        shuffleWriteClient.reportShuffleResult(partitionToServers, appId, shuffleId,
-            taskAttemptId, ptb, bitmapSplitNum);
-        LOG.info("Report shuffle result for task[{}] with bitmapNum[{}] cost {} ms",
-            taskAttemptId, bitmapSplitNum, (System.currentTimeMillis() - start));
-        // todo: we can replace the dummy host and port with the real shuffle server which we prefer to read
-        final BlockManagerId blockManagerId = BlockManagerId.apply(appId + "_" + taskId,
-            DUMMY_HOST,
-            DUMMY_PORT,
-            Option.apply(Long.toString(taskAttemptId)));
+        shuffleWriteClient.reportShuffleResult(
+            partitionToServers, appId, shuffleId, taskAttemptId, ptb, bitmapSplitNum);
+        LOG.info(
+            "Report shuffle result for task[{}] with bitmapNum[{}] cost {} ms",
+            taskAttemptId,
+            bitmapSplitNum,
+            (System.currentTimeMillis() - start));
+        // todo: we can replace the dummy host and port with the real shuffle server which we prefer
+        // to read
+        final BlockManagerId blockManagerId =
+            BlockManagerId.apply(
+                appId + "_" + taskId,
+                DUMMY_HOST,
+                DUMMY_PORT,
+                Option.apply(Long.toString(taskAttemptId)));
         MapStatus mapStatus = MapStatus.apply(blockManagerId, partitionLengths, taskAttemptId);
         return Option.apply(mapStatus);
       } else {
@@ -360,4 +460,9 @@ public class RssShuffleWriter<K, V, C> extends ShuffleWriter<K, V> {
   Map<Integer, Set<Long>> getPartitionToBlockIds() {
     return partitionToBlockIds;
   }
+
+  @VisibleForTesting
+  public WriteBufferManager getBufferManager() {
+    return bufferManager;
+  }
 }
