@@ -22,20 +22,19 @@ import java.util.Set;
 
 import org.apache.commons.lang3.SystemUtils;
 import org.apache.spark.SparkConf;
-import org.apache.spark.util.EventLoop;
+import org.apache.spark.shuffle.writer.DataPusher;
 
 public class TestUtils {
 
-  private TestUtils() {
-  }
+  private TestUtils() {}
 
   public static RssShuffleManager createShuffleManager(
       SparkConf conf,
       Boolean isDriver,
-      EventLoop loop,
+      DataPusher dataPusher,
       Map<String, Set<Long>> successBlockIds,
       Map<String, Set<Long>> failBlockIds) {
-    return new RssShuffleManager(conf, isDriver, loop, successBlockIds, failBlockIds);
+    return new RssShuffleManager(conf, isDriver, dataPusher, successBlockIds, failBlockIds);
   }
 
   public static boolean isMacOnAppleSilicon() {
