@@ -21,6 +21,8 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+import scala.Option;
+
 import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
 import org.apache.spark.ShuffleDependency;
@@ -33,12 +35,12 @@ import org.apache.spark.serializer.Serializer;
 import org.apache.spark.shuffle.RssShuffleHandle;
 import org.junit.jupiter.api.Test;
 import org.roaringbitmap.longlong.Roaring64NavigableMap;
-import scala.Option;
 
 import org.apache.uniffle.common.ShuffleDataDistributionType;
 import org.apache.uniffle.common.ShuffleServerInfo;
+import org.apache.uniffle.common.config.RssClientConf;
 import org.apache.uniffle.common.config.RssConf;
-import org.apache.uniffle.storage.handler.impl.HdfsShuffleWriteHandler;
+import org.apache.uniffle.storage.handler.impl.HadoopShuffleWriteHandler;
 import org.apache.uniffle.storage.util.StorageType;
 
 import static org.mockito.Mockito.doNothing;
@@ -54,23 +56,23 @@ public class RssShuffleReaderTest extends AbstractRssReaderTest {
   public void readTest() throws Exception {
     ShuffleServerInfo ssi = new ShuffleServerInfo("127.0.0.1", 0);
     String basePath = HDFS_URI + "readTest1";
-    HdfsShuffleWriteHandler writeHandler =
-        new HdfsShuffleWriteHandler("appId", 0, 0, 0, basePath, ssi.getId(), conf);
-    final HdfsShuffleWriteHandler writeHandler1 =
-        new HdfsShuffleWriteHandler("appId", 0, 1, 1, basePath, ssi.getId(), conf);
+    HadoopShuffleWriteHandler writeHandler =
+        new HadoopShuffleWriteHandler("appId", 0, 0, 0, basePath, ssi.getId(), conf);
+    final HadoopShuffleWriteHandler writeHandler1 =
+        new HadoopShuffleWriteHandler("appId", 0, 1, 1, basePath, ssi.getId(), conf);
 
     Roaring64NavigableMap blockIdBitmap = Roaring64NavigableMap.bitmapOf();
     final Roaring64NavigableMap taskIdBitmap = Roaring64NavigableMap.bitmapOf(0);
     Map<String, String> expectedData = Maps.newHashMap();
     final Roaring64NavigableMap blockIdBitmap1 = Roaring64NavigableMap.bitmapOf();
-    writeTestData(writeHandler, 2, 5, expectedData,
-        blockIdBitmap, "key", KRYO_SERIALIZER, 0);
+    writeTestData(writeHandler, 2, 5, expectedData, blockIdBitmap, "key", KRYO_SERIALIZER, 0);
 
-    RssShuffleHandle handleMock = mock(RssShuffleHandle.class);
-    ShuffleDependency dependencyMock = mock(ShuffleDependency.class);
+    RssShuffleHandle<String, String, String> handleMock = mock(RssShuffleHandle.class);
+    ShuffleDependency<String, String, String> dependencyMock = mock(ShuffleDependency.class);
     when(handleMock.getAppId()).thenReturn("appId");
     when(handleMock.getDependency()).thenReturn(dependencyMock);
     when(handleMock.getShuffleId()).thenReturn(1);
+    when(handleMock.getNumMaps()).thenReturn(1);
     Map<Integer, List<ShuffleServerInfo>> partitionToServers = new HashMap<>();
     partitionToServers.put(0, Lists.newArrayList(ssi));
     partitionToServers.put(1, Lists.newArrayList(ssi));
@@ -87,71 +89,68 @@ public class RssShuffleReaderTest extends AbstractRssReaderTest {
 
     Map<Integer, Roaring64NavigableMap> partitionToExpectBlocks = Maps.newHashMap();
     partitionToExpectBlocks.put(0, blockIdBitmap);
-    RssShuffleReader rssShuffleReaderSpy = spy(new RssShuffleReader<String, String>(
-        0,
-        1,
-        0,
-        Integer.MAX_VALUE,
-        contextMock,
-        handleMock,
-        basePath,
-        1000,
-        conf,
-        StorageType.HDFS.name(),
-        1000,
-        1,
-        partitionToExpectBlocks,
-        taskIdBitmap,
-        new ShuffleReadMetrics(),
-        new RssConf(),
-        ShuffleDataDistributionType.NORMAL
-    ));
+    RssConf rssConf = new RssConf();
+    rssConf.set(RssClientConf.RSS_STORAGE_TYPE, StorageType.HDFS.name());
+    rssConf.set(RssClientConf.RSS_INDEX_READ_LIMIT, 1000);
+    rssConf.set(RssClientConf.RSS_CLIENT_READ_BUFFER_SIZE, "1000");
+    RssShuffleReader<String, String> rssShuffleReaderSpy =
+        spy(
+            new RssShuffleReader<>(
+                0,
+                1,
+                0,
+                Integer.MAX_VALUE,
+                contextMock,
+                handleMock,
+                basePath,
+                conf,
+                1,
+                partitionToExpectBlocks,
+                taskIdBitmap,
+                new ShuffleReadMetrics(),
+                rssConf,
+                ShuffleDataDistributionType.NORMAL));
     validateResult(rssShuffleReaderSpy.read(), expectedData, 10);
 
-    writeTestData(writeHandler1, 2, 4, expectedData,
-        blockIdBitmap1, "another_key", KRYO_SERIALIZER, 1);
+    writeTestData(
+        writeHandler1, 2, 4, expectedData, blockIdBitmap1, "another_key", KRYO_SERIALIZER, 1);
     partitionToExpectBlocks.put(1, blockIdBitmap1);
-    RssShuffleReader rssShuffleReaderSpy1 = spy(new RssShuffleReader<String, String>(
-        0,
-        2,
-        0,
-        Integer.MAX_VALUE,
-        contextMock,
-        handleMock,
-        basePath,
-        1000,
-        conf,
-        StorageType.HDFS.name(),
-        1000,
-        2,
-        partitionToExpectBlocks,
-        taskIdBitmap,
-        new ShuffleReadMetrics(),
-        new RssConf(),
-        ShuffleDataDistributionType.NORMAL
-    ));
+    RssShuffleReader<String, String> rssShuffleReaderSpy1 =
+        spy(
+            new RssShuffleReader<>(
+                0,
+                2,
+                0,
+                Integer.MAX_VALUE,
+                contextMock,
+                handleMock,
+                basePath,
+                conf,
+                2,
+                partitionToExpectBlocks,
+                taskIdBitmap,
+                new ShuffleReadMetrics(),
+                rssConf,
+                ShuffleDataDistributionType.NORMAL));
     validateResult(rssShuffleReaderSpy1.read(), expectedData, 18);
 
-    RssShuffleReader rssShuffleReaderSpy2 = spy(new RssShuffleReader<String, String>(
-        0,
-        2,
-        0,
-        Integer.MAX_VALUE,
-        contextMock,
-        handleMock,
-        basePath,
-        1000,
-        conf,
-        StorageType.HDFS.name(),
-        1000,
-        2,
-        partitionToExpectBlocks,
-        Roaring64NavigableMap.bitmapOf(),
-        new ShuffleReadMetrics(),
-        new RssConf(),
-        ShuffleDataDistributionType.NORMAL
-    ));
+    RssShuffleReader<String, String> rssShuffleReaderSpy2 =
+        spy(
+            new RssShuffleReader<>(
+                0,
+                2,
+                0,
+                Integer.MAX_VALUE,
+                contextMock,
+                handleMock,
+                basePath,
+                conf,
+                2,
+                partitionToExpectBlocks,
+                Roaring64NavigableMap.bitmapOf(),
+                new ShuffleReadMetrics(),
+                rssConf,
+                ShuffleDataDistributionType.NORMAL));
     validateResult(rssShuffleReaderSpy2.read(), Maps.newHashMap(), 0);
   }
-
 }
