@@ -22,33 +22,117 @@ import org.apache.uniffle.client.api.ShuffleWriteClient;
 import org.apache.uniffle.client.impl.ShuffleReadClientImpl;
 import org.apache.uniffle.client.impl.ShuffleWriteClientImpl;
 import org.apache.uniffle.client.request.CreateShuffleReadClientRequest;
+import org.apache.uniffle.common.config.RssConf;
 
 public class ShuffleClientFactory {
 
   private static final ShuffleClientFactory INSTANCE = new ShuffleClientFactory();
 
-  private ShuffleClientFactory() {
-  }
+  private ShuffleClientFactory() {}
 
   public static ShuffleClientFactory getInstance() {
     return INSTANCE;
   }
 
-  /**
-   * Only for MR engine, which won't used to unregister to remote shuffle-servers
-   */
+  /** Only for MR engine, which won't used to unregister to remote shuffle-servers */
   public ShuffleWriteClient createShuffleWriteClient(
-      String clientType, int retryMax, long retryIntervalMax, int heartBeatThreadNum,
-      int replica, int replicaWrite, int replicaRead, boolean replicaSkipEnabled, int dataTransferPoolSize,
+      String clientType,
+      int retryMax,
+      long retryIntervalMax,
+      int heartBeatThreadNum,
+      int replica,
+      int replicaWrite,
+      int replicaRead,
+      boolean replicaSkipEnabled,
+      int dataTransferPoolSize,
       int dataCommitPoolSize) {
-    return createShuffleWriteClient(clientType, retryMax, retryIntervalMax, heartBeatThreadNum, replica,
-        replicaWrite, replicaRead, replicaSkipEnabled, dataTransferPoolSize, dataCommitPoolSize, 10, 10);
+    return createShuffleWriteClient(
+        clientType,
+        retryMax,
+        retryIntervalMax,
+        heartBeatThreadNum,
+        replica,
+        replicaWrite,
+        replicaRead,
+        replicaSkipEnabled,
+        dataTransferPoolSize,
+        dataCommitPoolSize,
+        10,
+        10,
+        new RssConf());
   }
 
   public ShuffleWriteClient createShuffleWriteClient(
-      String clientType, int retryMax, long retryIntervalMax, int heartBeatThreadNum,
-      int replica, int replicaWrite, int replicaRead, boolean replicaSkipEnabled, int dataTransferPoolSize,
-      int dataCommitPoolSize, int unregisterThreadPoolSize, int unregisterRequestTimeoutSec) {
+      String clientType,
+      int retryMax,
+      long retryIntervalMax,
+      int heartBeatThreadNum,
+      int replica,
+      int replicaWrite,
+      int replicaRead,
+      boolean replicaSkipEnabled,
+      int dataTransferPoolSize,
+      int dataCommitPoolSize,
+      RssConf rssConf) {
+    return createShuffleWriteClient(
+        clientType,
+        retryMax,
+        retryIntervalMax,
+        heartBeatThreadNum,
+        replica,
+        replicaWrite,
+        replicaRead,
+        replicaSkipEnabled,
+        dataTransferPoolSize,
+        dataCommitPoolSize,
+        10,
+        10,
+        rssConf);
+  }
+
+  public ShuffleWriteClient createShuffleWriteClient(
+      String clientType,
+      int retryMax,
+      long retryIntervalMax,
+      int heartBeatThreadNum,
+      int replica,
+      int replicaWrite,
+      int replicaRead,
+      boolean replicaSkipEnabled,
+      int dataTransferPoolSize,
+      int dataCommitPoolSize,
+      int unregisterThreadPoolSize,
+      int unregisterRequestTimeoutSec) {
+    return createShuffleWriteClient(
+        clientType,
+        retryMax,
+        retryIntervalMax,
+        heartBeatThreadNum,
+        replica,
+        replicaWrite,
+        replicaRead,
+        replicaSkipEnabled,
+        dataTransferPoolSize,
+        dataCommitPoolSize,
+        unregisterThreadPoolSize,
+        unregisterRequestTimeoutSec,
+        new RssConf());
+  }
+
+  public ShuffleWriteClient createShuffleWriteClient(
+      String clientType,
+      int retryMax,
+      long retryIntervalMax,
+      int heartBeatThreadNum,
+      int replica,
+      int replicaWrite,
+      int replicaRead,
+      boolean replicaSkipEnabled,
+      int dataTransferPoolSize,
+      int dataCommitPoolSize,
+      int unregisterThreadPoolSize,
+      int unregisterRequestTimeoutSec,
+      RssConf rssConf) {
     // If replica > replicaWrite, blocks maybe be sent for 2 rounds.
     // We need retry less times in this case for let the first round fail fast.
     if (replicaSkipEnabled && replica > replicaWrite) {
@@ -66,20 +150,17 @@ public class ShuffleClientFactory {
         dataTransferPoolSize,
         dataCommitPoolSize,
         unregisterThreadPoolSize,
-        unregisterRequestTimeoutSec
-    );
+        unregisterRequestTimeoutSec,
+        rssConf);
   }
 
   public ShuffleReadClient createShuffleReadClient(CreateShuffleReadClientRequest request) {
     return new ShuffleReadClientImpl(
-        request.getStorageType(),
         request.getAppId(),
         request.getShuffleId(),
         request.getPartitionId(),
-        request.getIndexReadLimit(),
         request.getPartitionNumPerRange(),
         request.getPartitionNum(),
-        request.getReadBufferSize(),
         request.getBasePath(),
         request.getBlockIdBitmap(),
         request.getTaskIdBitmap(),
@@ -87,7 +168,7 @@ public class ShuffleClientFactory {
         request.getHadoopConf(),
         request.getIdHelper(),
         request.getShuffleDataDistributionType(),
-        request.isExpectedTaskIdsBitmapFilterEnable()
-    );
+        request.isExpectedTaskIdsBitmapFilterEnable(),
+        request.getRssConf());
   }
 }
