@@ -36,7 +36,9 @@ import org.apache.uniffle.common.BufferSegment;
 import org.apache.uniffle.common.ShuffleDataDistributionType;
 import org.apache.uniffle.common.ShuffleDataResult;
 import org.apache.uniffle.common.ShuffleServerInfo;
-import org.apache.uniffle.common.exception.RssException;
+import org.apache.uniffle.common.config.RssClientConf;
+import org.apache.uniffle.common.config.RssConf;
+import org.apache.uniffle.common.exception.RssFetchFailedException;
 import org.apache.uniffle.common.util.ChecksumUtils;
 import org.apache.uniffle.common.util.IdHelper;
 import org.apache.uniffle.common.util.RssUtils;
@@ -47,10 +49,10 @@ import org.apache.uniffle.storage.request.CreateShuffleReadHandlerRequest;
 public class ShuffleReadClientImpl implements ShuffleReadClient {
 
   private static final Logger LOG = LoggerFactory.getLogger(ShuffleReadClientImpl.class);
-  private final List<ShuffleServerInfo> shuffleServerInfoList;
+  private List<ShuffleServerInfo> shuffleServerInfoList;
   private int shuffleId;
   private int partitionId;
-  private byte[] readBuffer;
+  private ByteBuffer readBuffer;
   private Roaring64NavigableMap blockIdBitmap;
   private Roaring64NavigableMap taskIdBitmap;
   private Roaring64NavigableMap pendingBlockIds;
@@ -60,9 +62,86 @@ public class ShuffleReadClientImpl implements ShuffleReadClient {
   private AtomicLong copyTime = new AtomicLong(0);
   private AtomicLong crcCheckTime = new AtomicLong(0);
   private ClientReadHandler clientReadHandler;
-  private final IdHelper idHelper;
+  private IdHelper idHelper;
 
   public ShuffleReadClientImpl(
+      String appId,
+      int shuffleId,
+      int partitionId,
+      int partitionNumPerRange,
+      int partitionNum,
+      String storageBasePath,
+      Roaring64NavigableMap blockIdBitmap,
+      Roaring64NavigableMap taskIdBitmap,
+      List<ShuffleServerInfo> shuffleServerInfoList,
+      Configuration hadoopConf,
+      IdHelper idHelper,
+      ShuffleDataDistributionType dataDistributionType,
+      boolean expectedTaskIdsBitmapFilterEnable,
+      RssConf rssConf) {
+    final int indexReadLimit = rssConf.get(RssClientConf.RSS_INDEX_READ_LIMIT);
+    final String storageType = rssConf.get(RssClientConf.RSS_STORAGE_TYPE);
+    long readBufferSize =
+        rssConf.getSizeAsBytes(
+            RssClientConf.RSS_CLIENT_READ_BUFFER_SIZE.key(),
+            RssClientConf.RSS_CLIENT_READ_BUFFER_SIZE.defaultValue());
+    if (readBufferSize > Integer.MAX_VALUE) {
+      LOG.warn(RssClientConf.RSS_CLIENT_READ_BUFFER_SIZE.key() + " can support 2g as max");
+      readBufferSize = Integer.MAX_VALUE;
+    }
+    boolean offHeapEnabled = rssConf.get(RssClientConf.OFF_HEAP_MEMORY_ENABLE);
+    init(
+        storageType,
+        appId,
+        shuffleId,
+        partitionId,
+        indexReadLimit,
+        partitionNumPerRange,
+        partitionNum,
+        (int) readBufferSize,
+        storageBasePath,
+        blockIdBitmap,
+        taskIdBitmap,
+        shuffleServerInfoList,
+        hadoopConf,
+        idHelper,
+        dataDistributionType,
+        expectedTaskIdsBitmapFilterEnable,
+        offHeapEnabled,
+        rssConf);
+  }
+
+  public ShuffleReadClientImpl(
+      String appId,
+      int shuffleId,
+      int partitionId,
+      int partitionNumPerRange,
+      int partitionNum,
+      String storageBasePath,
+      Roaring64NavigableMap blockIdBitmap,
+      Roaring64NavigableMap taskIdBitmap,
+      List<ShuffleServerInfo> shuffleServerInfoList,
+      Configuration hadoopConf,
+      IdHelper idHelper,
+      RssConf rssConf) {
+    this(
+        appId,
+        shuffleId,
+        partitionId,
+        partitionNumPerRange,
+        partitionNum,
+        storageBasePath,
+        blockIdBitmap,
+        taskIdBitmap,
+        shuffleServerInfoList,
+        hadoopConf,
+        idHelper,
+        ShuffleDataDistributionType.NORMAL,
+        false,
+        rssConf);
+  }
+
+  private void init(
       String storageType,
       String appId,
       int shuffleId,
@@ -78,7 +157,9 @@ public class ShuffleReadClientImpl implements ShuffleReadClient {
       Configuration hadoopConf,
       IdHelper idHelper,
       ShuffleDataDistributionType dataDistributionType,
-      boolean expectedTaskIdsBitmapFilterEnable) {
+      boolean expectedTaskIdsBitmapFilterEnable,
+      boolean offHeapEnabled,
+      RssConf rssConf) {
     this.shuffleId = shuffleId;
     this.partitionId = partitionId;
     this.blockIdBitmap = blockIdBitmap;
@@ -94,7 +175,7 @@ public class ShuffleReadClientImpl implements ShuffleReadClient {
     request.setIndexReadLimit(indexReadLimit);
     request.setPartitionNumPerRange(partitionNumPerRange);
     request.setPartitionNum(partitionNum);
-    request.setReadBufferSize(readBufferSize);
+    request.setReadBufferSize((int) readBufferSize);
     request.setStorageBasePath(storageBasePath);
     request.setShuffleServerInfoList(shuffleServerInfoList);
     request.setHadoopConf(hadoopConf);
@@ -103,16 +184,21 @@ public class ShuffleReadClientImpl implements ShuffleReadClient {
     request.setDistributionType(dataDistributionType);
     request.setIdHelper(idHelper);
     request.setExpectTaskIds(taskIdBitmap);
+    request.setClientConf(rssConf);
     if (expectedTaskIdsBitmapFilterEnable) {
       request.useExpectedTaskIdsBitmapFilter();
     }
+    if (offHeapEnabled) {
+      request.enableOffHeap();
+    }
 
     List<Long> removeBlockIds = Lists.newArrayList();
-    blockIdBitmap.forEach(bid -> {
-      if (!taskIdBitmap.contains(idHelper.getTaskAttemptId(bid))) {
-        removeBlockIds.add(bid);
-      }
-    });
+    blockIdBitmap.forEach(
+        bid -> {
+          if (!taskIdBitmap.contains(idHelper.getTaskAttemptId(bid))) {
+            removeBlockIds.add(bid);
+          }
+        });
 
     for (long rid : removeBlockIds) {
       blockIdBitmap.removeLong(rid);
@@ -139,10 +225,29 @@ public class ShuffleReadClientImpl implements ShuffleReadClient {
       List<ShuffleServerInfo> shuffleServerInfoList,
       Configuration hadoopConf,
       IdHelper idHelper) {
-    this(storageType, appId, shuffleId, partitionId, indexReadLimit,
-        partitionNumPerRange, partitionNum, readBufferSize, storageBasePath,
-        blockIdBitmap, taskIdBitmap, shuffleServerInfoList, hadoopConf,
-        idHelper, ShuffleDataDistributionType.NORMAL, false);
+    RssConf rssConf = new RssConf();
+    rssConf.set(RssClientConf.RSS_STORAGE_TYPE, storageType);
+    rssConf.set(RssClientConf.RSS_INDEX_READ_LIMIT, indexReadLimit);
+    rssConf.set(RssClientConf.RSS_CLIENT_READ_BUFFER_SIZE, String.valueOf(readBufferSize));
+    init(
+        storageType,
+        appId,
+        shuffleId,
+        partitionId,
+        indexReadLimit,
+        partitionNumPerRange,
+        partitionNum,
+        readBufferSize,
+        storageBasePath,
+        blockIdBitmap,
+        taskIdBitmap,
+        shuffleServerInfoList,
+        hadoopConf,
+        idHelper,
+        ShuffleDataDistributionType.NORMAL,
+        false,
+        false,
+        rssConf);
   }
 
   @Override
@@ -192,16 +297,21 @@ public class ShuffleReadClientImpl implements ShuffleReadClient {
         }
 
         if (expectedCrc != actualCrc) {
-          String errMsg = "Unexpected crc value for blockId[" + bs.getBlockId()
-              + "], expected:" + expectedCrc + ", actual:" + actualCrc;
-          //If some blocks of one replica are corrupted,but maybe other replicas are not corrupted,
-          //so exception should not be thrown here if blocks have multiple replicas
+          String errMsg =
+              "Unexpected crc value for blockId["
+                  + bs.getBlockId()
+                  + "], expected:"
+                  + expectedCrc
+                  + ", actual:"
+                  + actualCrc;
+          // If some blocks of one replica are corrupted,but maybe other replicas are not corrupted,
+          // so exception should not be thrown here if blocks have multiple replicas
           if (shuffleServerInfoList.size() > 1) {
             LOG.warn(errMsg);
             clientReadHandler.updateConsumedBlockInfo(bs, true);
             continue;
           } else {
-            throw new RssException(errMsg);
+            throw new RssFetchFailedException(errMsg);
           }
         }
 
@@ -219,8 +329,10 @@ public class ShuffleReadClientImpl implements ShuffleReadClient {
     }
 
     if (bs != null) {
-      return new CompressedShuffleBlock(ByteBuffer.wrap(readBuffer,
-          bs.getOffset(), bs.getLength()), bs.getUncompressLength());
+      ByteBuffer compressedBuffer = readBuffer.duplicate();
+      compressedBuffer.position(bs.getOffset());
+      compressedBuffer.limit(bs.getOffset() + bs.getLength());
+      return new CompressedShuffleBlock(compressedBuffer, bs.getUncompressLength());
     }
     // current segment hasn't data, try next segment
     return readShuffleBlockData();
@@ -238,8 +350,11 @@ public class ShuffleReadClientImpl implements ShuffleReadClient {
     if (sdr == null) {
       return 0;
     }
-    readBuffer = sdr.getData();
-    if (readBuffer == null || readBuffer.length == 0) {
+    if (readBuffer != null) {
+      RssUtils.releaseByteBuffer(readBuffer);
+    }
+    readBuffer = sdr.getDataBuffer();
+    if (readBuffer == null || readBuffer.capacity() == 0) {
       return 0;
     }
     bufferSegmentQueue.addAll(sdr.getBufferSegments());
@@ -253,6 +368,9 @@ public class ShuffleReadClientImpl implements ShuffleReadClient {
 
   @Override
   public void close() {
+    if (readBuffer != null) {
+      RssUtils.releaseByteBuffer(readBuffer);
+    }
     if (clientReadHandler != null) {
       clientReadHandler.close();
     }
@@ -260,9 +378,19 @@ public class ShuffleReadClientImpl implements ShuffleReadClient {
 
   @Override
   public void logStatics() {
-    LOG.info("Metrics for shuffleId[" + shuffleId + "], partitionId[" + partitionId + "]"
-        + ", read data cost " + readDataTime + " ms, copy data cost " + copyTime
-        + " ms, crc check cost " + crcCheckTime + " ms");
+    LOG.info(
+        "Metrics for shuffleId["
+            + shuffleId
+            + "], partitionId["
+            + partitionId
+            + "]"
+            + ", read data cost "
+            + readDataTime
+            + " ms, copy data cost "
+            + copyTime
+            + " ms, crc check cost "
+            + crcCheckTime
+            + " ms");
     clientReadHandler.logConsumedBlockInfo();
   }
 }
