@@ -25,6 +25,7 @@ import org.roaringbitmap.longlong.Roaring64NavigableMap;
 import org.apache.uniffle.client.util.DefaultIdHelper;
 import org.apache.uniffle.common.ShuffleDataDistributionType;
 import org.apache.uniffle.common.ShuffleServerInfo;
+import org.apache.uniffle.common.config.RssConf;
 import org.apache.uniffle.common.util.IdHelper;
 
 public class CreateShuffleReadClientRequest {
@@ -32,10 +33,7 @@ public class CreateShuffleReadClientRequest {
   private String appId;
   private int shuffleId;
   private int partitionId;
-  private String storageType;
   private String basePath;
-  private int indexReadLimit;
-  private int readBufferSize;
   private int partitionNumPerRange;
   private int partitionNum;
   private Roaring64NavigableMap blockIdBitmap;
@@ -43,17 +41,16 @@ public class CreateShuffleReadClientRequest {
   private List<ShuffleServerInfo> shuffleServerInfoList;
   private Configuration hadoopConf;
   private IdHelper idHelper;
-  private ShuffleDataDistributionType shuffleDataDistributionType = ShuffleDataDistributionType.NORMAL;
+  private ShuffleDataDistributionType shuffleDataDistributionType =
+      ShuffleDataDistributionType.NORMAL;
   private boolean expectedTaskIdsBitmapFilterEnable = false;
+  private RssConf rssConf;
 
   public CreateShuffleReadClientRequest(
       String appId,
       int shuffleId,
       int partitionId,
-      String storageType,
       String basePath,
-      int indexReadLimit,
-      int readBufferSize,
       int partitionNumPerRange,
       int partitionNum,
       Roaring64NavigableMap blockIdBitmap,
@@ -61,10 +58,22 @@ public class CreateShuffleReadClientRequest {
       List<ShuffleServerInfo> shuffleServerInfoList,
       Configuration hadoopConf,
       ShuffleDataDistributionType dataDistributionType,
-      boolean expectedTaskIdsBitmapFilterEnable) {
-    this(appId, shuffleId, partitionId, storageType, basePath, indexReadLimit, readBufferSize,
-        partitionNumPerRange, partitionNum, blockIdBitmap, taskIdBitmap, shuffleServerInfoList,
-        hadoopConf, new DefaultIdHelper(), expectedTaskIdsBitmapFilterEnable);
+      boolean expectedTaskIdsBitmapFilterEnable,
+      RssConf rssConf) {
+    this(
+        appId,
+        shuffleId,
+        partitionId,
+        basePath,
+        partitionNumPerRange,
+        partitionNum,
+        blockIdBitmap,
+        taskIdBitmap,
+        shuffleServerInfoList,
+        hadoopConf,
+        new DefaultIdHelper(),
+        expectedTaskIdsBitmapFilterEnable,
+        rssConf);
     this.shuffleDataDistributionType = dataDistributionType;
   }
 
@@ -72,30 +81,37 @@ public class CreateShuffleReadClientRequest {
       String appId,
       int shuffleId,
       int partitionId,
-      String storageType,
       String basePath,
-      int indexReadLimit,
-      int readBufferSize,
       int partitionNumPerRange,
       int partitionNum,
       Roaring64NavigableMap blockIdBitmap,
       Roaring64NavigableMap taskIdBitmap,
       List<ShuffleServerInfo> shuffleServerInfoList,
       Configuration hadoopConf,
-      boolean expectedTaskIdsBitmapFilterEnable) {
-    this(appId, shuffleId, partitionId, storageType, basePath, indexReadLimit, readBufferSize,
-        partitionNumPerRange, partitionNum, blockIdBitmap, taskIdBitmap, shuffleServerInfoList,
-        hadoopConf, new DefaultIdHelper(), expectedTaskIdsBitmapFilterEnable);
+      IdHelper idHelper,
+      boolean expectedTaskIdsBitmapFilterEnable,
+      RssConf rssConf) {
+    this(
+        appId,
+        shuffleId,
+        partitionId,
+        basePath,
+        partitionNumPerRange,
+        partitionNum,
+        blockIdBitmap,
+        taskIdBitmap,
+        shuffleServerInfoList,
+        hadoopConf,
+        idHelper,
+        expectedTaskIdsBitmapFilterEnable);
+    this.rssConf = rssConf;
   }
 
   public CreateShuffleReadClientRequest(
       String appId,
       int shuffleId,
       int partitionId,
-      String storageType,
       String basePath,
-      int indexReadLimit,
-      int readBufferSize,
       int partitionNumPerRange,
       int partitionNum,
       Roaring64NavigableMap blockIdBitmap,
@@ -107,10 +123,7 @@ public class CreateShuffleReadClientRequest {
     this.appId = appId;
     this.shuffleId = shuffleId;
     this.partitionId = partitionId;
-    this.storageType = storageType;
     this.basePath = basePath;
-    this.indexReadLimit = indexReadLimit;
-    this.readBufferSize = readBufferSize;
     this.partitionNumPerRange = partitionNumPerRange;
     this.partitionNum = partitionNum;
     this.blockIdBitmap = blockIdBitmap;
@@ -121,6 +134,35 @@ public class CreateShuffleReadClientRequest {
     this.expectedTaskIdsBitmapFilterEnable = expectedTaskIdsBitmapFilterEnable;
   }
 
+  public CreateShuffleReadClientRequest(
+      String appId,
+      int shuffleId,
+      int partitionId,
+      String basePath,
+      int partitionNumPerRange,
+      int partitionNum,
+      Roaring64NavigableMap blockIdBitmap,
+      Roaring64NavigableMap taskIdBitmap,
+      List<ShuffleServerInfo> shuffleServerInfoList,
+      Configuration hadoopConf,
+      boolean expectedTaskIdsBitmapFilterEnable,
+      RssConf rssConf) {
+    this(
+        appId,
+        shuffleId,
+        partitionId,
+        basePath,
+        partitionNumPerRange,
+        partitionNum,
+        blockIdBitmap,
+        taskIdBitmap,
+        shuffleServerInfoList,
+        hadoopConf,
+        new DefaultIdHelper(),
+        expectedTaskIdsBitmapFilterEnable);
+    this.rssConf = rssConf;
+  }
+
   public String getAppId() {
     return appId;
   }
@@ -141,22 +183,10 @@ public class CreateShuffleReadClientRequest {
     return partitionNum;
   }
 
-  public String getStorageType() {
-    return storageType;
-  }
-
   public String getBasePath() {
     return basePath;
   }
 
-  public int getIndexReadLimit() {
-    return indexReadLimit;
-  }
-
-  public int getReadBufferSize() {
-    return readBufferSize;
-  }
-
   public Roaring64NavigableMap getBlockIdBitmap() {
     return blockIdBitmap;
   }
@@ -184,4 +214,8 @@ public class CreateShuffleReadClientRequest {
   public boolean isExpectedTaskIdsBitmapFilterEnable() {
     return expectedTaskIdsBitmapFilterEnable;
   }
+
+  public RssConf getRssConf() {
+    return rssConf;
+  }
 }
