@@ -41,8 +41,8 @@ import org.apache.uniffle.common.ShufflePartitionedBlock;
 import org.apache.uniffle.common.ShuffleServerInfo;
 import org.apache.uniffle.common.util.ChecksumUtils;
 import org.apache.uniffle.common.util.Constants;
-import org.apache.uniffle.storage.HdfsTestBase;
-import org.apache.uniffle.storage.handler.impl.HdfsShuffleWriteHandler;
+import org.apache.uniffle.storage.HadoopTestBase;
+import org.apache.uniffle.storage.handler.impl.HadoopShuffleWriteHandler;
 import org.apache.uniffle.storage.util.StorageType;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
@@ -51,7 +51,7 @@ import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.Assertions.fail;
 import static org.mockito.ArgumentMatchers.any;
 
-public class ShuffleReadClientImplTest extends HdfsTestBase {
+public class ShuffleReadClientImplTest extends HadoopTestBase {
 
   private static final String EXPECTED_EXCEPTION_MESSAGE = "Exception should be thrown";
   private static AtomicLong ATOMIC_LONG = new AtomicLong(0);
@@ -62,18 +62,30 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
   @Test
   public void readTest1() throws Exception {
     String basePath = HDFS_URI + "clientReadTest1";
-    HdfsShuffleWriteHandler writeHandler =
-        new HdfsShuffleWriteHandler("appId", 0, 1, 1, basePath, ssi1.getId(), conf);
+    HadoopShuffleWriteHandler writeHandler =
+        new HadoopShuffleWriteHandler("appId", 0, 1, 1, basePath, ssi1.getId(), conf);
 
     Map<Long, byte[]> expectedData = Maps.newHashMap();
     Roaring64NavigableMap blockIdBitmap = Roaring64NavigableMap.bitmapOf();
     Roaring64NavigableMap taskIdBitmap = Roaring64NavigableMap.bitmapOf(0);
-    writeTestData(writeHandler, 2, 30, 0, expectedData,
-        blockIdBitmap);
+    writeTestData(writeHandler, 2, 30, 0, expectedData, blockIdBitmap);
 
-    ShuffleReadClientImpl readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(), "appId", 0, 1, 100, 1,
-        10, 1000, basePath, blockIdBitmap, taskIdBitmap,
-        Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
+    ShuffleReadClientImpl readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            100,
+            1,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
 
     TestUtils.validateResult(readClient, expectedData);
     readClient.checkProcessedBlockIds();
@@ -81,9 +93,22 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
 
     blockIdBitmap.addLong(Constants.MAX_TASK_ATTEMPT_ID - 1);
     taskIdBitmap.addLong(Constants.MAX_TASK_ATTEMPT_ID - 1);
-    readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(), "appId", 0, 1, 100, 1,
-        10, 1000, basePath, blockIdBitmap, taskIdBitmap,
-        Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
+    readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            100,
+            1,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
     TestUtils.validateResult(readClient, expectedData);
     try {
       // can't find all expected block id, data loss
@@ -99,10 +124,10 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
   @Test
   public void readTest2() throws Exception {
     String basePath = HDFS_URI + "clientReadTest2";
-    HdfsShuffleWriteHandler writeHandler1 =
-        new HdfsShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi1.getId(), conf);
-    HdfsShuffleWriteHandler writeHandler2 =
-        new HdfsShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi2.getId(), conf);
+    HadoopShuffleWriteHandler writeHandler1 =
+        new HadoopShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi1.getId(), conf);
+    HadoopShuffleWriteHandler writeHandler2 =
+        new HadoopShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi2.getId(), conf);
 
     Map<Long, byte[]> expectedData = Maps.newHashMap();
     Roaring64NavigableMap blockIdBitmap = Roaring64NavigableMap.bitmapOf();
@@ -110,10 +135,22 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
     writeTestData(writeHandler1, 2, 30, 0, expectedData, blockIdBitmap);
     writeTestData(writeHandler2, 2, 30, 0, expectedData, blockIdBitmap);
 
-    ShuffleReadClientImpl readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(),
-        "appId", 0, 1, 100, 2, 10, 1000,
-        basePath, blockIdBitmap, taskIdBitmap, Lists.newArrayList(ssi1, ssi2),
-        new Configuration(), new DefaultIdHelper());
+    ShuffleReadClientImpl readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            100,
+            2,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1, ssi2),
+            new Configuration(),
+            new DefaultIdHelper());
 
     TestUtils.validateResult(readClient, expectedData);
     readClient.checkProcessedBlockIds();
@@ -123,10 +160,10 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
   @Test
   public void readTest3() throws Exception {
     String basePath = HDFS_URI + "clientReadTest3";
-    HdfsShuffleWriteHandler writeHandler1 =
-        new HdfsShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi1.getId(), conf);
-    HdfsShuffleWriteHandler writeHandler2 =
-        new HdfsShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi2.getId(), conf);
+    HadoopShuffleWriteHandler writeHandler1 =
+        new HadoopShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi1.getId(), conf);
+    HadoopShuffleWriteHandler writeHandler2 =
+        new HadoopShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi2.getId(), conf);
 
     Map<Long, byte[]> expectedData = Maps.newHashMap();
     final Roaring64NavigableMap blockIdBitmap = Roaring64NavigableMap.bitmapOf();
@@ -136,19 +173,51 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
 
     // duplicate file created, it should be used in product environment
     String shuffleFolder = basePath + "/appId/0/0-1";
-    FileUtil.copy(fs, new Path(shuffleFolder + "/" + ssi1.getId() + "_0.data"), fs,
-        new Path(basePath + "/" + ssi1.getId() + ".cp.data"), false, conf);
-    FileUtil.copy(fs, new Path(shuffleFolder + "/" + ssi1.getId() + "_0.index"), fs,
-        new Path(basePath + "/" + ssi1.getId() + ".cp.index"), false, conf);
-    FileUtil.copy(fs, new Path(shuffleFolder + "/" + ssi2.getId() + "_0.data"), fs,
-        new Path(basePath + "/" + ssi2.getId() + ".cp.data"), false, conf);
-    FileUtil.copy(fs, new Path(shuffleFolder + "/" + ssi2.getId() + "_0.index"), fs,
-        new Path(basePath + "/" + ssi2.getId() + ".cp.index"), false, conf);
+    FileUtil.copy(
+        fs,
+        new Path(shuffleFolder + "/" + ssi1.getId() + "_0.data"),
+        fs,
+        new Path(basePath + "/" + ssi1.getId() + ".cp.data"),
+        false,
+        conf);
+    FileUtil.copy(
+        fs,
+        new Path(shuffleFolder + "/" + ssi1.getId() + "_0.index"),
+        fs,
+        new Path(basePath + "/" + ssi1.getId() + ".cp.index"),
+        false,
+        conf);
+    FileUtil.copy(
+        fs,
+        new Path(shuffleFolder + "/" + ssi2.getId() + "_0.data"),
+        fs,
+        new Path(basePath + "/" + ssi2.getId() + ".cp.data"),
+        false,
+        conf);
+    FileUtil.copy(
+        fs,
+        new Path(shuffleFolder + "/" + ssi2.getId() + "_0.index"),
+        fs,
+        new Path(basePath + "/" + ssi2.getId() + ".cp.index"),
+        false,
+        conf);
 
-    ShuffleReadClientImpl readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(),
-        "appId", 0, 1, 100, 2, 10, 1000,
-        basePath, blockIdBitmap, taskIdBitmap, Lists.newArrayList(ssi1, ssi2),
-        new Configuration(), new DefaultIdHelper());
+    ShuffleReadClientImpl readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            100,
+            2,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1, ssi2),
+            new Configuration(),
+            new DefaultIdHelper());
 
     TestUtils.validateResult(readClient, expectedData);
     readClient.checkProcessedBlockIds();
@@ -158,17 +227,30 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
   @Test
   public void readTest4() throws Exception {
     String basePath = HDFS_URI + "clientReadTest4";
-    HdfsShuffleWriteHandler writeHandler =
-        new HdfsShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi1.getId(), conf);
+    HadoopShuffleWriteHandler writeHandler =
+        new HadoopShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi1.getId(), conf);
 
     Map<Long, byte[]> expectedData = Maps.newHashMap();
     Roaring64NavigableMap blockIdBitmap = Roaring64NavigableMap.bitmapOf();
     Roaring64NavigableMap taskIdBitmap = Roaring64NavigableMap.bitmapOf(0);
     writeTestData(writeHandler, 2, 30, 0, expectedData, blockIdBitmap);
 
-    ShuffleReadClientImpl readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(),
-        "appId", 0, 1, 100, 2, 10, 1000,
-        basePath, blockIdBitmap, taskIdBitmap, Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
+    ShuffleReadClientImpl readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            100,
+            2,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
     Path dataFile = new Path(basePath + "/appId/0/0-1/" + ssi1.getId() + "_0.data");
     // data file is deleted after readClient checkExpectedBlockIds
     fs.delete(dataFile, true);
@@ -193,18 +275,32 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
   @Test
   public void readTest5() throws Exception {
     String basePath = HDFS_URI + "clientReadTest5";
-    HdfsShuffleWriteHandler writeHandler =
-        new HdfsShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi1.getId(), conf);
+    HadoopShuffleWriteHandler writeHandler =
+        new HadoopShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi1.getId(), conf);
 
     Map<Long, byte[]> expectedData = Maps.newHashMap();
     Roaring64NavigableMap blockIdBitmap = Roaring64NavigableMap.bitmapOf();
     Roaring64NavigableMap taskIdBitmap = Roaring64NavigableMap.bitmapOf(0);
     writeTestData(writeHandler, 2, 30, 0, expectedData, blockIdBitmap);
 
-    ShuffleReadClientImpl readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(),
-        "appId", 0, 1, 100, 2, 10, 1000,
-        basePath, blockIdBitmap, taskIdBitmap, Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
-    // index file is deleted after iterator initialization, it should be ok, all index infos are read already
+    ShuffleReadClientImpl readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            100,
+            2,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
+    // index file is deleted after iterator initialization, it should be ok, all index infos are
+    // read already
     Path indexFile = new Path(basePath + "/appId/0/0-1/" + ssi1.getId() + "_0.index");
     fs.delete(indexFile, true);
     readClient.close();
@@ -215,8 +311,8 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
   @Test
   public void readTest7() throws Exception {
     String basePath = HDFS_URI + "clientReadTest7";
-    HdfsShuffleWriteHandler writeHandler =
-        new HdfsShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi1.getId(), conf);
+    HadoopShuffleWriteHandler writeHandler =
+        new HadoopShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi1.getId(), conf);
 
     Map<Long, byte[]> expectedData1 = Maps.newHashMap();
     Map<Long, byte[]> expectedData2 = Maps.newHashMap();
@@ -229,12 +325,38 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
 
     writeTestData(writeHandler, 10, 30, 0, expectedData1, blockIdBitmap1);
 
-    ShuffleReadClientImpl readClient1 = new ShuffleReadClientImpl(StorageType.HDFS.name(),
-        "appId", 0, 0, 100, 2, 10, 100,
-        basePath, blockIdBitmap1, taskIdBitmap, Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
-    final ShuffleReadClientImpl readClient2 = new ShuffleReadClientImpl(StorageType.HDFS.name(),
-        "appId", 0, 1, 100, 2, 10, 100,
-        basePath, blockIdBitmap2, taskIdBitmap, Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
+    ShuffleReadClientImpl readClient1 =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            0,
+            100,
+            2,
+            10,
+            100,
+            basePath,
+            blockIdBitmap1,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
+    final ShuffleReadClientImpl readClient2 =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            100,
+            2,
+            10,
+            100,
+            basePath,
+            blockIdBitmap2,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
     TestUtils.validateResult(readClient1, expectedData1);
     readClient1.checkProcessedBlockIds();
     readClient1.close();
@@ -247,21 +369,46 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
   @Test
   public void readTest8() throws Exception {
     String basePath = HDFS_URI + "clientReadTest8";
-    HdfsShuffleWriteHandler writeHandler =
-        new HdfsShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi1.getId(), conf);
+    HadoopShuffleWriteHandler writeHandler =
+        new HadoopShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi1.getId(), conf);
 
     Map<Long, byte[]> expectedData = Maps.newHashMap();
     Roaring64NavigableMap blockIdBitmap = Roaring64NavigableMap.bitmapOf();
     Roaring64NavigableMap taskIdBitmap = Roaring64NavigableMap.bitmapOf(0);
     writeTestData(writeHandler, 2, 30, 0, expectedData, blockIdBitmap);
 
-    ShuffleReadClientImpl readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(),
-        "appId", 0, 1, 100, 2, 10, 1000,
-        basePath, blockIdBitmap, taskIdBitmap, Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
-    ShuffleReadClientImpl readClient2 = new ShuffleReadClientImpl(StorageType.HDFS.name(),
-        "appId", 0, 1, 100, 2, 10, 1000,
-        basePath, blockIdBitmap, taskIdBitmap, Lists.newArrayList(ssi1, ssi2),
-        new Configuration(), new DefaultIdHelper());
+    ShuffleReadClientImpl readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            100,
+            2,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
+    ShuffleReadClientImpl readClient2 =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            100,
+            2,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1, ssi2),
+            new Configuration(),
+            new DefaultIdHelper());
     // crc32 is incorrect
     try (MockedStatic<ChecksumUtils> checksumUtilsMock = Mockito.mockStatic(ChecksumUtils.class)) {
       checksumUtilsMock.when(() -> ChecksumUtils.getCrc32((ByteBuffer) any())).thenReturn(-1L);
@@ -285,10 +432,22 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
   @Test
   public void readTest9() {
     // empty data
-    ShuffleReadClientImpl readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(),
-        "appId", 0, 1, 100, 2, 10, 1000,
-        "basePath", Roaring64NavigableMap.bitmapOf(), Roaring64NavigableMap.bitmapOf(),
-        Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
+    ShuffleReadClientImpl readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            100,
+            2,
+            10,
+            1000,
+            "basePath",
+            Roaring64NavigableMap.bitmapOf(),
+            Roaring64NavigableMap.bitmapOf(),
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
     assertNull(readClient.readShuffleBlockData());
     readClient.checkProcessedBlockIds();
   }
@@ -296,8 +455,8 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
   @Test
   public void readTest10() throws Exception {
     String basePath = HDFS_URI + "clientReadTest10";
-    HdfsShuffleWriteHandler writeHandler =
-        new HdfsShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi1.getId(), conf);
+    HadoopShuffleWriteHandler writeHandler =
+        new HadoopShuffleWriteHandler("appId", 0, 0, 1, basePath, ssi1.getId(), conf);
 
     Map<Long, byte[]> expectedData = Maps.newHashMap();
     Roaring64NavigableMap blockIdBitmap = Roaring64NavigableMap.bitmapOf();
@@ -309,10 +468,22 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
       wrongBlockIdBitmap.addLong(iter.next() + (1 << Constants.TASK_ATTEMPT_ID_MAX_LENGTH));
     }
 
-    ShuffleReadClientImpl readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(),
-        "appId", 0, 0, 100, 2, 10, 100,
-        basePath, wrongBlockIdBitmap, taskIdBitmap, Lists.newArrayList(ssi1),
-        new Configuration(), new DefaultIdHelper());
+    ShuffleReadClientImpl readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            0,
+            100,
+            2,
+            10,
+            100,
+            basePath,
+            wrongBlockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
     assertNull(readClient.readShuffleBlockData());
     try {
       readClient.checkProcessedBlockIds();
@@ -325,8 +496,8 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
   @Test
   public void readTest11() throws Exception {
     String basePath = HDFS_URI + "clientReadTest11";
-    HdfsShuffleWriteHandler writeHandler =
-        new HdfsShuffleWriteHandler("appId", 0, 1, 1, basePath, ssi1.getId(), conf);
+    HadoopShuffleWriteHandler writeHandler =
+        new HadoopShuffleWriteHandler("appId", 0, 1, 1, basePath, ssi1.getId(), conf);
 
     Map<Long, byte[]> expectedData = Maps.newHashMap();
     Roaring64NavigableMap blockIdBitmap = Roaring64NavigableMap.bitmapOf();
@@ -334,41 +505,106 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
     writeTestData(writeHandler, 10, 30, 0, expectedData, blockIdBitmap);
 
     // test with different indexReadLimit to validate result
-    ShuffleReadClientImpl readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(), "appId", 0, 1, 1, 1,
-        10, 1000, basePath, blockIdBitmap, taskIdBitmap,
-        Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
+    ShuffleReadClientImpl readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            1,
+            1,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
 
     TestUtils.validateResult(readClient, expectedData);
     readClient.checkProcessedBlockIds();
     readClient.close();
 
-    readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(), "appId", 0, 1, 2, 1,
-        10, 1000, basePath, blockIdBitmap, taskIdBitmap,
-        Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
+    readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            2,
+            1,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
 
     TestUtils.validateResult(readClient, expectedData);
     readClient.checkProcessedBlockIds();
     readClient.close();
 
-    readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(), "appId", 0, 1, 3, 1,
-        10, 1000, basePath, blockIdBitmap, taskIdBitmap,
-        Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
+    readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            3,
+            1,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
 
     TestUtils.validateResult(readClient, expectedData);
     readClient.checkProcessedBlockIds();
     readClient.close();
 
-    readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(), "appId", 0, 1, 10, 1,
-        10, 1000, basePath, blockIdBitmap, taskIdBitmap,
-        Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
+    readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            10,
+            1,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
 
     TestUtils.validateResult(readClient, expectedData);
     readClient.checkProcessedBlockIds();
     readClient.close();
 
-    readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(), "appId", 0, 1, 11, 1,
-        10, 1000, basePath, blockIdBitmap, taskIdBitmap,
-        Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
+    readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            11,
+            1,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
 
     TestUtils.validateResult(readClient, expectedData);
     readClient.checkProcessedBlockIds();
@@ -378,8 +614,8 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
   @Test
   public void readTest12() throws Exception {
     String basePath = HDFS_URI + "clientReadTest12";
-    HdfsShuffleWriteHandler writeHandler =
-        new HdfsShuffleWriteHandler("appId", 0, 1, 1, basePath, ssi1.getId(), conf);
+    HadoopShuffleWriteHandler writeHandler =
+        new HadoopShuffleWriteHandler("appId", 0, 1, 1, basePath, ssi1.getId(), conf);
 
     Map<Long, byte[]> expectedData = Maps.newHashMap();
     final Roaring64NavigableMap blockIdBitmap = Roaring64NavigableMap.bitmapOf();
@@ -389,9 +625,22 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
     writeTestData(writeHandler, 5, 30, 1, expectedData, blockIdBitmap);
 
     // unexpected taskAttemptId should be filtered
-    ShuffleReadClientImpl readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(), "appId", 0, 1, 100, 1,
-        10, 1000, basePath, blockIdBitmap, taskIdBitmap,
-        Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
+    ShuffleReadClientImpl readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            100,
+            1,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
 
     TestUtils.validateResult(readClient, expectedData);
     assertEquals(15, readClient.getProcessedBlockIds().getLongCardinality());
@@ -402,8 +651,8 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
   @Test
   public void readTest13() throws Exception {
     String basePath = HDFS_URI + "clientReadTest13";
-    HdfsShuffleWriteHandler writeHandler =
-        new HdfsShuffleWriteHandler("appId", 0, 1, 1, basePath, ssi1.getId(), conf);
+    HadoopShuffleWriteHandler writeHandler =
+        new HadoopShuffleWriteHandler("appId", 0, 1, 1, basePath, ssi1.getId(), conf);
 
     Map<Long, byte[]> expectedData = Maps.newHashMap();
     final Roaring64NavigableMap blockIdBitmap = Roaring64NavigableMap.bitmapOf();
@@ -416,9 +665,22 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
     writeTestData(writeHandler, 5, 30, 3, expectedData, blockIdBitmap);
 
     // unexpected taskAttemptId should be filtered
-    ShuffleReadClientImpl readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(), "appId", 0, 1, 100, 1,
-        10, 1000, basePath, blockIdBitmap, taskIdBitmap,
-        Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
+    ShuffleReadClientImpl readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            100,
+            1,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
 
     TestUtils.validateResult(readClient, expectedData);
     assertEquals(20, readClient.getProcessedBlockIds().getLongCardinality());
@@ -429,8 +691,8 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
   @Test
   public void readTest14() throws Exception {
     String basePath = HDFS_URI + "clientReadTest14";
-    HdfsShuffleWriteHandler writeHandler =
-        new HdfsShuffleWriteHandler("appId", 0, 1, 1, basePath, ssi1.getId(), conf);
+    HadoopShuffleWriteHandler writeHandler =
+        new HadoopShuffleWriteHandler("appId", 0, 1, 1, basePath, ssi1.getId(), conf);
 
     Map<Long, byte[]> expectedData = Maps.newHashMap();
     final Roaring64NavigableMap blockIdBitmap = Roaring64NavigableMap.bitmapOf();
@@ -440,9 +702,22 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
     writeTestData(writeHandler, 5, 30, 2, expectedData, blockIdBitmap);
 
     // unexpected taskAttemptId should be filtered
-    ShuffleReadClientImpl readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(), "appId", 0, 1, 100, 1,
-        10, 1000, basePath, blockIdBitmap, taskIdBitmap,
-        Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
+    ShuffleReadClientImpl readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            100,
+            1,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
 
     TestUtils.validateResult(readClient, expectedData);
     assertEquals(15, readClient.getProcessedBlockIds().getLongCardinality());
@@ -453,8 +728,8 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
   @Test
   public void readTest15() throws Exception {
     String basePath = HDFS_URI + "clientReadTest15";
-    HdfsShuffleWriteHandler writeHandler =
-        new HdfsShuffleWriteHandler("appId", 0, 1, 1, basePath, ssi1.getId(), conf);
+    HadoopShuffleWriteHandler writeHandler =
+        new HadoopShuffleWriteHandler("appId", 0, 1, 1, basePath, ssi1.getId(), conf);
 
     Map<Long, byte[]> expectedData = Maps.newHashMap();
     final Roaring64NavigableMap blockIdBitmap = Roaring64NavigableMap.bitmapOf();
@@ -466,9 +741,22 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
     writeTestData(writeHandler, 5, 30, 0, expectedData, blockIdBitmap);
     writeTestData(writeHandler, 5, 30, 0, Maps.newHashMap(), Roaring64NavigableMap.bitmapOf());
     // unexpected taskAttemptId should be filtered
-    ShuffleReadClientImpl readClient = new ShuffleReadClientImpl(StorageType.HDFS.name(), "appId", 0, 1, 100, 1,
-        10, 1000, basePath, blockIdBitmap, taskIdBitmap,
-        Lists.newArrayList(ssi1), new Configuration(), new DefaultIdHelper());
+    ShuffleReadClientImpl readClient =
+        new ShuffleReadClientImpl(
+            StorageType.HDFS.name(),
+            "appId",
+            0,
+            1,
+            100,
+            1,
+            10,
+            1000,
+            basePath,
+            blockIdBitmap,
+            taskIdBitmap,
+            Lists.newArrayList(ssi1),
+            new Configuration(),
+            new DefaultIdHelper());
 
     TestUtils.validateResult(readClient, expectedData);
     assertEquals(25, readClient.getProcessedBlockIds().getLongCardinality());
@@ -477,18 +765,24 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
   }
 
   private void writeTestData(
-      HdfsShuffleWriteHandler writeHandler,
-      int num, int length, long taskAttemptId,
+      HadoopShuffleWriteHandler writeHandler,
+      int num,
+      int length,
+      long taskAttemptId,
       Map<Long, byte[]> expectedData,
-      Roaring64NavigableMap blockIdBitmap) throws Exception {
+      Roaring64NavigableMap blockIdBitmap)
+      throws Exception {
     List<ShufflePartitionedBlock> blocks = Lists.newArrayList();
     for (int i = 0; i < num; i++) {
       byte[] buf = new byte[length];
       new Random().nextBytes(buf);
-      long blockId = (ATOMIC_LONG.getAndIncrement()
-          << (Constants.PARTITION_ID_MAX_LENGTH + Constants.TASK_ATTEMPT_ID_MAX_LENGTH)) + taskAttemptId;
-      blocks.add(new ShufflePartitionedBlock(
-          length, length, ChecksumUtils.getCrc32(buf), blockId, taskAttemptId, buf));
+      long blockId =
+          (ATOMIC_LONG.getAndIncrement()
+                  << (Constants.PARTITION_ID_MAX_LENGTH + Constants.TASK_ATTEMPT_ID_MAX_LENGTH))
+              + taskAttemptId;
+      blocks.add(
+          new ShufflePartitionedBlock(
+              length, length, ChecksumUtils.getCrc32(buf), blockId, taskAttemptId, buf));
       expectedData.put(blockId, buf);
       blockIdBitmap.addLong(blockId);
     }
@@ -496,18 +790,24 @@ public class ShuffleReadClientImplTest extends HdfsTestBase {
   }
 
   private void writeDuplicatedData(
-      HdfsShuffleWriteHandler writeHandler,
-      int num, int length, long taskAttemptId,
+      HadoopShuffleWriteHandler writeHandler,
+      int num,
+      int length,
+      long taskAttemptId,
       Map<Long, byte[]> expectedData,
-      Roaring64NavigableMap blockIdBitmap) throws Exception {
+      Roaring64NavigableMap blockIdBitmap)
+      throws Exception {
     List<ShufflePartitionedBlock> blocks = Lists.newArrayList();
     for (int i = 0; i < num; i++) {
       byte[] buf = new byte[length];
       new Random().nextBytes(buf);
-      long blockId = (ATOMIC_LONG.incrementAndGet()
-          << (Constants.PARTITION_ID_MAX_LENGTH + Constants.TASK_ATTEMPT_ID_MAX_LENGTH)) + taskAttemptId;
-      ShufflePartitionedBlock spb = new ShufflePartitionedBlock(
-          length, length, ChecksumUtils.getCrc32(buf), blockId, taskAttemptId, buf);
+      long blockId =
+          (ATOMIC_LONG.incrementAndGet()
+                  << (Constants.PARTITION_ID_MAX_LENGTH + Constants.TASK_ATTEMPT_ID_MAX_LENGTH))
+              + taskAttemptId;
+      ShufflePartitionedBlock spb =
+          new ShufflePartitionedBlock(
+              length, length, ChecksumUtils.getCrc32(buf), blockId, taskAttemptId, buf);
       blocks.add(spb);
       blocks.add(spb);
       expectedData.put(blockId, buf);
