@@ -52,21 +52,29 @@ public class ShuffleWriteClientImplTest {
     ShuffleWriteClientImpl spyClient = Mockito.spy(shuffleWriteClient);
     doReturn(mockShuffleServerClient).when(spyClient).getShuffleServerClient(any());
 
-    when(mockShuffleServerClient.sendShuffleData(any())).thenAnswer((Answer<String>) invocation -> {
-      Thread.sleep(50000);
-      return "ABCD1234";
-    });
+    when(mockShuffleServerClient.sendShuffleData(any()))
+        .thenAnswer(
+            (Answer<String>)
+                invocation -> {
+                  Thread.sleep(50000);
+                  return "ABCD1234";
+                });
 
     List<ShuffleServerInfo> shuffleServerInfoList =
         Lists.newArrayList(new ShuffleServerInfo("id", "host", 0));
-    List<ShuffleBlockInfo> shuffleBlockInfoList = Lists.newArrayList(new ShuffleBlockInfo(
-        0, 0, 10, 10, 10, new byte[]{1}, shuffleServerInfoList, 10, 100, 0));
+    List<ShuffleBlockInfo> shuffleBlockInfoList =
+        Lists.newArrayList(
+            new ShuffleBlockInfo(
+                0, 0, 10, 10, 10, new byte[] {1}, shuffleServerInfoList, 10, 100, 0));
 
     // It should directly exit and wont do rpc request.
-    Awaitility.await().timeout(1, TimeUnit.SECONDS).until(() -> {
-      spyClient.sendShuffleData("appId", shuffleBlockInfoList, () -> true);
-      return true;
-    });
+    Awaitility.await()
+        .timeout(1, TimeUnit.SECONDS)
+        .until(
+            () -> {
+              spyClient.sendShuffleData("appId", shuffleBlockInfoList, () -> true);
+              return true;
+            });
   }
 
   @Test
@@ -76,14 +84,17 @@ public class ShuffleWriteClientImplTest {
     ShuffleServerClient mockShuffleServerClient = mock(ShuffleServerClient.class);
     ShuffleWriteClientImpl spyClient = Mockito.spy(shuffleWriteClient);
     doReturn(mockShuffleServerClient).when(spyClient).getShuffleServerClient(any());
-    when(mockShuffleServerClient.sendShuffleData(any())).thenReturn(
-        new RssSendShuffleDataResponse(StatusCode.NO_BUFFER));
+    when(mockShuffleServerClient.sendShuffleData(any()))
+        .thenReturn(new RssSendShuffleDataResponse(StatusCode.NO_BUFFER));
 
     List<ShuffleServerInfo> shuffleServerInfoList =
         Lists.newArrayList(new ShuffleServerInfo("id", "host", 0));
-    List<ShuffleBlockInfo> shuffleBlockInfoList = Lists.newArrayList(new ShuffleBlockInfo(
-        0, 0, 10, 10, 10, new byte[]{1}, shuffleServerInfoList, 10, 100, 0));
-    SendShuffleDataResult result = spyClient.sendShuffleData("appId", shuffleBlockInfoList, () -> false);
+    List<ShuffleBlockInfo> shuffleBlockInfoList =
+        Lists.newArrayList(
+            new ShuffleBlockInfo(
+                0, 0, 10, 10, 10, new byte[] {1}, shuffleServerInfoList, 10, 100, 0));
+    SendShuffleDataResult result =
+        spyClient.sendShuffleData("appId", shuffleBlockInfoList, () -> false);
 
     assertTrue(result.getFailedBlockIds().contains(10L));
   }
@@ -105,6 +116,12 @@ public class ShuffleWriteClientImplTest {
     shuffleWriteClient.addShuffleServer(appId1, 1, server1);
     shuffleWriteClient.unregisterShuffle(appId1, 1);
     assertEquals(1, shuffleWriteClient.getAllShuffleServers(appId1).size());
+    shuffleWriteClient.unregisterShuffle(appId1);
+    assertEquals(0, shuffleWriteClient.getAllShuffleServers(appId1).size());
+    shuffleWriteClient.addShuffleServer(appId2, 2, server1);
+    assertEquals(2, shuffleWriteClient.getAllShuffleServers(appId2).size());
+    shuffleWriteClient.unregisterShuffle(appId2);
+    assertEquals(0, shuffleWriteClient.getAllShuffleServers(appId2).size());
   }
 
   @Test
@@ -114,34 +131,50 @@ public class ShuffleWriteClientImplTest {
     ShuffleServerClient mockShuffleServerClient = mock(ShuffleServerClient.class);
     ShuffleWriteClientImpl spyClient = Mockito.spy(shuffleWriteClient);
     doReturn(mockShuffleServerClient).when(spyClient).getShuffleServerClient(any());
-    when(mockShuffleServerClient.sendShuffleData(any())).thenReturn(
-        new RssSendShuffleDataResponse(StatusCode.NO_BUFFER),
-        new RssSendShuffleDataResponse(StatusCode.SUCCESS),
-        new RssSendShuffleDataResponse(StatusCode.SUCCESS));
+    when(mockShuffleServerClient.sendShuffleData(any()))
+        .thenReturn(
+            new RssSendShuffleDataResponse(StatusCode.NO_BUFFER),
+            new RssSendShuffleDataResponse(StatusCode.SUCCESS),
+            new RssSendShuffleDataResponse(StatusCode.SUCCESS));
 
     String appId = "testSendDataWithDefectiveServers_appId";
     ShuffleServerInfo ssi1 = new ShuffleServerInfo("127.0.0.1", 0);
     ShuffleServerInfo ssi2 = new ShuffleServerInfo("127.0.0.1", 1);
     ShuffleServerInfo ssi3 = new ShuffleServerInfo("127.0.0.1", 2);
-    List<ShuffleServerInfo> shuffleServerInfoList =
-        Lists.newArrayList(ssi1, ssi2, ssi3);
-    List<ShuffleBlockInfo> shuffleBlockInfoList = Lists.newArrayList(new ShuffleBlockInfo(
-        0, 0, 10, 10, 10, new byte[]{1}, shuffleServerInfoList, 10, 100, 0));
-    SendShuffleDataResult result = spyClient.sendShuffleData(appId, shuffleBlockInfoList, () -> false);
+    List<ShuffleServerInfo> shuffleServerInfoList = Lists.newArrayList(ssi1, ssi2, ssi3);
+    List<ShuffleBlockInfo> shuffleBlockInfoList =
+        Lists.newArrayList(
+            new ShuffleBlockInfo(
+                0, 0, 10, 10, 10, new byte[] {1}, shuffleServerInfoList, 10, 100, 0));
+    SendShuffleDataResult result =
+        spyClient.sendShuffleData(appId, shuffleBlockInfoList, () -> false);
     assertEquals(0, result.getFailedBlockIds().size());
 
     // Send data for the second time, the first shuffle server will be moved to the last.
-    when(mockShuffleServerClient.sendShuffleData(any())).thenReturn(
-        new RssSendShuffleDataResponse(StatusCode.SUCCESS),
-        new RssSendShuffleDataResponse(StatusCode.SUCCESS));
+    when(mockShuffleServerClient.sendShuffleData(any()))
+        .thenReturn(
+            new RssSendShuffleDataResponse(StatusCode.SUCCESS),
+            new RssSendShuffleDataResponse(StatusCode.SUCCESS));
     List<ShuffleServerInfo> excludeServers = new ArrayList<>();
-    spyClient.genServerToBlocks(shuffleBlockInfoList.get(0), shuffleServerInfoList,
-        2, excludeServers, Maps.newHashMap(), Maps.newHashMap(), true);
+    spyClient.genServerToBlocks(
+        shuffleBlockInfoList.get(0),
+        shuffleServerInfoList,
+        2,
+        excludeServers,
+        Maps.newHashMap(),
+        Maps.newHashMap(),
+        true);
     assertEquals(2, excludeServers.size());
     assertEquals(ssi2, excludeServers.get(0));
     assertEquals(ssi3, excludeServers.get(1));
-    spyClient.genServerToBlocks(shuffleBlockInfoList.get(0), shuffleServerInfoList,
-        1, excludeServers, Maps.newHashMap(), Maps.newHashMap(), false);
+    spyClient.genServerToBlocks(
+        shuffleBlockInfoList.get(0),
+        shuffleServerInfoList,
+        1,
+        excludeServers,
+        Maps.newHashMap(),
+        Maps.newHashMap(),
+        false);
     assertEquals(3, excludeServers.size());
     assertEquals(ssi1, excludeServers.get(2));
     result = spyClient.sendShuffleData(appId, shuffleBlockInfoList, () -> false);
@@ -149,25 +182,40 @@ public class ShuffleWriteClientImplTest {
 
     // Send data for the third time, the first server will be removed from the defectiveServers
     // and the second server will be added to the defectiveServers.
-    when(mockShuffleServerClient.sendShuffleData(any())).thenReturn(
-        new RssSendShuffleDataResponse(StatusCode.NO_BUFFER),
-        new RssSendShuffleDataResponse(StatusCode.SUCCESS),
-        new RssSendShuffleDataResponse(StatusCode.SUCCESS));
+    when(mockShuffleServerClient.sendShuffleData(any()))
+        .thenReturn(
+            new RssSendShuffleDataResponse(StatusCode.NO_BUFFER),
+            new RssSendShuffleDataResponse(StatusCode.SUCCESS),
+            new RssSendShuffleDataResponse(StatusCode.SUCCESS));
     List<ShuffleServerInfo> shuffleServerInfoList2 = Lists.newArrayList(ssi2, ssi1, ssi3);
-    List<ShuffleBlockInfo> shuffleBlockInfoList2 = Lists.newArrayList(new ShuffleBlockInfo(0, 0, 10, 10, 10,
-        new byte[]{1}, shuffleServerInfoList2, 10, 100, 0));
+    List<ShuffleBlockInfo> shuffleBlockInfoList2 =
+        Lists.newArrayList(
+            new ShuffleBlockInfo(
+                0, 0, 10, 10, 10, new byte[] {1}, shuffleServerInfoList2, 10, 100, 0));
     result = spyClient.sendShuffleData(appId, shuffleBlockInfoList2, () -> false);
     assertEquals(0, result.getFailedBlockIds().size());
     assertEquals(1, spyClient.getDefectiveServers().size());
     assertEquals(ssi2, spyClient.getDefectiveServers().toArray()[0]);
     excludeServers = new ArrayList<>();
-    spyClient.genServerToBlocks(shuffleBlockInfoList.get(0), shuffleServerInfoList,
-        2, excludeServers, Maps.newHashMap(), Maps.newHashMap(), true);
+    spyClient.genServerToBlocks(
+        shuffleBlockInfoList.get(0),
+        shuffleServerInfoList,
+        2,
+        excludeServers,
+        Maps.newHashMap(),
+        Maps.newHashMap(),
+        true);
     assertEquals(2, excludeServers.size());
     assertEquals(ssi1, excludeServers.get(0));
     assertEquals(ssi3, excludeServers.get(1));
-    spyClient.genServerToBlocks(shuffleBlockInfoList.get(0), shuffleServerInfoList,
-        1, excludeServers, Maps.newHashMap(), Maps.newHashMap(), false);
+    spyClient.genServerToBlocks(
+        shuffleBlockInfoList.get(0),
+        shuffleServerInfoList,
+        1,
+        excludeServers,
+        Maps.newHashMap(),
+        Maps.newHashMap(),
+        false);
     assertEquals(3, excludeServers.size());
     assertEquals(ssi2, excludeServers.get(2));
 
@@ -175,11 +223,16 @@ public class ShuffleWriteClientImplTest {
     spyClient.getDefectiveServers().add(ssi1);
     assertEquals(2, spyClient.getDefectiveServers().size());
     excludeServers = new ArrayList<>();
-    spyClient.genServerToBlocks(shuffleBlockInfoList.get(0), shuffleServerInfoList,
-        2, excludeServers, Maps.newHashMap(), Maps.newHashMap(), true);
+    spyClient.genServerToBlocks(
+        shuffleBlockInfoList.get(0),
+        shuffleServerInfoList,
+        2,
+        excludeServers,
+        Maps.newHashMap(),
+        Maps.newHashMap(),
+        true);
     assertEquals(2, excludeServers.size());
     assertEquals(ssi3, excludeServers.get(0));
     assertEquals(ssi1, excludeServers.get(1));
   }
-
 }
