@@ -17,26 +17,32 @@
 
 package org.apache.uniffle.coordinator;
 
+import java.io.Closeable;
 import java.net.URI;
 import java.net.URISyntaxException;
+import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
+import java.util.regex.Pattern;
 
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
 import com.google.common.collect.Sets;
+import org.apache.commons.lang3.Range;
 import org.apache.commons.lang3.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import org.apache.uniffle.common.Application;
 import org.apache.uniffle.common.RemoteStorageInfo;
 import org.apache.uniffle.common.util.Constants;
+import org.apache.uniffle.common.util.JavaUtils;
 import org.apache.uniffle.common.util.ThreadUtils;
 import org.apache.uniffle.coordinator.access.checker.AccessQuotaChecker;
 import org.apache.uniffle.coordinator.metric.CoordinatorMetrics;
@@ -46,7 +52,7 @@ import org.apache.uniffle.coordinator.strategy.storage.RankValue;
 import org.apache.uniffle.coordinator.strategy.storage.SelectStorageStrategy;
 import org.apache.uniffle.coordinator.util.CoordinatorUtils;
 
-public class ApplicationManager {
+public class ApplicationManager implements Closeable {
 
   private static final Logger LOG = LoggerFactory.getLogger(ApplicationManager.class);
   // TODO: Add anomaly detection for other storage
@@ -59,26 +65,35 @@ public class ApplicationManager {
   private final Map<String, RemoteStorageInfo> appIdToRemoteStorageInfo;
   // store remote path -> application count for assignment strategy
   private final Map<String, RankValue> remoteStoragePathRankValue;
-  private final Map<String, String> remoteStorageToHost = Maps.newConcurrentMap();
+  private final Map<String, String> remoteStorageToHost = JavaUtils.newConcurrentMap();
   private final Map<String, RemoteStorageInfo> availableRemoteStorageInfo;
   private final ScheduledExecutorService detectStorageScheduler;
-  private Map<String, Map<String, Long>> currentUserAndApp = Maps.newConcurrentMap();
-  private Map<String, String> appIdToUser = Maps.newConcurrentMap();
+  private final ScheduledExecutorService checkAppScheduler;
+  private Map<String, Map<String, Long>> currentUserAndApp = JavaUtils.newConcurrentMap();
+  private Map<String, String> appIdToUser = JavaUtils.newConcurrentMap();
   private QuotaManager quotaManager;
   // it's only for test case to check if status check has problem
   private boolean hasErrorInStatusCheck = false;
 
   public ApplicationManager(CoordinatorConf conf) {
     storageStrategy = conf.get(CoordinatorConf.COORDINATOR_REMOTE_STORAGE_SELECT_STRATEGY);
-    appIdToRemoteStorageInfo = Maps.newConcurrentMap();
-    remoteStoragePathRankValue = Maps.newConcurrentMap();
-    availableRemoteStorageInfo = Maps.newConcurrentMap();
+    appIdToRemoteStorageInfo = JavaUtils.newConcurrentMap();
+    remoteStoragePathRankValue = JavaUtils.newConcurrentMap();
+    availableRemoteStorageInfo = JavaUtils.newConcurrentMap();
     if (StrategyName.IO_SAMPLE == storageStrategy) {
-      selectStorageStrategy = new LowestIOSampleCostSelectStorageStrategy(remoteStoragePathRankValue,
-          appIdToRemoteStorageInfo, availableRemoteStorageInfo, conf);
+      selectStorageStrategy =
+          new LowestIOSampleCostSelectStorageStrategy(
+              remoteStoragePathRankValue,
+              appIdToRemoteStorageInfo,
+              availableRemoteStorageInfo,
+              conf);
     } else if (StrategyName.APP_BALANCE == storageStrategy) {
-      selectStorageStrategy = new AppBalanceSelectStorageStrategy(remoteStoragePathRankValue,
-          appIdToRemoteStorageInfo, availableRemoteStorageInfo, conf);
+      selectStorageStrategy =
+          new AppBalanceSelectStorageStrategy(
+              remoteStoragePathRankValue,
+              appIdToRemoteStorageInfo,
+              availableRemoteStorageInfo,
+              conf);
     } else {
       throw new UnsupportedOperationException("Unsupported selected storage strategy.");
     }
@@ -93,22 +108,27 @@ public class ApplicationManager {
       }
     }
     // the thread for checking application status
-    ScheduledExecutorService scheduledExecutorService = Executors.newSingleThreadScheduledExecutor(
-        ThreadUtils.getThreadFactory("ApplicationManager-%d"));
-    scheduledExecutorService.scheduleAtFixedRate(
+    checkAppScheduler = ThreadUtils.getDaemonSingleThreadScheduledExecutor("ApplicationManager");
+    checkAppScheduler.scheduleAtFixedRate(
         this::statusCheck, expired / 2, expired / 2, TimeUnit.MILLISECONDS);
     // the thread for checking if the storage is normal
-    detectStorageScheduler = Executors.newSingleThreadScheduledExecutor(
-        ThreadUtils.getThreadFactory("detectStoragesScheduler-%d"));
+    detectStorageScheduler =
+        ThreadUtils.getDaemonSingleThreadScheduledExecutor("detectStoragesScheduler");
     // should init later than the refreshRemoteStorage init
-    detectStorageScheduler.scheduleAtFixedRate(selectStorageStrategy::detectStorage, 1000,
-        conf.getLong(CoordinatorConf.COORDINATOR_REMOTE_STORAGE_SCHEDULE_TIME), TimeUnit.MILLISECONDS);
+    detectStorageScheduler.scheduleAtFixedRate(
+        selectStorageStrategy::detectStorage,
+        1000,
+        conf.getLong(CoordinatorConf.COORDINATOR_REMOTE_STORAGE_SCHEDULE_TIME),
+        TimeUnit.MILLISECONDS);
   }
 
   public void registerApplicationInfo(String appId, String user) {
-    // using computeIfAbsent is just for MR and spark which is used RssShuffleManager as implementation class
-    // in such case by default, there is no currentUserAndApp, so a unified user implementation named "user" is used.
-    Map<String, Long> appAndTime = currentUserAndApp.computeIfAbsent(user, x -> Maps.newConcurrentMap());
+    // using computeIfAbsent is just for MR and spark which is used RssShuffleManager as
+    // implementation class
+    // in such case by default, there is no currentUserAndApp, so a unified user implementation
+    // named "user" is used.
+    Map<String, Long> appAndTime =
+        currentUserAndApp.computeIfAbsent(user, x -> JavaUtils.newConcurrentMap());
     appIdToUser.put(appId, user);
     if (!appAndTime.containsKey(appId)) {
       CoordinatorMetrics.counterTotalAppNum.inc();
@@ -136,17 +156,23 @@ public class ApplicationManager {
     if (!StringUtils.isEmpty(remoteStoragePath)) {
       LOG.info("Refresh remote storage with {} {}", remoteStoragePath, remoteStorageConf);
       Set<String> paths = Sets.newHashSet(remoteStoragePath.split(Constants.COMMA_SPLIT_CHAR));
-      Map<String, Map<String, String>> confKVs = CoordinatorUtils.extractRemoteStorageConf(remoteStorageConf);
+      Map<String, Map<String, String>> confKVs =
+          CoordinatorUtils.extractRemoteStorageConf(remoteStorageConf);
       // add remote path if not exist
       for (String path : paths) {
         if (!availableRemoteStorageInfo.containsKey(path)) {
-          remoteStoragePathRankValue.putIfAbsent(path, new RankValue(0));
-          // refreshRemoteStorage is designed without multiple thread problem
-          // metrics shouldn't be added duplicated
-          addRemoteStorageMetrics(path);
+          remoteStoragePathRankValue.computeIfAbsent(
+              path,
+              key -> {
+                // refreshRemoteStorage is designed without multiple thread problem
+                // metrics shouldn't be added duplicated
+                addRemoteStorageMetrics(path);
+                return new RankValue(0);
+              });
         }
         String storageHost = getStorageHost(path);
-        RemoteStorageInfo rsInfo = new RemoteStorageInfo(path, confKVs.getOrDefault(storageHost, Maps.newHashMap()));
+        RemoteStorageInfo rsInfo =
+            new RemoteStorageInfo(path, confKVs.getOrDefault(storageHost, Maps.newHashMap()));
         availableRemoteStorageInfo.put(path, rsInfo);
       }
       // remove unused remote path if exist
@@ -190,7 +216,8 @@ public class ApplicationManager {
     } else {
       // it may be happened when assignment remote storage
       // and refresh remote storage at the same time
-      LOG.warn("Remote storage path lost during assignment: {} doesn't exist, reset it to 1",
+      LOG.warn(
+          "Remote storage path lost during assignment: {} doesn't exist, reset it to 1",
           remoteStoragePath);
       remoteStoragePathRankValue.put(remoteStoragePath, new RankValue(1));
     }
@@ -203,8 +230,10 @@ public class ApplicationManager {
       if (atomic != null) {
         double count = atomic.getAppNum().decrementAndGet();
         if (count < 0) {
-          LOG.warn("Unexpected counter for remote storage: {}, which is {}, reset to 0",
-              storagePath, count);
+          LOG.warn(
+              "Unexpected counter for remote storage: {}, which is {}, reset to 0",
+              storagePath,
+              count);
           atomic.getAppNum().set(0);
         }
       } else {
@@ -220,8 +249,9 @@ public class ApplicationManager {
 
   public synchronized void removePathFromCounter(String storagePath) {
     RankValue atomic = remoteStoragePathRankValue.get(storagePath);
-    // The time spent reading and writing cannot be used to determine whether the current path is still used by apps.
-    // Therefore, determine whether the HDFS path is still used by the number of apps
+    // The time spent reading and writing cannot be used to determine whether the current path is
+    // still used by apps.
+    // Therefore, determine whether the Hadoop FS path is still used by the number of apps
     if (atomic != null && atomic.getAppNum().get() == 0) {
       remoteStoragePathRankValue.remove(storagePath);
     }
@@ -262,11 +292,13 @@ public class ApplicationManager {
     detectStorageScheduler.shutdownNow();
   }
 
-  private void statusCheck() {
+  protected void statusCheck() {
     List<Map<String, Long>> appAndNums = Lists.newArrayList(currentUserAndApp.values());
     Map<String, Long> appIds = Maps.newHashMap();
-    // The reason for setting an expired uuid here is that there is a scenario where accessCluster succeeds,
-    // but the registration of shuffle fails, resulting in no normal heartbeat, and no normal update of uuid to appId.
+    // The reason for setting an expired uuid here is that there is a scenario where accessCluster
+    // succeeds,
+    // but the registration of shuffle fails, resulting in no normal heartbeat, and no normal update
+    // of uuid to appId.
     // Therefore, an expiration time is set to automatically remove expired uuids
     Set<String> expiredAppIds = Sets.newHashSet();
     try {
@@ -282,9 +314,9 @@ public class ApplicationManager {
           }
         }
       }
-      LOG.info("Start to check status for " + appIds.size() + " applications");
+      LOG.info("Start to check status for {} applications.", appIds.size());
       for (String appId : expiredAppIds) {
-        LOG.info("Remove expired application:" + appId);
+        LOG.info("Remove expired application : {}.", appId);
         appIds.remove(appId);
         if (appIdToRemoteStorageInfo.containsKey(appId)) {
           decRemoteStorageCounter(appIdToRemoteStorageInfo.get(appId).getPath());
@@ -293,6 +325,9 @@ public class ApplicationManager {
       }
       CoordinatorMetrics.gaugeRunningAppNum.set(appIds.size());
       updateRemoteStorageMetrics();
+      if (quotaManager != null) {
+        quotaManager.updateQuotaMetrics();
+      }
     } catch (Exception e) {
       // the flag is only for test case
       hasErrorInStatusCheck = true;
@@ -304,8 +339,8 @@ public class ApplicationManager {
     for (String remoteStoragePath : availableRemoteStorageInfo.keySet()) {
       try {
         String storageHost = getStorageHost(remoteStoragePath);
-        CoordinatorMetrics.updateDynamicGaugeForRemoteStorage(storageHost,
-            remoteStoragePathRankValue.get(remoteStoragePath).getAppNum().get());
+        CoordinatorMetrics.updateDynamicGaugeForRemoteStorage(
+            storageHost, remoteStoragePathRankValue.get(remoteStoragePath).getAppNum().get());
       } catch (Exception e) {
         LOG.warn("Update remote storage metrics for {} failed ", remoteStoragePath);
       }
@@ -335,6 +370,127 @@ public class ApplicationManager {
     return storageHost;
   }
 
+  /**
+   * Get Applications, The list contains applicationId, user, lastHeartBeatTime, remoteStoragePath.
+   *
+   * <p>We have set 6 criteria for filtering applicationId, and these criteria are in an 'AND'
+   * relationship. All the criteria must be met for the applicationId to be selected.
+   *
+   * @param appIds Application List.
+   * @param pageSize Items per page.
+   * @param currentPage The number of pages to be queried.
+   * @param pHeartBeatStartTime heartbeat start time.
+   * @param pHeartBeatEndTime heartbeat end time.
+   * @param appIdRegex applicationId regular expression.
+   * @return Applications.
+   */
+  public List<Application> getApplications(
+      Set<String> appIds,
+      int pageSize,
+      int currentPage,
+      String pHeartBeatStartTime,
+      String pHeartBeatEndTime,
+      String appIdRegex) {
+    List<Application> applications = new ArrayList<>();
+    for (Map.Entry<String, Map<String, Long>> entry : currentUserAndApp.entrySet()) {
+      String user = entry.getKey();
+      Map<String, Long> apps = entry.getValue();
+      apps.forEach(
+          (appId, heartBeatTime) -> {
+            // Filter condition 1: Check whether applicationId is included in the filter list.
+            boolean match = appIds.size() == 0 || appIds.contains(appId);
+
+            // Filter condition 2: whether it meets the applicationId rule.
+            if (StringUtils.isNotBlank(appIdRegex) && match) {
+              match = match && matchApplicationId(appId, appIdRegex);
+            }
+
+            // Filter condition 3: Determine whether the start and
+            // end of the heartbeat time are in line with expectations.
+            if (StringUtils.isNotBlank(pHeartBeatStartTime)
+                || StringUtils.isNotBlank(pHeartBeatEndTime)) {
+              match =
+                  matchHeartBeatStartTimeAndEndTime(
+                      pHeartBeatStartTime, pHeartBeatEndTime, heartBeatTime);
+            }
+
+            // If it meets expectations, add to the list to be returned.
+            if (match) {
+              RemoteStorageInfo remoteStorageInfo =
+                  appIdToRemoteStorageInfo.getOrDefault(appId, null);
+              Application application =
+                  new Application.Builder()
+                      .applicationId(appId)
+                      .user(user)
+                      .lastHeartBeatTime(heartBeatTime)
+                      .remoteStoragePath(remoteStorageInfo)
+                      .build();
+              applications.add(application);
+            }
+          });
+    }
+    Collections.sort(applications);
+    int startIndex = (currentPage - 1) * pageSize;
+    int endIndex = Math.min(startIndex + pageSize, applications.size());
+
+    LOG.info("getApplications >> appIds = {}.", applications);
+    return applications.subList(startIndex, endIndex);
+  }
+
+  /**
+   * Based on the regular expression, determine if the applicationId matches the regular expression.
+   *
+   * @param applicationId applicationId
+   * @param regex regular expression pattern.
+   * @return If it returns true, it means the regular expression successfully matches the
+   *     applicationId; otherwise, the regular expression fails to match the applicationId.
+   */
+  private boolean matchApplicationId(String applicationId, String regex) {
+    Pattern pattern = Pattern.compile(regex);
+    return pattern.matcher(applicationId).matches();
+  }
+
+  /**
+   * Filter heartbeat time based on query conditions.
+   *
+   * @param pStartTime heartbeat start time.
+   * @param pEndTime heartbeat end time.
+   * @param appHeartBeatTime application HeartBeatTime
+   * @return Returns true if the heartbeat time is within the given query range, otherwise returns
+   *     false.
+   */
+  private boolean matchHeartBeatStartTimeAndEndTime(
+      String pStartTime, String pEndTime, long appHeartBeatTime) {
+    long startTime = 0;
+    long endTime = Long.MAX_VALUE;
+
+    if (StringUtils.isNotBlank(pStartTime)) {
+      startTime = parseLongValue(pStartTime, "heartBeatStartTime");
+    }
+
+    if (StringUtils.isNotBlank(pEndTime)) {
+      endTime = parseLongValue(pEndTime, "heartBeatEndTime");
+    }
+
+    Range<Long> heartBeatTime = Range.between(startTime, endTime);
+    return heartBeatTime.contains(appHeartBeatTime);
+  }
+
+  /**
+   * Convert String to Long.
+   *
+   * @param strValue String Value
+   * @param fieldName Field Name
+   * @return Long value.
+   */
+  private long parseLongValue(String strValue, String fieldName) {
+    try {
+      return Long.parseLong(strValue);
+    } catch (NumberFormatException e) {
+      throw new NumberFormatException(fieldName + " value must be a number!");
+    }
+  }
+
   public Map<String, Integer> getDefaultUserApps() {
     return quotaManager.getDefaultUserApps();
   }
@@ -347,6 +503,15 @@ public class ApplicationManager {
     return REMOTE_PATH_SCHEMA;
   }
 
+  public void close() {
+    if (detectStorageScheduler != null) {
+      detectStorageScheduler.shutdownNow();
+    }
+    if (checkAppScheduler != null) {
+      checkAppScheduler.shutdownNow();
+    }
+  }
+
   public enum StrategyName {
     APP_BALANCE,
     IO_SAMPLE
