@@ -21,12 +21,10 @@ import java.io.Closeable;
 import java.io.IOException;
 import java.nio.charset.StandardCharsets;
 import java.util.Map;
-import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicLong;
 
-import com.google.common.collect.Maps;
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang3.ArrayUtils;
 import org.apache.commons.lang3.StringUtils;
@@ -39,12 +37,13 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import org.apache.uniffle.common.filesystem.HadoopFilesystemProvider;
+import org.apache.uniffle.common.util.JavaUtils;
 import org.apache.uniffle.common.util.ThreadUtils;
 
 public class ClientConfManager implements Closeable {
   private static final Logger LOG = LoggerFactory.getLogger(ClientConfManager.class);
 
-  private Map<String, String> clientConf = Maps.newConcurrentMap();
+  private Map<String, String> clientConf = JavaUtils.newConcurrentMap();
   private final AtomicLong lastCandidatesUpdateMS = new AtomicLong(0L);
   private Path path;
   private ScheduledExecutorService updateClientConfSES = null;
@@ -52,8 +51,9 @@ public class ClientConfManager implements Closeable {
   private static final String WHITESPACE_REGEX = "\\s+";
   private ApplicationManager applicationManager;
 
-  public ClientConfManager(CoordinatorConf conf, Configuration hadoopConf,
-      ApplicationManager applicationManager) throws Exception {
+  public ClientConfManager(
+      CoordinatorConf conf, Configuration hadoopConf, ApplicationManager applicationManager)
+      throws Exception {
     if (conf.getBoolean(CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_ENABLED)) {
       this.applicationManager = applicationManager;
       init(conf, hadoopConf);
@@ -72,11 +72,11 @@ public class ClientConfManager implements Closeable {
       throw new IllegalStateException(msg);
     }
     updateClientConfInternal();
-    LOG.info("Load client conf from " + pathStr + " successfully");
+    LOG.info("Load client conf from {} successfully", pathStr);
 
-    int updateIntervalS = conf.getInteger(CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_UPDATE_INTERVAL_SEC);
-    updateClientConfSES = Executors.newSingleThreadScheduledExecutor(
-        ThreadUtils.getThreadFactory("ClientConfManager-%d"));
+    int updateIntervalS =
+        conf.getInteger(CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_UPDATE_INTERVAL_SEC);
+    updateClientConfSES = ThreadUtils.getDaemonSingleThreadScheduledExecutor("ClientConfManager");
     updateClientConfSES.scheduleAtFixedRate(
         this::updateClientConf, 0, updateIntervalS, TimeUnit.SECONDS);
   }
@@ -95,12 +95,12 @@ public class ClientConfManager implements Closeable {
         LOG.warn("Client conf file not found with {}", path);
       }
     } catch (Exception e) {
-      LOG.warn("Error when update client conf with " + path, e);
+      LOG.warn("Error when update client conf with {}.", path, e);
     }
   }
 
   private void updateClientConfInternal() {
-    Map<String, String> newClientConf = Maps.newConcurrentMap();
+    Map<String, String> newClientConf = JavaUtils.newConcurrentMap();
     String content = loadClientConfContent();
     if (StringUtils.isEmpty(content)) {
       clientConf = newClientConf;
@@ -119,7 +119,9 @@ public class ClientConfManager implements Closeable {
           if (CoordinatorConf.COORDINATOR_REMOTE_STORAGE_PATH.key().equals(confKV[0])) {
             hasRemoteStorageConf = true;
             remoteStoragePath = confKV[1];
-          } else if (CoordinatorConf.COORDINATOR_REMOTE_STORAGE_CLUSTER_CONF.key().equals(confKV[0])) {
+          } else if (CoordinatorConf.COORDINATOR_REMOTE_STORAGE_CLUSTER_CONF
+              .key()
+              .equals(confKV[0])) {
             remoteStorageConf = confKV[1];
           } else {
             newClientConf.put(confKV[0], confKV[1]);
