@@ -41,19 +41,33 @@ public interface ClusterManager extends Closeable, Reconfigurable {
   List<ServerNode> getServerList(Set<String> requiredTags);
 
   /**
-   * @return number of server nodes in the cluster
+   * Get lost nodes from the cluster
+   *
+   * @return list of lost nodes
    */
-  int getNodesNum();
+  List<ServerNode> getLostServerList();
 
   /**
-   * @return list all server nodes in the cluster
+   * Get unhealthy nodes from the cluster
+   *
+   * @return list of unhealthy nodes
    */
+  List<ServerNode> getUnhealthyServerList();
+
+  /** @return number of server nodes in the cluster */
+  int getNodesNum();
+
+  /** @return list all server nodes in the cluster */
   List<ServerNode> list();
 
   int getShuffleNodesMax();
 
-  /**
-   * @return whether to be ready for serving
-   */
+  /** @return whether to be ready for serving */
   boolean isReadyForServe();
+
+  ServerNode getServerNodeById(String serverId);
+
+  void decommission(String serverId);
+
+  void cancelDecommission(String serverId);
 }
