@@ -23,13 +23,11 @@ import java.io.FileNotFoundException;
 import java.io.InputStreamReader;
 import java.nio.charset.StandardCharsets;
 import java.util.Map;
-import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicLong;
 
 import com.google.common.annotations.VisibleForTesting;
-import com.google.common.collect.Maps;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileStatus;
 import org.apache.hadoop.fs.FileSystem;
@@ -39,38 +37,40 @@ import org.slf4j.LoggerFactory;
 
 import org.apache.uniffle.common.filesystem.HadoopFilesystemProvider;
 import org.apache.uniffle.common.util.Constants;
+import org.apache.uniffle.common.util.JavaUtils;
 import org.apache.uniffle.common.util.ThreadUtils;
+import org.apache.uniffle.coordinator.metric.CoordinatorMetrics;
 
-/**
- * QuotaManager is a manager for resource restriction.
- */
+/** QuotaManager is a manager for resource restriction. */
 public class QuotaManager {
   private static final Logger LOG = LoggerFactory.getLogger(QuotaManager.class);
-  private final Map<String, Map<String, Long>> currentUserAndApp = Maps.newConcurrentMap();
-  private final Map<String, String> appIdToUser = Maps.newConcurrentMap();
+  private final Map<String, Map<String, Long>> currentUserAndApp = JavaUtils.newConcurrentMap();
+  private final Map<String, String> appIdToUser = JavaUtils.newConcurrentMap();
   private final String quotaFilePath;
   private final Integer quotaAppNum;
   private FileSystem hadoopFileSystem;
   private final AtomicLong quotaFileLastModify = new AtomicLong(0L);
-  private final Map<String, Integer> defaultUserApps = Maps.newConcurrentMap();
+  private final Map<String, Integer> defaultUserApps = JavaUtils.newConcurrentMap();
 
   public QuotaManager(CoordinatorConf conf) {
     this.quotaFilePath = conf.get(CoordinatorConf.COORDINATOR_QUOTA_DEFAULT_PATH);
     this.quotaAppNum = conf.getInteger(CoordinatorConf.COORDINATOR_QUOTA_DEFAULT_APP_NUM);
     if (quotaFilePath == null) {
-      LOG.warn("{} is not configured, each user will use the default quota : {}",
+      LOG.warn(
+          "{} is not configured, each user will use the default quota : {}",
           CoordinatorConf.COORDINATOR_QUOTA_DEFAULT_PATH.key(),
           conf.get(CoordinatorConf.COORDINATOR_QUOTA_DEFAULT_APP_NUM));
     } else {
       final Long updateTime = conf.get(CoordinatorConf.COORDINATOR_QUOTA_UPDATE_INTERVAL);
       try {
-        hadoopFileSystem = HadoopFilesystemProvider.getFilesystem(new Path(quotaFilePath), new Configuration());
+        hadoopFileSystem =
+            HadoopFilesystemProvider.getFilesystem(new Path(quotaFilePath), new Configuration());
       } catch (Exception e) {
-        LOG.error("Cannot init remoteFS on path : " + quotaFilePath, e);
+        LOG.error("Cannot init remoteFS on path : {}", quotaFilePath, e);
       }
       // Threads that update the number of submitted applications
-      ScheduledExecutorService scheduledExecutorService = Executors.newSingleThreadScheduledExecutor(
-          ThreadUtils.getThreadFactory("UpdateDefaultApp-%d"));
+      ScheduledExecutorService scheduledExecutorService =
+          ThreadUtils.getDaemonSingleThreadScheduledExecutor("UpdateDefaultApp");
       scheduledExecutorService.scheduleAtFixedRate(
           this::detectUserResource, 0, updateTime / 2, TimeUnit.MILLISECONDS);
       LOG.info("QuotaManager initialized successfully.");
@@ -101,7 +101,7 @@ public class QuotaManager {
   public void parseQuotaFile(DataInputStream fsDataInputStream) {
     String content;
     try (BufferedReader bufferedReader =
-             new BufferedReader(new InputStreamReader(fsDataInputStream, StandardCharsets.UTF_8))) {
+        new BufferedReader(new InputStreamReader(fsDataInputStream, StandardCharsets.UTF_8))) {
       while ((content = bufferedReader.readLine()) != null) {
         // to avoid reading comments
         if (!content.startsWith("#") && !content.isEmpty()) {
@@ -116,7 +116,8 @@ public class QuotaManager {
   }
 
   public boolean checkQuota(String user, String uuid) {
-    Map<String, Long> appAndTimes = currentUserAndApp.computeIfAbsent(user, x -> Maps.newConcurrentMap());
+    Map<String, Long> appAndTimes =
+        currentUserAndApp.computeIfAbsent(user, x -> JavaUtils.newConcurrentMap());
     Integer defaultAppNum = defaultUserApps.computeIfAbsent(user, x -> quotaAppNum);
     synchronized (this) {
       int currentAppNum = appAndTimes.size();
@@ -124,6 +125,7 @@ public class QuotaManager {
         return true;
       } else {
         appAndTimes.put(uuid, System.currentTimeMillis());
+        CoordinatorMetrics.gaugeRunningAppNumToUser.labels(user).inc();
         return false;
       }
     }
@@ -140,6 +142,17 @@ public class QuotaManager {
     }
   }
 
+  protected void updateQuotaMetrics() {
+    for (Map.Entry<String, Map<String, Long>> userAndApp : currentUserAndApp.entrySet()) {
+      String user = userAndApp.getKey();
+      try {
+        CoordinatorMetrics.gaugeRunningAppNumToUser.labels(user).set(userAndApp.getValue().size());
+      } catch (Exception e) {
+        LOG.warn("Update user metrics for {} failed ", user, e);
+      }
+    }
+  }
+
   @VisibleForTesting
   public Map<String, Integer> getDefaultUserApps() {
     return defaultUserApps;
