@@ -22,6 +22,7 @@ import java.util.Set;
 
 import com.google.common.collect.Maps;
 
+import org.apache.uniffle.common.ServerStatus;
 import org.apache.uniffle.common.storage.StorageInfo;
 import org.apache.uniffle.proto.RssProtos.ShuffleServerId;
 
@@ -29,16 +30,18 @@ public class ServerNode implements Comparable<ServerNode> {
 
   private String id;
   private String ip;
-  private int port;
+  private int grpcPort;
   private long usedMemory;
   private long preAllocatedMemory;
   private long availableMemory;
   private int eventNumInFlush;
   private long timestamp;
   private Set<String> tags;
-  private boolean isHealthy;
+  private ServerStatus status;
   private Map<String, StorageInfo> storageInfo;
+  private int nettyPort = -1;
 
+  // Only for test
   public ServerNode(
       String id,
       String ip,
@@ -47,9 +50,17 @@ public class ServerNode implements Comparable<ServerNode> {
       long preAllocatedMemory,
       long availableMemory,
       int eventNumInFlush,
-      Set<String> tags,
-      boolean isHealthy) {
-    this(id, ip, port, usedMemory, preAllocatedMemory, availableMemory, eventNumInFlush, tags, isHealthy,
+      Set<String> tags) {
+    this(
+        id,
+        ip,
+        port,
+        usedMemory,
+        preAllocatedMemory,
+        availableMemory,
+        eventNumInFlush,
+        tags,
+        ServerStatus.ACTIVE,
         Maps.newHashMap());
   }
 
@@ -62,23 +73,80 @@ public class ServerNode implements Comparable<ServerNode> {
       long availableMemory,
       int eventNumInFlush,
       Set<String> tags,
-      boolean isHealthy,
+      ServerStatus status) {
+    this(
+        id,
+        ip,
+        port,
+        usedMemory,
+        preAllocatedMemory,
+        availableMemory,
+        eventNumInFlush,
+        tags,
+        status,
+        Maps.newHashMap());
+  }
+
+  public ServerNode(
+      String id,
+      String ip,
+      int port,
+      long usedMemory,
+      long preAllocatedMemory,
+      long availableMemory,
+      int eventNumInFlush,
+      Set<String> tags,
+      ServerStatus status,
       Map<String, StorageInfo> storageInfoMap) {
+    this(
+        id,
+        ip,
+        port,
+        usedMemory,
+        preAllocatedMemory,
+        availableMemory,
+        eventNumInFlush,
+        tags,
+        status,
+        storageInfoMap,
+        -1);
+  }
+
+  public ServerNode(
+      String id,
+      String ip,
+      int grpcPort,
+      long usedMemory,
+      long preAllocatedMemory,
+      long availableMemory,
+      int eventNumInFlush,
+      Set<String> tags,
+      ServerStatus status,
+      Map<String, StorageInfo> storageInfoMap,
+      int nettyPort) {
     this.id = id;
     this.ip = ip;
-    this.port = port;
+    this.grpcPort = grpcPort;
     this.usedMemory = usedMemory;
     this.preAllocatedMemory = preAllocatedMemory;
     this.availableMemory = availableMemory;
     this.eventNumInFlush = eventNumInFlush;
     this.timestamp = System.currentTimeMillis();
     this.tags = tags;
-    this.isHealthy = isHealthy;
+    this.status = status;
     this.storageInfo = storageInfoMap;
+    if (nettyPort > 0) {
+      this.nettyPort = nettyPort;
+    }
   }
 
   public ShuffleServerId convertToGrpcProto() {
-    return ShuffleServerId.newBuilder().setId(id).setIp(ip).setPort(port).build();
+    return ShuffleServerId.newBuilder()
+        .setId(id)
+        .setIp(ip)
+        .setPort(grpcPort)
+        .setNettyPort(nettyPort)
+        .build();
   }
 
   public String getId() {
@@ -89,8 +157,8 @@ public class ServerNode implements Comparable<ServerNode> {
     return ip;
   }
 
-  public int getPort() {
-    return port;
+  public int getGrpcPort() {
+    return grpcPort;
   }
 
   public long getTimestamp() {
@@ -117,8 +185,12 @@ public class ServerNode implements Comparable<ServerNode> {
     return tags;
   }
 
-  public boolean isHealthy() {
-    return isHealthy;
+  public ServerStatus getStatus() {
+    return status;
+  }
+
+  public void setStatus(ServerStatus serverStatus) {
+    this.status = serverStatus;
   }
 
   public Map<String, StorageInfo> getStorageInfo() {
@@ -127,24 +199,36 @@ public class ServerNode implements Comparable<ServerNode> {
 
   @Override
   public String toString() {
-    return "ServerNode with id[" + id
-        + "], ip[" + ip
-        + "], port[" + port
-        + "], usedMemory[" + usedMemory
-        + "], preAllocatedMemory[" + preAllocatedMemory
-        + "], availableMemory[" + availableMemory
-        + "], eventNumInFlush[" + eventNumInFlush
-        + "], timestamp[" + timestamp
-        + "], tags" + tags.toString() + ""
-        + ", healthy[" + isHealthy
-        + "], storages[num=" + storageInfo.size() + "]";
-
+    return "ServerNode with id["
+        + id
+        + "], ip["
+        + ip
+        + "], grpc port["
+        + grpcPort
+        + "], netty port["
+        + nettyPort
+        + "], usedMemory["
+        + usedMemory
+        + "], preAllocatedMemory["
+        + preAllocatedMemory
+        + "], availableMemory["
+        + availableMemory
+        + "], eventNumInFlush["
+        + eventNumInFlush
+        + "], timestamp["
+        + timestamp
+        + "], tags"
+        + tags.toString()
+        + ""
+        + ", status["
+        + status
+        + "], storages[num="
+        + storageInfo.size()
+        + "]";
   }
 
-  /**
-   * Only for test case
-   */
-  void setTimestamp(long timestamp) {
+  /** Only for test case */
+  public void setTimestamp(long timestamp) {
     this.timestamp = timestamp;
   }
 
@@ -174,4 +258,8 @@ public class ServerNode implements Comparable<ServerNode> {
   public long getTotalMemory() {
     return availableMemory + usedMemory;
   }
+
+  public int getNettyPort() {
+    return nettyPort;
+  }
 }
