@@ -65,20 +65,26 @@ public class ApplicationManagerTest {
     String remoteStoragePath = remotePath1 + Constants.COMMA_SPLIT_CHAR + remotePath2;
     Set<String> expectedAvailablePath = Sets.newHashSet(remotePath1, remotePath2);
     applicationManager.refreshRemoteStorage(remoteStoragePath, "");
-    assertEquals(expectedAvailablePath, applicationManager.getAvailableRemoteStorageInfo().keySet());
-    assertEquals(expectedAvailablePath, applicationManager.getRemoteStoragePathRankValue().keySet());
+    assertEquals(
+        expectedAvailablePath, applicationManager.getAvailableRemoteStorageInfo().keySet());
+    assertEquals(
+        expectedAvailablePath, applicationManager.getRemoteStoragePathRankValue().keySet());
 
     remoteStoragePath = remotePath3;
     expectedAvailablePath = Sets.newHashSet(remotePath3);
     applicationManager.refreshRemoteStorage(remoteStoragePath, "");
-    assertEquals(expectedAvailablePath, applicationManager.getAvailableRemoteStorageInfo().keySet());
-    assertEquals(expectedAvailablePath, applicationManager.getRemoteStoragePathRankValue().keySet());
+    assertEquals(
+        expectedAvailablePath, applicationManager.getAvailableRemoteStorageInfo().keySet());
+    assertEquals(
+        expectedAvailablePath, applicationManager.getRemoteStoragePathRankValue().keySet());
 
     remoteStoragePath = remotePath1 + Constants.COMMA_SPLIT_CHAR + remotePath3;
     expectedAvailablePath = Sets.newHashSet(remotePath1, remotePath3);
     applicationManager.refreshRemoteStorage(remoteStoragePath, remoteStorageConf);
-    assertEquals(expectedAvailablePath, applicationManager.getAvailableRemoteStorageInfo().keySet());
-    assertEquals(expectedAvailablePath, applicationManager.getRemoteStoragePathRankValue().keySet());
+    assertEquals(
+        expectedAvailablePath, applicationManager.getAvailableRemoteStorageInfo().keySet());
+    assertEquals(
+        expectedAvailablePath, applicationManager.getRemoteStoragePathRankValue().keySet());
     Map<String, RemoteStorageInfo> storages = applicationManager.getAvailableRemoteStorageInfo();
     RemoteStorageInfo remoteStorageInfo = storages.get(remotePath1);
     assertEquals(2, remoteStorageInfo.getConfItems().size());
@@ -93,8 +99,10 @@ public class ApplicationManagerTest {
     remoteStorageInfo = storages.get(remotePath2);
     assertEquals(1, remoteStorageInfo.getConfItems().size());
     assertEquals("v3", remoteStorageInfo.getConfItems().get("k3"));
-    assertEquals(expectedAvailablePath, applicationManager.getAvailableRemoteStorageInfo().keySet());
-    assertEquals(expectedAvailablePath, applicationManager.getRemoteStoragePathRankValue().keySet());
+    assertEquals(
+        expectedAvailablePath, applicationManager.getAvailableRemoteStorageInfo().keySet());
+    assertEquals(
+        expectedAvailablePath, applicationManager.getRemoteStoragePathRankValue().keySet());
     assertFalse(applicationManager.hasErrorInStatusCheck());
   }
 
