@@ -19,7 +19,6 @@ package org.apache.uniffle.coordinator;
 
 import java.io.File;
 import java.io.FileWriter;
-import java.io.IOException;
 import java.io.PrintWriter;
 import java.nio.file.Files;
 import java.util.Map;
@@ -29,8 +28,6 @@ import java.util.Set;
 import com.google.common.collect.Sets;
 import org.apache.commons.io.FileUtils;
 import org.apache.hadoop.conf.Configuration;
-import org.apache.hadoop.hdfs.MiniDFSCluster;
-import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
@@ -49,11 +46,6 @@ import static org.junit.jupiter.api.Assertions.assertTrue;
 
 public class ClientConfManagerTest {
 
-  @TempDir
-  private final File remotePath = new File("hdfs://rss");
-  private static MiniDFSCluster cluster;
-  private final Configuration hdfsConf = new Configuration();
-
   @BeforeEach
   public void setUp() {
     CoordinatorMetrics.register();
@@ -64,24 +56,13 @@ public class ClientConfManagerTest {
     CoordinatorMetrics.clear();
   }
 
-  @AfterAll
-  public static void close() {
-    cluster.close();
-  }
-
-  public void createMiniHdfs(String hdfsPath) throws IOException {
-    hdfsConf.set("fs.defaultFS", remotePath.getAbsolutePath());
-    hdfsConf.set("dfs.nameservices", "rss");
-    hdfsConf.set(MiniDFSCluster.HDFS_MINIDFS_BASEDIR, hdfsPath);
-    cluster = (new MiniDFSCluster.Builder(hdfsConf)).build();
-  }
-
   @Test
   public void test(@TempDir File tempDir) throws Exception {
     File cfgFile = File.createTempFile("tmp", ".conf", tempDir);
     final String cfgFileName = cfgFile.getAbsolutePath();
-    final String filePath = Objects.requireNonNull(
-        getClass().getClassLoader().getResource("coordinator.conf")).getFile();
+    final String filePath =
+        Objects.requireNonNull(getClass().getClassLoader().getResource("coordinator.conf"))
+            .getFile();
     CoordinatorConf conf = new CoordinatorConf(filePath);
     conf.set(CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_PATH, tempDir.toURI().toString());
     conf.set(CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_ENABLED, true);
@@ -98,7 +79,8 @@ public class ClientConfManagerTest {
     assertTrue(expectedException.getMessage().endsWith("is not a file."));
 
     conf.set(CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_PATH, cfgFile.toURI().toString());
-    ClientConfManager clientConfManager = new ClientConfManager(conf, new Configuration(), applicationManager);
+    ClientConfManager clientConfManager =
+        new ClientConfManager(conf, new Configuration(), applicationManager);
     assertEquals(0, clientConfManager.getClientConf().size());
 
     FileWriter fileWriter = new FileWriter(cfgFile);
@@ -170,17 +152,20 @@ public class ClientConfManagerTest {
     writeRemoteStorageConf(cfgFile, remotePath1);
 
     CoordinatorConf conf = new CoordinatorConf();
-    conf.set(CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_UPDATE_INTERVAL_SEC, updateIntervalSec);
+    conf.set(
+        CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_UPDATE_INTERVAL_SEC, updateIntervalSec);
     conf.set(CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_PATH, cfgFile.toURI().toString());
     conf.setLong(CoordinatorConf.COORDINATOR_REMOTE_STORAGE_SCHEDULE_TIME, 60000);
     conf.setInteger(CoordinatorConf.COORDINATOR_REMOTE_STORAGE_SCHEDULE_ACCESS_TIMES, 1);
     conf.set(CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_ENABLED, true);
     ApplicationManager applicationManager = new ApplicationManager(conf);
 
-    final ClientConfManager clientConfManager = new ClientConfManager(conf, new Configuration(), applicationManager);
+    final ClientConfManager clientConfManager =
+        new ClientConfManager(conf, new Configuration(), applicationManager);
     applicationManager.getSelectStorageStrategy().detectStorage();
     Set<String> expectedAvailablePath = Sets.newHashSet(remotePath1);
-    assertEquals(expectedAvailablePath, applicationManager.getAvailableRemoteStorageInfo().keySet());
+    assertEquals(
+        expectedAvailablePath, applicationManager.getAvailableRemoteStorageInfo().keySet());
     RemoteStorageInfo remoteStorageInfo = applicationManager.pickRemoteStorage("testAppId1");
     assertEquals(remotePath1, remoteStorageInfo.getPath());
     assertTrue(remoteStorageInfo.getConfItems().isEmpty());
@@ -193,7 +178,8 @@ public class ClientConfManagerTest {
     assertEquals(remotePath3, remoteStorageInfo.getPath());
 
     String confItems = "host2,k1=v1,k2=v2;host3,k3=v3";
-    writeRemoteStorageConf(cfgFile, remotePath2 + Constants.COMMA_SPLIT_CHAR + remotePath3, confItems);
+    writeRemoteStorageConf(
+        cfgFile, remotePath2 + Constants.COMMA_SPLIT_CHAR + remotePath3, confItems);
     expectedAvailablePath = Sets.newHashSet(remotePath2, remotePath3);
     waitForUpdate(expectedAvailablePath, applicationManager);
     applicationManager.getSelectStorageStrategy().detectStorage();
@@ -204,19 +190,20 @@ public class ClientConfManagerTest {
     assertEquals("v2", remoteStorageInfo.getConfItems().get("k2"));
 
     confItems = "host1,keyTest1=test1,keyTest2=test2;host2,k1=deadbeaf";
-    writeRemoteStorageConf(cfgFile, remotePath1 + Constants.COMMA_SPLIT_CHAR + remotePath2, confItems);
+    writeRemoteStorageConf(
+        cfgFile, remotePath1 + Constants.COMMA_SPLIT_CHAR + remotePath2, confItems);
     expectedAvailablePath = Sets.newHashSet(remotePath1, remotePath2);
     waitForUpdate(expectedAvailablePath, applicationManager);
     remoteStorageInfo = applicationManager.pickRemoteStorage("testAppId4");
     // one of remote storage will be chosen
     assertTrue(
         (remotePath1.equals(remoteStorageInfo.getPath())
-                      && (remoteStorageInfo.getConfItems().size() == 2)
-                      && (remoteStorageInfo.getConfItems().get("keyTest1").equals("test1")))
-                      && (remoteStorageInfo.getConfItems().get("keyTest2").equals("test2"))
+                    && (remoteStorageInfo.getConfItems().size() == 2)
+                    && (remoteStorageInfo.getConfItems().get("keyTest1").equals("test1")))
+                && (remoteStorageInfo.getConfItems().get("keyTest2").equals("test2"))
             || (remotePath2.equals(remoteStorageInfo.getPath())
-                      && remoteStorageInfo.getConfItems().size() == 1)
-                      && remoteStorageInfo.getConfItems().get("k1").equals("deadbeaf"));
+                    && remoteStorageInfo.getConfItems().size() == 1)
+                && remoteStorageInfo.getConfItems().get("k1").equals("deadbeaf"));
 
     clientConfManager.close();
   }
@@ -230,10 +217,10 @@ public class ClientConfManagerTest {
     File cfgFile = Files.createTempFile("dynamicRemoteStorageTest", ".conf").toFile();
     cfgFile.deleteOnExit();
     writeRemoteStorageConf(cfgFile, remotePath1);
-    createMiniHdfs(remotePath.getAbsolutePath());
 
     CoordinatorConf conf = new CoordinatorConf();
-    conf.set(CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_UPDATE_INTERVAL_SEC, updateIntervalSec);
+    conf.set(
+        CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_UPDATE_INTERVAL_SEC, updateIntervalSec);
     conf.set(CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_PATH, cfgFile.toURI().toString());
     conf.set(CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_ENABLED, true);
     conf.setLong(CoordinatorConf.COORDINATOR_REMOTE_STORAGE_SCHEDULE_TIME, 60000);
@@ -246,11 +233,13 @@ public class ClientConfManagerTest {
         (LowestIOSampleCostSelectStorageStrategy) applicationManager.getSelectStorageStrategy();
     String testPath = "/test";
 
-    final ClientConfManager clientConfManager = new ClientConfManager(conf, new Configuration(), applicationManager);
+    final ClientConfManager clientConfManager =
+        new ClientConfManager(conf, new Configuration(), applicationManager);
     // the reason for sleep here is to ensure that threads can be scheduled normally, the same below
     applicationManager.getSelectStorageStrategy().detectStorage();
     Set<String> expectedAvailablePath = Sets.newHashSet(remotePath1);
-    assertEquals(expectedAvailablePath, applicationManager.getAvailableRemoteStorageInfo().keySet());
+    assertEquals(
+        expectedAvailablePath, applicationManager.getAvailableRemoteStorageInfo().keySet());
     selectStorageStrategy.sortPathByRankValue(remotePath1, testPath, System.currentTimeMillis());
     RemoteStorageInfo remoteStorageInfo = applicationManager.pickRemoteStorage("testAppId1");
     assertEquals(remotePath1, remoteStorageInfo.getPath());
@@ -267,7 +256,8 @@ public class ClientConfManagerTest {
 
     String confItems = "host2,k1=v1,k2=v2;host3,k3=v3";
     final long current = System.currentTimeMillis();
-    writeRemoteStorageConf(cfgFile, remotePath2 + Constants.COMMA_SPLIT_CHAR + remotePath3, confItems);
+    writeRemoteStorageConf(
+        cfgFile, remotePath2 + Constants.COMMA_SPLIT_CHAR + remotePath3, confItems);
     expectedAvailablePath = Sets.newHashSet(remotePath2, remotePath3);
     waitForUpdate(expectedAvailablePath, applicationManager);
     selectStorageStrategy.sortPathByRankValue(remotePath2, testPath, current);
@@ -280,19 +270,20 @@ public class ClientConfManagerTest {
     assertEquals("v2", remoteStorageInfo.getConfItems().get("k2"));
 
     confItems = "host1,keyTest1=test1,keyTest2=test2;host2,k1=deadbeaf";
-    writeRemoteStorageConf(cfgFile, remotePath1 + Constants.COMMA_SPLIT_CHAR + remotePath2, confItems);
+    writeRemoteStorageConf(
+        cfgFile, remotePath1 + Constants.COMMA_SPLIT_CHAR + remotePath2, confItems);
     expectedAvailablePath = Sets.newHashSet(remotePath1, remotePath2);
     waitForUpdate(expectedAvailablePath, applicationManager);
     remoteStorageInfo = applicationManager.pickRemoteStorage("testAppId4");
     // one of remote storage will be chosen
     assertTrue(
         (remotePath1.equals(remoteStorageInfo.getPath())
-            && (remoteStorageInfo.getConfItems().size() == 2)
-            && (remoteStorageInfo.getConfItems().get("keyTest1").equals("test1")))
-            && (remoteStorageInfo.getConfItems().get("keyTest2").equals("test2"))
+                    && (remoteStorageInfo.getConfItems().size() == 2)
+                    && (remoteStorageInfo.getConfItems().get("keyTest1").equals("test1")))
+                && (remoteStorageInfo.getConfItems().get("keyTest2").equals("test2"))
             || (remotePath2.equals(remoteStorageInfo.getPath())
-            && remoteStorageInfo.getConfItems().size() == 1)
-            && remoteStorageInfo.getConfItems().get("k1").equals("deadbeaf"));
+                    && remoteStorageInfo.getConfItems().size() == 1)
+                && remoteStorageInfo.getConfItems().get("k1").equals("deadbeaf"));
 
     clientConfManager.close();
   }
@@ -301,22 +292,23 @@ public class ClientConfManagerTest {
     writeRemoteStorageConf(cfgFile, value, null);
   }
 
-  private void writeRemoteStorageConf(File cfgFile, String pathItems, String confItems) throws Exception {
+  private void writeRemoteStorageConf(File cfgFile, String pathItems, String confItems)
+      throws Exception {
     // sleep 2 secs to make sure the modified time will be updated
     Thread.sleep(2000);
     FileWriter fileWriter = new FileWriter(cfgFile);
     PrintWriter printWriter = new PrintWriter(fileWriter);
     printWriter.println(CoordinatorConf.COORDINATOR_REMOTE_STORAGE_PATH.key() + " " + pathItems);
     if (confItems != null) {
-      printWriter.println(CoordinatorConf.COORDINATOR_REMOTE_STORAGE_CLUSTER_CONF.key() + " " + confItems);
+      printWriter.println(
+          CoordinatorConf.COORDINATOR_REMOTE_STORAGE_CLUSTER_CONF.key() + " " + confItems);
     }
     printWriter.flush();
     printWriter.close();
   }
 
   private void waitForUpdate(
-      Set<String> expectedAvailablePath,
-      ApplicationManager applicationManager) throws Exception {
+      Set<String> expectedAvailablePath, ApplicationManager applicationManager) throws Exception {
     int maxAttempt = 10;
     int attempt = 0;
     while (true) {
@@ -325,7 +317,8 @@ public class ClientConfManagerTest {
       }
       Thread.sleep(1000);
       try {
-        assertEquals(expectedAvailablePath, applicationManager.getAvailableRemoteStorageInfo().keySet());
+        assertEquals(
+            expectedAvailablePath, applicationManager.getAvailableRemoteStorageInfo().keySet());
         break;
       } catch (Throwable e) {
         // ignore
