@@ -24,15 +24,21 @@ function exit_with_usage() {
   echo "Usage:"
   echo "+------------------------------------------------------------------------------------------------------+"
   echo "| ./build.sh [--hadoop-version <hadoop version>] [--registry <registry url>] [--author <author name>]  |"
+  echo "|            [--base-os-distribution <os distribution>] [--base-image <base image url>]                |"
+  echo "|            [--push-image <true|false>] [--apache-mirror <apache mirror url>]                         |"
   echo "+------------------------------------------------------------------------------------------------------+"
   exit 1
 }
 
-UNKNOWN_REGISTRY="UNKNOWN_REGISTRY"
-
-REGISTRY=$UNKNOWN_REGISTRY
+REGISTRY="docker.io/library"
 HADOOP_VERSION=2.8.5
+HADOOP_SHORT_VERSION=$(echo $HADOOP_VERSION | awk -F "." '{print $1"."$2}')
 AUTHOR=$(whoami)
+# If you are based in China, you could pass --apache-mirror <a_mirror_url> when building this.
+APACHE_MIRROR="https://dlcdn.apache.org"
+OS_DISTRIBUTION=debian
+BASE_IMAGE=""
+PUSH_IMAGE="true"
 
 while (( "$#" )); do
   case $1 in
@@ -48,9 +54,25 @@ while (( "$#" )); do
       AUTHOR="$2"
       shift
       ;;
+    --base-os-distribution)
+      OS_DISTRIBUTION="$2"
+      shift
+      ;;
+    --base-image)
+      BASE_IMAGE="$2"
+      shift
+      ;;
+    --push-image)
+      PUSH_IMAGE="$2"
+      shift
+      ;;
     --help)
       exit_with_usage
       ;;
+    --apache-mirror)
+      APACHE_MIRROR="$2"
+      shift
+      ;;
     --*)
       echo "Error: $1 is not supported"
       exit_with_usage
@@ -66,24 +88,33 @@ while (( "$#" )); do
   shift
 done
 
-if [ "$REGISTRY" == $UNKNOWN_REGISTRY ]; \
-  then echo "please set registry url"; exit; \
+if [ -z "$BASE_IMAGE" ]; then
+  echo "start building base image: uniffle-base"
+  docker build -t "uniffle-base:latest" \
+    -f base/"${OS_DISTRIBUTION}"/Dockerfile .
+  BASE_IMAGE="uniffle-base:latest"
+else
+  echo "using base image(${BASE_IMAGE}) to build rss server"
 fi
 
+
 HADOOP_FILE=hadoop-${HADOOP_VERSION}.tar.gz
-HADOOP_URL=https://archive.apache.org/dist/hadoop/core/hadoop-${HADOOP_VERSION}/${HADOOP_FILE}
-echo "HADOOP_URL is $HADOOP_URL"
+ARCHIVE_HADOOP_URL=https://archive.apache.org/dist/hadoop/core/hadoop-${HADOOP_VERSION}/${HADOOP_FILE}
+HADOOP_URL=${APACHE_MIRROR}/hadoop/core/hadoop-${HADOOP_VERSION}/${HADOOP_FILE}
+echo "HADOOP_URL is either ${HADOOP_URL} or ${ARCHIVE_HADOOP_URL}"
 if [ ! -e "$HADOOP_FILE" ]; \
-  then wget "$HADOOP_URL"; \
+  then wget "${HADOOP_URL}" || wget "$ARCHIVE_HADOOP_URL"; \
   else echo "${HADOOP_FILE} has been downloaded"; \
 fi
 
 RSS_DIR=../../..
 cd $RSS_DIR || exit
 RSS_VERSION=$(mvn help:evaluate -Dexpression=project.version 2>/dev/null | grep -v "INFO" | grep -v "WARNING" | tail -n 1)
-RSS_FILE=rss-${RSS_VERSION}.tgz
+RSS_FILE=rss-${RSS_VERSION}-hadoop${HADOOP_SHORT_VERSION}.tgz
+echo "RSS_VERSION: $RSS_VERSION"
+echo "RSS_FILE: $RSS_FILE"
 if [ ! -e "$RSS_FILE" ]; \
-  then sh ./build_distribution.sh; \
+  then bash ./build_distribution.sh; \
   else echo "$RSS_FILE has been built"; \
 fi
 cd "$OLDPWD" || exit
@@ -94,13 +125,17 @@ GIT_COMMIT=$(git describe --dirty --always --tags | sed 's/-/./g')
 echo "image version: ${IMAGE_VERSION:=$RSS_VERSION-$GIT_COMMIT}"
 IMAGE=$REGISTRY/rss-server:$IMAGE_VERSION
 echo "building image: $IMAGE"
-docker build -t "$IMAGE" \
+docker build --network=host -t "$IMAGE" \
              --build-arg RSS_VERSION="$RSS_VERSION" \
              --build-arg HADOOP_VERSION="$HADOOP_VERSION" \
+             --build-arg HADOOP_SHORT_VERSION="$HADOOP_SHORT_VERSION" \
              --build-arg AUTHOR="$AUTHOR" \
              --build-arg GIT_COMMIT="$GIT_COMMIT" \
              --build-arg GIT_BRANCH="$GIT_BRANCH" \
+             --build-arg BASE_IMAGE="$BASE_IMAGE" \
              -f Dockerfile --no-cache .
 
-echo "pushing image: $IMAGE"
-docker push "$IMAGE"
+if [ x"${PUSH_IMAGE}" == x"true" ]; then
+  echo "pushing image: $IMAGE"
+  docker push "$IMAGE"
+fi
