@@ -69,6 +69,11 @@ public class AccessClusterTest extends CoordinatorTestBase {
       return new AccessCheckResult(false, "");
     }
 
+    @Override
+    public void refreshAccessChecker() {
+      // ignore.
+    }
+
     @Override
     public void close() throws IOException {
       // ignore.
@@ -79,31 +84,42 @@ public class AccessClusterTest extends CoordinatorTestBase {
   public void testUsingCustomExtraProperties() throws Exception {
     CoordinatorConf coordinatorConf = getCoordinatorConf();
     coordinatorConf.setString(
-            "rss.coordinator.access.checkers",
-            "org.apache.uniffle.test.AccessClusterTest$MockedAccessChecker");
+        "rss.coordinator.access.checkers",
+        "org.apache.uniffle.test.AccessClusterTest$MockedAccessChecker");
     createCoordinatorServer(coordinatorConf);
     startServers();
     Uninterruptibles.sleepUninterruptibly(3, TimeUnit.SECONDS);
     // case1: empty map
     String accessID = "acessid";
-    RssAccessClusterRequest request = new RssAccessClusterRequest(accessID,
-        Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION), 2000, "user");
+    RssAccessClusterRequest request =
+        new RssAccessClusterRequest(
+            accessID, Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION), 2000, "user");
     RssAccessClusterResponse response = coordinatorClient.accessCluster(request);
     assertEquals(StatusCode.ACCESS_DENIED, response.getStatusCode());
 
     // case2: illegal names
     Map<String, String> extraProperties = new HashMap<>();
     extraProperties.put("key", "illegalName");
-    request = new RssAccessClusterRequest(accessID, Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION),
-        2000, extraProperties, "user");
+    request =
+        new RssAccessClusterRequest(
+            accessID,
+            Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION),
+            2000,
+            extraProperties,
+            "user");
     response = coordinatorClient.accessCluster(request);
     assertEquals(StatusCode.ACCESS_DENIED, response.getStatusCode());
 
     // case3: legal names
     extraProperties.clear();
     extraProperties.put("key", "v1");
-    request = new RssAccessClusterRequest(accessID, Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION),
-        2000, extraProperties, "user");
+    request =
+        new RssAccessClusterRequest(
+            accessID,
+            Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION),
+            2000,
+            extraProperties,
+            "user");
     response = coordinatorClient.accessCluster(request);
     assertEquals(StatusCode.SUCCESS, response.getStatusCode());
 
@@ -125,9 +141,9 @@ public class AccessClusterTest extends CoordinatorTestBase {
     coordinatorConf.setInteger("rss.coordinator.access.loadChecker.serverNum.threshold", 2);
     coordinatorConf.setString("rss.coordinator.access.candidates.path", cfgFile.getAbsolutePath());
     coordinatorConf.setString(
-            "rss.coordinator.access.checkers",
-            "org.apache.uniffle.coordinator.access.checker.AccessCandidatesChecker,"
-                + "org.apache.uniffle.coordinator.access.checker.AccessClusterLoadChecker");
+        "rss.coordinator.access.checkers",
+        "org.apache.uniffle.coordinator.access.checker.AccessCandidatesChecker,"
+            + "org.apache.uniffle.coordinator.access.checker.AccessClusterLoadChecker");
     createCoordinatorServer(coordinatorConf);
 
     ShuffleServerConf shuffleServerConf = getShuffleServerConf();
@@ -135,15 +151,17 @@ public class AccessClusterTest extends CoordinatorTestBase {
     startServers();
     Uninterruptibles.sleepUninterruptibly(3, TimeUnit.SECONDS);
     String accessId = "111111";
-    RssAccessClusterRequest request = new RssAccessClusterRequest(accessId,
-        Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION), 2000, "user");
+    RssAccessClusterRequest request =
+        new RssAccessClusterRequest(
+            accessId, Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION), 2000, "user");
     RssAccessClusterResponse response = coordinatorClient.accessCluster(request);
     assertEquals(StatusCode.ACCESS_DENIED, response.getStatusCode());
     assertTrue(response.getMessage().startsWith("Denied by AccessCandidatesChecker"));
 
     accessId = "135";
-    request = new RssAccessClusterRequest(accessId,
-        Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION), 2000, "user");
+    request =
+        new RssAccessClusterRequest(
+            accessId, Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION), 2000, "user");
     response = coordinatorClient.accessCluster(request);
     assertEquals(StatusCode.ACCESS_DENIED, response.getStatusCode());
     assertTrue(response.getMessage().startsWith("Denied by AccessClusterLoadChecker"));
@@ -154,16 +172,19 @@ public class AccessClusterTest extends CoordinatorTestBase {
     shuffleServer.start();
     Uninterruptibles.sleepUninterruptibly(3, TimeUnit.SECONDS);
 
-    CoordinatorClient client = new CoordinatorClientFactory(ClientType.GRPC)
-        .createCoordinatorClient(LOCALHOST, COORDINATOR_PORT_1 + 13);
-    request = new RssAccessClusterRequest(accessId,
-        Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION), 2000, "user");
+    CoordinatorClient client =
+        new CoordinatorClientFactory(ClientType.GRPC)
+            .createCoordinatorClient(LOCALHOST, COORDINATOR_PORT_1 + 13);
+    request =
+        new RssAccessClusterRequest(
+            accessId, Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION), 2000, "user");
     response = client.accessCluster(request);
     assertEquals(StatusCode.INTERNAL_ERROR, response.getStatusCode());
     assertTrue(response.getMessage().startsWith("UNAVAILABLE: io exception"));
 
-    request = new RssAccessClusterRequest(accessId,
-        Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION), 2000, "user");
+    request =
+        new RssAccessClusterRequest(
+            accessId, Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION), 2000, "user");
     response = coordinatorClient.accessCluster(request);
     assertEquals(StatusCode.SUCCESS, response.getStatusCode());
     assertTrue(response.getMessage().startsWith("SUCCESS"));
@@ -171,4 +192,3 @@ public class AccessClusterTest extends CoordinatorTestBase {
     shutdownServers();
   }
 }
-
