@@ -17,10 +17,12 @@
 
 package org.apache.uniffle.test;
 
+import java.lang.reflect.Field;
 import java.util.Arrays;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
 
 import com.google.common.collect.Lists;
 import com.google.common.collect.Sets;
@@ -31,10 +33,12 @@ import org.apache.uniffle.client.request.RssApplicationInfoRequest;
 import org.apache.uniffle.client.request.RssGetShuffleAssignmentsRequest;
 import org.apache.uniffle.client.response.RssApplicationInfoResponse;
 import org.apache.uniffle.client.response.RssGetShuffleAssignmentsResponse;
+import org.apache.uniffle.common.ClientType;
 import org.apache.uniffle.common.PartitionRange;
 import org.apache.uniffle.common.ShuffleRegisterInfo;
 import org.apache.uniffle.common.ShuffleServerInfo;
 import org.apache.uniffle.common.config.RssBaseConf;
+import org.apache.uniffle.common.config.RssConf;
 import org.apache.uniffle.common.rpc.StatusCode;
 import org.apache.uniffle.common.storage.StorageInfo;
 import org.apache.uniffle.common.storage.StorageMedia;
@@ -69,6 +73,7 @@ public class CoordinatorGrpcTest extends CoordinatorTestBase {
     coordinatorConf.setLong("rss.coordinator.server.heartbeat.timeout", 3000);
     createCoordinatorServer(coordinatorConf);
     ShuffleServerConf shuffleServerConf = getShuffleServerConf();
+    shuffleServerConf.remove(ShuffleServerConf.NETTY_SERVER_PORT.key());
     createShuffleServer(shuffleServerConf);
     shuffleServerConf.setInteger("rss.rpc.server.port", SHUFFLE_SERVER_PORT + 1);
     shuffleServerConf.setInteger("rss.jetty.http.port", 18081);
@@ -83,17 +88,25 @@ public class CoordinatorGrpcTest extends CoordinatorTestBase {
     Map<Integer, List<ShuffleServerInfo>> partitionToServers =
         coordinatorClient.getPartitionToServers(testResponse);
 
-    assertEquals(Arrays.asList(new ShuffleServerInfo("id1", "0.0.0.1", 100),
-        new ShuffleServerInfo("id2", "0.0.0.2", 100)),
+    assertEquals(
+        Arrays.asList(
+            new ShuffleServerInfo("id1", "0.0.0.1", 100),
+            new ShuffleServerInfo("id2", "0.0.0.2", 100)),
         partitionToServers.get(0));
-    assertEquals(Arrays.asList(new ShuffleServerInfo("id1", "0.0.0.1", 100),
-        new ShuffleServerInfo("id2", "0.0.0.2", 100)),
+    assertEquals(
+        Arrays.asList(
+            new ShuffleServerInfo("id1", "0.0.0.1", 100),
+            new ShuffleServerInfo("id2", "0.0.0.2", 100)),
         partitionToServers.get(1));
-    assertEquals(Arrays.asList(new ShuffleServerInfo("id3", "0.0.0.3", 100),
-        new ShuffleServerInfo("id4", "0.0.0.4", 100)),
+    assertEquals(
+        Arrays.asList(
+            new ShuffleServerInfo("id3", "0.0.0.3", 100),
+            new ShuffleServerInfo("id4", "0.0.0.4", 100)),
         partitionToServers.get(2));
-    assertEquals(Arrays.asList(new ShuffleServerInfo("id3", "0.0.0.3", 100),
-        new ShuffleServerInfo("id4", "0.0.0.4", 100)),
+    assertEquals(
+        Arrays.asList(
+            new ShuffleServerInfo("id3", "0.0.0.3", 100),
+            new ShuffleServerInfo("id4", "0.0.0.4", 100)),
         partitionToServers.get(3));
     assertNull(partitionToServers.get(4));
   }
@@ -103,33 +116,66 @@ public class CoordinatorGrpcTest extends CoordinatorTestBase {
     GetShuffleAssignmentsResponse testResponse = generateShuffleAssignmentsResponse();
     Map<ShuffleServerInfo, List<PartitionRange>> serverToPartitionRanges =
         coordinatorClient.getServerToPartitionRanges(testResponse);
-    List<ShuffleRegisterInfo> expected = Arrays.asList(
-        new ShuffleRegisterInfo(new ShuffleServerInfo("id1", "0.0.0.1", 100),
-            Lists.newArrayList(new PartitionRange(0, 1))),
-        new ShuffleRegisterInfo(new ShuffleServerInfo("id2", "0.0.0.2", 100),
-            Lists.newArrayList(new PartitionRange(0, 1))),
-        new ShuffleRegisterInfo(new ShuffleServerInfo("id3", "0.0.0.3", 100),
-            Lists.newArrayList(new PartitionRange(2, 3))),
-        new ShuffleRegisterInfo(new ShuffleServerInfo("id4", "0.0.0.4", 100),
-            Lists.newArrayList(new PartitionRange(2, 3))));
+    List<ShuffleRegisterInfo> expected =
+        Arrays.asList(
+            new ShuffleRegisterInfo(
+                new ShuffleServerInfo("id1", "0.0.0.1", 100),
+                Lists.newArrayList(new PartitionRange(0, 1))),
+            new ShuffleRegisterInfo(
+                new ShuffleServerInfo("id2", "0.0.0.2", 100),
+                Lists.newArrayList(new PartitionRange(0, 1))),
+            new ShuffleRegisterInfo(
+                new ShuffleServerInfo("id3", "0.0.0.3", 100),
+                Lists.newArrayList(new PartitionRange(2, 3))),
+            new ShuffleRegisterInfo(
+                new ShuffleServerInfo("id4", "0.0.0.4", 100),
+                Lists.newArrayList(new PartitionRange(2, 3))));
     assertEquals(4, serverToPartitionRanges.size());
     for (ShuffleRegisterInfo sri : expected) {
-      List<PartitionRange> partitionRanges = serverToPartitionRanges.get(sri.getShuffleServerInfo());
+      List<PartitionRange> partitionRanges =
+          serverToPartitionRanges.get(sri.getShuffleServerInfo());
       assertEquals(sri.getPartitionRanges(), partitionRanges);
     }
   }
 
   @Test
   public void getShuffleAssignmentsTest() throws Exception {
-    String appId = "getShuffleAssignmentsTest";
-    CoordinatorTestUtils.waitForRegister(coordinatorClient,2);
-    RssGetShuffleAssignmentsRequest request = new RssGetShuffleAssignmentsRequest(
-        appId, 1, 10, 4, 1,
-        Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION));
+    final String appId = "getShuffleAssignmentsTest";
+    CoordinatorTestUtils.waitForRegister(coordinatorClient, 2);
+    // When the shuffleServerHeartbeat Test is completed before the current test,
+    // the server's tags will be [ss_v4, GRPC_NETTY] and [ss_v4, GRPC], respectively.
+    // We need to remove the first machine's tag from GRPC_NETTY to GRPC
+    shuffleServers.get(0).stopServer();
+    RssConf shuffleServerConf = shuffleServers.get(0).getShuffleServerConf();
+    Class<RssConf> clazz = RssConf.class;
+    Field field = clazz.getDeclaredField("settings");
+    field.setAccessible(true);
+    ((ConcurrentHashMap<Object, Object>) field.get(shuffleServerConf))
+        .remove(ShuffleServerConf.NETTY_SERVER_PORT.key());
+    String storageTypeJsonSource = String.format("{\"%s\": \"ssd\"}", baseDir);
+    withEnvironmentVariables("RSS_ENV_KEY", storageTypeJsonSource)
+        .execute(
+            () -> {
+              shuffleServerConf.remove(ShuffleServerConf.NETTY_SERVER_PORT.key());
+              ShuffleServer ss = new ShuffleServer((ShuffleServerConf) shuffleServerConf);
+              ss.start();
+              shuffleServers.set(0, ss);
+            });
+    Thread.sleep(5000);
+    // add tag when ClientType is `GRPC`
+    RssGetShuffleAssignmentsRequest request =
+        new RssGetShuffleAssignmentsRequest(
+            appId,
+            1,
+            10,
+            4,
+            1,
+            Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION, ClientType.GRPC.name()));
     RssGetShuffleAssignmentsResponse response = coordinatorClient.getShuffleAssignments(request);
     Set<Integer> expectedStart = Sets.newHashSet(0, 4, 8);
 
-    Map<ShuffleServerInfo, List<PartitionRange>> serverToPartitionRanges = response.getServerToPartitionRanges();
+    Map<ShuffleServerInfo, List<PartitionRange>> serverToPartitionRanges =
+        response.getServerToPartitionRanges();
     assertEquals(2, serverToPartitionRanges.size());
     List<PartitionRange> partitionRanges = Lists.newArrayList();
     for (List<PartitionRange> ranges : serverToPartitionRanges.values()) {
@@ -155,9 +201,14 @@ public class CoordinatorGrpcTest extends CoordinatorTestBase {
     }
     assertTrue(expectedStart.isEmpty());
 
-    request = new RssGetShuffleAssignmentsRequest(
-        appId, 1, 10, 4, 2,
-        Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION));
+    request =
+        new RssGetShuffleAssignmentsRequest(
+            appId,
+            1,
+            10,
+            4,
+            2,
+            Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION, ClientType.GRPC.name()));
     response = coordinatorClient.getShuffleAssignments(request);
     serverToPartitionRanges = response.getServerToPartitionRanges();
     assertEquals(2, serverToPartitionRanges.size());
@@ -191,9 +242,8 @@ public class CoordinatorGrpcTest extends CoordinatorTestBase {
     assertEquals(2, range4To7);
     assertEquals(2, range8To11);
 
-    request = new RssGetShuffleAssignmentsRequest(
-        appId, 3, 2, 1, 1,
-        Sets.newHashSet("fake_version"));
+    request =
+        new RssGetShuffleAssignmentsRequest(appId, 3, 2, 1, 1, Sets.newHashSet("fake_version"));
     try {
       coordinatorClient.getShuffleAssignments(request);
       fail("Exception should be thrown");
@@ -208,11 +258,13 @@ public class CoordinatorGrpcTest extends CoordinatorTestBase {
         coordinatorClient.registerApplicationInfo(
             new RssApplicationInfoRequest("application_appHeartbeatTest1", 1000, "user"));
     assertEquals(StatusCode.SUCCESS, response.getStatusCode());
-    assertEquals(Sets.newHashSet("application_appHeartbeatTest1"),
+    assertEquals(
+        Sets.newHashSet("application_appHeartbeatTest1"),
         coordinators.get(0).getApplicationManager().getAppIds());
     coordinatorClient.registerApplicationInfo(
         new RssApplicationInfoRequest("application_appHeartbeatTest2", 1000, "user"));
-    assertEquals(Sets.newHashSet("application_appHeartbeatTest1", "application_appHeartbeatTest2"),
+    assertEquals(
+        Sets.newHashSet("application_appHeartbeatTest1", "application_appHeartbeatTest2"),
         coordinators.get(0).getApplicationManager().getAppIds());
     int retry = 0;
     while (retry < 5) {
@@ -222,7 +274,8 @@ public class CoordinatorGrpcTest extends CoordinatorTestBase {
       Thread.sleep(1000);
     }
     // appHeartbeatTest2 was removed because of expired
-    assertEquals(Sets.newHashSet("application_appHeartbeatTest1"),
+    assertEquals(
+        Sets.newHashSet("application_appHeartbeatTest1"),
         coordinators.get(0).getApplicationManager().getAppIds());
   }
 
@@ -237,82 +290,122 @@ public class CoordinatorGrpcTest extends CoordinatorTestBase {
     ServerNode node = nodes.get(0);
     assertEquals(1, node.getStorageInfo().size());
     StorageInfo infoHead = node.getStorageInfo().values().iterator().next();
-    assertEquals(StorageMedia.HDD, infoHead.getType());
+    final StorageInfo expectedStorageInfo =
+        shuffleServers.get(1).getStorageManager().getStorageInfo().values().iterator().next();
+    assertEquals(expectedStorageInfo, infoHead);
     assertEquals(StorageStatus.NORMAL, infoHead.getStatus());
     assertTrue(node.getTags().contains(Constants.SHUFFLE_SERVER_VERSION));
     assertTrue(scm.getTagToNodes().get(Constants.SHUFFLE_SERVER_VERSION).contains(node));
     ShuffleServerConf shuffleServerConf = shuffleServers.get(0).getShuffleServerConf();
     shuffleServerConf.setInteger("rss.rpc.server.port", SHUFFLE_SERVER_PORT + 2);
     shuffleServerConf.setInteger("rss.jetty.http.port", 18082);
+    shuffleServerConf.setInteger(ShuffleServerConf.NETTY_SERVER_PORT, SHUFFLE_SERVER_PORT + 5);
     shuffleServerConf.set(ShuffleServerConf.STORAGE_MEDIA_PROVIDER_ENV_KEY, "RSS_ENV_KEY");
     String baseDir = shuffleServerConf.get(ShuffleServerConf.RSS_STORAGE_BASE_PATH).get(0);
     String storageTypeJsonSource = String.format("{\"%s\": \"ssd\"}", baseDir);
-    withEnvironmentVariables("RSS_ENV_KEY", storageTypeJsonSource).execute(() -> {
-      // set this server's tag to ssd
-      shuffleServerConf.set(ShuffleServerConf.TAGS, Lists.newArrayList("SSD"));
-      ShuffleServer ss = new ShuffleServer(shuffleServerConf);
-      ss.start();
-      shuffleServers.set(0, ss);
-    });
+    withEnvironmentVariables("RSS_ENV_KEY", storageTypeJsonSource)
+        .execute(
+            () -> {
+              // set this server's tag to ssd
+              shuffleServerConf.set(ShuffleServerConf.TAGS, Lists.newArrayList("SSD"));
+              ShuffleServer ss = new ShuffleServer(shuffleServerConf);
+              ss.start();
+              shuffleServers.set(0, ss);
+            });
     Thread.sleep(3000);
     assertEquals(2, coordinators.get(0).getClusterManager().getNodesNum());
     nodes = scm.getServerList(Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION, "SSD"));
     assertEquals(1, nodes.size());
     ServerNode ssdNode = nodes.get(0);
     infoHead = ssdNode.getStorageInfo().values().iterator().next();
+    assertEquals(SHUFFLE_SERVER_PORT + 5, ssdNode.getNettyPort());
     assertEquals(StorageMedia.SSD, infoHead.getType());
+
     scm.close();
   }
 
   @Test
   public void rpcMetricsTest() throws Exception {
-    double oldValue = coordinators.get(0).getGrpcMetrics().getCounterMap()
-        .get(CoordinatorGrpcMetrics.HEARTBEAT_METHOD).get();
+    double oldValue =
+        coordinators
+            .get(0)
+            .getGrpcMetrics()
+            .getCounterMap()
+            .get(CoordinatorGrpcMetrics.HEARTBEAT_METHOD)
+            .get();
     CoordinatorTestUtils.waitForRegister(coordinatorClient, 2);
-    double newValue = coordinators.get(0).getGrpcMetrics().getCounterMap()
-        .get(CoordinatorGrpcMetrics.HEARTBEAT_METHOD).get();
+    double newValue =
+        coordinators
+            .get(0)
+            .getGrpcMetrics()
+            .getCounterMap()
+            .get(CoordinatorGrpcMetrics.HEARTBEAT_METHOD)
+            .get();
     assertTrue(newValue - oldValue > 1);
 
     String appId = "rpcMetricsTest";
-    RssGetShuffleAssignmentsRequest request = new RssGetShuffleAssignmentsRequest(
-        appId, 1, 10, 4, 1,
-        Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION));
-    oldValue = coordinators.get(0).getGrpcMetrics().getCounterMap()
-        .get(CoordinatorGrpcMetrics.GET_SHUFFLE_ASSIGNMENTS_METHOD).get();
+    RssGetShuffleAssignmentsRequest request =
+        new RssGetShuffleAssignmentsRequest(
+            appId, 1, 10, 4, 1, Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION));
+    oldValue =
+        coordinators
+            .get(0)
+            .getGrpcMetrics()
+            .getCounterMap()
+            .get(CoordinatorGrpcMetrics.GET_SHUFFLE_ASSIGNMENTS_METHOD)
+            .get();
     coordinatorClient.getShuffleAssignments(request);
-    newValue = coordinators.get(0).getGrpcMetrics().getCounterMap()
-        .get(CoordinatorGrpcMetrics.GET_SHUFFLE_ASSIGNMENTS_METHOD).get();
+    newValue =
+        coordinators
+            .get(0)
+            .getGrpcMetrics()
+            .getCounterMap()
+            .get(CoordinatorGrpcMetrics.GET_SHUFFLE_ASSIGNMENTS_METHOD)
+            .get();
     assertEquals(oldValue + 1, newValue, 0.5);
 
-    double connectionSize = coordinators.get(0)
-        .getGrpcMetrics().getGaugeMap().get(GRPC_SERVER_CONNECTION_NUMBER_KEY).get();
+    double connectionSize =
+        coordinators
+            .get(0)
+            .getGrpcMetrics()
+            .getGaugeMap()
+            .get(GRPC_SERVER_CONNECTION_NUMBER_KEY)
+            .get();
     assertTrue(connectionSize > 0);
   }
 
   private GetShuffleAssignmentsResponse generateShuffleAssignmentsResponse() {
-    ShuffleServerId ss1 = RssProtos.ShuffleServerId.newBuilder()
-        .setIp("0.0.0.1")
-        .setPort(100)
-        .setId("id1")
-        .build();
+    ShuffleServerId ss1 =
+        RssProtos.ShuffleServerId.newBuilder()
+            .setIp("0.0.0.1")
+            .setPort(100)
+            .setNettyPort(-1)
+            .setId("id1")
+            .build();
 
-    ShuffleServerId ss2 = RssProtos.ShuffleServerId.newBuilder()
-        .setIp("0.0.0.2")
-        .setPort(100)
-        .setId("id2")
-        .build();
+    ShuffleServerId ss2 =
+        RssProtos.ShuffleServerId.newBuilder()
+            .setIp("0.0.0.2")
+            .setPort(100)
+            .setNettyPort(-1)
+            .setId("id2")
+            .build();
 
-    ShuffleServerId ss3 = RssProtos.ShuffleServerId.newBuilder()
-        .setIp("0.0.0.3")
-        .setPort(100)
-        .setId("id3")
-        .build();
+    ShuffleServerId ss3 =
+        RssProtos.ShuffleServerId.newBuilder()
+            .setIp("0.0.0.3")
+            .setPort(100)
+            .setNettyPort(-1)
+            .setId("id3")
+            .build();
 
-    ShuffleServerId ss4 = RssProtos.ShuffleServerId.newBuilder()
-        .setIp("0.0.0.4")
-        .setPort(100)
-        .setId("id4")
-        .build();
+    ShuffleServerId ss4 =
+        RssProtos.ShuffleServerId.newBuilder()
+            .setIp("0.0.0.4")
+            .setPort(100)
+            .setNettyPort(-1)
+            .setId("id4")
+            .build();
 
     PartitionRangeAssignment assignment1 =
         RssProtos.PartitionRangeAssignment.newBuilder()
