@@ -32,6 +32,7 @@ import org.junit.jupiter.api.io.TempDir;
 
 import org.apache.uniffle.client.request.RssGetShuffleAssignmentsRequest;
 import org.apache.uniffle.client.response.RssGetShuffleAssignmentsResponse;
+import org.apache.uniffle.common.ServerStatus;
 import org.apache.uniffle.common.rpc.StatusCode;
 import org.apache.uniffle.common.util.Constants;
 import org.apache.uniffle.coordinator.CoordinatorConf;
@@ -41,10 +42,9 @@ import org.apache.uniffle.storage.util.StorageType;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.Assertions.fail;
 
-public class HealthCheckCoordinatorGrpcTest extends CoordinatorTestBase  {
+public class HealthCheckCoordinatorGrpcTest extends CoordinatorTestBase {
 
   private static File tempDataFile;
   private static int writeDataSize;
@@ -74,17 +74,23 @@ public class HealthCheckCoordinatorGrpcTest extends CoordinatorTestBase  {
     createCoordinatorServer(coordinatorConf);
     ShuffleServerConf shuffleServerConf = getShuffleServerConf();
     shuffleServerConf.setBoolean(ShuffleServerConf.HEALTH_CHECK_ENABLE, true);
-    shuffleServerConf.setString(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.LOCALFILE.name());
-    shuffleServerConf.set(ShuffleServerConf.RSS_STORAGE_BASE_PATH, Arrays.asList(data1.getAbsolutePath()));
-    shuffleServerConf.setDouble(ShuffleServerConf.HEALTH_STORAGE_RECOVERY_USAGE_PERCENTAGE, healthUsage);
+    shuffleServerConf.setString(
+        ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.LOCALFILE.name());
+    shuffleServerConf.set(
+        ShuffleServerConf.RSS_STORAGE_BASE_PATH, Arrays.asList(data1.getAbsolutePath()));
+    shuffleServerConf.setDouble(
+        ShuffleServerConf.HEALTH_STORAGE_RECOVERY_USAGE_PERCENTAGE, healthUsage);
     shuffleServerConf.setDouble(ShuffleServerConf.HEALTH_STORAGE_MAX_USAGE_PERCENTAGE, maxUsage);
     shuffleServerConf.setLong(ShuffleServerConf.HEALTH_CHECK_INTERVAL, 1000L);
     createShuffleServer(shuffleServerConf);
     shuffleServerConf.setInteger(ShuffleServerConf.RPC_SERVER_PORT, SHUFFLE_SERVER_PORT + 1);
     shuffleServerConf.setInteger(ShuffleServerConf.JETTY_HTTP_PORT, 18081);
-    shuffleServerConf.setString(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.LOCALFILE.name());
-    shuffleServerConf.set(ShuffleServerConf.RSS_STORAGE_BASE_PATH, Arrays.asList(data2.getAbsolutePath()));
-    shuffleServerConf.setDouble(ShuffleServerConf.HEALTH_STORAGE_RECOVERY_USAGE_PERCENTAGE, healthUsage);
+    shuffleServerConf.setString(
+        ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.LOCALFILE.name());
+    shuffleServerConf.set(
+        ShuffleServerConf.RSS_STORAGE_BASE_PATH, Arrays.asList(data2.getAbsolutePath()));
+    shuffleServerConf.setDouble(
+        ShuffleServerConf.HEALTH_STORAGE_RECOVERY_USAGE_PERCENTAGE, healthUsage);
     shuffleServerConf.setDouble(ShuffleServerConf.HEALTH_STORAGE_MAX_USAGE_PERCENTAGE, maxUsage);
     shuffleServerConf.setLong(ShuffleServerConf.HEALTH_CHECK_INTERVAL, 1000L);
     shuffleServerConf.setBoolean(ShuffleServerConf.HEALTH_CHECK_ENABLE, true);
@@ -96,24 +102,21 @@ public class HealthCheckCoordinatorGrpcTest extends CoordinatorTestBase  {
   public void healthCheckTest() throws Exception {
     Uninterruptibles.sleepUninterruptibly(5, TimeUnit.SECONDS);
     assertEquals(2, coordinatorClient.getShuffleServerList().getServersCount());
-    List<ServerNode> nodes  = coordinators.get(0).getClusterManager()
-        .getServerList(Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION));
+    List<ServerNode> nodes =
+        coordinators
+            .get(0)
+            .getClusterManager()
+            .getServerList(Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION));
     assertEquals(2, coordinatorClient.getShuffleServerList().getServersCount());
     assertEquals(2, nodes.size());
 
     RssGetShuffleAssignmentsRequest request =
         new RssGetShuffleAssignmentsRequest(
-          "1",
-          1,
-          1,
-          1,
-          1,
-          Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION));
-    RssGetShuffleAssignmentsResponse response =
-        coordinatorClient.getShuffleAssignments(request);
+            "1", 1, 1, 1, 1, Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION));
+    RssGetShuffleAssignmentsResponse response = coordinatorClient.getShuffleAssignments(request);
     assertFalse(response.getPartitionToServers().isEmpty());
     for (ServerNode node : nodes) {
-      assertTrue(node.isHealthy());
+      assertEquals(ServerStatus.ACTIVE, node.getStatus());
     }
     byte[] bytes = new byte[writeDataSize];
     new Random().nextBytes(bytes);
@@ -122,12 +125,16 @@ public class HealthCheckCoordinatorGrpcTest extends CoordinatorTestBase  {
     }
     Uninterruptibles.sleepUninterruptibly(10, TimeUnit.SECONDS);
 
-    nodes  = coordinators.get(0).getClusterManager().list();
+    nodes = coordinators.get(0).getClusterManager().list();
     assertEquals(2, nodes.size());
     for (ServerNode node : nodes) {
-      assertFalse(node.isHealthy());
+      assertEquals(ServerStatus.UNHEALTHY, node.getStatus());
     }
-    nodes = coordinators.get(0).getClusterManager().getServerList(Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION));
+    nodes =
+        coordinators
+            .get(0)
+            .getClusterManager()
+            .getServerList(Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION));
     assertEquals(0, nodes.size());
     response = coordinatorClient.getShuffleAssignments(request);
     assertEquals(StatusCode.INTERNAL_ERROR, response.getStatusCode());
@@ -136,19 +143,21 @@ public class HealthCheckCoordinatorGrpcTest extends CoordinatorTestBase  {
     int i = 0;
     do {
       Uninterruptibles.sleepUninterruptibly(5, TimeUnit.SECONDS);
-      nodes = coordinators.get(0).getClusterManager()
-          .getServerList(Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION));
+      nodes =
+          coordinators
+              .get(0)
+              .getClusterManager()
+              .getServerList(Sets.newHashSet(Constants.SHUFFLE_SERVER_VERSION));
       i++;
       if (i == 10) {
         fail();
       }
     } while (nodes.size() != 2);
     for (ServerNode node : nodes) {
-      assertTrue(node.isHealthy());
+      assertEquals(ServerStatus.ACTIVE, node.getStatus());
     }
     assertEquals(2, nodes.size());
-    response =
-        coordinatorClient.getShuffleAssignments(request);
+    response = coordinatorClient.getShuffleAssignments(request);
     assertFalse(response.getPartitionToServers().isEmpty());
   }
 }
