@@ -23,9 +23,11 @@ import java.io.PrintWriter;
 import java.nio.file.Files;
 import java.util.List;
 import java.util.Map;
+import java.util.concurrent.atomic.AtomicInteger;
 
 import com.google.common.collect.Lists;
 import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.io.TempDir;
 
 import org.apache.uniffle.common.util.RssUtils;
 import org.apache.uniffle.coordinator.CoordinatorConf;
@@ -35,10 +37,10 @@ import org.apache.uniffle.server.MockedShuffleServer;
 import org.apache.uniffle.server.ShuffleServer;
 import org.apache.uniffle.server.ShuffleServerConf;
 import org.apache.uniffle.server.ShuffleServerMetrics;
-import org.apache.uniffle.storage.HdfsTestBase;
+import org.apache.uniffle.storage.HadoopTestBase;
 import org.apache.uniffle.storage.util.StorageType;
 
-public abstract class IntegrationTestBase extends HdfsTestBase {
+public abstract class IntegrationTestBase extends HadoopTestBase {
 
   protected static final int SHUFFLE_SERVER_PORT = 20001;
   protected static final String LOCALHOST;
@@ -60,6 +62,11 @@ public abstract class IntegrationTestBase extends HdfsTestBase {
   protected static List<ShuffleServer> shuffleServers = Lists.newArrayList();
   protected static List<CoordinatorServer> coordinators = Lists.newArrayList();
 
+  protected static final int NETTY_PORT = 21000;
+  protected static AtomicInteger nettyPortCounter = new AtomicInteger();
+
+  static @TempDir File tempDir;
+
   public static void startServers() throws Exception {
     for (CoordinatorServer coordinator : coordinators) {
       coordinator.start();
@@ -95,18 +102,17 @@ public abstract class IntegrationTestBase extends HdfsTestBase {
       CoordinatorConf coordinatorConf, Map<String, String> dynamicConf) throws Exception {
     File file = createDynamicConfFile(dynamicConf);
     coordinatorConf.setBoolean(CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_ENABLED, true);
-    coordinatorConf.setString(CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_PATH,
-        file.getAbsolutePath());
-    coordinatorConf.setInteger(CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_UPDATE_INTERVAL_SEC, 5);
+    coordinatorConf.setString(
+        CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_PATH, file.getAbsolutePath());
+    coordinatorConf.setInteger(
+        CoordinatorConf.COORDINATOR_DYNAMIC_CLIENT_CONF_UPDATE_INTERVAL_SEC, 5);
   }
 
   protected static ShuffleServerConf getShuffleServerConf() throws Exception {
-    File dataFolder = Files.createTempDirectory("rssdata").toFile();
     ShuffleServerConf serverConf = new ShuffleServerConf();
-    dataFolder.deleteOnExit();
     serverConf.setInteger("rss.rpc.server.port", SHUFFLE_SERVER_PORT);
     serverConf.setString("rss.storage.type", StorageType.MEMORY_LOCALFILE_HDFS.name());
-    serverConf.setString("rss.storage.basePath", dataFolder.getAbsolutePath());
+    serverConf.setString("rss.storage.basePath", tempDir.getAbsolutePath());
     serverConf.setString("rss.server.buffer.capacity", "671088640");
     serverConf.setString("rss.server.memory.shuffle.highWaterMark", "50.0");
     serverConf.setString("rss.server.memory.shuffle.lowWaterMark", "0.0");
@@ -122,6 +128,9 @@ public abstract class IntegrationTestBase extends HdfsTestBase {
     serverConf.setBoolean("rss.server.health.check.enable", false);
     serverConf.setBoolean(ShuffleServerConf.RSS_TEST_MODE_ENABLE, true);
     serverConf.set(ShuffleServerConf.SERVER_TRIGGER_FLUSH_CHECK_INTERVAL, 500L);
+    serverConf.setInteger(
+        ShuffleServerConf.NETTY_SERVER_PORT, NETTY_PORT + nettyPortCounter.getAndIncrement());
+    serverConf.setString("rss.server.tags", "GRPC,GRPC_NETTY");
     return serverConf;
   }
 
@@ -138,8 +147,7 @@ public abstract class IntegrationTestBase extends HdfsTestBase {
   }
 
   protected static void createAndStartServers(
-      ShuffleServerConf shuffleServerConf,
-      CoordinatorConf coordinatorConf) throws Exception {
+      ShuffleServerConf shuffleServerConf, CoordinatorConf coordinatorConf) throws Exception {
     createCoordinatorServer(coordinatorConf);
     createShuffleServer(shuffleServerConf);
     startServers();
@@ -151,8 +159,8 @@ public abstract class IntegrationTestBase extends HdfsTestBase {
     return dynamicConfFile;
   }
 
-  protected static void writeRemoteStorageConf(
-      File cfgFile, Map<String, String> dynamicConf) throws Exception {
+  protected static void writeRemoteStorageConf(File cfgFile, Map<String, String> dynamicConf)
+      throws Exception {
     // sleep 2 secs to make sure the modified time will be updated
     Thread.sleep(2000);
     FileWriter fileWriter = new FileWriter(cfgFile);
