@@ -39,6 +39,7 @@ import org.apache.uniffle.common.PartitionRange;
 import org.apache.uniffle.common.ShuffleBlockInfo;
 import org.apache.uniffle.common.ShuffleDataResult;
 import org.apache.uniffle.common.ShuffleServerInfo;
+import org.apache.uniffle.common.util.ByteBufUtils;
 import org.apache.uniffle.coordinator.CoordinatorConf;
 import org.apache.uniffle.server.ShuffleServerConf;
 import org.apache.uniffle.server.buffer.ShuffleBuffer;
@@ -64,7 +65,8 @@ public class ShuffleServerWithMemoryTest extends ShuffleReadWriteBase {
     ShuffleServerConf shuffleServerConf = getShuffleServerConf();
     File dataDir = new File(tmpDir, "data");
     String basePath = dataDir.getAbsolutePath();
-    shuffleServerConf.set(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.LOCALFILE.name());
+    shuffleServerConf.setString(
+        ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.LOCALFILE.name());
     shuffleServerConf.set(ShuffleServerConf.RSS_STORAGE_BASE_PATH, Arrays.asList(basePath));
     shuffleServerConf.set(ShuffleServerConf.SERVER_APP_EXPIRED_WITHOUT_HEARTBEAT, 5000L);
     shuffleServerConf.set(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_LOWWATERMARK_PERCENTAGE, 20.0);
@@ -90,48 +92,55 @@ public class ShuffleServerWithMemoryTest extends ShuffleReadWriteBase {
     String testAppId = "memoryWriteReadTest";
     int shuffleId = 0;
     int partitionId = 0;
-    RssRegisterShuffleRequest rrsr = new RssRegisterShuffleRequest(testAppId, 0,
-        Lists.newArrayList(new PartitionRange(0, 0)), "");
+    RssRegisterShuffleRequest rrsr =
+        new RssRegisterShuffleRequest(
+            testAppId, 0, Lists.newArrayList(new PartitionRange(0, 0)), "");
     shuffleServerClient.registerShuffle(rrsr);
     Roaring64NavigableMap expectBlockIds = Roaring64NavigableMap.bitmapOf();
     Map<Long, byte[]> dataMap = Maps.newHashMap();
     Roaring64NavigableMap[] bitmaps = new Roaring64NavigableMap[1];
     bitmaps[0] = Roaring64NavigableMap.bitmapOf();
-    List<ShuffleBlockInfo> blocks = createShuffleBlockList(
-        shuffleId, partitionId, 0, 3, 25,
-        expectBlockIds, dataMap, mockSSI);
+    List<ShuffleBlockInfo> blocks =
+        createShuffleBlockList(shuffleId, partitionId, 0, 3, 25, expectBlockIds, dataMap, mockSSI);
     Map<Integer, List<ShuffleBlockInfo>> partitionToBlocks = Maps.newHashMap();
     partitionToBlocks.put(partitionId, blocks);
     Map<Integer, Map<Integer, List<ShuffleBlockInfo>>> shuffleToBlocks = Maps.newHashMap();
     shuffleToBlocks.put(shuffleId, partitionToBlocks);
 
     // send data to shuffle server
-    RssSendShuffleDataRequest rssdr = new RssSendShuffleDataRequest(
-        testAppId, 3, 1000, shuffleToBlocks);
+    RssSendShuffleDataRequest rssdr =
+        new RssSendShuffleDataRequest(testAppId, 3, 1000, shuffleToBlocks);
     shuffleServerClient.sendShuffleData(rssdr);
 
     // data is cached
-    assertEquals(3, shuffleServers.get(0).getShuffleBufferManager()
-        .getShuffleBuffer(testAppId, shuffleId, 0).getBlocks().size());
+    assertEquals(
+        3,
+        shuffleServers
+            .get(0)
+            .getShuffleBufferManager()
+            .getShuffleBuffer(testAppId, shuffleId, 0)
+            .getBlocks()
+            .size());
 
     Roaring64NavigableMap exceptTaskIds = Roaring64NavigableMap.bitmapOf(0);
     // create memory handler to read data,
-    MemoryClientReadHandler memoryClientReadHandler = new MemoryClientReadHandler(
-        testAppId, shuffleId, partitionId, 20, shuffleServerClient, exceptTaskIds);
+    MemoryClientReadHandler memoryClientReadHandler =
+        new MemoryClientReadHandler(
+            testAppId, shuffleId, partitionId, 20, shuffleServerClient, exceptTaskIds);
     // start to read data, one block data for every call
-    ShuffleDataResult sdr  = memoryClientReadHandler.readShuffleData();
+    ShuffleDataResult sdr = memoryClientReadHandler.readShuffleData();
     Map<Long, byte[]> expectedData = Maps.newHashMap();
-    expectedData.put(blocks.get(0).getBlockId(), blocks.get(0).getData());
+    expectedData.put(blocks.get(0).getBlockId(), ByteBufUtils.readBytes(blocks.get(0).getData()));
     validateResult(expectedData, sdr);
 
     sdr = memoryClientReadHandler.readShuffleData();
     expectedData.clear();
-    expectedData.put(blocks.get(1).getBlockId(), blocks.get(1).getData());
+    expectedData.put(blocks.get(1).getBlockId(), ByteBufUtils.readBytes(blocks.get(1).getData()));
     validateResult(expectedData, sdr);
 
     sdr = memoryClientReadHandler.readShuffleData();
     expectedData.clear();
-    expectedData.put(blocks.get(2).getBlockId(), blocks.get(2).getData());
+    expectedData.put(blocks.get(2).getBlockId(), ByteBufUtils.readBytes(blocks.get(2).getData()));
     validateResult(expectedData, sdr);
 
     // no data in cache, empty return
@@ -139,40 +148,48 @@ public class ShuffleServerWithMemoryTest extends ShuffleReadWriteBase {
     assertEquals(0, sdr.getBufferSegments().size());
 
     // case: read with ComposedClientReadHandler
-    memoryClientReadHandler = new MemoryClientReadHandler(
-        testAppId, shuffleId, partitionId, 50, shuffleServerClient,
-        exceptTaskIds);
+    memoryClientReadHandler =
+        new MemoryClientReadHandler(
+            testAppId, shuffleId, partitionId, 50, shuffleServerClient, exceptTaskIds);
 
     Roaring64NavigableMap processBlockIds = Roaring64NavigableMap.bitmapOf();
-    LocalFileClientReadHandler localFileQuorumClientReadHandler = new LocalFileClientReadHandler(
-        testAppId, shuffleId, partitionId, 0, 1, 3,
-        50, expectBlockIds, processBlockIds, shuffleServerClient);
+    LocalFileClientReadHandler localFileQuorumClientReadHandler =
+        new LocalFileClientReadHandler(
+            testAppId,
+            shuffleId,
+            partitionId,
+            0,
+            1,
+            3,
+            50,
+            expectBlockIds,
+            processBlockIds,
+            shuffleServerClient);
     ClientReadHandler[] handlers = new ClientReadHandler[2];
     handlers[0] = memoryClientReadHandler;
     handlers[1] = localFileQuorumClientReadHandler;
-    ComposedClientReadHandler composedClientReadHandler = new ComposedClientReadHandler(
-        new ShuffleServerInfo(LOCALHOST, SHUFFLE_SERVER_PORT), handlers);
+    ComposedClientReadHandler composedClientReadHandler =
+        new ComposedClientReadHandler(
+            new ShuffleServerInfo(LOCALHOST, SHUFFLE_SERVER_PORT), handlers);
     // read from memory with ComposedClientReadHandler
-    sdr  = composedClientReadHandler.readShuffleData();
+    sdr = composedClientReadHandler.readShuffleData();
     expectedData.clear();
-    expectedData.put(blocks.get(0).getBlockId(), blocks.get(0).getData());
-    expectedData.put(blocks.get(1).getBlockId(), blocks.get(1).getData());
+    expectedData.put(blocks.get(0).getBlockId(), ByteBufUtils.readBytes(blocks.get(0).getData()));
+    expectedData.put(blocks.get(1).getBlockId(), ByteBufUtils.readBytes(blocks.get(1).getData()));
     validateResult(expectedData, sdr);
 
     // send data to shuffle server, flush should happen
     processBlockIds.addLong(blocks.get(0).getBlockId());
     processBlockIds.addLong(blocks.get(1).getBlockId());
 
-    List<ShuffleBlockInfo> blocks2 = createShuffleBlockList(
-        shuffleId, partitionId, 0, 3, 50,
-        expectBlockIds, dataMap, mockSSI);
+    List<ShuffleBlockInfo> blocks2 =
+        createShuffleBlockList(shuffleId, partitionId, 0, 3, 50, expectBlockIds, dataMap, mockSSI);
     partitionToBlocks = Maps.newHashMap();
     partitionToBlocks.put(partitionId, blocks2);
     shuffleToBlocks = Maps.newHashMap();
     shuffleToBlocks.put(shuffleId, partitionToBlocks);
 
-    rssdr = new RssSendShuffleDataRequest(
-        testAppId, 3, 1000, shuffleToBlocks);
+    rssdr = new RssSendShuffleDataRequest(testAppId, 3, 1000, shuffleToBlocks);
     shuffleServerClient.sendShuffleData(rssdr);
     // wait until flush finished
     int retry = 0;
@@ -180,8 +197,8 @@ public class ShuffleServerWithMemoryTest extends ShuffleReadWriteBase {
       if (retry > 5) {
         fail("Timeout for flush data");
       }
-      ShuffleBuffer shuffleBuffer = shuffleServers.get(0).getShuffleBufferManager()
-          .getShuffleBuffer(testAppId, shuffleId, 0);
+      ShuffleBuffer shuffleBuffer =
+          shuffleServers.get(0).getShuffleBufferManager().getShuffleBuffer(testAppId, shuffleId, 0);
       if (shuffleBuffer.getBlocks().size() == 0 && shuffleBuffer.getInFlushBlockMap().size() == 0) {
         break;
       }
@@ -192,36 +209,36 @@ public class ShuffleServerWithMemoryTest extends ShuffleReadWriteBase {
     // when segment filter is introduced, there is no need to read duplicated data
     sdr = composedClientReadHandler.readShuffleData();
     expectedData.clear();
-    expectedData.put(blocks.get(2).getBlockId(), blocks.get(2).getData());
-    expectedData.put(blocks2.get(0).getBlockId(), blocks2.get(0).getData());
+    expectedData.put(blocks.get(2).getBlockId(), ByteBufUtils.readBytes(blocks.get(2).getData()));
+    expectedData.put(blocks2.get(0).getBlockId(), ByteBufUtils.readBytes(blocks2.get(0).getData()));
     validateResult(expectedData, sdr);
     processBlockIds.addLong(blocks.get(2).getBlockId());
     processBlockIds.addLong(blocks2.get(0).getBlockId());
 
-    sdr  = composedClientReadHandler.readShuffleData();
+    sdr = composedClientReadHandler.readShuffleData();
     expectedData.clear();
-    expectedData.put(blocks2.get(1).getBlockId(), blocks2.get(1).getData());
+    expectedData.put(blocks2.get(1).getBlockId(), ByteBufUtils.readBytes(blocks2.get(1).getData()));
     validateResult(expectedData, sdr);
     processBlockIds.addLong(blocks2.get(1).getBlockId());
 
-    sdr  = composedClientReadHandler.readShuffleData();
+    sdr = composedClientReadHandler.readShuffleData();
     expectedData.clear();
-    expectedData.put(blocks2.get(2).getBlockId(), blocks2.get(2).getData());
+    expectedData.put(blocks2.get(2).getBlockId(), ByteBufUtils.readBytes(blocks2.get(2).getData()));
     validateResult(expectedData, sdr);
     processBlockIds.addLong(blocks2.get(2).getBlockId());
 
-    sdr  = composedClientReadHandler.readShuffleData();
+    sdr = composedClientReadHandler.readShuffleData();
     assertNull(sdr);
   }
 
-
   @Test
   public void memoryWriteReadWithMultiReplicaTest() throws Exception {
     String testAppId = "memoryWriteReadWithMultiReplicaTest";
     int shuffleId = 0;
     int partitionId = 0;
-    RssRegisterShuffleRequest rrsr = new RssRegisterShuffleRequest(testAppId, 0,
-        Lists.newArrayList(new PartitionRange(0, 0)), "");
+    RssRegisterShuffleRequest rrsr =
+        new RssRegisterShuffleRequest(
+            testAppId, 0, Lists.newArrayList(new PartitionRange(0, 0)), "");
     shuffleServerClient.registerShuffle(rrsr);
     Roaring64NavigableMap expectBlockIds = Roaring64NavigableMap.bitmapOf();
     Map<Long, byte[]> dataMap = Maps.newHashMap();
@@ -230,9 +247,9 @@ public class ShuffleServerWithMemoryTest extends ShuffleReadWriteBase {
     // create blocks which belong to different tasks
     List<ShuffleBlockInfo> blocks = Lists.newArrayList();
     for (int i = 0; i < 3; i++) {
-      blocks.addAll(createShuffleBlockList(
-          shuffleId, partitionId, i, 1, 25,
-          expectBlockIds, dataMap, mockSSI));
+      blocks.addAll(
+          createShuffleBlockList(
+              shuffleId, partitionId, i, 1, 25, expectBlockIds, dataMap, mockSSI));
     }
     Map<Integer, List<ShuffleBlockInfo>> partitionToBlocks = Maps.newHashMap();
     partitionToBlocks.put(partitionId, blocks);
@@ -240,41 +257,49 @@ public class ShuffleServerWithMemoryTest extends ShuffleReadWriteBase {
     shuffleToBlocks.put(shuffleId, partitionToBlocks);
 
     // send data to shuffle server
-    RssSendShuffleDataRequest rssdr = new RssSendShuffleDataRequest(
-        testAppId, 3, 1000, shuffleToBlocks);
+    RssSendShuffleDataRequest rssdr =
+        new RssSendShuffleDataRequest(testAppId, 3, 1000, shuffleToBlocks);
     shuffleServerClient.sendShuffleData(rssdr);
 
     // data is cached
-    assertEquals(3, shuffleServers.get(0).getShuffleBufferManager()
-        .getShuffleBuffer(testAppId, shuffleId, 0).getBlocks().size());
+    assertEquals(
+        3,
+        shuffleServers
+            .get(0)
+            .getShuffleBufferManager()
+            .getShuffleBuffer(testAppId, shuffleId, 0)
+            .getBlocks()
+            .size());
 
     Roaring64NavigableMap processBlockIds = Roaring64NavigableMap.bitmapOf();
     Roaring64NavigableMap exceptTaskIds = Roaring64NavigableMap.bitmapOf(0, 1, 2);
     // create memory handler to read data,
-    MemoryClientReadHandler memoryClientReadHandler = new MemoryClientReadHandler(
-        testAppId, shuffleId, partitionId, 20, shuffleServerClient, exceptTaskIds);
+    MemoryClientReadHandler memoryClientReadHandler =
+        new MemoryClientReadHandler(
+            testAppId, shuffleId, partitionId, 20, shuffleServerClient, exceptTaskIds);
     // start to read data, one block data for every call
-    ShuffleDataResult sdr  = memoryClientReadHandler.readShuffleData();
+    ShuffleDataResult sdr = memoryClientReadHandler.readShuffleData();
     Map<Long, byte[]> expectedData = Maps.newHashMap();
-    expectedData.put(blocks.get(0).getBlockId(), blocks.get(0).getData());
+    expectedData.put(blocks.get(0).getBlockId(), ByteBufUtils.readBytes(blocks.get(0).getData()));
     validateResult(expectedData, sdr);
     // read by different reader, the first block should be skipped.
     exceptTaskIds.removeLong(blocks.get(0).getTaskAttemptId());
-    MemoryClientReadHandler memoryClientReadHandler2 = new MemoryClientReadHandler(
-        testAppId, shuffleId, partitionId, 20, shuffleServerClient, exceptTaskIds);
+    MemoryClientReadHandler memoryClientReadHandler2 =
+        new MemoryClientReadHandler(
+            testAppId, shuffleId, partitionId, 20, shuffleServerClient, exceptTaskIds);
     sdr = memoryClientReadHandler2.readShuffleData();
     expectedData.clear();
-    expectedData.put(blocks.get(1).getBlockId(), blocks.get(1).getData());
+    expectedData.put(blocks.get(1).getBlockId(), ByteBufUtils.readBytes(blocks.get(1).getData()));
     validateResult(expectedData, sdr);
 
     sdr = memoryClientReadHandler.readShuffleData();
     expectedData.clear();
-    expectedData.put(blocks.get(1).getBlockId(), blocks.get(1).getData());
+    expectedData.put(blocks.get(1).getBlockId(), ByteBufUtils.readBytes(blocks.get(1).getData()));
     validateResult(expectedData, sdr);
 
     sdr = memoryClientReadHandler2.readShuffleData();
     expectedData.clear();
-    expectedData.put(blocks.get(2).getBlockId(), blocks.get(2).getData());
+    expectedData.put(blocks.get(2).getBlockId(), ByteBufUtils.readBytes(blocks.get(2).getData()));
     validateResult(expectedData, sdr);
     // no data in cache, empty return
     sdr = memoryClientReadHandler2.readShuffleData();
@@ -286,60 +311,69 @@ public class ShuffleServerWithMemoryTest extends ShuffleReadWriteBase {
     String testAppId = "memoryAndLocalFileReadWithFilterTest";
     int shuffleId = 0;
     int partitionId = 0;
-    RssRegisterShuffleRequest rrsr = new RssRegisterShuffleRequest(testAppId, 0,
-        Lists.newArrayList(new PartitionRange(0, 0)), "");
+    RssRegisterShuffleRequest rrsr =
+        new RssRegisterShuffleRequest(
+            testAppId, 0, Lists.newArrayList(new PartitionRange(0, 0)), "");
     shuffleServerClient.registerShuffle(rrsr);
     Roaring64NavigableMap expectBlockIds = Roaring64NavigableMap.bitmapOf();
     Map<Long, byte[]> dataMap = Maps.newHashMap();
     Roaring64NavigableMap[] bitmaps = new Roaring64NavigableMap[1];
     bitmaps[0] = Roaring64NavigableMap.bitmapOf();
-    List<ShuffleBlockInfo> blocks = createShuffleBlockList(
-        shuffleId, partitionId, 0, 3, 25,
-        expectBlockIds, dataMap, mockSSI);
+    List<ShuffleBlockInfo> blocks =
+        createShuffleBlockList(shuffleId, partitionId, 0, 3, 25, expectBlockIds, dataMap, mockSSI);
     Map<Integer, List<ShuffleBlockInfo>> partitionToBlocks = Maps.newHashMap();
     partitionToBlocks.put(partitionId, blocks);
     Map<Integer, Map<Integer, List<ShuffleBlockInfo>>> shuffleToBlocks = Maps.newHashMap();
     shuffleToBlocks.put(shuffleId, partitionToBlocks);
 
     // send data to shuffle server's memory
-    RssSendShuffleDataRequest rssdr = new RssSendShuffleDataRequest(
-        testAppId, 3, 1000, shuffleToBlocks);
+    RssSendShuffleDataRequest rssdr =
+        new RssSendShuffleDataRequest(testAppId, 3, 1000, shuffleToBlocks);
     shuffleServerClient.sendShuffleData(rssdr);
 
     // read the 1-th segment from memory
     Roaring64NavigableMap processBlockIds = Roaring64NavigableMap.bitmapOf();
     Roaring64NavigableMap exceptTaskIds = Roaring64NavigableMap.bitmapOf(0);
-    MemoryClientReadHandler memoryClientReadHandler = new MemoryClientReadHandler(
-        testAppId, shuffleId, partitionId, 150, shuffleServerClient, exceptTaskIds);
-    LocalFileClientReadHandler localFileClientReadHandler = new LocalFileClientReadHandler(
-        testAppId, shuffleId, partitionId, 0, 1, 3,
-        75, expectBlockIds, processBlockIds, shuffleServerClient);
+    MemoryClientReadHandler memoryClientReadHandler =
+        new MemoryClientReadHandler(
+            testAppId, shuffleId, partitionId, 150, shuffleServerClient, exceptTaskIds);
+    LocalFileClientReadHandler localFileClientReadHandler =
+        new LocalFileClientReadHandler(
+            testAppId,
+            shuffleId,
+            partitionId,
+            0,
+            1,
+            3,
+            75,
+            expectBlockIds,
+            processBlockIds,
+            shuffleServerClient);
     ClientReadHandler[] handlers = new ClientReadHandler[2];
     handlers[0] = memoryClientReadHandler;
     handlers[1] = localFileClientReadHandler;
-    ComposedClientReadHandler composedClientReadHandler = new ComposedClientReadHandler(
-        new ShuffleServerInfo(LOCALHOST, SHUFFLE_SERVER_PORT), handlers);
+    ComposedClientReadHandler composedClientReadHandler =
+        new ComposedClientReadHandler(
+            new ShuffleServerInfo(LOCALHOST, SHUFFLE_SERVER_PORT), handlers);
     Map<Long, byte[]> expectedData = Maps.newHashMap();
     expectedData.clear();
-    expectedData.put(blocks.get(0).getBlockId(), blocks.get(0).getData());
-    expectedData.put(blocks.get(1).getBlockId(), blocks.get(1).getData());
-    expectedData.put(blocks.get(2).getBlockId(), blocks.get(1).getData());
-    ShuffleDataResult sdr  = composedClientReadHandler.readShuffleData();
+    expectedData.put(blocks.get(0).getBlockId(), ByteBufUtils.readBytes(blocks.get(0).getData()));
+    expectedData.put(blocks.get(1).getBlockId(), ByteBufUtils.readBytes(blocks.get(1).getData()));
+    expectedData.put(blocks.get(2).getBlockId(), ByteBufUtils.readBytes(blocks.get(1).getData()));
+    ShuffleDataResult sdr = composedClientReadHandler.readShuffleData();
     validateResult(expectedData, sdr);
     processBlockIds.addLong(blocks.get(0).getBlockId());
     processBlockIds.addLong(blocks.get(1).getBlockId());
     processBlockIds.addLong(blocks.get(2).getBlockId());
 
     // send data to shuffle server, and wait until flush finish
-    List<ShuffleBlockInfo> blocks2 = createShuffleBlockList(
-        shuffleId, partitionId, 0, 3, 50,
-        expectBlockIds, dataMap, mockSSI);
+    List<ShuffleBlockInfo> blocks2 =
+        createShuffleBlockList(shuffleId, partitionId, 0, 3, 50, expectBlockIds, dataMap, mockSSI);
     partitionToBlocks = Maps.newHashMap();
     partitionToBlocks.put(partitionId, blocks2);
     shuffleToBlocks = Maps.newHashMap();
     shuffleToBlocks.put(shuffleId, partitionToBlocks);
-    rssdr = new RssSendShuffleDataRequest(
-      testAppId, 3, 1000, shuffleToBlocks);
+    rssdr = new RssSendShuffleDataRequest(testAppId, 3, 1000, shuffleToBlocks);
     shuffleServerClient.sendShuffleData(rssdr);
 
     int retry = 0;
@@ -347,8 +381,8 @@ public class ShuffleServerWithMemoryTest extends ShuffleReadWriteBase {
       if (retry > 5) {
         fail("Timeout for flush data");
       }
-      ShuffleBuffer shuffleBuffer = shuffleServers.get(0).getShuffleBufferManager()
-          .getShuffleBuffer(testAppId, shuffleId, 0);
+      ShuffleBuffer shuffleBuffer =
+          shuffleServers.get(0).getShuffleBufferManager().getShuffleBuffer(testAppId, shuffleId, 0);
       if (shuffleBuffer.getBlocks().size() == 0 && shuffleBuffer.getInFlushBlockMap().size() == 0) {
         break;
       }
@@ -358,29 +392,27 @@ public class ShuffleServerWithMemoryTest extends ShuffleReadWriteBase {
 
     // read the 2-th segment from localFile
     // notice: the 1-th segment is skipped, because it is processed
-    sdr  = composedClientReadHandler.readShuffleData();
+    sdr = composedClientReadHandler.readShuffleData();
     expectedData.clear();
-    expectedData.put(blocks2.get(0).getBlockId(), blocks2.get(0).getData());
-    expectedData.put(blocks2.get(1).getBlockId(), blocks2.get(1).getData());
+    expectedData.put(blocks2.get(0).getBlockId(), ByteBufUtils.readBytes(blocks2.get(0).getData()));
+    expectedData.put(blocks2.get(1).getBlockId(), ByteBufUtils.readBytes(blocks2.get(1).getData()));
     validateResult(expectedData, sdr);
     processBlockIds.addLong(blocks2.get(0).getBlockId());
     processBlockIds.addLong(blocks2.get(1).getBlockId());
 
     // read the 3-th segment from localFile
-    sdr  = composedClientReadHandler.readShuffleData();
+    sdr = composedClientReadHandler.readShuffleData();
     expectedData.clear();
-    expectedData.put(blocks2.get(2).getBlockId(), blocks2.get(2).getData());
+    expectedData.put(blocks2.get(2).getBlockId(), ByteBufUtils.readBytes(blocks2.get(2).getData()));
     validateResult(expectedData, sdr);
     processBlockIds.addLong(blocks2.get(2).getBlockId());
 
     // all segments are processed
-    sdr  = composedClientReadHandler.readShuffleData();
+    sdr = composedClientReadHandler.readShuffleData();
     assertNull(sdr);
   }
 
-  protected void validateResult(
-      Map<Long, byte[]> expectedData,
-      ShuffleDataResult sdr) {
+  protected void validateResult(Map<Long, byte[]> expectedData, ShuffleDataResult sdr) {
     byte[] buffer = sdr.getData();
     List<BufferSegment> bufferSegments = sdr.getBufferSegments();
     assertEquals(expectedData.size(), bufferSegments.size());
