@@ -20,13 +20,14 @@ package org.apache.uniffle.test;
 import java.util.Map;
 import java.util.concurrent.TimeUnit;
 
+import scala.Option;
+
 import com.google.common.util.concurrent.Uninterruptibles;
 import org.apache.spark.SparkConf;
 import org.apache.spark.shuffle.RssSparkConfig;
 import org.apache.spark.sql.SparkSession;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import scala.Option;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 
@@ -40,8 +41,7 @@ public abstract class SparkIntegrationTestBase extends IntegrationTestBase {
     return null;
   }
 
-  public void updateSparkConfCustomer(SparkConf sparkConf) {
-  }
+  public void updateSparkConfCustomer(SparkConf sparkConf) {}
 
   public void run() throws Exception {
 
@@ -58,17 +58,27 @@ public abstract class SparkIntegrationTestBase extends IntegrationTestBase {
     updateSparkConfCustomer(sparkConf);
     start = System.currentTimeMillis();
     Map resultWithRss = runSparkApp(sparkConf, fileName);
-    long durationWithRss = System.currentTimeMillis() - start;
+    final long durationWithRss = System.currentTimeMillis() - start;
 
+    updateSparkConfWithRssNetty(sparkConf);
+    start = System.currentTimeMillis();
+    Map resultWithRssNetty = runSparkApp(sparkConf, fileName);
+    final long durationWithRssNetty = System.currentTimeMillis() - start;
     verifyTestResult(resultWithoutRss, resultWithRss);
+    verifyTestResult(resultWithoutRss, resultWithRssNetty);
 
-    LOG.info("Test: durationWithoutRss[" + durationWithoutRss
-        + "], durationWithRss[" + durationWithRss + "]");
+    LOG.info(
+        "Test: durationWithoutRss["
+            + durationWithoutRss
+            + "], durationWithRss["
+            + durationWithRss
+            + "]"
+            + "], durationWithRssNetty["
+            + durationWithRssNetty
+            + "]");
   }
 
-  public void updateCommonSparkConf(SparkConf sparkConf) {
-
-  }
+  public void updateCommonSparkConf(SparkConf sparkConf) {}
 
   private static <T> T getIfExists(Option<T> o) {
     return o.isDefined() ? o.get() : null;
@@ -86,9 +96,7 @@ public abstract class SparkIntegrationTestBase extends IntegrationTestBase {
   }
 
   protected SparkConf createSparkConf() {
-    return new SparkConf()
-        .setAppName(this.getClass().getSimpleName())
-        .setMaster("local[4]");
+    return new SparkConf().setAppName(this.getClass().getSimpleName()).setMaster("local[4]");
   }
 
   public void updateSparkConfWithRss(SparkConf sparkConf) {
@@ -110,6 +118,10 @@ public abstract class SparkIntegrationTestBase extends IntegrationTestBase {
     sparkConf.set(RssSparkConfig.RSS_TEST_MODE_ENABLE.key(), "true");
   }
 
+  public void updateSparkConfWithRssNetty(SparkConf sparkConf) {
+    sparkConf.set(RssSparkConfig.RSS_CLIENT_TYPE, "GRPC_NETTY");
+  }
+
   protected void verifyTestResult(Map expected, Map actual) {
     assertEquals(expected.size(), actual.size());
     for (Object expectedKey : expected.keySet()) {
