@@ -59,7 +59,8 @@ public interface ShuffleServerClient {
 
   RssGetShuffleResultResponse getShuffleResult(RssGetShuffleResultRequest request);
 
-  RssGetShuffleResultResponse getShuffleResultForMultiPart(RssGetShuffleResultForMultiPartRequest request);
+  RssGetShuffleResultResponse getShuffleResultForMultiPart(
+      RssGetShuffleResultForMultiPartRequest request);
 
   RssGetShuffleIndexResponse getShuffleIndex(RssGetShuffleIndexRequest request);
 
