@@ -28,6 +28,7 @@ import org.slf4j.LoggerFactory;
 import org.apache.uniffle.client.api.CoordinatorClient;
 import org.apache.uniffle.client.impl.grpc.CoordinatorGrpcClient;
 import org.apache.uniffle.common.ClientType;
+import org.apache.uniffle.common.exception.RssException;
 
 public class CoordinatorClientFactory {
   private static final Logger LOG = LoggerFactory.getLogger(CoordinatorClientFactory.class);
@@ -39,7 +40,7 @@ public class CoordinatorClientFactory {
   }
 
   public CoordinatorClient createCoordinatorClient(String host, int port) {
-    if (clientType.equals(ClientType.GRPC)) {
+    if (clientType.equals(ClientType.GRPC) || clientType.equals(ClientType.GRPC_NETTY)) {
       return new CoordinatorGrpcClient(host, port);
     } else {
       throw new UnsupportedOperationException("Unsupported client type " + clientType);
@@ -53,15 +54,15 @@ public class CoordinatorClientFactory {
     if (coordinatorList.length == 0) {
       String msg = "Invalid " + coordinators;
       LOG.error(msg);
-      throw new RuntimeException(msg);
+      throw new RssException(msg);
     }
 
-    for (String coordinator: coordinatorList) {
+    for (String coordinator : coordinatorList) {
       String[] ipPort = coordinator.trim().split(":");
       if (ipPort.length != 2) {
         String msg = "Invalid coordinator format " + Arrays.toString(ipPort);
         LOG.error(msg);
-        throw new RuntimeException(msg);
+        throw new RssException(msg);
       }
 
       String host = ipPort[0];
@@ -70,8 +71,11 @@ public class CoordinatorClientFactory {
       coordinatorClients.add(coordinatorClient);
       LOG.info("Add coordinator client {}", coordinatorClient.getDesc());
     }
-    LOG.info("Finish create coordinator clients {}",
-        coordinatorClients.stream().map(CoordinatorClient::getDesc).collect(Collectors.joining(", ")));
+    LOG.info(
+        "Finish create coordinator clients {}",
+        coordinatorClients.stream()
+            .map(CoordinatorClient::getDesc)
+            .collect(Collectors.joining(", ")));
     return coordinatorClients;
   }
 }
