@@ -19,19 +19,20 @@ package org.apache.uniffle.client.factory;
 
 import java.util.Map;
 
-import com.google.common.collect.Maps;
-
 import org.apache.uniffle.client.api.ShuffleServerClient;
 import org.apache.uniffle.client.impl.grpc.ShuffleServerGrpcClient;
+import org.apache.uniffle.client.impl.grpc.ShuffleServerGrpcNettyClient;
 import org.apache.uniffle.common.ClientType;
 import org.apache.uniffle.common.ShuffleServerInfo;
+import org.apache.uniffle.common.config.RssConf;
+import org.apache.uniffle.common.util.JavaUtils;
 
 public class ShuffleServerClientFactory {
 
   private Map<String, Map<ShuffleServerInfo, ShuffleServerClient>> clients;
 
   private ShuffleServerClientFactory() {
-    clients = Maps.newConcurrentMap();
+    clients = JavaUtils.newConcurrentMap();
   }
 
   private static class LazyHolder {
@@ -42,9 +43,17 @@ public class ShuffleServerClientFactory {
     return LazyHolder.INSTANCE;
   }
 
-  private ShuffleServerClient createShuffleServerClient(String clientType, ShuffleServerInfo shuffleServerInfo) {
+  private ShuffleServerClient createShuffleServerClient(
+      String clientType, ShuffleServerInfo shuffleServerInfo, RssConf rssConf) {
     if (clientType.equalsIgnoreCase(ClientType.GRPC.name())) {
-      return new ShuffleServerGrpcClient(shuffleServerInfo.getHost(), shuffleServerInfo.getPort());
+      return new ShuffleServerGrpcClient(
+          shuffleServerInfo.getHost(), shuffleServerInfo.getGrpcPort());
+    } else if (clientType.equalsIgnoreCase(ClientType.GRPC_NETTY.name())) {
+      return new ShuffleServerGrpcNettyClient(
+          rssConf,
+          shuffleServerInfo.getHost(),
+          shuffleServerInfo.getGrpcPort(),
+          shuffleServerInfo.getNettyPort());
     } else {
       throw new UnsupportedOperationException("Unsupported client type " + clientType);
     }
@@ -52,10 +61,16 @@ public class ShuffleServerClientFactory {
 
   public synchronized ShuffleServerClient getShuffleServerClient(
       String clientType, ShuffleServerInfo shuffleServerInfo) {
-    clients.putIfAbsent(clientType, Maps.newConcurrentMap());
+    return getShuffleServerClient(clientType, shuffleServerInfo, new RssConf());
+  }
+
+  public synchronized ShuffleServerClient getShuffleServerClient(
+      String clientType, ShuffleServerInfo shuffleServerInfo, RssConf rssConf) {
+    clients.putIfAbsent(clientType, JavaUtils.newConcurrentMap());
     Map<ShuffleServerInfo, ShuffleServerClient> serverToClients = clients.get(clientType);
     if (serverToClients.get(shuffleServerInfo) == null) {
-      serverToClients.put(shuffleServerInfo, createShuffleServerClient(clientType, shuffleServerInfo));
+      serverToClients.put(
+          shuffleServerInfo, createShuffleServerClient(clientType, shuffleServerInfo, rssConf));
     }
     return serverToClients.get(shuffleServerInfo);
   }
@@ -63,6 +78,6 @@ public class ShuffleServerClientFactory {
   // Only for tests
   public synchronized void cleanupCache() {
     clients.values().stream().flatMap(x -> x.values().stream()).forEach(ShuffleServerClient::close);
-    this.clients = Maps.newConcurrentMap();
+    this.clients = JavaUtils.newConcurrentMap();
   }
 }
