@@ -17,13 +17,15 @@
 
 package org.apache.uniffle.client.response;
 
+import java.nio.ByteBuffer;
+
 import org.apache.uniffle.common.ShuffleIndexResult;
 import org.apache.uniffle.common.rpc.StatusCode;
 
-public class RssGetShuffleIndexResponse extends ClientResponse  {
+public class RssGetShuffleIndexResponse extends ClientResponse {
   private final ShuffleIndexResult shuffleIndexResult;
 
-  public RssGetShuffleIndexResponse(StatusCode statusCode, byte[] data, long dataFileLen) {
+  public RssGetShuffleIndexResponse(StatusCode statusCode, ByteBuffer data, long dataFileLen) {
     super(statusCode);
     this.shuffleIndexResult = new ShuffleIndexResult(data, dataFileLen);
   }
@@ -31,5 +33,4 @@ public class RssGetShuffleIndexResponse extends ClientResponse  {
   public ShuffleIndexResult getShuffleIndexResult() {
     return shuffleIndexResult;
   }
-
 }
