@@ -20,32 +20,37 @@ package org.apache.uniffle.server;
 import java.lang.reflect.Constructor;
 import java.util.List;
 import java.util.concurrent.TimeUnit;
-import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.concurrent.atomic.AtomicReference;
 
-import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.Lists;
 import com.google.common.util.concurrent.Uninterruptibles;
 import org.apache.commons.collections.CollectionUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import org.apache.uniffle.common.ServerStatus;
+
 /**
- * HealthCheck will check every server whether it has the ability to process shuffle data. Currently, we only support
- * disk checker. If enough disks don't have enough disk space, server will become unhealthy, and only enough disks
- * have enough disk space, server will become healthy again.
- **/
+ * HealthCheck will check every server whether it has the ability to process shuffle data.
+ * Currently, we only support disk checker. If enough disks don't have enough disk space, server
+ * will become unhealthy, and only enough disks have enough disk space, server will become healthy
+ * again.
+ */
 public class HealthCheck {
 
   private static final Logger LOG = LoggerFactory.getLogger(HealthCheck.class);
 
-  private final AtomicBoolean isHealthy;
+  private AtomicReference<ServerStatus> serverStatus;
   private final long checkIntervalMs;
   private final Thread thread;
   private volatile boolean isStop = false;
   private List<Checker> checkers = Lists.newArrayList();
 
-  public HealthCheck(AtomicBoolean isHealthy, ShuffleServerConf conf, List<Checker> buildInCheckers) {
-    this.isHealthy = isHealthy;
+  public HealthCheck(
+      AtomicReference<ServerStatus> serverStatus,
+      ShuffleServerConf conf,
+      List<Checker> buildInCheckers) {
+    this.serverStatus = serverStatus;
     this.checkIntervalMs = conf.getLong(ShuffleServerConf.HEALTH_CHECK_INTERVAL);
     List<String> configuredCheckers = conf.get(ShuffleServerConf.HEALTH_CHECKER_CLASS_NAMES);
     if (CollectionUtils.isEmpty(configuredCheckers) && buildInCheckers.isEmpty()) {
@@ -64,31 +69,38 @@ public class HealthCheck {
         throw new IllegalArgumentException("The checkers init fail");
       }
     }
-    this.thread = new Thread(() -> {
-      while (!isStop) {
-        try {
-          check();
-          Uninterruptibles.sleepUninterruptibly(checkIntervalMs, TimeUnit.MILLISECONDS);
-        } catch (Exception e) {
-          LOG.error("HealthCheck encounter the exception", e);
-        }
-      }
-    });
+    this.thread =
+        new Thread(
+            () -> {
+              while (!isStop) {
+                try {
+                  check();
+                  Uninterruptibles.sleepUninterruptibly(checkIntervalMs, TimeUnit.MILLISECONDS);
+                } catch (Exception e) {
+                  LOG.error("HealthCheck encounter the exception", e);
+                }
+              }
+            });
     thread.setName("HealthCheckService");
     thread.setDaemon(true);
   }
 
-  @VisibleForTesting
-  void check() {
+  public void check() {
     for (Checker checker : checkers) {
       if (!checker.checkIsHealthy()) {
-        isHealthy.set(false);
+        serverStatus.set(ServerStatus.UNHEALTHY);
         ShuffleServerMetrics.gaugeIsHealthy.set(1);
         return;
       }
     }
     ShuffleServerMetrics.gaugeIsHealthy.set(0);
-    isHealthy.set(true);
+    if (serverStatus.get() == ServerStatus.UNHEALTHY) {
+      serverStatus.set(ServerStatus.ACTIVE);
+    }
+  }
+
+  public ServerStatus getServerStatus() {
+    return serverStatus.get();
   }
 
   public void start() {
