@@ -22,6 +22,9 @@ import java.io.FileInputStream;
 import java.io.FileOutputStream;
 import java.io.IOException;
 import java.util.List;
+import java.util.concurrent.CountDownLatch;
+import java.util.concurrent.atomic.AtomicInteger;
+import java.util.concurrent.atomic.AtomicLong;
 
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.Lists;
@@ -35,6 +38,8 @@ import org.apache.uniffle.common.util.RssUtils;
 import org.apache.uniffle.storage.common.LocalStorage;
 import org.apache.uniffle.storage.util.ShuffleStorageUtils;
 
+import static org.apache.uniffle.common.util.Constants.DEVICE_NO_SPACE_ERROR_MESSAGE;
+
 public class LocalStorageChecker extends Checker {
 
   private static final Logger LOG = LoggerFactory.getLogger(LocalStorageChecker.class);
@@ -43,7 +48,7 @@ public class LocalStorageChecker extends Checker {
   private final double diskMaxUsagePercentage;
   private final double diskRecoveryUsagePercentage;
   private final double minStorageHealthyPercentage;
-  private final List<StorageInfo> storageInfos  = Lists.newArrayList();
+  private final List<StorageInfo> storageInfos = Lists.newArrayList();
   private boolean isHealthy = true;
 
   public LocalStorageChecker(ShuffleServerConf conf, List<LocalStorage> storages) {
@@ -52,46 +57,63 @@ public class LocalStorageChecker extends Checker {
     if (CollectionUtils.isEmpty(basePaths)) {
       throw new IllegalArgumentException("The base path cannot be empty");
     }
-    String storageType = conf.getString(ShuffleServerConf.RSS_STORAGE_TYPE);
+    String storageType = conf.get(ShuffleServerConf.RSS_STORAGE_TYPE).name();
     if (!ShuffleStorageUtils.containsLocalFile(storageType)) {
-      throw new IllegalArgumentException("Only StorageType contains LOCALFILE support storageChecker");
+      throw new IllegalArgumentException(
+          "Only StorageType contains LOCALFILE support storageChecker");
     }
     for (LocalStorage storage : storages) {
       storageInfos.add(new StorageInfo(storage));
     }
 
-    this.diskMaxUsagePercentage = conf.getDouble(ShuffleServerConf.HEALTH_STORAGE_MAX_USAGE_PERCENTAGE);
-    this.diskRecoveryUsagePercentage = conf.getDouble(ShuffleServerConf.HEALTH_STORAGE_RECOVERY_USAGE_PERCENTAGE);
-    this.minStorageHealthyPercentage = conf.getDouble(ShuffleServerConf.HEALTH_MIN_STORAGE_PERCENTAGE);
+    this.diskMaxUsagePercentage =
+        conf.getDouble(ShuffleServerConf.HEALTH_STORAGE_MAX_USAGE_PERCENTAGE);
+    this.diskRecoveryUsagePercentage =
+        conf.getDouble(ShuffleServerConf.HEALTH_STORAGE_RECOVERY_USAGE_PERCENTAGE);
+    this.minStorageHealthyPercentage =
+        conf.getDouble(ShuffleServerConf.HEALTH_MIN_STORAGE_PERCENTAGE);
   }
 
   @Override
   public boolean checkIsHealthy() {
-    int num = 0;
-    long totalSpace = 0L;
-    long usedSpace = 0L;
-    int corruptedDirs = 0;
+    AtomicInteger num = new AtomicInteger(0);
+    AtomicLong totalSpace = new AtomicLong(0L);
+    AtomicLong wholeDiskUsedSpace = new AtomicLong(0L);
+    AtomicLong serviceUsedSpace = new AtomicLong(0L);
+    AtomicInteger corruptedDirs = new AtomicInteger(0);
+    CountDownLatch cdl = new CountDownLatch(storageInfos.size());
+    storageInfos
+        .parallelStream()
+        .forEach(
+            storageInfo -> {
+              if (!storageInfo.checkStorageReadAndWrite()) {
+                storageInfo.markCorrupted();
+                corruptedDirs.incrementAndGet();
+                cdl.countDown();
+                return;
+              }
 
-    for (StorageInfo storageInfo : storageInfos) {
-      if (!storageInfo.checkStorageReadAndWrite()) {
-        storageInfo.markCorrupted();
-        corruptedDirs++;
-        continue;
-      }
+              totalSpace.addAndGet(getTotalSpace(storageInfo.storageDir));
+              wholeDiskUsedSpace.addAndGet(getWholeDiskUsedSpace(storageInfo.storageDir));
+              serviceUsedSpace.addAndGet(getServiceUsedSpace(storageInfo.storageDir));
 
-      totalSpace += getTotalSpace(storageInfo.storageDir);
-      usedSpace += getUsedSpace(storageInfo.storageDir);
-
-      if (storageInfo.checkIsSpaceEnough()) {
-        num++;
-      }
+              if (storageInfo.checkIsSpaceEnough()) {
+                num.incrementAndGet();
+              }
+              cdl.countDown();
+            });
+    try {
+      cdl.await();
+    } catch (InterruptedException e) {
+      LOG.error("Failed to check local storage!");
     }
-
-    ShuffleServerMetrics.gaugeLocalStorageTotalSpace.set(totalSpace);
-    ShuffleServerMetrics.gaugeLocalStorageUsedSpace.set(usedSpace);
+    ShuffleServerMetrics.gaugeLocalStorageTotalSpace.set(totalSpace.get());
+    ShuffleServerMetrics.gaugeLocalStorageWholeDiskUsedSpace.set(wholeDiskUsedSpace.get());
+    ShuffleServerMetrics.gaugeLocalStorageServiceUsedSpace.set(serviceUsedSpace.get());
     ShuffleServerMetrics.gaugeLocalStorageTotalDirsNum.set(storageInfos.size());
-    ShuffleServerMetrics.gaugeLocalStorageCorruptedDirsNum.set(corruptedDirs);
-    ShuffleServerMetrics.gaugeLocalStorageUsedSpaceRatio.set(usedSpace * 1.0 / totalSpace);
+    ShuffleServerMetrics.gaugeLocalStorageCorruptedDirsNum.set(corruptedDirs.get());
+    ShuffleServerMetrics.gaugeLocalStorageUsedSpaceRatio.set(
+        wholeDiskUsedSpace.get() * 1.0 / totalSpace.get());
 
     if (storageInfos.isEmpty()) {
       if (isHealthy) {
@@ -101,7 +123,7 @@ public class LocalStorageChecker extends Checker {
       return false;
     }
 
-    double availablePercentage = num * 100.0 / storageInfos.size();
+    double availablePercentage = num.get() * 100.0 / storageInfos.size();
     if (Double.compare(availablePercentage, minStorageHealthyPercentage) >= 0) {
       if (!isHealthy) {
         LOG.info("shuffle server become healthy");
@@ -124,11 +146,38 @@ public class LocalStorageChecker extends Checker {
 
   // Only for testing
   @VisibleForTesting
-  long getUsedSpace(File file) {
+  long getWholeDiskUsedSpace(File file) {
     return file.getTotalSpace() - file.getUsableSpace();
   }
 
-  // todo: This function will be integrated to MultiStorageManager, currently we only support disk check.
+  protected static long getServiceUsedSpace(File storageDir) {
+    if (storageDir == null || !storageDir.exists()) {
+      return 0;
+    }
+
+    if (storageDir.isFile()) {
+      return storageDir.length();
+    }
+
+    File[] files = storageDir.listFiles();
+    if (files == null) {
+      return 0;
+    }
+
+    long totalUsage = 0;
+    for (File file : files) {
+      if (file.isFile()) {
+        totalUsage += file.length();
+      } else {
+        totalUsage += getServiceUsedSpace(file);
+      }
+    }
+
+    return totalUsage;
+  }
+
+  // todo: This function will be integrated to MultiStorageManager, currently we only support disk
+  // check.
   class StorageInfo {
 
     private final File storageDir;
@@ -147,7 +196,7 @@ public class LocalStorageChecker extends Checker {
         this.isHealthy = false;
         return false;
       }
-      double usagePercent = getUsedSpace(storageDir) * 100.0 / getTotalSpace(storageDir);
+      double usagePercent = getWholeDiskUsedSpace(storageDir) * 100.0 / getTotalSpace(storageDir);
       if (isHealthy) {
         if (Double.compare(usagePercent, diskMaxUsagePercentage) >= 0) {
           isHealthy = false;
@@ -200,6 +249,10 @@ public class LocalStorageChecker extends Checker {
         }
       } catch (Exception e) {
         LOG.error("Storage read and write error. Storage dir: {}", storageDir, e);
+        // avoid check bad track failure due to lack of disk space
+        if (e.getMessage() != null && DEVICE_NO_SPACE_ERROR_MESSAGE.equals(e.getMessage())) {
+          return true;
+        }
         return false;
       } finally {
         try {
