@@ -21,7 +21,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ExecutorService;
-import java.util.concurrent.Executors;
 import java.util.concurrent.Future;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
@@ -35,6 +34,7 @@ import org.apache.uniffle.client.api.CoordinatorClient;
 import org.apache.uniffle.client.factory.CoordinatorClientFactory;
 import org.apache.uniffle.client.request.RssSendHeartBeatRequest;
 import org.apache.uniffle.client.response.RssSendHeartBeatResponse;
+import org.apache.uniffle.common.ServerStatus;
 import org.apache.uniffle.common.rpc.StatusCode;
 import org.apache.uniffle.common.storage.StorageInfo;
 import org.apache.uniffle.common.util.ThreadUtils;
@@ -48,78 +48,86 @@ public class RegisterHeartBeat {
   private final ShuffleServer shuffleServer;
   private final String coordinatorQuorum;
   private final List<CoordinatorClient> coordinatorClients;
-  private final ScheduledExecutorService service = Executors.newSingleThreadScheduledExecutor(
-      ThreadUtils.getThreadFactory("startHeartBeat-%d"));
+  private final ScheduledExecutorService service =
+      ThreadUtils.getDaemonSingleThreadScheduledExecutor("startHeartBeat");
   private final ExecutorService heartBeatExecutorService;
-  private long heartBeatTimeout;
 
   public RegisterHeartBeat(ShuffleServer shuffleServer) {
     ShuffleServerConf conf = shuffleServer.getShuffleServerConf();
     this.heartBeatInitialDelay = conf.getLong(ShuffleServerConf.SERVER_HEARTBEAT_DELAY);
     this.heartBeatInterval = conf.getLong(ShuffleServerConf.SERVER_HEARTBEAT_INTERVAL);
-    this.heartBeatTimeout = conf.getLong(ShuffleServerConf.SERVER_HEARTBEAT_TIMEOUT);
     this.coordinatorQuorum = conf.getString(ShuffleServerConf.RSS_COORDINATOR_QUORUM);
     CoordinatorClientFactory factory =
         new CoordinatorClientFactory(conf.get(ShuffleServerConf.RSS_CLIENT_TYPE));
     this.coordinatorClients = factory.createCoordinatorClient(this.coordinatorQuorum);
     this.shuffleServer = shuffleServer;
-    this.heartBeatExecutorService = Executors.newFixedThreadPool(
-        conf.getInteger(ShuffleServerConf.SERVER_HEARTBEAT_THREAD_NUM),
-        ThreadUtils.getThreadFactory("sendHeartBeat-%d"));
+    this.heartBeatExecutorService =
+        ThreadUtils.getDaemonFixedThreadPool(
+            conf.getInteger(ShuffleServerConf.SERVER_HEARTBEAT_THREAD_NUM), "sendHeartBeat");
   }
 
   public void startHeartBeat() {
-    LOG.info("Start heartbeat to coordinator {} after {}ms and interval is {}ms",
-        coordinatorQuorum, heartBeatInitialDelay, heartBeatInterval);
-    Runnable runnable = () -> {
-      try {
-        sendHeartBeat(
-            shuffleServer.getId(),
-            shuffleServer.getIp(),
-            shuffleServer.getPort(),
-            shuffleServer.getUsedMemory(),
-            shuffleServer.getPreAllocatedMemory(),
-            shuffleServer.getAvailableMemory(),
-            shuffleServer.getEventNumInFlush(),
-            shuffleServer.getTags(),
-            shuffleServer.isHealthy(),
-            shuffleServer.getStorageManager().getStorageInfo());
-      } catch (Exception e) {
-        LOG.warn("Error happened when send heart beat to coordinator");
-      }
-    };
-    service.scheduleAtFixedRate(runnable, heartBeatInitialDelay, heartBeatInterval, TimeUnit.MILLISECONDS);
+    LOG.info(
+        "Start heartbeat to coordinator {} after {}ms and interval is {}ms",
+        coordinatorQuorum,
+        heartBeatInitialDelay,
+        heartBeatInterval);
+    Runnable runnable =
+        () -> {
+          try {
+            sendHeartBeat(
+                shuffleServer.getId(),
+                shuffleServer.getIp(),
+                shuffleServer.getGrpcPort(),
+                shuffleServer.getUsedMemory(),
+                shuffleServer.getPreAllocatedMemory(),
+                shuffleServer.getAvailableMemory(),
+                shuffleServer.getEventNumInFlush(),
+                shuffleServer.getTags(),
+                shuffleServer.getServerStatus(),
+                shuffleServer.getStorageManager().getStorageInfo(),
+                shuffleServer.getNettyPort());
+          } catch (Exception e) {
+            LOG.warn("Error happened when send heart beat to coordinator");
+          }
+        };
+    service.scheduleAtFixedRate(
+        runnable, heartBeatInitialDelay, heartBeatInterval, TimeUnit.MILLISECONDS);
   }
 
   @VisibleForTesting
   boolean sendHeartBeat(
       String id,
       String ip,
-      int port,
+      int grpcPort,
       long usedMemory,
       long preAllocatedMemory,
       long availableMemory,
       int eventNumInFlush,
       Set<String> tags,
-      boolean isHealthy,
-      Map<String, StorageInfo> localStorageInfo) {
+      ServerStatus serverStatus,
+      Map<String, StorageInfo> localStorageInfo,
+      int nettyPort) {
     boolean sendSuccessfully = false;
-    RssSendHeartBeatRequest request = new RssSendHeartBeatRequest(
-        id,
-        ip,
-        port,
-        usedMemory,
-        preAllocatedMemory,
-        availableMemory,
-        eventNumInFlush,
-        heartBeatTimeout,
-        tags,
-        isHealthy,
-        localStorageInfo);
-    List<Future<RssSendHeartBeatResponse>> respFutures = coordinatorClients
-        .stream()
-        .map(client -> heartBeatExecutorService.submit(() -> client.sendHeartBeat(request)))
-        .collect(Collectors.toList());
+    // use `rss.server.heartbeat.interval` as the timeout option
+    RssSendHeartBeatRequest request =
+        new RssSendHeartBeatRequest(
+            id,
+            ip,
+            grpcPort,
+            usedMemory,
+            preAllocatedMemory,
+            availableMemory,
+            eventNumInFlush,
+            heartBeatInterval,
+            tags,
+            serverStatus,
+            localStorageInfo,
+            nettyPort);
+    List<Future<RssSendHeartBeatResponse>> respFutures =
+        coordinatorClients.stream()
+            .map(client -> heartBeatExecutorService.submit(() -> client.sendHeartBeat(request)))
+            .collect(Collectors.toList());
 
     String msg = "";
     for (Future<RssSendHeartBeatResponse> rf : respFutures) {
