@@ -47,6 +47,9 @@ public class ShuffleDataFlushEvent {
   private Storage underStorage;
   private final List<Runnable> cleanupCallbackChains;
 
+  private boolean ownedByHugePartition = false;
+  private long startPendingTime;
+
   public ShuffleDataFlushEvent(
       long eventId,
       String appId,
@@ -122,6 +125,7 @@ public class ShuffleDataFlushEvent {
 
   public void markPended() {
     isPended = true;
+    startPendingTime = System.currentTimeMillis();
   }
 
   public Storage getUnderStorage() {
@@ -145,8 +149,7 @@ public class ShuffleDataFlushEvent {
     return ret;
   }
 
-  public void addCleanupCallback(
-      Runnable cleanupCallback) {
+  public void addCleanupCallback(Runnable cleanupCallback) {
     if (cleanupCallback != null) {
       cleanupCallbackChains.add(cleanupCallback);
     }
@@ -154,13 +157,33 @@ public class ShuffleDataFlushEvent {
 
   @Override
   public String toString() {
-    return "ShuffleDataFlushEvent: eventId=" + eventId
-        + ", appId=" + appId
-        + ", shuffleId=" + shuffleId
-        + ", startPartition=" + startPartition
-        + ", endPartition=" + endPartition
-        + ", retryTimes=" + retryTimes
-        + ", underStorage=" + (underStorage == null ? null : underStorage.getClass().getSimpleName())
-        + ", isPended=" + isPended;
+    return "ShuffleDataFlushEvent: eventId="
+        + eventId
+        + ", appId="
+        + appId
+        + ", shuffleId="
+        + shuffleId
+        + ", startPartition="
+        + startPartition
+        + ", endPartition="
+        + endPartition
+        + ", retryTimes="
+        + retryTimes
+        + ", underStorage="
+        + (underStorage == null ? null : underStorage.getClass().getSimpleName())
+        + ", isPended="
+        + isPended;
+  }
+
+  public boolean isOwnedByHugePartition() {
+    return ownedByHugePartition;
+  }
+
+  public void markOwnedByHugePartition() {
+    this.ownedByHugePartition = true;
+  }
+
+  public long getStartPendingTime() {
+    return startPendingTime;
   }
 }
