@@ -24,58 +24,53 @@ import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.atomic.AtomicReference;
 
-import com.google.common.collect.Maps;
 import com.google.common.collect.Sets;
 import org.roaringbitmap.longlong.Roaring64NavigableMap;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import org.apache.uniffle.common.ShuffleDataDistributionType;
+import org.apache.uniffle.common.util.JavaUtils;
 
 /**
- * ShuffleTaskInfo contains the information of submitting the shuffle,
- * the information of the cache block, user and timestamp corresponding to the app
+ * ShuffleTaskInfo contains the information of submitting the shuffle, the information of the cache
+ * block, user and timestamp corresponding to the app
  */
 public class ShuffleTaskInfo {
   private static final Logger LOGGER = LoggerFactory.getLogger(ShuffleTaskInfo.class);
 
   private final String appId;
   private Long currentTimes;
-  /**
-   * shuffleId -> commit count
-   */
+  /** shuffleId -> commit count */
   private Map<Integer, AtomicInteger> commitCounts;
+
   private Map<Integer, Object> commitLocks;
-  /**
-   * shuffleId -> blockIds
-    */
+  /** shuffleId -> blockIds */
   private Map<Integer, Roaring64NavigableMap> cachedBlockIds;
+
   private AtomicReference<String> user;
 
-  private AtomicReference<ShuffleDataDistributionType> dataDistType;
-
   private AtomicLong totalDataSize = new AtomicLong(0);
-  /**
-   * shuffleId -> partitionId -> partition shuffle data size
-   */
+  /** shuffleId -> partitionId -> partition shuffle data size */
   private Map<Integer, Map<Integer, Long>> partitionDataSizes;
-  /**
-   * shuffleId -> huge partitionIds set
-   */
-  private final Map<Integer, Set> hugePartitionTags;
+  /** shuffleId -> huge partitionIds set */
+  private final Map<Integer, Set<Integer>> hugePartitionTags;
+
   private final AtomicBoolean existHugePartition;
 
+  private final AtomicReference<ShuffleSpecification> specification;
+
   public ShuffleTaskInfo(String appId) {
     this.appId = appId;
     this.currentTimes = System.currentTimeMillis();
-    this.commitCounts = Maps.newConcurrentMap();
-    this.commitLocks = Maps.newConcurrentMap();
-    this.cachedBlockIds = Maps.newConcurrentMap();
+    this.commitCounts = JavaUtils.newConcurrentMap();
+    this.commitLocks = JavaUtils.newConcurrentMap();
+    this.cachedBlockIds = JavaUtils.newConcurrentMap();
     this.user = new AtomicReference<>();
-    this.dataDistType = new AtomicReference<>();
-    this.partitionDataSizes = Maps.newConcurrentMap();
-    this.hugePartitionTags = Maps.newConcurrentMap();
+    this.partitionDataSizes = JavaUtils.newConcurrentMap();
+    this.hugePartitionTags = JavaUtils.newConcurrentMap();
     this.existHugePartition = new AtomicBoolean(false);
+    this.specification = new AtomicReference<>();
   }
 
   public Long getCurrentTimes() {
@@ -106,18 +101,21 @@ public class ShuffleTaskInfo {
     this.user.set(user);
   }
 
-  public void setDataDistType(
-      ShuffleDataDistributionType dataDistType) {
-    this.dataDistType.set(dataDistType);
+  public int getMaxConcurrencyPerPartitionToWrite() {
+    return specification.get().getMaxConcurrencyPerPartitionToWrite();
   }
 
   public ShuffleDataDistributionType getDataDistType() {
-    return dataDistType.get();
+    return specification.get().getDistributionType();
+  }
+
+  public void setSpecification(ShuffleSpecification specification) {
+    this.specification.set(specification);
   }
 
   public long addPartitionDataSize(int shuffleId, int partitionId, long delta) {
     totalDataSize.addAndGet(delta);
-    partitionDataSizes.computeIfAbsent(shuffleId, key -> Maps.newConcurrentMap());
+    partitionDataSizes.computeIfAbsent(shuffleId, key -> JavaUtils.newConcurrentMap());
     Map<Integer, Long> partitions = partitionDataSizes.get(shuffleId);
     partitions.putIfAbsent(partitionId, 0L);
     return partitions.computeIfPresent(partitionId, (k, v) -> v + delta);
@@ -156,11 +154,16 @@ public class ShuffleTaskInfo {
       }
     }
 
-    Set<Integer> partitions = hugePartitionTags.computeIfAbsent(shuffleId, key -> Sets.newConcurrentHashSet());
+    Set<Integer> partitions =
+        hugePartitionTags.computeIfAbsent(shuffleId, key -> Sets.newConcurrentHashSet());
     if (partitions.add(partitionId)) {
       ShuffleServerMetrics.counterTotalHugePartitionNum.inc();
       ShuffleServerMetrics.gaugeHugePartitionNum.inc();
-      LOGGER.warn("Huge partition occurs, appId: {}, shuffleId: {}, partitionId: {}", appId, shuffleId, partitionId);
+      LOGGER.warn(
+          "Huge partition occurs, appId: {}, shuffleId: {}, partitionId: {}",
+          appId,
+          shuffleId,
+          partitionId);
     }
   }
 }
