@@ -40,17 +40,19 @@ import org.apache.uniffle.common.ShuffleDataResult;
 import org.apache.uniffle.common.ShufflePartitionedData;
 import org.apache.uniffle.common.rpc.StatusCode;
 import org.apache.uniffle.common.util.Constants;
+import org.apache.uniffle.common.util.JavaUtils;
 import org.apache.uniffle.common.util.RssUtils;
-import org.apache.uniffle.common.util.TripleFunction;
 import org.apache.uniffle.server.ShuffleDataFlushEvent;
 import org.apache.uniffle.server.ShuffleFlushManager;
 import org.apache.uniffle.server.ShuffleServerConf;
 import org.apache.uniffle.server.ShuffleServerMetrics;
+import org.apache.uniffle.server.ShuffleTaskManager;
 
 public class ShuffleBufferManager {
 
   private static final Logger LOG = LoggerFactory.getLogger(ShuffleBufferManager.class);
 
+  private ShuffleTaskManager shuffleTaskManager;
   private final ShuffleFlushManager shuffleFlushManager;
   private long capacity;
   private long readCapacity;
@@ -59,7 +61,8 @@ public class ShuffleBufferManager {
   private long lowWaterMark;
   private boolean bufferFlushEnabled;
   private long bufferFlushThreshold;
-  // when shuffle buffer manager flushes data, shuffles with data size < shuffleFlushThreshold is kept in memory to
+  // when shuffle buffer manager flushes data, shuffles with data size < shuffleFlushThreshold is
+  // kept in memory to
   // reduce small I/Os to persistent storage, especially for local HDDs.
   private long shuffleFlushThreshold;
   // Huge partition vars
@@ -74,72 +77,88 @@ public class ShuffleBufferManager {
   // appId -> shuffleId -> partitionId -> ShuffleBuffer to avoid too many appId
   protected Map<String, Map<Integer, RangeMap<Integer, ShuffleBuffer>>> bufferPool;
   // appId -> shuffleId -> shuffle size in buffer
-  protected Map<String, Map<Integer, AtomicLong>> shuffleSizeMap = Maps.newConcurrentMap();
+  protected Map<String, Map<Integer, AtomicLong>> shuffleSizeMap = JavaUtils.newConcurrentMap();
 
   public ShuffleBufferManager(ShuffleServerConf conf, ShuffleFlushManager shuffleFlushManager) {
+    long heapSize = Runtime.getRuntime().maxMemory();
     this.capacity = conf.getSizeAsBytes(ShuffleServerConf.SERVER_BUFFER_CAPACITY);
+    if (this.capacity < 0) {
+      this.capacity =
+          (long) (heapSize * conf.getDouble(ShuffleServerConf.SERVER_BUFFER_CAPACITY_RATIO));
+    }
     this.readCapacity = conf.getSizeAsBytes(ShuffleServerConf.SERVER_READ_BUFFER_CAPACITY);
+    if (this.readCapacity < 0) {
+      this.readCapacity =
+          (long) (heapSize * conf.getDouble(ShuffleServerConf.SERVER_READ_BUFFER_CAPACITY_RATIO));
+    }
+    LOG.info(
+        "Init shuffle buffer manager with capacity: {}, read buffer capacity: {}.",
+        capacity,
+        readCapacity);
     this.shuffleFlushManager = shuffleFlushManager;
     this.bufferPool = new ConcurrentHashMap<>();
     this.retryNum = conf.getInteger(ShuffleServerConf.SERVER_MEMORY_REQUEST_RETRY_MAX);
-    this.highWaterMark = (long)(capacity / 100.0
-        * conf.get(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_HIGHWATERMARK_PERCENTAGE));
-    this.lowWaterMark = (long)(capacity / 100.0
-        * conf.get(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_LOWWATERMARK_PERCENTAGE));
+    this.highWaterMark =
+        (long)
+            (capacity
+                / 100.0
+                * conf.get(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_HIGHWATERMARK_PERCENTAGE));
+    this.lowWaterMark =
+        (long)
+            (capacity
+                / 100.0
+                * conf.get(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_LOWWATERMARK_PERCENTAGE));
     this.bufferFlushEnabled = conf.getBoolean(ShuffleServerConf.SINGLE_BUFFER_FLUSH_ENABLED);
-    this.bufferFlushThreshold = conf.getLong(ShuffleServerConf.SINGLE_BUFFER_FLUSH_THRESHOLD);
-    this.shuffleFlushThreshold = conf.getLong(ShuffleServerConf.SERVER_SHUFFLE_FLUSH_THRESHOLD);
-    this.hugePartitionSizeThreshold = conf.getSizeAsBytes(ShuffleServerConf.HUGE_PARTITION_SIZE_THRESHOLD);
-    this.hugePartitionMemoryLimitSize = Math.round(
-        capacity * conf.get(ShuffleServerConf.HUGE_PARTITION_MEMORY_USAGE_LIMITATION_RATIO)
-    );
+    this.bufferFlushThreshold =
+        conf.getSizeAsBytes(ShuffleServerConf.SINGLE_BUFFER_FLUSH_THRESHOLD);
+    this.shuffleFlushThreshold =
+        conf.getSizeAsBytes(ShuffleServerConf.SERVER_SHUFFLE_FLUSH_THRESHOLD);
+    this.hugePartitionSizeThreshold =
+        conf.getSizeAsBytes(ShuffleServerConf.HUGE_PARTITION_SIZE_THRESHOLD);
+    this.hugePartitionMemoryLimitSize =
+        Math.round(
+            capacity * conf.get(ShuffleServerConf.HUGE_PARTITION_MEMORY_USAGE_LIMITATION_RATIO));
   }
 
-  public StatusCode registerBuffer(String appId, int shuffleId, int startPartition, int endPartition) {
-    bufferPool.putIfAbsent(appId, Maps.newConcurrentMap());
+  public void setShuffleTaskManager(ShuffleTaskManager taskManager) {
+    this.shuffleTaskManager = taskManager;
+  }
+
+  public StatusCode registerBuffer(
+      String appId, int shuffleId, int startPartition, int endPartition) {
+    bufferPool.computeIfAbsent(appId, key -> JavaUtils.newConcurrentMap());
     Map<Integer, RangeMap<Integer, ShuffleBuffer>> shuffleIdToBuffers = bufferPool.get(appId);
-    shuffleIdToBuffers.putIfAbsent(shuffleId, TreeRangeMap.create());
+    shuffleIdToBuffers.computeIfAbsent(shuffleId, key -> TreeRangeMap.create());
     RangeMap<Integer, ShuffleBuffer> bufferRangeMap = shuffleIdToBuffers.get(shuffleId);
     if (bufferRangeMap.get(startPartition) == null) {
       ShuffleServerMetrics.counterTotalPartitionNum.inc();
       ShuffleServerMetrics.gaugeTotalPartitionNum.inc();
       bufferRangeMap.put(Range.closed(startPartition, endPartition), new ShuffleBuffer(bufferSize));
     } else {
-      LOG.warn("Already register for appId[" + appId + "], shuffleId[" + shuffleId + "], startPartition["
-              + startPartition + "], endPartition[" + endPartition + "]");
+      LOG.warn(
+          "Already register for appId["
+              + appId
+              + "], shuffleId["
+              + shuffleId
+              + "], startPartition["
+              + startPartition
+              + "], endPartition["
+              + endPartition
+              + "]");
     }
 
     return StatusCode.SUCCESS;
   }
 
-  // Only for tests
   public StatusCode cacheShuffleData(
-      String appId,
-      int shuffleId,
-      boolean isPreAllocated,
-      ShufflePartitionedData spd) {
-    return cacheShuffleData(
-        appId,
-        shuffleId,
-        isPreAllocated,
-        spd,
-        null
-    );
-  }
-
-  public StatusCode cacheShuffleData(
-      String appId,
-      int shuffleId,
-      boolean isPreAllocated,
-      ShufflePartitionedData spd,
-      TripleFunction<String, Integer, Integer, Long> getPartitionDataSizeFunc) {
+      String appId, int shuffleId, boolean isPreAllocated, ShufflePartitionedData spd) {
     if (!isPreAllocated && isFull()) {
       LOG.warn("Got unexpected data, can't cache it because the space is full");
       return StatusCode.NO_BUFFER;
     }
 
-    Entry<Range<Integer>, ShuffleBuffer> entry = getShuffleBufferEntry(
-        appId, shuffleId, spd.getPartitionId());
+    Entry<Range<Integer>, ShuffleBuffer> entry =
+        getShuffleBufferEntry(appId, shuffleId, spd.getPartitionId());
     if (entry == null) {
       return StatusCode.NO_REGISTER;
     }
@@ -157,18 +176,16 @@ public class ShuffleBufferManager {
           shuffleId,
           spd.getPartitionId(),
           entry.getKey().lowerEndpoint(),
-          entry.getKey().upperEndpoint(),
-          getPartitionDataSizeFunc
-      );
+          entry.getKey().upperEndpoint());
       flushIfNecessary();
     }
     return StatusCode.SUCCESS;
   }
 
   private void updateShuffleSize(String appId, int shuffleId, long size) {
-    shuffleSizeMap.putIfAbsent(appId, Maps.newConcurrentMap());
+    shuffleSizeMap.computeIfAbsent(appId, key -> JavaUtils.newConcurrentMap());
     Map<Integer, AtomicLong> shuffleIdToSize = shuffleSizeMap.get(appId);
-    shuffleIdToSize.putIfAbsent(shuffleId, new AtomicLong(0));
+    shuffleIdToSize.computeIfAbsent(shuffleId, key -> new AtomicLong(0));
     shuffleIdToSize.get(shuffleId).addAndGet(size);
   }
 
@@ -190,23 +207,19 @@ public class ShuffleBufferManager {
   }
 
   public ShuffleDataResult getShuffleData(
-      String appId, int shuffleId, int partitionId, long blockId,
-      int readBufferSize) {
-    return getShuffleData(
-        appId,
-        shuffleId,
-        partitionId,
-        blockId,
-        readBufferSize,
-        null
-    );
+      String appId, int shuffleId, int partitionId, long blockId, int readBufferSize) {
+    return getShuffleData(appId, shuffleId, partitionId, blockId, readBufferSize, null);
   }
 
   public ShuffleDataResult getShuffleData(
-      String appId, int shuffleId, int partitionId, long blockId,
-      int readBufferSize, Roaring64NavigableMap expectedTaskIds) {
-    Map.Entry<Range<Integer>, ShuffleBuffer> entry = getShuffleBufferEntry(
-        appId, shuffleId, partitionId);
+      String appId,
+      int shuffleId,
+      int partitionId,
+      long blockId,
+      int readBufferSize,
+      Roaring64NavigableMap expectedTaskIds) {
+    Map.Entry<Range<Integer>, ShuffleBuffer> entry =
+        getShuffleBufferEntry(appId, shuffleId, partitionId);
     if (entry == null) {
       return null;
     }
@@ -224,19 +237,13 @@ public class ShuffleBufferManager {
       int shuffleId,
       int partitionId,
       int startPartition,
-      int endPartition,
-      TripleFunction<String, Integer, Integer, Long> getPartitionDataSizeFunc) {
+      int endPartition) {
+    boolean isHugePartition = isHugePartition(appId, shuffleId, partitionId);
     // When we use multi storage and trigger single buffer flush, the buffer size should be bigger
     // than rss.server.flush.cold.storage.threshold.size, otherwise cold storage will be useless.
-    if (this.bufferFlushEnabled && buffer.getSize() > this.bufferFlushThreshold) {
-      flushBuffer(buffer, appId, shuffleId, startPartition, endPartition);
-      return;
-    }
-
-    if (getPartitionDataSizeFunc != null
-        && getPartitionDataSizeFunc.accept(appId, shuffleId, partitionId) > hugePartitionSizeThreshold
+    if ((isHugePartition || this.bufferFlushEnabled)
         && buffer.getSize() > this.bufferFlushThreshold) {
-      flushBuffer(buffer, appId, shuffleId, startPartition, endPartition);
+      flushBuffer(buffer, appId, shuffleId, startPartition, endPartition, isHugePartition);
       return;
     }
   }
@@ -245,8 +252,11 @@ public class ShuffleBufferManager {
     // if data size in buffer > highWaterMark, do the flush
     if (usedMemory.get() - preAllocatedSize.get() - inFlushSize.get() > highWaterMark) {
       // todo: add a metric here to track how many times flush occurs.
-      LOG.info("Start to flush with usedMemory[{}], preAllocatedSize[{}], inFlushSize[{}]",
-          usedMemory.get(), preAllocatedSize.get(), inFlushSize.get());
+      LOG.info(
+          "Start to flush with usedMemory[{}], preAllocatedSize[{}], inFlushSize[{}]",
+          usedMemory.get(),
+          preAllocatedSize.get(),
+          inFlushSize.get());
       Map<String, Set<Integer>> pickedShuffle = pickFlushedShuffle();
       flush(pickedShuffle);
     }
@@ -257,12 +267,23 @@ public class ShuffleBufferManager {
     for (Map.Entry<Range<Integer>, ShuffleBuffer> entry : buffers.asMapOfRanges().entrySet()) {
       ShuffleBuffer buffer = entry.getValue();
       Range<Integer> range = entry.getKey();
-      flushBuffer(buffer, appId, shuffleId, range.lowerEndpoint(), range.upperEndpoint());
+      flushBuffer(
+          buffer,
+          appId,
+          shuffleId,
+          range.lowerEndpoint(),
+          range.upperEndpoint(),
+          isHugePartition(appId, shuffleId, range.lowerEndpoint()));
     }
   }
 
-  protected void flushBuffer(ShuffleBuffer buffer, String appId,
-      int shuffleId, int startPartition, int endPartition) {
+  protected void flushBuffer(
+      ShuffleBuffer buffer,
+      String appId,
+      int shuffleId,
+      int startPartition,
+      int endPartition,
+      boolean isHugePartition) {
     ShuffleDataFlushEvent event =
         buffer.toFlushEvent(
             appId,
@@ -270,12 +291,14 @@ public class ShuffleBufferManager {
             startPartition,
             endPartition,
             () -> bufferPool.containsKey(appId),
-            shuffleFlushManager.getDataDistributionType(appId)
-        );
+            shuffleFlushManager.getDataDistributionType(appId));
     if (event != null) {
       event.addCleanupCallback(() -> releaseMemory(event.getSize(), true, false));
       updateShuffleSize(appId, shuffleId, -event.getSize());
       inFlushSize.addAndGet(event.getSize());
+      if (isHugePartition) {
+        event.markOwnedByHugePartition();
+      }
       ShuffleServerMetrics.gaugeInFlushBufferSize.set(inFlushSize.get());
       shuffleFlushManager.addToFlushQueue(event);
     }
@@ -300,18 +323,30 @@ public class ShuffleBufferManager {
       }
       return true;
     }
-    LOG.debug("Require memory failed with " + size + " bytes, usedMemory[" + usedMemory.get()
-        + "] include preAllocation[" + preAllocatedSize.get()
-        + "], inFlushSize[" + inFlushSize.get() + "]");
+    LOG.debug(
+        "Require memory failed with "
+            + size
+            + " bytes, usedMemory["
+            + usedMemory.get()
+            + "] include preAllocation["
+            + preAllocatedSize.get()
+            + "], inFlushSize["
+            + inFlushSize.get()
+            + "]");
     return false;
   }
 
-  public void releaseMemory(long size, boolean isReleaseFlushMemory, boolean isReleasePreAllocation) {
+  public void releaseMemory(
+      long size, boolean isReleaseFlushMemory, boolean isReleasePreAllocation) {
     if (usedMemory.get() >= size) {
       usedMemory.addAndGet(-size);
     } else {
-      LOG.warn("Current allocated memory[" + usedMemory.get()
-          + "] is less than released[" + size + "], set allocated memory to 0");
+      LOG.warn(
+          "Current allocated memory["
+              + usedMemory.get()
+              + "] is less than released["
+              + size
+              + "], set allocated memory to 0");
       usedMemory.set(0L);
     }
 
@@ -330,8 +365,12 @@ public class ShuffleBufferManager {
     if (inFlushSize.get() >= size) {
       inFlushSize.addAndGet(-size);
     } else {
-      LOG.warn("Current in flush memory[" + inFlushSize.get()
-          + "] is less than released[" + size + "], set allocated memory to 0");
+      LOG.warn(
+          "Current in flush memory["
+              + inFlushSize.get()
+              + "] is less than released["
+              + size
+              + "], set allocated memory to 0");
       inFlushSize.set(0L);
     }
     ShuffleServerMetrics.gaugeInFlushBufferSize.set(inFlushSize.get());
@@ -347,8 +386,16 @@ public class ShuffleBufferManager {
           return true;
         }
       }
-      LOG.info("Can't require[" + size + "] for read data, current[" + readDataMemory.get()
-          + "], capacity[" + readCapacity + "], re-try " + i + " times");
+      LOG.info(
+          "Can't require["
+              + size
+              + "] for read data, current["
+              + readDataMemory.get()
+              + "], capacity["
+              + readCapacity
+              + "], re-try "
+              + i
+              + " times");
       ShuffleServerMetrics.counterTotalRequireReadMemoryRetryNum.inc();
       try {
         Thread.sleep(1000);
@@ -365,8 +412,12 @@ public class ShuffleBufferManager {
       readDataMemory.addAndGet(-size);
       ShuffleServerMetrics.gaugeReadBufferUsedSize.dec(size);
     } else {
-      LOG.warn("Current read memory[" + readDataMemory.get()
-          + "] is less than released[" + size + "], set read memory to 0");
+      LOG.warn(
+          "Current read memory["
+              + readDataMemory.get()
+              + "] is less than released["
+              + size
+              + "], set read memory to 0");
       readDataMemory.set(0L);
       ShuffleServerMetrics.gaugeReadBufferUsedSize.set(0);
     }
@@ -374,8 +425,8 @@ public class ShuffleBufferManager {
 
   // flush the buffer with required map which is <appId -> shuffleId>
   public synchronized void flush(Map<String, Set<Integer>> requiredFlush) {
-    for (Map.Entry<String, Map<Integer, RangeMap<Integer, ShuffleBuffer>>>
-        appIdToBuffers : bufferPool.entrySet()) {
+    for (Map.Entry<String, Map<Integer, RangeMap<Integer, ShuffleBuffer>>> appIdToBuffers :
+        bufferPool.entrySet()) {
       String appId = appIdToBuffers.getKey();
       if (requiredFlush.containsKey(appId)) {
         for (Map.Entry<Integer, RangeMap<Integer, ShuffleBuffer>> shuffleIdToBuffers :
@@ -386,8 +437,13 @@ public class ShuffleBufferManager {
             for (Map.Entry<Range<Integer>, ShuffleBuffer> rangeEntry :
                 shuffleIdToBuffers.getValue().asMapOfRanges().entrySet()) {
               Range<Integer> range = rangeEntry.getKey();
-              flushBuffer(rangeEntry.getValue(), appId, shuffleId,
-                  range.lowerEndpoint(), range.upperEndpoint());
+              flushBuffer(
+                  rangeEntry.getValue(),
+                  appId,
+                  shuffleId,
+                  range.lowerEndpoint(),
+                  range.upperEndpoint(),
+                  isHugePartition(appId, shuffleId, range.lowerEndpoint()));
             }
           }
         }
@@ -437,6 +493,11 @@ public class ShuffleBufferManager {
     return capacity;
   }
 
+  @VisibleForTesting
+  public long getReadCapacity() {
+    return readCapacity;
+  }
+
   @VisibleForTesting
   public void resetSize() {
     usedMemory = new AtomicLong(0L);
@@ -457,23 +518,24 @@ public class ShuffleBufferManager {
   private Map<String, Set<Integer>> pickFlushedShuffle() {
     // create list for sort
     List<Entry<String, AtomicLong>> sizeList = generateSizeList();
-    sizeList.sort((entry1, entry2) -> {
-      if (entry1 == null && entry2 == null) {
-        return 0;
-      }
-      if (entry1 == null) {
-        return 1;
-      }
-      if (entry2 == null) {
-        return -1;
-      }
-      if (entry1.getValue().get() > entry2.getValue().get()) {
-        return -1;
-      } else if (entry1.getValue().get() == entry2.getValue().get()) {
-        return 0;
-      }
-      return 1;
-    });
+    sizeList.sort(
+        (entry1, entry2) -> {
+          if (entry1 == null && entry2 == null) {
+            return 0;
+          }
+          if (entry1 == null) {
+            return 1;
+          }
+          if (entry2 == null) {
+            return -1;
+          }
+          if (entry1.getValue().get() > entry2.getValue().get()) {
+            return -1;
+          } else if (entry1.getValue().get() == entry2.getValue().get()) {
+            return 0;
+          }
+          return 1;
+        });
 
     Map<String, Set<Integer>> pickedShuffle = Maps.newHashMap();
     // The algorithm here is to flush data size > highWaterMark - lowWaterMark
@@ -501,7 +563,8 @@ public class ShuffleBufferManager {
           break;
         }
       } else {
-        // since shuffle size is ordered by size desc, we can skip process more shuffle data once some shuffle's size
+        // since shuffle size is ordered by size desc, we can skip process more shuffle data once
+        // some shuffle's size
         // is less than threshold
         if (printIgnoreIndex < printMax) {
           LOG.info("Ignore application_shuffleId[{}] with {} bytes", appIdShuffleIdKey, size);
@@ -526,11 +589,11 @@ public class ShuffleBufferManager {
     return Lists.newArrayList(sizeMap.entrySet());
   }
 
-  private void addPickedShuffle(String key, Map<String, Set<Integer>> pickedShuffle) {
-    String[] splits = key.split(Constants.KEY_SPLIT_CHAR);
+  private void addPickedShuffle(String shuffleIdKey, Map<String, Set<Integer>> pickedShuffle) {
+    String[] splits = shuffleIdKey.split(Constants.KEY_SPLIT_CHAR);
     String appId = splits[0];
     Integer shuffleId = Integer.parseInt(splits[1]);
-    pickedShuffle.putIfAbsent(appId, Sets.newHashSet());
+    pickedShuffle.computeIfAbsent(appId, key -> Sets.newHashSet());
     Set<Integer> shuffleIdSet = pickedShuffle.get(appId);
     shuffleIdSet.add(shuffleId);
   }
@@ -552,6 +615,7 @@ public class ShuffleBufferManager {
       Collection<ShuffleBuffer> buffers = bufferRangeMap.asMapOfRanges().values();
       if (buffers != null) {
         for (ShuffleBuffer buffer : buffers) {
+          buffer.getBlocks().forEach(spb -> spb.getData().release());
           ShuffleServerMetrics.gaugeTotalPartitionNum.dec();
           size += buffer.getSize();
         }
@@ -563,16 +627,28 @@ public class ShuffleBufferManager {
     }
   }
 
+  boolean isHugePartition(String appId, int shuffleId, int partitionId) {
+    return shuffleTaskManager != null
+        && shuffleTaskManager.getPartitionDataSize(appId, shuffleId, partitionId)
+            > hugePartitionSizeThreshold;
+  }
+
   public boolean isHugePartition(long usedPartitionDataSize) {
     return usedPartitionDataSize > hugePartitionSizeThreshold;
   }
 
-  public boolean limitHugePartition(String appId, int shuffleId, int partitionId, long usedPartitionDataSize) {
+  public boolean limitHugePartition(
+      String appId, int shuffleId, int partitionId, long usedPartitionDataSize) {
     if (usedPartitionDataSize > hugePartitionSizeThreshold) {
       long memoryUsed = getShuffleBufferEntry(appId, shuffleId, partitionId).getValue().getSize();
       if (memoryUsed > hugePartitionMemoryLimitSize) {
-        LOG.warn("AppId: {}, shuffleId: {}, partitionId: {}, memory used: {}, "
-            + "huge partition triggered memory limitation.", appId, shuffleId, partitionId, memoryUsed);
+        LOG.warn(
+            "AppId: {}, shuffleId: {}, partitionId: {}, memory used: {}, "
+                + "huge partition triggered memory limitation.",
+            appId,
+            shuffleId,
+            partitionId,
+            memoryUsed);
         return true;
       }
     }
