@@ -52,19 +52,20 @@ import org.apache.uniffle.common.ShuffleDataResult;
 import org.apache.uniffle.common.ShufflePartitionedBlock;
 import org.apache.uniffle.common.config.RssBaseConf;
 import org.apache.uniffle.common.util.ChecksumUtils;
+import org.apache.uniffle.common.util.Constants;
 import org.apache.uniffle.server.buffer.ShuffleBufferManager;
 import org.apache.uniffle.server.event.AppPurgeEvent;
-import org.apache.uniffle.server.storage.HdfsStorageManager;
+import org.apache.uniffle.server.storage.HadoopStorageManager;
 import org.apache.uniffle.server.storage.LocalStorageManager;
 import org.apache.uniffle.server.storage.LocalStorageManagerFallbackStrategy;
 import org.apache.uniffle.server.storage.MultiStorageManager;
 import org.apache.uniffle.server.storage.StorageManager;
 import org.apache.uniffle.server.storage.StorageManagerFactory;
-import org.apache.uniffle.storage.HdfsTestBase;
+import org.apache.uniffle.storage.HadoopTestBase;
 import org.apache.uniffle.storage.common.AbstractStorage;
-import org.apache.uniffle.storage.common.HdfsStorage;
+import org.apache.uniffle.storage.common.HadoopStorage;
 import org.apache.uniffle.storage.common.LocalStorage;
-import org.apache.uniffle.storage.handler.impl.HdfsClientReadHandler;
+import org.apache.uniffle.storage.handler.impl.HadoopClientReadHandler;
 import org.apache.uniffle.storage.util.StorageType;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
@@ -76,13 +77,14 @@ import static org.junit.jupiter.api.Assertions.fail;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
-public class ShuffleFlushManagerTest extends HdfsTestBase {
+public class ShuffleFlushManagerTest extends HadoopTestBase {
 
   private static AtomicInteger ATOMIC_INT = new AtomicInteger(0);
   private static AtomicLong ATOMIC_LONG = new AtomicLong(0);
 
   private ShuffleServerConf shuffleServerConf = new ShuffleServerConf();
-  private RemoteStorageInfo remoteStorage = new RemoteStorageInfo(HDFS_URI + "rss/test", Maps.newHashMap());
+  private RemoteStorageInfo remoteStorage =
+      new RemoteStorageInfo(HDFS_URI + "rss/test", Maps.newHashMap());
 
   private static ShuffleServer mockShuffleServer = mock(ShuffleServer.class);
 
@@ -99,7 +101,8 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
   public void prepare() {
     ShuffleServerMetrics.register();
     shuffleServerConf.set(ShuffleServerConf.RSS_STORAGE_BASE_PATH, Collections.emptyList());
-    shuffleServerConf.setString(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.HDFS.name());
+    shuffleServerConf.setString(ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.HDFS.name());
+    shuffleServerConf.setInteger(ShuffleServerConf.SERVER_MAX_CONCURRENCY_OF_ONE_PARTITION, 1);
     LogManager.getRootLogger().setLevel(Level.INFO);
   }
 
@@ -115,37 +118,78 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
     StorageManager storageManager =
         StorageManagerFactory.getInstance().createStorageManager(shuffleServerConf);
     ShuffleFlushManager manager =
-        new ShuffleFlushManager(shuffleServerConf, "shuffleServerId", mockShuffleServer, storageManager);
+        new ShuffleFlushManager(shuffleServerConf, mockShuffleServer, storageManager);
     assertEquals("2", manager.getHadoopConf().get("dfs.replication"));
     assertEquals("value", manager.getHadoopConf().get("a.b"));
   }
 
+  /**
+   * When enable concurrent writing single partition data, it should always write one file if no
+   * race condition.
+   */
+  @Test
+  public void concurrentWrite2HdfsWriteOneByOne() throws Exception {
+    ShuffleServerConf shuffleServerConf = new ShuffleServerConf();
+    shuffleServerConf.set(ShuffleServerConf.RSS_STORAGE_BASE_PATH, Collections.emptyList());
+    shuffleServerConf.setString(ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.HDFS.name());
+    int maxConcurrency = 3;
+    shuffleServerConf.setInteger(
+        ShuffleServerConf.SERVER_MAX_CONCURRENCY_OF_ONE_PARTITION, maxConcurrency);
+
+    String appId = "concurrentWrite2HdfsWriteOneByOne_appId";
+    StorageManager storageManager =
+        StorageManagerFactory.getInstance().createStorageManager(shuffleServerConf);
+    storageManager.registerRemoteStorage(appId, remoteStorage);
+    ShuffleFlushManager manager =
+        new ShuffleFlushManager(shuffleServerConf, mockShuffleServer, storageManager);
+
+    for (int i = 0; i < 10; i++) {
+      ShuffleDataFlushEvent shuffleDataFlushEvent =
+          createShuffleDataFlushEvent(appId, i, 1, 1, null);
+      manager.addToFlushQueue(shuffleDataFlushEvent);
+      waitForFlush(manager, appId, i, 5);
+    }
+
+    FileStatus[] fileStatuses = fs.listStatus(new Path(HDFS_URI + "/rss/test/" + appId + "/1/1-1"));
+    long actual =
+        Arrays.stream(fileStatuses).filter(x -> x.getPath().getName().endsWith("data")).count();
+    assertEquals(1, actual);
+    actual =
+        Arrays.stream(fileStatuses).filter(x -> x.getPath().getName().endsWith("index")).count();
+    assertEquals(1, actual);
+  }
+
   @Test
   public void concurrentWrite2HdfsWriteOfSinglePartition() throws Exception {
     ShuffleServerConf shuffleServerConf = new ShuffleServerConf();
     shuffleServerConf.set(ShuffleServerConf.RSS_STORAGE_BASE_PATH, Collections.emptyList());
-    shuffleServerConf.setString(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.HDFS.name());
+    shuffleServerConf.setString(shuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.HDFS.name());
     int maxConcurrency = 3;
-    shuffleServerConf.setInteger(ShuffleServerConf.SERVER_MAX_CONCURRENCY_OF_ONE_PARTITION, maxConcurrency);
+    shuffleServerConf.setInteger(
+        ShuffleServerConf.SERVER_MAX_CONCURRENCY_OF_ONE_PARTITION, maxConcurrency);
 
     String appId = "concurrentWrite2HdfsWriteOfSinglePartition_appId";
     StorageManager storageManager =
         StorageManagerFactory.getInstance().createStorageManager(shuffleServerConf);
     storageManager.registerRemoteStorage(appId, remoteStorage);
     ShuffleFlushManager manager =
-        new ShuffleFlushManager(shuffleServerConf, "shuffleServerId", mockShuffleServer, storageManager);
+        new ShuffleFlushManager(shuffleServerConf, mockShuffleServer, storageManager);
 
-    IntStream.range(0, 20).forEach(x -> {
-      ShuffleDataFlushEvent event = createShuffleDataFlushEvent(appId, 1, 1, 1, null);
-      manager.addToFlushQueue(event);
-    });
-    waitForFlush(manager, appId, 1, 10 * 5);
+    IntStream.range(0, 20)
+        .forEach(
+            x -> {
+              ShuffleDataFlushEvent event = createShuffleDataFlushEvent(appId, 1, 1, 1, null);
+              manager.addToFlushQueue(event);
+            });
+    waitForFlush(manager, appId, 1, 20 * 5);
 
     FileStatus[] fileStatuses = fs.listStatus(new Path(HDFS_URI + "/rss/test/" + appId + "/1/1-1"));
-    long actual = Arrays.stream(fileStatuses).filter(x -> x.getPath().getName().endsWith("data")).count();
+    long actual =
+        Arrays.stream(fileStatuses).filter(x -> x.getPath().getName().endsWith("data")).count();
 
     assertEquals(maxConcurrency, actual);
-    actual = Arrays.stream(fileStatuses).filter(x -> x.getPath().getName().endsWith("index")).count();
+    actual =
+        Arrays.stream(fileStatuses).filter(x -> x.getPath().getName().endsWith("index")).count();
     assertEquals(maxConcurrency, actual);
   }
 
@@ -155,23 +199,40 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
     StorageManager storageManager =
         StorageManagerFactory.getInstance().createStorageManager(shuffleServerConf);
     storageManager.registerRemoteStorage(appId, remoteStorage);
-    String storageHost = "localhost";
-    assertEquals(0.0, ShuffleServerMetrics.counterRemoteStorageTotalWrite.get(storageHost).get(), 0.5);
-    assertEquals(0.0, ShuffleServerMetrics.counterRemoteStorageRetryWrite.get(storageHost).get(), 0.5);
-    assertEquals(0.0, ShuffleServerMetrics.counterRemoteStorageFailedWrite.get(storageHost).get(), 0.5);
-    assertEquals(0.0, ShuffleServerMetrics.counterRemoteStorageSuccessWrite.get(storageHost).get(), 0.5);
+    String storageHost = cluster.getURI().getHost();
+    assertEquals(
+        0.0,
+        ShuffleServerMetrics.counterRemoteStorageTotalWrite
+            .labels(Constants.SHUFFLE_SERVER_VERSION, storageHost)
+            .get(),
+        0.5);
+    assertEquals(
+        0.0,
+        ShuffleServerMetrics.counterRemoteStorageRetryWrite
+            .labels(Constants.SHUFFLE_SERVER_VERSION, storageHost)
+            .get(),
+        0.5);
+    assertEquals(
+        0.0,
+        ShuffleServerMetrics.counterRemoteStorageFailedWrite
+            .labels(Constants.SHUFFLE_SERVER_VERSION, storageHost)
+            .get(),
+        0.5);
+    assertEquals(
+        0.0,
+        ShuffleServerMetrics.counterRemoteStorageSuccessWrite
+            .labels(Constants.SHUFFLE_SERVER_VERSION, storageHost)
+            .get(),
+        0.5);
     ShuffleFlushManager manager =
-        new ShuffleFlushManager(shuffleServerConf, "shuffleServerId", mockShuffleServer, storageManager);
-    ShuffleDataFlushEvent event1 =
-        createShuffleDataFlushEvent(appId, 1, 1, 1, null);
+        new ShuffleFlushManager(shuffleServerConf, mockShuffleServer, storageManager);
+    ShuffleDataFlushEvent event1 = createShuffleDataFlushEvent(appId, 1, 1, 1, null);
     final List<ShufflePartitionedBlock> blocks1 = event1.getShuffleBlocks();
     manager.addToFlushQueue(event1);
-    ShuffleDataFlushEvent event21 =
-        createShuffleDataFlushEvent(appId, 2, 2, 2, null);
+    ShuffleDataFlushEvent event21 = createShuffleDataFlushEvent(appId, 2, 2, 2, null);
     final List<ShufflePartitionedBlock> blocks21 = event21.getShuffleBlocks();
     manager.addToFlushQueue(event21);
-    ShuffleDataFlushEvent event22 =
-        createShuffleDataFlushEvent(appId, 2, 2, 2, null);
+    ShuffleDataFlushEvent event22 = createShuffleDataFlushEvent(appId, 2, 2, 2, null);
     final List<ShufflePartitionedBlock> blocks22 = event22.getShuffleBlocks();
     manager.addToFlushQueue(event22);
     // wait for write data
@@ -184,44 +245,106 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
     validate(appId, 2, 2, blocks21, 1, remoteStorage.getPath());
     assertEquals(blocks21.size(), manager.getCommittedBlockIds(appId, 2).getLongCardinality());
 
-    assertEquals(3.0, ShuffleServerMetrics.counterRemoteStorageTotalWrite.get(storageHost).get(), 0.5);
-    assertEquals(3.0, ShuffleServerMetrics.counterRemoteStorageSuccessWrite.get(storageHost).get(), 0.5);
+    assertEquals(
+        3.0,
+        ShuffleServerMetrics.counterRemoteStorageTotalWrite
+            .labels(Constants.SHUFFLE_SERVER_VERSION, storageHost)
+            .get(),
+        0.5);
+    assertEquals(
+        3.0,
+        ShuffleServerMetrics.counterRemoteStorageSuccessWrite
+            .labels(Constants.SHUFFLE_SERVER_VERSION, storageHost)
+            .get(),
+        0.5);
 
     // test case for process event whose related app was cleared already
     assertEquals(0, ShuffleServerMetrics.gaugeWriteHandler.get(), 0.5);
-    ShuffleDataFlushEvent fakeEvent =
-        createShuffleDataFlushEvent("fakeAppId", 1, 1, 1, null);
+    ShuffleDataFlushEvent fakeEvent = createShuffleDataFlushEvent("fakeAppId", 1, 1, 1, null);
     manager.addToFlushQueue(fakeEvent);
     waitForQueueClear(manager);
     waitForMetrics(ShuffleServerMetrics.gaugeWriteHandler, 0, 0.5);
   }
-  
+
   @Test
   public void localMetricsTest(@TempDir File tempDir) throws Exception {
-    shuffleServerConf.set(ShuffleServerConf.RSS_STORAGE_BASE_PATH, Arrays.asList(tempDir.getAbsolutePath()));
-    shuffleServerConf.set(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.MEMORY_LOCALFILE.name());
+    shuffleServerConf.set(
+        ShuffleServerConf.RSS_STORAGE_BASE_PATH, Arrays.asList(tempDir.getAbsolutePath()));
+    shuffleServerConf.setString(
+        ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.MEMORY_LOCALFILE.name());
 
     String appId = "localMetricsTest_appId";
     StorageManager storageManager =
-            StorageManagerFactory.getInstance().createStorageManager(shuffleServerConf);
+        StorageManagerFactory.getInstance().createStorageManager(shuffleServerConf);
     ShuffleFlushManager manager =
-            new ShuffleFlushManager(shuffleServerConf, "shuffleServerId", mockShuffleServer, storageManager);
-    ShuffleDataFlushEvent event1 =
-            createShuffleDataFlushEvent(appId, 1, 1, 1, null);
+        new ShuffleFlushManager(shuffleServerConf, mockShuffleServer, storageManager);
+    ShuffleDataFlushEvent event1 = createShuffleDataFlushEvent(appId, 1, 1, 1, null);
     manager.addToFlushQueue(event1);
     // wait for write data
     waitForFlush(manager, appId, 1, 5);
 
-    validateLocalMetadata(storageManager, 160L);
+    validateLocalMetadata(storageManager, 0, 160L);
 
-    ShuffleDataFlushEvent event12 =
-            createShuffleDataFlushEvent(appId, 1, 1, 1, null);
+    ShuffleDataFlushEvent event12 = createShuffleDataFlushEvent(appId, 1, 1, 1, null);
     manager.addToFlushQueue(event12);
 
     // wait for write data
     waitForFlush(manager, appId, 1, 10);
 
-    validateLocalMetadata(storageManager, 320L);
+    validateLocalMetadata(storageManager, 0, 320L);
+  }
+
+  @Test
+  public void totalLocalFileWriteDataMetricTest() throws Exception {
+    List<String> storagePaths = Arrays.asList("/tmp/rss-data1", "/tmp/rss-data2", "/tmp/rss-data3");
+
+    shuffleServerConf.set(ShuffleServerConf.RSS_STORAGE_BASE_PATH, storagePaths);
+    shuffleServerConf.setLong(ShuffleServerConf.DISK_CAPACITY, 1024L);
+    shuffleServerConf.setString(
+        ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.LOCALFILE.name());
+
+    String appId = "localMetricsTest_appId";
+    StorageManager storageManager =
+        StorageManagerFactory.getInstance().createStorageManager(shuffleServerConf);
+    ShuffleFlushManager manager =
+        new ShuffleFlushManager(shuffleServerConf, mockShuffleServer, storageManager);
+
+    ShuffleDataFlushEvent flushEvent = createShuffleDataFlushEvent(appId, 1, 1, 1, 10, 100, null);
+    manager.addToFlushQueue(flushEvent);
+    // wait for write data
+    waitForFlush(manager, appId, 1, 10);
+    int storageIndex = storagePaths.indexOf(flushEvent.getUnderStorage().getStoragePath());
+    validateLocalMetadata(storageManager, storageIndex, 1000L);
+
+    flushEvent = createShuffleDataFlushEvent(appId, 2, 1, 1, 10, 101, null);
+    manager.addToFlushQueue(flushEvent);
+    // wait for write data
+    waitForFlush(manager, appId, 2, 10);
+    int storageIndex1 = storagePaths.indexOf(flushEvent.getUnderStorage().getStoragePath());
+    validateLocalMetadata(storageManager, storageIndex1, 1010L);
+
+    flushEvent = createShuffleDataFlushEvent(appId, 3, 1, 1, 10, 102, null);
+    manager.addToFlushQueue(flushEvent);
+    // wait for write data
+    waitForFlush(manager, appId, 3, 10);
+    int storageIndex2 = storagePaths.indexOf(flushEvent.getUnderStorage().getStoragePath());
+    validateLocalMetadata(storageManager, storageIndex2, 1020L);
+
+    assertEquals(
+        1000L,
+        ShuffleServerMetrics.counterTotalLocalFileWriteDataSize
+            .labels(storagePaths.get(storageIndex))
+            .get());
+    assertEquals(
+        1010L,
+        ShuffleServerMetrics.counterTotalLocalFileWriteDataSize
+            .labels(storagePaths.get(storageIndex1))
+            .get());
+    assertEquals(
+        1020L,
+        ShuffleServerMetrics.counterTotalLocalFileWriteDataSize
+            .labels(storagePaths.get(storageIndex2))
+            .get());
   }
 
   @Test
@@ -234,8 +357,8 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
     List<ShufflePartitionedBlock> expectedBlocks = Lists.newArrayList();
     List<ShuffleDataFlushEvent> flushEvents1 = Lists.newArrayList();
     List<ShuffleDataFlushEvent> flushEvents2 = Lists.newArrayList();
-    ShuffleFlushManager manager = new ShuffleFlushManager(shuffleServerConf, "shuffleServerId",
-        mockShuffleServer, storageManager);
+    ShuffleFlushManager manager =
+        new ShuffleFlushManager(shuffleServerConf, mockShuffleServer, storageManager);
     for (int i = 0; i < 30; i++) {
       ShuffleDataFlushEvent flushEvent1 = createShuffleDataFlushEvent(appId, 1, 1, 1, null);
       ShuffleDataFlushEvent flushEvent2 = createShuffleDataFlushEvent(appId, 1, 1, 1, null);
@@ -244,17 +367,21 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
       flushEvents1.add(flushEvent1);
       flushEvents2.add(flushEvent2);
     }
-    Thread flushThread1 = new Thread(() -> {
-      for (ShuffleDataFlushEvent event : flushEvents1) {
-        manager.addToFlushQueue(event);
-      }
-    });
+    Thread flushThread1 =
+        new Thread(
+            () -> {
+              for (ShuffleDataFlushEvent event : flushEvents1) {
+                manager.addToFlushQueue(event);
+              }
+            });
 
-    Thread flushThread2 = new Thread(() -> {
-      for (ShuffleDataFlushEvent event : flushEvents2) {
-        manager.addToFlushQueue(event);
-      }
-    });
+    Thread flushThread2 =
+        new Thread(
+            () -> {
+              for (ShuffleDataFlushEvent event : flushEvents2) {
+                manager.addToFlushQueue(event);
+              }
+            });
     flushThread1.start();
     flushThread2.start();
     flushThread1.join();
@@ -273,12 +400,10 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
     storageManager.registerRemoteStorage(appId1, remoteStorage);
     storageManager.registerRemoteStorage(appId2, remoteStorage);
     ShuffleFlushManager manager =
-        new ShuffleFlushManager(shuffleServerConf, "shuffleServerId", mockShuffleServer, storageManager);
-    ShuffleDataFlushEvent event1 =
-        createShuffleDataFlushEvent(appId1, 1, 0, 1, null);
+        new ShuffleFlushManager(shuffleServerConf, mockShuffleServer, storageManager);
+    ShuffleDataFlushEvent event1 = createShuffleDataFlushEvent(appId1, 1, 0, 1, null);
     manager.addToFlushQueue(event1);
-    ShuffleDataFlushEvent event2 =
-        createShuffleDataFlushEvent(appId2, 1, 0, 1, null);
+    ShuffleDataFlushEvent event2 = createShuffleDataFlushEvent(appId2, 1, 0, 1, null);
     manager.addToFlushQueue(event2);
     waitForFlush(manager, appId1, 1, 5);
     waitForFlush(manager, appId2, 1, 5);
@@ -292,11 +417,9 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
     assertTrue(fileStatus.length > 0);
     manager.removeResources(appId1);
 
-    assertTrue(((HdfsStorageManager)storageManager).getAppIdToStorages().containsKey(appId1));
-    storageManager.removeResources(
-        new AppPurgeEvent(appId1, StringUtils.EMPTY, Arrays.asList(1))
-    );
-    assertFalse(((HdfsStorageManager)storageManager).getAppIdToStorages().containsKey(appId1));
+    assertTrue(((HadoopStorageManager) storageManager).getAppIdToStorages().containsKey(appId1));
+    storageManager.removeResources(new AppPurgeEvent(appId1, StringUtils.EMPTY, Arrays.asList(1)));
+    assertFalse(((HadoopStorageManager) storageManager).getAppIdToStorages().containsKey(appId1));
     try {
       fs.listStatus(new Path(remoteStorage.getPath() + "/" + appId1 + "/"));
       fail("Exception should be thrown");
@@ -309,11 +432,9 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
     size = storage.getHandlerSize();
     assertEquals(1, size);
     manager.removeResources(appId2);
-    assertTrue(((HdfsStorageManager)storageManager).getAppIdToStorages().containsKey(appId2));
-    storageManager.removeResources(
-        new AppPurgeEvent(appId2, StringUtils.EMPTY, Arrays.asList(1))
-    );
-    assertFalse(((HdfsStorageManager)storageManager).getAppIdToStorages().containsKey(appId2));
+    assertTrue(((HadoopStorageManager) storageManager).getAppIdToStorages().containsKey(appId2));
+    storageManager.removeResources(new AppPurgeEvent(appId2, StringUtils.EMPTY, Arrays.asList(1)));
+    assertFalse(((HadoopStorageManager) storageManager).getAppIdToStorages().containsKey(appId2));
     assertEquals(0, manager.getCommittedBlockIds(appId2, 1).getLongCardinality());
     size = storage.getHandlerSize();
     assertEquals(0, size);
@@ -322,10 +443,10 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
     Path path = new Path(remoteStorage.getPath() + "/" + appId2 + "/");
     assertTrue(fs.mkdirs(path));
     storageManager.removeResources(
-        new AppPurgeEvent(appId2, StringUtils.EMPTY, Lists.newArrayList(1))
-    );
+        new AppPurgeEvent(appId2, StringUtils.EMPTY, Lists.newArrayList(1)));
     assertFalse(fs.exists(path));
-    HdfsStorage storageByAppId = ((HdfsStorageManager) storageManager).getStorageByAppId(appId2);
+    HadoopStorage storageByAppId =
+        ((HadoopStorageManager) storageManager).getStorageByAppId(appId2);
     assertNull(storageByAppId);
   }
 
@@ -334,18 +455,17 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
     final String appId1 = "clearLocalTest_appId1";
     final String appId2 = "clearLocalTest_appId2";
     ShuffleServerConf serverConf = new ShuffleServerConf();
-    serverConf.set(ShuffleServerConf.RSS_STORAGE_BASE_PATH, Arrays.asList(tempDir.getAbsolutePath()));
-    serverConf.setString(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.LOCALFILE.name());
+    serverConf.set(
+        ShuffleServerConf.RSS_STORAGE_BASE_PATH, Arrays.asList(tempDir.getAbsolutePath()));
+    serverConf.setString(ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.LOCALFILE.name());
     serverConf.setLong(ShuffleServerConf.DISK_CAPACITY, 1024L * 1024L * 1024L);
     StorageManager storageManager =
         StorageManagerFactory.getInstance().createStorageManager(serverConf);
     ShuffleFlushManager manager =
-        new ShuffleFlushManager(serverConf, "shuffleServerId", mockShuffleServer, storageManager);
-    ShuffleDataFlushEvent event1 =
-        createShuffleDataFlushEvent(appId1, 1, 0, 1, null);
+        new ShuffleFlushManager(serverConf, mockShuffleServer, storageManager);
+    ShuffleDataFlushEvent event1 = createShuffleDataFlushEvent(appId1, 1, 0, 1, null);
     manager.addToFlushQueue(event1);
-    ShuffleDataFlushEvent event2 =
-        createShuffleDataFlushEvent(appId2, 1, 0, 1, null);
+    ShuffleDataFlushEvent event2 = createShuffleDataFlushEvent(appId2, 1, 0, 1, null);
     manager.addToFlushQueue(event2);
     assertEquals(storageManager.selectStorage(event1), storageManager.selectStorage(event2));
     final AbstractStorage storage = (AbstractStorage) storageManager.selectStorage(event1);
@@ -357,12 +477,10 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
     File file = new File(tempDir, appId1);
     assertTrue(file.exists());
     storageManager.removeResources(
-        new AppPurgeEvent(appId1, StringUtils.EMPTY, Lists.newArrayList(1))
-    );
+        new AppPurgeEvent(appId1, StringUtils.EMPTY, Lists.newArrayList(1)));
     manager.removeResources(appId1);
     assertFalse(file.exists());
-    ShuffleDataFlushEvent event3 =
-        createShuffleDataFlushEvent(appId1, 1, 0, 1, () -> false);
+    ShuffleDataFlushEvent event3 = createShuffleDataFlushEvent(appId1, 1, 0, 1, () -> false);
     manager.addToFlushQueue(event3);
     Thread.sleep(1000);
     assertEquals(0, manager.getCommittedBlockIds(appId1, 1).getLongCardinality());
@@ -370,13 +488,12 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
     assertEquals(1, storage.getHandlerSize());
     manager.removeResources(appId2);
     storageManager.removeResources(
-        new AppPurgeEvent(appId2, StringUtils.EMPTY, Lists.newArrayList(1))
-    );
+        new AppPurgeEvent(appId2, StringUtils.EMPTY, Lists.newArrayList(1)));
     assertEquals(0, manager.getCommittedBlockIds(appId2, 1).getLongCardinality());
     assertEquals(0, storage.getHandlerSize());
   }
 
-  private void waitForMetrics(Gauge gauge, double expected, double delta) throws Exception {
+  private void waitForMetrics(Gauge.Child gauge, double expected, double delta) throws Exception {
     int retry = 0;
     boolean match = false;
     do {
@@ -407,8 +524,9 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
     } while (size > 0);
   }
 
-  public static void waitForFlush(ShuffleFlushManager manager,
-      String appId, int shuffleId, int expectedBlockNum) throws Exception {
+  public static void waitForFlush(
+      ShuffleFlushManager manager, String appId, int shuffleId, int expectedBlockNum)
+      throws Exception {
     int retry = 0;
     int size = 0;
     do {
@@ -422,15 +540,12 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
   }
 
   public static ShuffleDataFlushEvent createShuffleDataFlushEvent(
-      String appId, int shuffleId, int startPartition, int endPartition, Supplier<Boolean> isValid) {
-    return createShuffleDataFlushEvent(
-      appId,
-      shuffleId,
-        startPartition,
-        endPartition,
-        isValid,
-        1
-    );
+      String appId,
+      int shuffleId,
+      int startPartition,
+      int endPartition,
+      Supplier<Boolean> isValid) {
+    return createShuffleDataFlushEvent(appId, shuffleId, startPartition, endPartition, isValid, 1);
   }
 
   public static ShuffleDataFlushEvent createShuffleDataFlushEvent(
@@ -441,8 +556,36 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
       Supplier<Boolean> isValid,
       int size) {
     List<ShufflePartitionedBlock> spbs = createBlock(5, 32);
-    return new ShuffleDataFlushEvent(ATOMIC_LONG.getAndIncrement(),
-        appId, shuffleId, startPartition, endPartition, size, spbs, isValid, null);
+    return new ShuffleDataFlushEvent(
+        ATOMIC_LONG.getAndIncrement(),
+        appId,
+        shuffleId,
+        startPartition,
+        endPartition,
+        size,
+        spbs,
+        isValid,
+        null);
+  }
+
+  public static ShuffleDataFlushEvent createShuffleDataFlushEvent(
+      String appId,
+      int shuffleId,
+      int startPartition,
+      int endPartition,
+      int blockNum,
+      int blockSize,
+      Supplier<Boolean> isValid) {
+    return new ShuffleDataFlushEvent(
+        ATOMIC_LONG.getAndIncrement(),
+        appId,
+        shuffleId,
+        startPartition,
+        endPartition,
+        (long) blockNum * blockSize,
+        createBlock(blockNum, blockSize),
+        isValid,
+        null);
   }
 
   public static List<ShufflePartitionedBlock> createBlock(int num, int length) {
@@ -450,15 +593,20 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
     for (int i = 0; i < num; i++) {
       byte[] buf = new byte[length];
       new Random().nextBytes(buf);
-      blocks.add(new ShufflePartitionedBlock(
-          length, length, ChecksumUtils.getCrc32(buf),
-          ATOMIC_INT.incrementAndGet(), 0, buf));
+      blocks.add(
+          new ShufflePartitionedBlock(
+              length, length, ChecksumUtils.getCrc32(buf), ATOMIC_INT.incrementAndGet(), 0, buf));
     }
     return blocks;
   }
 
-  private void validate(String appId, int shuffleId, int partitionId, List<ShufflePartitionedBlock> blocks,
-      int partitionNumPerRange, String basePath) {
+  private void validate(
+      String appId,
+      int shuffleId,
+      int partitionId,
+      List<ShufflePartitionedBlock> blocks,
+      int partitionNumPerRange,
+      String basePath) {
     Roaring64NavigableMap expectBlockIds = Roaring64NavigableMap.bitmapOf();
     Roaring64NavigableMap processBlockIds = Roaring64NavigableMap.bitmapOf();
     Set<Long> remainIds = Sets.newHashSet();
@@ -466,18 +614,19 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
       expectBlockIds.addLong(spb.getBlockId());
       remainIds.add(spb.getBlockId());
     }
-    HdfsClientReadHandler handler = new HdfsClientReadHandler(
-        appId,
-        shuffleId,
-        partitionId,
-        100,
-        partitionNumPerRange,
-        10,
-        blocks.size() * 32,
-        expectBlockIds,
-        processBlockIds,
-        basePath,
-        new Configuration());
+    HadoopClientReadHandler handler =
+        new HadoopClientReadHandler(
+            appId,
+            shuffleId,
+            partitionId,
+            100,
+            partitionNumPerRange,
+            10,
+            blocks.size() * 32,
+            expectBlockIds,
+            processBlockIds,
+            basePath,
+            new Configuration());
     ShuffleDataResult sdr = null;
     int matchNum = 0;
     sdr = handler.readShuffleData();
@@ -497,25 +646,25 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
   }
 
   @Test
-  public void fallbackWrittenWhenMultiStorageManagerEnableTest(@TempDir File tempDir) throws InterruptedException {
+  public void fallbackWrittenWhenMultiStorageManagerEnableTest(@TempDir File tempDir)
+      throws InterruptedException {
     shuffleServerConf.setLong(ShuffleServerConf.FLUSH_COLD_STORAGE_THRESHOLD_SIZE, 10000L);
-    shuffleServerConf.set(RssBaseConf.RSS_STORAGE_TYPE, StorageType.LOCALFILE_HDFS.toString());
-    shuffleServerConf.set(RssBaseConf.RSS_STORAGE_BASE_PATH, Arrays.asList(tempDir.getAbsolutePath()));
+    shuffleServerConf.setString(
+        RssBaseConf.RSS_STORAGE_TYPE.key(), StorageType.LOCALFILE_HDFS.toString());
+    shuffleServerConf.set(
+        RssBaseConf.RSS_STORAGE_BASE_PATH, Arrays.asList(tempDir.getAbsolutePath()));
     shuffleServerConf.set(ShuffleServerConf.DISK_CAPACITY, 100L);
-    shuffleServerConf.setString(ShuffleServerConf.MULTISTORAGE_FALLBACK_STRATEGY_CLASS,
+    shuffleServerConf.setString(
+        ShuffleServerConf.MULTISTORAGE_FALLBACK_STRATEGY_CLASS,
         LocalStorageManagerFallbackStrategy.class.getCanonicalName());
 
-    StorageManager storageManager = StorageManagerFactory.getInstance().createStorageManager(shuffleServerConf);
-    String remoteStorage = "test";
+    StorageManager storageManager =
+        StorageManagerFactory.getInstance().createStorageManager(shuffleServerConf);
     String appId = "fallbackWrittenWhenMultiStorageManagerEnableTest";
-    storageManager.registerRemoteStorage(appId, new RemoteStorageInfo(remoteStorage));
+    storageManager.registerRemoteStorage(appId, new RemoteStorageInfo(remoteStorage.getPath()));
 
-    ShuffleFlushManager flushManager = new ShuffleFlushManager(
-        shuffleServerConf,
-        "shuffle-server-id",
-        mockShuffleServer,
-        storageManager
-    );
+    ShuffleFlushManager flushManager =
+        new ShuffleFlushManager(shuffleServerConf, mockShuffleServer, storageManager);
 
     // case1: normally written to local storage
     ShuffleDataFlushEvent event = createShuffleDataFlushEvent(appId, 1, 1, 1, null, 100);
@@ -527,67 +676,84 @@ public class ShuffleFlushManagerTest extends HdfsTestBase {
     event = createShuffleDataFlushEvent(appId, 1, 1, 1, null, 100000);
     flushManager.addToFlushQueue(event);
     Thread.sleep(1000);
-    assertTrue(event.getUnderStorage() instanceof HdfsStorage);
+    assertTrue(event.getUnderStorage() instanceof HadoopStorage);
     assertEquals(0, event.getRetryTimes());
 
     // case3: local disk is full or corrupted, fallback to HDFS
-    List<ShufflePartitionedBlock> blocks = Lists.newArrayList(
-        new ShufflePartitionedBlock(100000, 1000, 1, 1, 1L, null)
-    );
-    ShuffleDataFlushEvent bigEvent = new ShuffleDataFlushEvent(1, "1", 1, 1, 1, 100, blocks, null, null);
-    bigEvent.setUnderStorage(((MultiStorageManager)storageManager).getWarmStorageManager().selectStorage(event));
-    ((MultiStorageManager)storageManager).getWarmStorageManager().updateWriteMetrics(bigEvent, 0);
+    List<ShufflePartitionedBlock> blocks =
+        Lists.newArrayList(new ShufflePartitionedBlock(100000, 1000, 1, 1, 1L, (byte[]) null));
+    ShuffleDataFlushEvent bigEvent =
+        new ShuffleDataFlushEvent(1, "1", 1, 1, 1, 100, blocks, null, null);
+    bigEvent.setUnderStorage(
+        ((MultiStorageManager) storageManager).getWarmStorageManager().selectStorage(event));
+    ((MultiStorageManager) storageManager).getWarmStorageManager().updateWriteMetrics(bigEvent, 0);
 
     event = createShuffleDataFlushEvent(appId, 1, 1, 1, null, 100);
     flushManager.addToFlushQueue(event);
     Thread.sleep(1000);
-    assertTrue(event.getUnderStorage() instanceof HdfsStorage);
+    assertTrue(event.getUnderStorage() instanceof HadoopStorage);
     assertEquals(1, event.getRetryTimes());
   }
 
   @Test
-  public void processPendingEventsTest(@TempDir File tempDir) {
-    try {
-      shuffleServerConf.set(RssBaseConf.RSS_STORAGE_TYPE, StorageType.LOCALFILE.toString());
-      shuffleServerConf.set(RssBaseConf.RSS_STORAGE_BASE_PATH, Arrays.asList(tempDir.getAbsolutePath()));
-      shuffleServerConf.set(ShuffleServerConf.DISK_CAPACITY, 100L);
-      shuffleServerConf.set(ShuffleServerConf.PENDING_EVENT_TIMEOUT_SEC, 5L);
-      StorageManager storageManager =
-          StorageManagerFactory.getInstance().createStorageManager(shuffleServerConf);
-      ShuffleFlushManager manager =
-          new ShuffleFlushManager(shuffleServerConf, "shuffleServerId", mockShuffleServer, storageManager);
-      ShuffleDataFlushEvent event = new ShuffleDataFlushEvent(1, "1", 1, 1, 1, 100, null, null, null);
-      assertEquals(0, manager.getPendingEventsSize());
-      manager.addPendingEvents(event);
-      Thread.sleep(1000);
-      assertEquals(0, manager.getPendingEventsSize());
-      do {
-        Thread.sleep(1 * 1000);
-      } while (manager.getEventNumInFlush() != 0);
+  public void defaultFlushEventHandlerTest(@TempDir File tempDir) throws Exception {
+    shuffleServerConf.setLong(ShuffleServerConf.FLUSH_COLD_STORAGE_THRESHOLD_SIZE, 10000L);
+    shuffleServerConf.setString(
+        RssBaseConf.RSS_STORAGE_TYPE.key(), StorageType.LOCALFILE_HDFS.toString());
+    shuffleServerConf.set(
+        RssBaseConf.RSS_STORAGE_BASE_PATH, Arrays.asList(tempDir.getAbsolutePath()));
+    shuffleServerConf.set(ShuffleServerConf.DISK_CAPACITY, 100L);
+    shuffleServerConf.set(ShuffleServerConf.SERVER_FLUSH_HADOOP_THREAD_POOL_SIZE, 1);
+    shuffleServerConf.set(ShuffleServerConf.SERVER_FLUSH_LOCALFILE_THREAD_POOL_SIZE, 1);
+    shuffleServerConf.setString(
+        ShuffleServerConf.MULTISTORAGE_FALLBACK_STRATEGY_CLASS,
+        LocalStorageManagerFallbackStrategy.class.getCanonicalName());
 
-      List<ShufflePartitionedBlock> blocks = Lists.newArrayList(new ShufflePartitionedBlock(100, 1000, 1, 1, 1L, null));
-      ShuffleDataFlushEvent bigEvent = new ShuffleDataFlushEvent(1, "1", 1, 1, 1, 100, blocks, null, null);
-      bigEvent.setUnderStorage(storageManager.selectStorage(event));
-      storageManager.updateWriteMetrics(bigEvent, 0);
+    StorageManager storageManager =
+        StorageManagerFactory.getInstance().createStorageManager(shuffleServerConf);
+    String appId = "fallbackWrittenWhenMultiStorageManagerEnableTest";
+    storageManager.registerRemoteStorage(appId, new RemoteStorageInfo(remoteStorage.getPath()));
 
-      manager.addPendingEvents(event);
-      manager.addPendingEvents(event);
-      manager.addPendingEvents(event);
-      Thread.sleep(1000);
-      assertTrue(2 <= manager.getPendingEventsSize());
-      int eventNum = (int) ShuffleServerMetrics.counterTotalDroppedEventNum.get();
-      Thread.sleep(6 * 1000);
-      assertEquals(eventNum + 3, (int) ShuffleServerMetrics.counterTotalDroppedEventNum.get());
-      assertEquals(0, manager.getPendingEventsSize());
-    } catch (Exception e) {
-      e.printStackTrace();
-      fail();
-    }
+    ShuffleFlushManager flushManager =
+        new ShuffleFlushManager(shuffleServerConf, mockShuffleServer, storageManager);
+
+    ShuffleServerMetrics.counterLocalFileEventFlush.clear();
+    ShuffleServerMetrics.counterHadoopEventFlush.clear();
+    // case1: normally written to local storage
+    ShuffleDataFlushEvent event = createShuffleDataFlushEvent(appId, 1, 1, 1, null, 100);
+    flushManager.addToFlushQueue(event);
+    waitForFlush(flushManager, appId, 1, 5);
+    assertEquals(0, event.getRetryTimes());
+    assertEquals(1, ShuffleServerMetrics.counterLocalFileEventFlush.get());
+
+    // case2: huge event is written to cold storage directly
+    event = createShuffleDataFlushEvent(appId, 1, 1, 1, null, 100000);
+    flushManager.addToFlushQueue(event);
+    waitForFlush(flushManager, appId, 1, 10);
+    assertEquals(0, event.getRetryTimes());
+    assertEquals(1, ShuffleServerMetrics.counterHadoopEventFlush.get());
+
+    // case3: local disk is full or corrupted, fallback to HDFS
+    List<ShufflePartitionedBlock> blocks =
+        Lists.newArrayList(new ShufflePartitionedBlock(100000, 1000, 1, 1, 1L, (byte[]) null));
+    ShuffleDataFlushEvent bigEvent =
+        new ShuffleDataFlushEvent(1, "1", 1, 1, 1, 100, blocks, null, null);
+    bigEvent.setUnderStorage(
+        ((MultiStorageManager) storageManager).getWarmStorageManager().selectStorage(event));
+    ((MultiStorageManager) storageManager).getWarmStorageManager().updateWriteMetrics(bigEvent, 0);
+
+    event = createShuffleDataFlushEvent(appId, 1, 1, 1, null, 100);
+    flushManager.addToFlushQueue(event);
+    waitForFlush(flushManager, appId, 1, 15);
+    assertEquals(1, event.getRetryTimes());
+    assertEquals(2, ShuffleServerMetrics.counterLocalFileEventFlush.get());
+    assertEquals(2, ShuffleServerMetrics.counterHadoopEventFlush.get());
   }
-  
-  private void validateLocalMetadata(StorageManager storageManager, Long size) {
+
+  private void validateLocalMetadata(StorageManager storageManager, int storageIndex, Long size) {
     assertInstanceOf(LocalStorageManager.class, storageManager);
-    LocalStorage localStorage = ((LocalStorageManager) storageManager).getStorages().get(0);
+    LocalStorage localStorage =
+        ((LocalStorageManager) storageManager).getStorages().get(storageIndex);
     assertEquals(size, localStorage.getMetaData().getDiskSize().longValue());
   }
 }
