@@ -34,9 +34,11 @@ import org.junit.jupiter.api.Test;
 
 import org.apache.uniffle.common.RemoteStorageInfo;
 import org.apache.uniffle.common.metrics.TestUtils;
+import org.apache.uniffle.common.util.Constants;
 import org.apache.uniffle.storage.common.LocalStorage;
 import org.apache.uniffle.storage.util.StorageType;
 
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
@@ -45,6 +47,7 @@ public class ShuffleServerMetricsTest {
   private static final String SERVER_METRICS_URL = "http://127.0.0.1:12345/metrics/server";
   private static final String SERVER_JVM_URL = "http://127.0.0.1:12345/metrics/jvm";
   private static final String SERVER_GRPC_URL = "http://127.0.0.1:12345/metrics/grpc";
+  private static final String SERVER_NETTY_URL = "http://127.0.0.1:12345/metrics/netty";
   private static final String REMOTE_STORAGE_PATH = "hdfs://hdfs1:9000/rss";
   private static final String STORAGE_HOST = "hdfs1";
   private static ShuffleServer shuffleServer;
@@ -57,15 +60,14 @@ public class ShuffleServerMetricsTest {
     ssc.set(ShuffleServerConf.RPC_SERVER_PORT, 12346);
     ssc.set(ShuffleServerConf.RSS_STORAGE_BASE_PATH, Arrays.asList("tmp"));
     ssc.set(ShuffleServerConf.DISK_CAPACITY, 1024L * 1024L * 1024L);
-    ssc.set(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.MEMORY_LOCALFILE_HDFS.name());
+    ssc.setString(
+        ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.MEMORY_LOCALFILE_HDFS.name());
     ssc.set(ShuffleServerConf.RSS_COORDINATOR_QUORUM, "fake.coordinator:123");
     ssc.set(ShuffleServerConf.SERVER_BUFFER_CAPACITY, 1000L);
     shuffleServer = new ShuffleServer(ssc);
-    shuffleServer.getStorageManager()
-        .registerRemoteStorage(
-            "metricsTest",
-            new RemoteStorageInfo(REMOTE_STORAGE_PATH)
-        );
+    shuffleServer
+        .getStorageManager()
+        .registerRemoteStorage("metricsTest", new RemoteStorageInfo(REMOTE_STORAGE_PATH));
     shuffleServer.start();
   }
 
@@ -77,7 +79,7 @@ public class ShuffleServerMetricsTest {
 
   @Test
   public void testJvmMetrics() throws Exception {
-    String content = TestUtils.httpGetMetrics(SERVER_JVM_URL);
+    String content = TestUtils.httpGet(SERVER_JVM_URL);
     ObjectMapper mapper = new ObjectMapper();
     JsonNode actualObj = mapper.readTree(content);
     assertEquals(2, actualObj.size());
@@ -85,32 +87,44 @@ public class ShuffleServerMetricsTest {
 
   @Test
   public void testServerMetrics() throws Exception {
-    String content = TestUtils.httpGetMetrics(SERVER_METRICS_URL);
+    ShuffleServerMetrics.counterRemoteStorageFailedWrite
+        .labels(Constants.SHUFFLE_SERVER_VERSION, STORAGE_HOST)
+        .inc(0);
+    ShuffleServerMetrics.counterRemoteStorageSuccessWrite
+        .labels(Constants.SHUFFLE_SERVER_VERSION, STORAGE_HOST)
+        .inc(0);
+    ShuffleServerMetrics.counterRemoteStorageTotalWrite
+        .labels(Constants.SHUFFLE_SERVER_VERSION, STORAGE_HOST)
+        .inc(0);
+    ShuffleServerMetrics.counterRemoteStorageRetryWrite
+        .labels(Constants.SHUFFLE_SERVER_VERSION, STORAGE_HOST)
+        .inc(0);
+    String content = TestUtils.httpGet(SERVER_METRICS_URL);
     ObjectMapper mapper = new ObjectMapper();
     JsonNode actualObj = mapper.readTree(content);
     assertEquals(2, actualObj.size());
     JsonNode metricsNode = actualObj.get("metrics");
-
-    List<String> expectedMetricNames = Lists.newArrayList(
-        ShuffleServerMetrics.STORAGE_TOTAL_WRITE_REMOTE_PREFIX + STORAGE_HOST,
-        ShuffleServerMetrics.STORAGE_SUCCESS_WRITE_REMOTE_PREFIX + STORAGE_HOST,
-        ShuffleServerMetrics.STORAGE_FAILED_WRITE_REMOTE_PREFIX + STORAGE_HOST,
-        ShuffleServerMetrics.STORAGE_RETRY_WRITE_REMOTE_PREFIX + STORAGE_HOST);
+    List<String> expectedMetricNames =
+        Lists.newArrayList(
+            ShuffleServerMetrics.STORAGE_TOTAL_WRITE_REMOTE,
+            ShuffleServerMetrics.STORAGE_SUCCESS_WRITE_REMOTE,
+            ShuffleServerMetrics.STORAGE_FAILED_WRITE_REMOTE,
+            ShuffleServerMetrics.STORAGE_RETRY_WRITE_REMOTE);
     for (String expectMetricName : expectedMetricNames) {
-      validateMetrics(metricsNode, expectMetricName);
+      validateMetrics(
+          mapper, metricsNode, expectMetricName, Constants.SHUFFLE_SERVER_VERSION, STORAGE_HOST);
     }
-
-    // for duplicate register, IllegalArgumentException shouldn't be thrown
-    String hostName = "duplicateHost";
-    ShuffleServerMetrics.addDynamicCounterForRemoteStorage(hostName);
-    ShuffleServerMetrics.addDynamicCounterForRemoteStorage(hostName);
   }
 
-  private void validateMetrics(JsonNode metricsNode, String expectedMetricName) {
+  private void validateMetrics(
+      ObjectMapper mapper, JsonNode metricsNode, String expectedMetricName, String... labels) {
     boolean bingo = false;
     for (int i = 0; i < metricsNode.size(); i++) {
       JsonNode metricsName = metricsNode.get(i).get("name");
       if (expectedMetricName.equals(metricsName.textValue())) {
+        List<String> labelValues =
+            mapper.convertValue(metricsNode.get(i).get("labelValues"), ArrayList.class);
+        assertArrayEquals(labels, labelValues.toArray(new String[0]));
         bingo = true;
         break;
       }
@@ -118,6 +132,42 @@ public class ShuffleServerMetricsTest {
     assertTrue(bingo);
   }
 
+  @Test
+  public void testHadoopStorageWriteDataSize() {
+    // case1
+    String host1 = "hadoop-cluster01";
+    ShuffleServerMetrics.incHadoopStorageWriteDataSize(host1, 1000);
+    assertEquals(
+        1000.0,
+        ShuffleServerMetrics.counterTotalHadoopWriteDataSize
+            .labels(Constants.SHUFFLE_SERVER_VERSION, host1)
+            .get());
+
+    // case2
+    ShuffleServerMetrics.incHadoopStorageWriteDataSize(host1, 500);
+    assertEquals(
+        1500.0,
+        ShuffleServerMetrics.counterTotalHadoopWriteDataSize
+            .labels(Constants.SHUFFLE_SERVER_VERSION, host1)
+            .get());
+
+    // case3
+    String host2 = "hadoop-cluster2";
+    ShuffleServerMetrics.incHadoopStorageWriteDataSize(host2, 2000);
+    assertEquals(
+        2000.0,
+        ShuffleServerMetrics.counterTotalHadoopWriteDataSize
+            .labels(Constants.SHUFFLE_SERVER_VERSION, host2)
+            .get());
+
+    // case4
+    assertEquals(
+        3500.0,
+        ShuffleServerMetrics.counterTotalHadoopWriteDataSize
+            .labels(Constants.SHUFFLE_SERVER_VERSION, ShuffleServerMetrics.STORAGE_HOST_LABEL_ALL)
+            .get());
+  }
+
   @Test
   public void testStorageCounter() {
     // test for local storage
@@ -133,25 +183,64 @@ public class ShuffleServerMetricsTest {
 
     // test for remote storage
     ShuffleServerMetrics.incStorageRetryCounter(STORAGE_HOST);
-    assertEquals(1.0, ShuffleServerMetrics.counterRemoteStorageTotalWrite.get(STORAGE_HOST).get(), 0.5);
-    assertEquals(1.0, ShuffleServerMetrics.counterRemoteStorageRetryWrite.get(STORAGE_HOST).get(), 0.5);
+    assertEquals(
+        1.0,
+        ShuffleServerMetrics.counterRemoteStorageTotalWrite
+            .labels(Constants.SHUFFLE_SERVER_VERSION, STORAGE_HOST)
+            .get(),
+        0.5);
+    assertEquals(
+        1.0,
+        ShuffleServerMetrics.counterRemoteStorageRetryWrite
+            .labels(Constants.SHUFFLE_SERVER_VERSION, STORAGE_HOST)
+            .get(),
+        0.5);
     ShuffleServerMetrics.incStorageSuccessCounter(STORAGE_HOST);
-    assertEquals(2.0, ShuffleServerMetrics.counterRemoteStorageTotalWrite.get(STORAGE_HOST).get(), 0.5);
-    assertEquals(1.0, ShuffleServerMetrics.counterRemoteStorageSuccessWrite.get(STORAGE_HOST).get(), 0.5);
+    assertEquals(
+        2.0,
+        ShuffleServerMetrics.counterRemoteStorageTotalWrite
+            .labels(Constants.SHUFFLE_SERVER_VERSION, STORAGE_HOST)
+            .get(),
+        0.5);
+    assertEquals(
+        1.0,
+        ShuffleServerMetrics.counterRemoteStorageSuccessWrite
+            .labels(Constants.SHUFFLE_SERVER_VERSION, STORAGE_HOST)
+            .get(),
+        0.5);
     ShuffleServerMetrics.incStorageFailedCounter(STORAGE_HOST);
-    assertEquals(3.0, ShuffleServerMetrics.counterRemoteStorageTotalWrite.get(STORAGE_HOST).get(), 0.5);
-    assertEquals(1.0, ShuffleServerMetrics.counterRemoteStorageFailedWrite.get(STORAGE_HOST).get(), 0.5);
+    assertEquals(
+        3.0,
+        ShuffleServerMetrics.counterRemoteStorageTotalWrite
+            .labels(Constants.SHUFFLE_SERVER_VERSION, STORAGE_HOST)
+            .get(),
+        0.5);
+    assertEquals(
+        1.0,
+        ShuffleServerMetrics.counterRemoteStorageFailedWrite
+            .labels(Constants.SHUFFLE_SERVER_VERSION, STORAGE_HOST)
+            .get(),
+        0.5);
   }
 
   @Test
   public void testGrpcMetrics() throws Exception {
-    String content = TestUtils.httpGetMetrics(SERVER_GRPC_URL);
+    String content = TestUtils.httpGet(SERVER_GRPC_URL);
     ObjectMapper mapper = new ObjectMapper();
     JsonNode actualObj = mapper.readTree(content);
     assertEquals(2, actualObj.size());
     assertEquals(69, actualObj.get("metrics").size());
   }
 
+  @Test
+  public void testNettyMetrics() throws Exception {
+    String content = TestUtils.httpGet(SERVER_NETTY_URL);
+    ObjectMapper mapper = new ObjectMapper();
+    JsonNode actualObj = mapper.readTree(content);
+    assertEquals(2, actualObj.size());
+    assertEquals(66, actualObj.get("metrics").size());
+  }
+
   @Test
   public void testServerMetricsConcurrently() throws Exception {
     ExecutorService executorService = Executors.newFixedThreadPool(3);
@@ -162,22 +251,24 @@ public class ShuffleServerMetricsTest {
     for (int i = 1; i < 5; ++i) {
       int cur = i * i;
       if (i % 2 == 0) {
-        calls.add(new Callable<Void>() {
-          @Override
-          public Void call() throws Exception {
-            ShuffleServerMetrics.gaugeInFlushBufferSize.inc(cur);
-            return null;
-          }
-        });
+        calls.add(
+            new Callable<Void>() {
+              @Override
+              public Void call() throws Exception {
+                ShuffleServerMetrics.gaugeInFlushBufferSize.inc(cur);
+                return null;
+              }
+            });
         expectedNum += cur;
       } else {
-        calls.add(new Callable<Void>() {
-          @Override
-          public Void call() throws Exception {
-            ShuffleServerMetrics.gaugeInFlushBufferSize.dec(cur);
-            return null;
-          }
-        });
+        calls.add(
+            new Callable<Void>() {
+              @Override
+              public Void call() throws Exception {
+                ShuffleServerMetrics.gaugeInFlushBufferSize.dec(cur);
+                return null;
+              }
+            });
         expectedNum -= cur;
       }
     }
@@ -187,16 +278,20 @@ public class ShuffleServerMetricsTest {
       f.get();
     }
 
-    String content = TestUtils.httpGetMetrics(SERVER_METRICS_URL);
+    String content = TestUtils.httpGet(SERVER_METRICS_URL);
     ObjectMapper mapper = new ObjectMapper();
     JsonNode actualObj = mapper.readTree(content);
 
     final long tmp = expectedNum;
-    actualObj.get("metrics").iterator().forEachRemaining(jsonNode -> {
-      String name = jsonNode.get("name").textValue();
-      if (name.equals("buffered_data_size")) {
-        assertEquals(tmp, jsonNode.get("value").asLong());
-      }
-    });
+    actualObj
+        .get("metrics")
+        .iterator()
+        .forEachRemaining(
+            jsonNode -> {
+              String name = jsonNode.get("name").textValue();
+              if (name.equals("buffered_data_size")) {
+                assertEquals(tmp, jsonNode.get("value").asLong());
+              }
+            });
   }
 }
