@@ -18,7 +18,6 @@
 package org.apache.uniffle.server;
 
 import java.io.File;
-import java.nio.file.Files;
 import java.util.Arrays;
 import java.util.HashSet;
 import java.util.List;
@@ -49,6 +48,7 @@ import org.apache.uniffle.common.RemoteStorageInfo;
 import org.apache.uniffle.common.ShuffleDataResult;
 import org.apache.uniffle.common.ShufflePartitionedBlock;
 import org.apache.uniffle.common.ShufflePartitionedData;
+import org.apache.uniffle.common.exception.RssException;
 import org.apache.uniffle.common.rpc.StatusCode;
 import org.apache.uniffle.common.util.ChecksumUtils;
 import org.apache.uniffle.common.util.Constants;
@@ -58,12 +58,14 @@ import org.apache.uniffle.server.buffer.ShuffleBuffer;
 import org.apache.uniffle.server.buffer.ShuffleBufferManager;
 import org.apache.uniffle.server.storage.LocalStorageManager;
 import org.apache.uniffle.server.storage.StorageManager;
-import org.apache.uniffle.storage.HdfsTestBase;
+import org.apache.uniffle.storage.HadoopTestBase;
 import org.apache.uniffle.storage.common.LocalStorage;
-import org.apache.uniffle.storage.handler.impl.HdfsClientReadHandler;
+import org.apache.uniffle.storage.handler.impl.HadoopClientReadHandler;
 import org.apache.uniffle.storage.util.ShuffleStorageUtils;
 import org.apache.uniffle.storage.util.StorageType;
 
+import static org.apache.uniffle.server.ShuffleServerConf.CLIENT_MAX_CONCURRENCY_LIMITATION_OF_ONE_PARTITION;
+import static org.apache.uniffle.server.ShuffleServerConf.SERVER_MAX_CONCURRENCY_OF_ONE_PARTITION;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotEquals;
@@ -72,16 +74,21 @@ import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.Assertions.fail;
 
-public class ShuffleTaskManagerTest extends HdfsTestBase {
+public class ShuffleTaskManagerTest extends HadoopTestBase {
 
   private static final AtomicInteger ATOMIC_INT = new AtomicInteger(0);
 
   private ShuffleServer shuffleServer;
 
+  @TempDir File tempDir1;
+  @TempDir File tempDir2;
+
   @BeforeEach
   public void beforeEach() {
     ShuffleServerMetrics.clear();
     ShuffleServerMetrics.register();
+    assertTrue(this.tempDir1.isDirectory());
+    assertTrue(this.tempDir2.isDirectory());
   }
 
   @AfterEach
@@ -96,7 +103,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
   public void hugePartitionMemoryUsageLimitTest() throws Exception {
     String confFile = ClassLoader.getSystemResource("server.conf").getFile();
     ShuffleServerConf conf = new ShuffleServerConf(confFile);
-    conf.set(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.MEMORY_LOCALFILE.name());
+    conf.setString(ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.MEMORY_LOCALFILE.name());
     conf.setString(ShuffleServerConf.HUGE_PARTITION_SIZE_THRESHOLD.key(), "1K");
     conf.setString("rss.server.buffer.capacity", "10K");
     conf.set(ShuffleServerConf.HUGE_PARTITION_MEMORY_USAGE_LIMITATION_RATIO, 0.1);
@@ -107,26 +114,29 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     String appId = "hugePartitionMemoryUsageLimitTest_appId";
     int shuffleId = 1;
 
+    // case1, return -4 means not registered.
+    long requiredId = shuffleTaskManager.requireBuffer(appId, 1, Arrays.asList(1), 500);
+    assertEquals(-4, requiredId);
+
     shuffleTaskManager.registerShuffle(
         appId,
         shuffleId,
         Lists.newArrayList(new PartitionRange(1, 1)),
         RemoteStorageInfo.EMPTY_REMOTE_STORAGE,
-        StringUtils.EMPTY
-    );
-
-    // case1
-    long requiredId = shuffleTaskManager.requireBuffer(appId, 1, Arrays.asList(1), 500);
-    assertNotEquals(-1, requiredId);
+        StringUtils.EMPTY);
 
     // case2
+    requiredId = shuffleTaskManager.requireBuffer(appId, 1, Arrays.asList(1), 500);
+    assertNotEquals(-1, requiredId);
+
+    // case3
     ShufflePartitionedData partitionedData0 = createPartitionedData(1, 1, 500);
     shuffleTaskManager.cacheShuffleData(appId, shuffleId, true, partitionedData0);
     shuffleTaskManager.updateCachedBlockIds(appId, shuffleId, 1, partitionedData0.getBlockList());
     requiredId = shuffleTaskManager.requireBuffer(appId, 1, Arrays.asList(1), 500);
     assertNotEquals(-1, requiredId);
 
-    // case3
+    // case4
     partitionedData0 = createPartitionedData(1, 1, 500);
     shuffleTaskManager.cacheShuffleData(appId, shuffleId, true, partitionedData0);
     shuffleTaskManager.updateCachedBlockIds(appId, shuffleId, 1, partitionedData0.getBlockList());
@@ -140,8 +150,8 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     assertEquals(1, ShuffleServerMetrics.gaugeHugePartitionNum.get());
     assertEquals(1, ShuffleServerMetrics.gaugeAppWithHugePartitionNum.get());
 
-    // case4
-    shuffleTaskManager.removeResources(appId);
+    // case5
+    shuffleTaskManager.removeResources(appId, false);
     assertEquals(0, ShuffleServerMetrics.gaugeHugePartitionNum.get());
     assertEquals(0, ShuffleServerMetrics.gaugeAppWithHugePartitionNum.get());
   }
@@ -150,7 +160,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
   public void partitionDataSizeSummaryTest() throws Exception {
     String confFile = ClassLoader.getSystemResource("server.conf").getFile();
     ShuffleServerConf conf = new ShuffleServerConf(confFile);
-    conf.set(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.MEMORY_LOCALFILE.name());
+    conf.setString(ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.MEMORY_LOCALFILE.name());
     shuffleServer = new ShuffleServer(conf);
     ShuffleTaskManager shuffleTaskManager = shuffleServer.getShuffleTaskManager();
 
@@ -162,31 +172,22 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
         shuffleId,
         Lists.newArrayList(new PartitionRange(0, 1)),
         RemoteStorageInfo.EMPTY_REMOTE_STORAGE,
-        StringUtils.EMPTY
-    );
+        StringUtils.EMPTY);
 
     // case1
     ShufflePartitionedData partitionedData0 = createPartitionedData(1, 1, 35);
     long size1 = partitionedData0.getTotalBlockSize();
     shuffleTaskManager.updateCachedBlockIds(appId, shuffleId, 1, partitionedData0.getBlockList());
 
-    assertEquals(
-        size1,
-        shuffleTaskManager.getShuffleTaskInfo(appId).getTotalDataSize()
-    );
+    assertEquals(size1, shuffleTaskManager.getShuffleTaskInfo(appId).getTotalDataSize());
 
     // case2
     partitionedData0 = createPartitionedData(1, 1, 35);
     long size2 = partitionedData0.getTotalBlockSize();
     shuffleTaskManager.updateCachedBlockIds(appId, shuffleId, 1, partitionedData0.getBlockList());
+    assertEquals(size1 + size2, shuffleTaskManager.getShuffleTaskInfo(appId).getTotalDataSize());
     assertEquals(
-        size1 + size2,
-        shuffleTaskManager.getShuffleTaskInfo(appId).getTotalDataSize()
-    );
-    assertEquals(
-        size1 + size2,
-        shuffleTaskManager.getShuffleTaskInfo(appId).getPartitionDataSize(1, 1)
-    );
+        size1 + size2, shuffleTaskManager.getShuffleTaskInfo(appId).getPartitionDataSize(1, 1));
   }
 
   @Test
@@ -196,7 +197,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     conf.set(ShuffleServerConf.SERVER_BUFFER_CAPACITY, 128L);
     conf.set(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_HIGHWATERMARK_PERCENTAGE, 50.0);
     conf.set(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_LOWWATERMARK_PERCENTAGE, 0.0);
-    conf.set(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.HDFS.name());
+    conf.setString(ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.HDFS.name());
     conf.set(ShuffleServerConf.RSS_TEST_MODE_ENABLE, true);
     conf.set(ShuffleServerConf.SERVER_COMMIT_TIMEOUT, 10000L);
     conf.set(ShuffleServerConf.HEALTH_CHECK_ENABLE, false);
@@ -211,15 +212,13 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
         shuffleId,
         Lists.newArrayList(new PartitionRange(0, 1)),
         RemoteStorageInfo.EMPTY_REMOTE_STORAGE,
-        StringUtils.EMPTY
-    );
+        StringUtils.EMPTY);
     shuffleTaskManager.registerShuffle(
         appId,
         shuffleId,
         Lists.newArrayList(new PartitionRange(2, 3)),
         RemoteStorageInfo.EMPTY_REMOTE_STORAGE,
-        StringUtils.EMPTY
-    );
+        StringUtils.EMPTY);
 
     Map<String, Map<Integer, RangeMap<Integer, ShuffleBuffer>>> bufferPool =
         shuffleServer.getShuffleBufferManager().getBufferPool();
@@ -228,7 +227,8 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     ShuffleBuffer buffer = bufferPool.get(appId).get(shuffleId).get(0);
     assertEquals(buffer, bufferPool.get(appId).get(shuffleId).get(1));
     assertNotNull(bufferPool.get(appId).get(shuffleId).get(2));
-    assertEquals(bufferPool.get(appId).get(shuffleId).get(2), bufferPool.get(appId).get(shuffleId).get(3));
+    assertEquals(
+        bufferPool.get(appId).get(shuffleId).get(2), bufferPool.get(appId).get(shuffleId).get(3));
 
     // register again
     shuffleTaskManager.registerShuffle(
@@ -236,8 +236,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
         shuffleId,
         Lists.newArrayList(new PartitionRange(0, 1)),
         RemoteStorageInfo.EMPTY_REMOTE_STORAGE,
-        StringUtils.EMPTY
-    );
+        StringUtils.EMPTY);
     assertEquals(buffer, bufferPool.get(appId).get(shuffleId).get(0));
   }
 
@@ -251,7 +250,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     conf.set(ShuffleServerConf.SERVER_BUFFER_CAPACITY, 128L);
     conf.set(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_HIGHWATERMARK_PERCENTAGE, 50.0);
     conf.set(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_LOWWATERMARK_PERCENTAGE, 0.0);
-    conf.set(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.HDFS.name());
+    conf.setString(ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.HDFS.name());
     conf.set(ShuffleServerConf.RSS_TEST_MODE_ENABLE, true);
     conf.set(ShuffleServerConf.SERVER_COMMIT_TIMEOUT, 10000L);
     conf.set(ShuffleServerConf.SERVER_PRE_ALLOCATION_EXPIRED, 3000L);
@@ -263,15 +262,13 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
         shuffleId,
         Lists.newArrayList(new PartitionRange(1, 1)),
         new RemoteStorageInfo(remoteStorage),
-        StringUtils.EMPTY
-    );
+        StringUtils.EMPTY);
     shuffleTaskManager.registerShuffle(
         appId,
         shuffleId,
         Lists.newArrayList(new PartitionRange(2, 2)),
         new RemoteStorageInfo(remoteStorage),
-        StringUtils.EMPTY
-    );
+        StringUtils.EMPTY);
     final List<ShufflePartitionedBlock> expectedBlocks1 = Lists.newArrayList();
     final List<ShufflePartitionedBlock> expectedBlocks2 = Lists.newArrayList();
     final Map<Long, PreAllocatedBufferInfo> bufferIds = shuffleTaskManager.getRequireBufferIds();
@@ -303,7 +300,8 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     shuffleTaskManager.removeAndReleasePreAllocatedBuffer(bufferId);
 
     ShuffleFlushManager shuffleFlushManager = shuffleServer.getShuffleFlushManager();
-    assertEquals(1, shuffleFlushManager.getCommittedBlockIds(appId, shuffleId).getLongCardinality());
+    assertEquals(
+        1, shuffleFlushManager.getCommittedBlockIds(appId, shuffleId).getLongCardinality());
 
     // flush for partition 1-1
     ShufflePartitionedData partitionedData1 = createPartitionedData(1, 2, 35);
@@ -383,6 +381,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
 
   /**
    * Clean up the shuffle data of stage level for one app
+   *
    * @throws Exception
    */
   @Test
@@ -413,8 +412,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
           i,
           Lists.newArrayList(new PartitionRange(0, 1)),
           new RemoteStorageInfo(storageBasePath, Maps.newHashMap()),
-          StringUtils.EMPTY
-      );
+          StringUtils.EMPTY);
     }
     shuffleTaskManager.refreshAppId(appId);
 
@@ -434,7 +432,8 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     assertEquals(1, shuffleTaskManager.getAppIds().size());
 
     ShuffleBufferManager shuffleBufferManager = shuffleServer.getShuffleBufferManager();
-    RangeMap<Integer, ShuffleBuffer> rangeMap = shuffleBufferManager.getBufferPool().get(appId).get(0);
+    RangeMap<Integer, ShuffleBuffer> rangeMap =
+        shuffleBufferManager.getBufferPool().get(appId).get(0);
     assertFalse(rangeMap.asMapOfRanges().isEmpty());
     shuffleTaskManager.commitShuffle(appId, 0);
 
@@ -449,7 +448,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     assertTrue(fs.exists(new Path(appBasePath)));
     assertNull(shuffleBufferManager.getBufferPool().get(appId).get(0));
     assertNotNull(shuffleBufferManager.getBufferPool().get(appId).get(1));
-    shuffleTaskManager.removeResources(appId);
+    shuffleTaskManager.removeResources(appId, false);
   }
 
   @Test
@@ -467,12 +466,11 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     conf.set(ShuffleServerConf.SERVER_APP_EXPIRED_WITHOUT_HEARTBEAT, 100000L);
     conf.set(ShuffleServerConf.HEALTH_CHECK_ENABLE, false);
 
-    conf.set(ShuffleServerConf.RSS_STORAGE_TYPE, "LOCALFILE");
+    conf.setString(ShuffleServerConf.RSS_STORAGE_TYPE.key(), "LOCALFILE");
     conf.set(ShuffleServerConf.RSS_TEST_MODE_ENABLE, true);
-    java.nio.file.Path path1 = Files.createTempDirectory("removeShuffleDataWithLocalfileTest");
-    java.nio.file.Path path2 = Files.createTempDirectory("removeShuffleDataWithLocalfileTest");
-    conf.setString(ShuffleServerConf.RSS_STORAGE_BASE_PATH.key(),
-        path1.toAbsolutePath().toString() + "," + path2.toAbsolutePath().toString());
+    conf.setString(
+        ShuffleServerConf.RSS_STORAGE_BASE_PATH.key(),
+        tempDir1.getAbsolutePath() + "," + tempDir2.getAbsolutePath());
 
     shuffleServer = new ShuffleServer(conf);
     ShuffleTaskManager shuffleTaskManager = shuffleServer.getShuffleTaskManager();
@@ -486,8 +484,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
           i,
           Lists.newArrayList(new PartitionRange(0, 1)),
           RemoteStorageInfo.EMPTY_REMOTE_STORAGE,
-          StringUtils.EMPTY
-      );
+          StringUtils.EMPTY);
 
       ShufflePartitionedData partitionedData0 = createPartitionedData(1, 1, 35);
       shuffleTaskManager.requireBuffer(35);
@@ -524,7 +521,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     conf.set(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_HIGHWATERMARK_PERCENTAGE, 50.0);
     conf.set(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_LOWWATERMARK_PERCENTAGE, 0.0);
     conf.set(ShuffleServerConf.RSS_STORAGE_BASE_PATH, Arrays.asList(storageBasePath));
-    conf.set(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.HDFS.name());
+    conf.setString(ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.HDFS.name());
     conf.set(ShuffleServerConf.RSS_TEST_MODE_ENABLE, true);
     conf.set(ShuffleServerConf.SERVER_COMMIT_TIMEOUT, 10000L);
     conf.set(ShuffleServerConf.SERVER_APP_EXPIRED_WITHOUT_HEARTBEAT, 2000L);
@@ -537,15 +534,13 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
         shuffleId,
         Lists.newArrayList(new PartitionRange(0, 1)),
         RemoteStorageInfo.EMPTY_REMOTE_STORAGE,
-        StringUtils.EMPTY
-    );
+        StringUtils.EMPTY);
     shuffleTaskManager.registerShuffle(
         "clearTest2",
         shuffleId,
         Lists.newArrayList(new PartitionRange(0, 1)),
         RemoteStorageInfo.EMPTY_REMOTE_STORAGE,
-        StringUtils.EMPTY
-    );
+        StringUtils.EMPTY);
     shuffleTaskManager.refreshAppId("clearTest1");
     shuffleTaskManager.refreshAppId("clearTest2");
     assertEquals(2, shuffleTaskManager.getAppIds().size());
@@ -556,14 +551,16 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     while (retry < 10) {
       Thread.sleep(1000);
       shuffleTaskManager.cacheShuffleData("clearTest1", shuffleId, false, partitionedData0);
-      shuffleTaskManager.updateCachedBlockIds("clearTest1", shuffleId, partitionedData0.getBlockList());
+      shuffleTaskManager.updateCachedBlockIds(
+          "clearTest1", shuffleId, partitionedData0.getBlockList());
       shuffleTaskManager.refreshAppId("clearTest1");
       shuffleTaskManager.checkResourceStatus();
       retry++;
     }
     // application "clearTest2" was removed according to rss.server.app.expired.withoutHeartbeat
     assertEquals(Sets.newHashSet("clearTest1"), shuffleTaskManager.getAppIds());
-    assertEquals(1, shuffleTaskManager.getCachedBlockIds("clearTest1", shuffleId).getLongCardinality());
+    assertEquals(
+        1, shuffleTaskManager.getCachedBlockIds("clearTest1", shuffleId).getLongCardinality());
 
     // register again
     shuffleTaskManager.registerShuffle(
@@ -571,8 +568,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
         shuffleId,
         Lists.newArrayList(new PartitionRange(0, 1)),
         RemoteStorageInfo.EMPTY_REMOTE_STORAGE,
-        StringUtils.EMPTY
-    );
+        StringUtils.EMPTY);
     shuffleTaskManager.refreshAppId("clearTest2");
     shuffleTaskManager.checkResourceStatus();
     assertEquals(Sets.newHashSet("clearTest1", "clearTest2"), shuffleTaskManager.getAppIds());
@@ -584,7 +580,6 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     assertTrue(shuffleTaskManager.getCachedBlockIds("clearTest1", shuffleId).isEmpty());
   }
 
-
   @Test
   public void clearMultiTimesTest() throws Exception {
     ShuffleServerConf conf = new ShuffleServerConf();
@@ -598,7 +593,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     conf.set(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_HIGHWATERMARK_PERCENTAGE, 50.0);
     conf.set(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_LOWWATERMARK_PERCENTAGE, 0.0);
     conf.set(ShuffleServerConf.RSS_STORAGE_BASE_PATH, Arrays.asList(storageBasePath));
-    conf.set(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.HDFS.name());
+    conf.setString(ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.HDFS.name());
     conf.set(ShuffleServerConf.RSS_TEST_MODE_ENABLE, true);
     conf.set(ShuffleServerConf.SERVER_COMMIT_TIMEOUT, 10000L);
     conf.set(ShuffleServerConf.SERVER_APP_EXPIRED_WITHOUT_HEARTBEAT, 2000L);
@@ -612,23 +607,24 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
         shuffleId,
         Lists.newArrayList(new PartitionRange(0, 1)),
         RemoteStorageInfo.EMPTY_REMOTE_STORAGE,
-        StringUtils.EMPTY
-    );
+        StringUtils.EMPTY);
     shuffleTaskManager.refreshAppId(appId);
     assertEquals(1, shuffleTaskManager.getAppIds().size());
-    
+
     shuffleTaskManager.checkResourceStatus();
     assertEquals(Sets.newHashSet(appId), shuffleTaskManager.getAppIds());
 
     CountDownLatch countDownLatch = new CountDownLatch(3);
     for (int i = 0; i < 3; i++) {
-      new Thread(() -> {
-        try {
-          shuffleTaskManager.removeResources(appId);
-        } finally {
-          countDownLatch.countDown();
-        }
-      }).start();
+      new Thread(
+              () -> {
+                try {
+                  shuffleTaskManager.removeResources(appId, false);
+                } finally {
+                  countDownLatch.countDown();
+                }
+              })
+          .start();
     }
     countDownLatch.await();
     assertEquals(Sets.newHashSet(), shuffleTaskManager.getAppIds());
@@ -648,7 +644,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     conf.set(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_HIGHWATERMARK_PERCENTAGE, 50.0);
     conf.set(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_LOWWATERMARK_PERCENTAGE, 0.0);
     conf.set(ShuffleServerConf.RSS_STORAGE_BASE_PATH, Arrays.asList(storageBasePath));
-    conf.set(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.HDFS.name());
+    conf.setString(ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.HDFS.name());
     conf.set(ShuffleServerConf.RSS_TEST_MODE_ENABLE, true);
     conf.set(ShuffleServerConf.SERVER_COMMIT_TIMEOUT, 10000L);
     conf.set(ShuffleServerConf.SERVER_APP_EXPIRED_WITHOUT_HEARTBEAT, 2000L);
@@ -662,8 +658,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
         shuffleId,
         Lists.newArrayList(new PartitionRange(0, 1)),
         RemoteStorageInfo.EMPTY_REMOTE_STORAGE,
-        StringUtils.EMPTY
-    );
+        StringUtils.EMPTY);
     shuffleTaskManager.refreshAppId(appId);
     assertEquals(1, shuffleTaskManager.getAppIds().size());
 
@@ -673,13 +668,15 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     CountDownLatch countDownLatch = new CountDownLatch(3);
     List<Integer> shuffleIds = Lists.newArrayList(shuffleId);
     for (int i = 0; i < 3; i++) {
-      new Thread(() -> {
-        try {
-          shuffleTaskManager.removeResourcesByShuffleIds(appId, shuffleIds);
-        } finally {
-          countDownLatch.countDown();
-        }
-      }).start();
+      new Thread(
+              () -> {
+                try {
+                  shuffleTaskManager.removeResourcesByShuffleIds(appId, shuffleIds);
+                } finally {
+                  countDownLatch.countDown();
+                }
+              })
+          .start();
     }
     countDownLatch.await();
     assertEquals(0, (int) ShuffleServerMetrics.gaugeTotalPartitionNum.get());
@@ -688,8 +685,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
   @Test
   public void getBlockIdsByPartitionIdTest() {
     ShuffleServerConf conf = new ShuffleServerConf();
-    ShuffleTaskManager shuffleTaskManager = new ShuffleTaskManager(
-        conf, null, null, null);
+    ShuffleTaskManager shuffleTaskManager = new ShuffleTaskManager(conf, null, null, null);
 
     Roaring64NavigableMap expectedBlockIds = Roaring64NavigableMap.bitmapOf();
     int expectedPartitionId = 5;
@@ -705,28 +701,33 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
         }
       }
     }
-    Roaring64NavigableMap resultBlockIds = shuffleTaskManager.getBlockIdsByPartitionId(
-        Sets.newHashSet(expectedPartitionId), bitmapBlockIds, Roaring64NavigableMap.bitmapOf());
+    Roaring64NavigableMap resultBlockIds =
+        shuffleTaskManager.getBlockIdsByPartitionId(
+            Sets.newHashSet(expectedPartitionId), bitmapBlockIds, Roaring64NavigableMap.bitmapOf());
     assertEquals(expectedBlockIds, resultBlockIds);
 
     bitmapBlockIds.addLong(getBlockId(0, 0, 0));
-    resultBlockIds = shuffleTaskManager.getBlockIdsByPartitionId(Sets.newHashSet(0), bitmapBlockIds,
-        Roaring64NavigableMap.bitmapOf());
+    resultBlockIds =
+        shuffleTaskManager.getBlockIdsByPartitionId(
+            Sets.newHashSet(0), bitmapBlockIds, Roaring64NavigableMap.bitmapOf());
     assertEquals(Roaring64NavigableMap.bitmapOf(0L), resultBlockIds);
 
-    long expectedBlockId = getBlockId(
-        Constants.MAX_PARTITION_ID, Constants.MAX_TASK_ATTEMPT_ID, Constants.MAX_SEQUENCE_NO);
+    long expectedBlockId =
+        getBlockId(
+            Constants.MAX_PARTITION_ID, Constants.MAX_TASK_ATTEMPT_ID, Constants.MAX_SEQUENCE_NO);
     bitmapBlockIds.addLong(expectedBlockId);
-    resultBlockIds = shuffleTaskManager.getBlockIdsByPartitionId(Sets.newHashSet(Math.toIntExact(
-        Constants.MAX_PARTITION_ID)), bitmapBlockIds, Roaring64NavigableMap.bitmapOf());
+    resultBlockIds =
+        shuffleTaskManager.getBlockIdsByPartitionId(
+            Sets.newHashSet(Math.toIntExact(Constants.MAX_PARTITION_ID)),
+            bitmapBlockIds,
+            Roaring64NavigableMap.bitmapOf());
     assertEquals(Roaring64NavigableMap.bitmapOf(expectedBlockId), resultBlockIds);
   }
 
   @Test
   public void getBlockIdsByMultiPartitionTest() {
     ShuffleServerConf conf = new ShuffleServerConf();
-    ShuffleTaskManager shuffleTaskManager = new ShuffleTaskManager(
-        conf, null, null, null);
+    ShuffleTaskManager shuffleTaskManager = new ShuffleTaskManager(conf, null, null, null);
 
     Roaring64NavigableMap expectedBlockIds = Roaring64NavigableMap.bitmapOf();
     int startPartition = 3;
@@ -753,11 +754,13 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     }
 
     Roaring64NavigableMap resultBlockIds =
-        shuffleTaskManager.getBlockIdsByPartitionId(requestPartitions, bitmapBlockIds,
-            Roaring64NavigableMap.bitmapOf());
+        shuffleTaskManager.getBlockIdsByPartitionId(
+            requestPartitions, bitmapBlockIds, Roaring64NavigableMap.bitmapOf());
     assertEquals(expectedBlockIds, resultBlockIds);
-    assertEquals(bitmapBlockIds, shuffleTaskManager.getBlockIdsByPartitionId(allPartitions, bitmapBlockIds,
-        Roaring64NavigableMap.bitmapOf()));
+    assertEquals(
+        bitmapBlockIds,
+        shuffleTaskManager.getBlockIdsByPartitionId(
+            allPartitions, bitmapBlockIds, Roaring64NavigableMap.bitmapOf()));
   }
 
   @Test
@@ -778,7 +781,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     conf.set(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_HIGHWATERMARK_PERCENTAGE, 50.0);
     conf.set(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_LOWWATERMARK_PERCENTAGE, 0.0);
     conf.set(ShuffleServerConf.RSS_STORAGE_BASE_PATH, Arrays.asList(storageBasePath));
-    conf.set(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.HDFS.name());
+    conf.setString(ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.HDFS.name());
     conf.set(ShuffleServerConf.RSS_TEST_MODE_ENABLE, true);
     conf.set(ShuffleServerConf.SERVER_COMMIT_TIMEOUT, 10000L);
     conf.set(ShuffleServerConf.SERVER_APP_EXPIRED_WITHOUT_HEARTBEAT, 2000L);
@@ -788,13 +791,13 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     ShuffleBufferManager shuffleBufferManager = shuffleServer.getShuffleBufferManager();
     ShuffleFlushManager shuffleFlushManager = shuffleServer.getShuffleFlushManager();
     StorageManager storageManager = shuffleServer.getStorageManager();
-    ShuffleTaskManager shuffleTaskManager = new ShuffleTaskManager(conf, shuffleFlushManager,
-        shuffleBufferManager, storageManager);
+    ShuffleTaskManager shuffleTaskManager =
+        new ShuffleTaskManager(conf, shuffleFlushManager, shuffleBufferManager, storageManager);
 
     int startPartition = 6;
     int endPartition = 9;
     Roaring64NavigableMap expectedBlockIds = Roaring64NavigableMap.bitmapOf();
-    Map<Integer, long[]>  blockIdsToReport = Maps.newHashMap();
+    Map<Integer, long[]> blockIdsToReport = Maps.newHashMap();
 
     for (int partitionId = 0; partitionId < partitionNum; partitionId++) {
       shuffleTaskManager.registerShuffle(
@@ -802,8 +805,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
           shuffleId,
           Lists.newArrayList(new PartitionRange(partitionId, partitionId)),
           new RemoteStorageInfo(storageBasePath),
-          StringUtils.EMPTY
-      );
+          StringUtils.EMPTY);
       long[] blockIds = new long[taskNum * blocksPerTask];
       for (int taskId = 0; taskId < taskNum; taskId++) {
         for (int i = 0; i < blocksPerTask; i++) {
@@ -816,7 +818,8 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
         expectedBlockIds.add(blockIds);
       }
     }
-    assertEquals((endPartition - startPartition + 1) * taskNum *  blocksPerTask,
+    assertEquals(
+        (endPartition - startPartition + 1) * taskNum * blocksPerTask,
         expectedBlockIds.getLongCardinality());
 
     shuffleTaskManager.addFinishedBlockIds(appId, shuffleId, blockIdsToReport, bitNum);
@@ -830,7 +833,6 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     assertEquals(expectedBlockIds, resBlockIds);
   }
 
-
   @Test
   public void testAddFinishedBlockIdsWithoutRegister() throws Exception {
     ShuffleServerConf conf = new ShuffleServerConf();
@@ -846,7 +848,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     conf.set(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_HIGHWATERMARK_PERCENTAGE, 50.0);
     conf.set(ShuffleServerConf.SERVER_MEMORY_SHUFFLE_LOWWATERMARK_PERCENTAGE, 0.0);
     conf.set(ShuffleServerConf.RSS_STORAGE_BASE_PATH, Arrays.asList(storageBasePath));
-    conf.set(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.HDFS.name());
+    conf.setString(ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.HDFS.name());
     conf.set(ShuffleServerConf.RSS_TEST_MODE_ENABLE, true);
     conf.set(ShuffleServerConf.SERVER_COMMIT_TIMEOUT, 10000L);
     conf.set(ShuffleServerConf.SERVER_APP_EXPIRED_WITHOUT_HEARTBEAT, 2000L);
@@ -856,9 +858,9 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     ShuffleBufferManager shuffleBufferManager = shuffleServer.getShuffleBufferManager();
     ShuffleFlushManager shuffleFlushManager = shuffleServer.getShuffleFlushManager();
     StorageManager storageManager = shuffleServer.getStorageManager();
-    ShuffleTaskManager shuffleTaskManager = new ShuffleTaskManager(conf, shuffleFlushManager,
-        shuffleBufferManager, storageManager);
-    Map<Integer, long[]>  blockIdsToReport = Maps.newHashMap();
+    ShuffleTaskManager shuffleTaskManager =
+        new ShuffleTaskManager(conf, shuffleFlushManager, shuffleBufferManager, storageManager);
+    Map<Integer, long[]> blockIdsToReport = Maps.newHashMap();
     try {
       shuffleTaskManager.addFinishedBlockIds(appId, shuffleId, blockIdsToReport, bitNum);
       fail("Exception should be thrown");
@@ -884,7 +886,7 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     conf.set(ShuffleServerConf.SERVER_APP_EXPIRED_WITHOUT_HEARTBEAT, 2000L);
     conf.set(ShuffleServerConf.HEALTH_CHECK_ENABLE, false);
     conf.set(ShuffleServerConf.RSS_STORAGE_BASE_PATH, Arrays.asList(tempDir.getAbsolutePath()));
-    conf.setString(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.LOCALFILE.name());
+    conf.setString(ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.LOCALFILE.name());
     conf.set(ShuffleServerConf.RSS_TEST_MODE_ENABLE, true);
     conf.setLong(ShuffleServerConf.DISK_CAPACITY, 1024L * 1024L * 1024L);
     // make sure not to check leak shuffle data automatically
@@ -893,12 +895,11 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     shuffleServer = new ShuffleServer(conf);
     ShuffleTaskManager shuffleTaskManager = shuffleServer.getShuffleTaskManager();
     shuffleTaskManager.registerShuffle(
-            appId,
-            shuffleId,
-            Lists.newArrayList(new PartitionRange(0, 1)),
-            RemoteStorageInfo.EMPTY_REMOTE_STORAGE,
-            StringUtils.EMPTY
-    );
+        appId,
+        shuffleId,
+        Lists.newArrayList(new PartitionRange(0, 1)),
+        RemoteStorageInfo.EMPTY_REMOTE_STORAGE,
+        StringUtils.EMPTY);
 
     shuffleTaskManager.refreshAppId(appId);
     assertEquals(1, shuffleTaskManager.getAppIds().size());
@@ -926,16 +927,18 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     assertTrue(appIdsOnDisk.contains(appId));
 
     // make sure heartbeat timeout and resources are removed
-    Awaitility.await().timeout(10, TimeUnit.SECONDS).until(
-        () -> shuffleTaskManager.getAppIds().size() == 0);
+    Awaitility.await()
+        .timeout(10, TimeUnit.SECONDS)
+        .until(() -> shuffleTaskManager.getAppIds().size() == 0);
 
     // Create the hidden dir to simulate LocalStorageChecker's check
     String storageDir = tempDir.getAbsolutePath();
     File hiddenFile = new File(storageDir + "/" + LocalStorageChecker.CHECKER_DIR_NAME);
     hiddenFile.mkdir();
 
-    appIdsOnDisk = getAppIdsOnDisk(localStorageManager);
-    assertFalse(appIdsOnDisk.contains(appId));
+    Awaitility.await()
+        .timeout(10, TimeUnit.SECONDS)
+        .until(() -> !getAppIdsOnDisk(localStorageManager).contains(appId));
     assertFalse(appIdsOnDisk.contains(LocalStorageChecker.CHECKER_DIR_NAME));
 
     // mock leak shuffle data
@@ -964,15 +967,18 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
   // copy from ClientUtils
   private Long getBlockId(long partitionId, long taskAttemptId, long atomicInt) {
     return (atomicInt << (Constants.PARTITION_ID_MAX_LENGTH + Constants.TASK_ATTEMPT_ID_MAX_LENGTH))
-        + (partitionId << Constants.TASK_ATTEMPT_ID_MAX_LENGTH) + taskAttemptId;
+        + (partitionId << Constants.TASK_ATTEMPT_ID_MAX_LENGTH)
+        + taskAttemptId;
   }
 
-  private void waitForFlush(ShuffleFlushManager shuffleFlushManager,
-      String appId, int shuffleId, int expectedBlockNum) throws Exception {
+  private void waitForFlush(
+      ShuffleFlushManager shuffleFlushManager, String appId, int shuffleId, int expectedBlockNum)
+      throws Exception {
     int retry = 0;
     while (true) {
       // remove flushed eventId to test timeout in commit
-      if (shuffleFlushManager.getCommittedBlockIds(appId, shuffleId).getIntCardinality() == expectedBlockNum) {
+      if (shuffleFlushManager.getCommittedBlockIds(appId, shuffleId).getIntCardinality()
+          == expectedBlockNum) {
         break;
       }
       Thread.sleep(1000);
@@ -983,7 +989,8 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     }
   }
 
-  private ShufflePartitionedData createPartitionedData(int partitionId, int blockNum, int dataLength) {
+  private ShufflePartitionedData createPartitionedData(
+      int partitionId, int blockNum, int dataLength) {
     ShufflePartitionedBlock[] blocks = createBlock(blockNum, dataLength);
     return new ShufflePartitionedData(partitionId, blocks);
   }
@@ -993,13 +1000,18 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     for (int i = 0; i < num; i++) {
       byte[] buf = new byte[length];
       new Random().nextBytes(buf);
-      blocks[i] = new ShufflePartitionedBlock(
-          length, length, ChecksumUtils.getCrc32(buf), ATOMIC_INT.incrementAndGet(), 0, buf);
+      blocks[i] =
+          new ShufflePartitionedBlock(
+              length, length, ChecksumUtils.getCrc32(buf), ATOMIC_INT.incrementAndGet(), 0, buf);
     }
     return blocks;
   }
 
-  private void validate(String appId, int shuffleId, int partitionId, List<ShufflePartitionedBlock> blocks,
+  private void validate(
+      String appId,
+      int shuffleId,
+      int partitionId,
+      List<ShufflePartitionedBlock> blocks,
       String basePath) {
     Roaring64NavigableMap expectBlockIds = Roaring64NavigableMap.bitmapOf();
     Roaring64NavigableMap processBlockIds = Roaring64NavigableMap.bitmapOf();
@@ -1008,8 +1020,19 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
       expectBlockIds.addLong(spb.getBlockId());
       remainIds.add(spb.getBlockId());
     }
-    HdfsClientReadHandler handler = new HdfsClientReadHandler(appId, shuffleId, partitionId,
-        100, 1, 10, 1000, expectBlockIds, processBlockIds, basePath, new Configuration());
+    HadoopClientReadHandler handler =
+        new HadoopClientReadHandler(
+            appId,
+            shuffleId,
+            partitionId,
+            100,
+            1,
+            10,
+            1000,
+            expectBlockIds,
+            processBlockIds,
+            basePath,
+            new Configuration());
 
     ShuffleDataResult sdr = handler.readShuffleData();
     List<BufferSegment> bufferSegments = sdr.getBufferSegments();
@@ -1026,4 +1049,78 @@ public class ShuffleTaskManagerTest extends HdfsTestBase {
     }
     assertEquals(blocks.size(), matchNum);
   }
+
+  @Test
+  public void testGetMaxConcurrencyWriting() {
+    ShuffleServerConf conf = new ShuffleServerConf();
+    conf.set(SERVER_MAX_CONCURRENCY_OF_ONE_PARTITION, 10);
+    conf.set(CLIENT_MAX_CONCURRENCY_LIMITATION_OF_ONE_PARTITION, 30);
+
+    // case1: client max concurrency is <= 0
+    assertEquals(10, ShuffleTaskManager.getMaxConcurrencyWriting(-1, conf));
+
+    // case2: client max concurrency is 24
+    assertEquals(24, ShuffleTaskManager.getMaxConcurrencyWriting(24, conf));
+
+    // case3: client max concurrency exceed 30
+    assertEquals(30, ShuffleTaskManager.getMaxConcurrencyWriting(40, conf));
+  }
+
+  @Test
+  public void testRegisterShuffleAfterAppIsExpired() throws Exception {
+    String confFile = ClassLoader.getSystemResource("server.conf").getFile();
+    ShuffleServerConf conf = new ShuffleServerConf(confFile);
+    final String storageBasePath = HDFS_URI + "rss/testRegisterShuffleAfterAppIsExpired";
+    conf.set(ShuffleServerConf.RSS_TEST_MODE_ENABLE, true);
+    conf.set(ShuffleServerConf.RPC_SERVER_PORT, 1234);
+    conf.set(ShuffleServerConf.RSS_COORDINATOR_QUORUM, "localhost:9527");
+
+    shuffleServer = new ShuffleServer(conf);
+    ShuffleTaskManager shuffleTaskManager = shuffleServer.getShuffleTaskManager();
+
+    String appId = "appId1";
+    shuffleTaskManager.registerShuffle(
+        appId,
+        1,
+        Lists.newArrayList(new PartitionRange(0, 1)),
+        new RemoteStorageInfo(storageBasePath, Maps.newHashMap()),
+        StringUtils.EMPTY);
+    shuffleTaskManager.refreshAppId(appId);
+    assertEquals(1, shuffleTaskManager.getAppIds().size());
+
+    ShufflePartitionedData partitionedData0 = createPartitionedData(1, 1, 35);
+    shuffleTaskManager.requireBuffer(35);
+    shuffleTaskManager.cacheShuffleData(appId, 0, false, partitionedData0);
+    shuffleTaskManager.updateCachedBlockIds(appId, 0, partitionedData0.getBlockList());
+    shuffleTaskManager.refreshAppId(appId);
+    shuffleTaskManager.checkResourceStatus();
+    assertEquals(1, shuffleTaskManager.getAppIds().size());
+
+    // App is expired due to no heartbeat, so it was added to expired queue and will be removed
+    // resource soon.
+    Thread thread =
+        new Thread(
+            () -> {
+              try {
+                Thread.sleep(1000);
+                shuffleTaskManager.removeResources(appId, true);
+              } catch (InterruptedException e) {
+                throw new RssException(e);
+              }
+            });
+    thread.start();
+
+    // At this moment, this app re-registers shuffle.
+    shuffleTaskManager.registerShuffle(
+        appId,
+        2,
+        Lists.newArrayList(new PartitionRange(0, 1)),
+        new RemoteStorageInfo(storageBasePath, Maps.newHashMap()),
+        StringUtils.EMPTY);
+    Thread.sleep(2000);
+
+    // The NO_REGISTER status code should not appear.
+    assertTrue(shuffleTaskManager.requireBuffer(appId, 2, Arrays.asList(1), 35) != -4);
+    shuffleTaskManager.removeResources(appId, false);
+  }
 }
