@@ -18,10 +18,12 @@
 package org.apache.uniffle.server;
 
 import java.io.File;
+import java.io.IOException;
 import java.util.Arrays;
 import java.util.List;
 
 import com.google.common.collect.Lists;
+import org.apache.commons.io.FileUtils;
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
@@ -30,6 +32,7 @@ import org.junit.jupiter.api.io.TempDir;
 import org.apache.uniffle.storage.common.LocalStorage;
 import org.apache.uniffle.storage.util.StorageType;
 
+import static org.apache.uniffle.common.util.Constants.DEVICE_NO_SPACE_ERROR_MESSAGE;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -52,7 +55,7 @@ public class StorageCheckerTest {
   public void checkTest(@TempDir File baseDir) throws Exception {
     ShuffleServerConf conf = new ShuffleServerConf();
     conf.setBoolean(ShuffleServerConf.HEALTH_CHECK_ENABLE, true);
-    conf.setString(ShuffleServerConf.RSS_STORAGE_TYPE, StorageType.LOCALFILE.name());
+    conf.setString(ShuffleServerConf.RSS_STORAGE_TYPE.key(), StorageType.LOCALFILE.name());
     String st1 = new File(baseDir, "st1").getPath();
     String st2 = new File(baseDir, "st2").getPath();
     String st3 = new File(baseDir, "st3").getPath();
@@ -66,7 +69,7 @@ public class StorageCheckerTest {
 
     assertTrue(checker.checkIsHealthy());
     assertEquals(3000, ShuffleServerMetrics.gaugeLocalStorageTotalSpace.get());
-    assertEquals(600, ShuffleServerMetrics.gaugeLocalStorageUsedSpace.get());
+    assertEquals(600, ShuffleServerMetrics.gaugeLocalStorageWholeDiskUsedSpace.get());
     assertEquals(0.2, ShuffleServerMetrics.gaugeLocalStorageUsedSpaceRatio.get());
     assertEquals(3, ShuffleServerMetrics.gaugeLocalStorageTotalDirsNum.get());
     assertEquals(0, ShuffleServerMetrics.gaugeLocalStorageCorruptedDirsNum.get());
@@ -74,14 +77,14 @@ public class StorageCheckerTest {
     callTimes++;
     assertTrue(checker.checkIsHealthy());
     assertEquals(3000, ShuffleServerMetrics.gaugeLocalStorageTotalSpace.get());
-    assertEquals(1400, ShuffleServerMetrics.gaugeLocalStorageUsedSpace.get());
+    assertEquals(1400, ShuffleServerMetrics.gaugeLocalStorageWholeDiskUsedSpace.get());
     assertEquals(3, ShuffleServerMetrics.gaugeLocalStorageTotalDirsNum.get());
     assertEquals(0, ShuffleServerMetrics.gaugeLocalStorageCorruptedDirsNum.get());
 
     callTimes++;
     assertFalse(checker.checkIsHealthy());
     assertEquals(3000, ShuffleServerMetrics.gaugeLocalStorageTotalSpace.get());
-    assertEquals(2100, ShuffleServerMetrics.gaugeLocalStorageUsedSpace.get());
+    assertEquals(2100, ShuffleServerMetrics.gaugeLocalStorageWholeDiskUsedSpace.get());
     assertEquals(3, ShuffleServerMetrics.gaugeLocalStorageTotalDirsNum.get());
     assertEquals(0, ShuffleServerMetrics.gaugeLocalStorageCorruptedDirsNum.get());
 
@@ -91,7 +94,7 @@ public class StorageCheckerTest {
     checker = new MockStorageChecker(conf, storages);
     assertFalse(checker.checkIsHealthy());
     assertEquals(3000, ShuffleServerMetrics.gaugeLocalStorageTotalSpace.get());
-    assertEquals(1600, ShuffleServerMetrics.gaugeLocalStorageUsedSpace.get());
+    assertEquals(1600, ShuffleServerMetrics.gaugeLocalStorageWholeDiskUsedSpace.get());
     assertEquals(3, ShuffleServerMetrics.gaugeLocalStorageTotalDirsNum.get());
     assertEquals(0, ShuffleServerMetrics.gaugeLocalStorageCorruptedDirsNum.get());
 
@@ -99,9 +102,22 @@ public class StorageCheckerTest {
     checker.checkIsHealthy();
     assertTrue(checker.checkIsHealthy());
     assertEquals(3000, ShuffleServerMetrics.gaugeLocalStorageTotalSpace.get());
-    assertEquals(250, ShuffleServerMetrics.gaugeLocalStorageUsedSpace.get());
+    assertEquals(250, ShuffleServerMetrics.gaugeLocalStorageWholeDiskUsedSpace.get());
     assertEquals(3, ShuffleServerMetrics.gaugeLocalStorageTotalDirsNum.get());
     assertEquals(0, ShuffleServerMetrics.gaugeLocalStorageCorruptedDirsNum.get());
+
+    storages.clear();
+    storages.add(LocalStorage.newBuilder().basePath(st1).build());
+    checker = new MockNoSpaceStorageChecker(conf, storages);
+    assertTrue(checker.checkIsHealthy());
+    storages.clear();
+    storages.add(LocalStorage.newBuilder().basePath(st2).build());
+    checker = new MockNoSpaceStorageChecker(conf, storages);
+    assertTrue(checker.checkIsHealthy());
+    storages.clear();
+    storages.add(LocalStorage.newBuilder().basePath(st3).build());
+    checker = new MockNoSpaceStorageChecker(conf, storages);
+    assertFalse(checker.checkIsHealthy());
   }
 
   private class MockStorageChecker extends LocalStorageChecker {
@@ -117,7 +133,7 @@ public class StorageCheckerTest {
     // we mock this method, and will return different values according
     // to call times.
     @Override
-    long getUsedSpace(File file) {
+    long getWholeDiskUsedSpace(File file) {
       long result = 0;
       switch (file.getName()) {
         case "st1":
@@ -173,5 +189,72 @@ public class StorageCheckerTest {
       }
       return result;
     }
+
+    @Override
+    public boolean checkIsHealthy() {
+      return super.checkIsHealthy();
+    }
+  }
+
+  private class MockNoSpaceStorageChecker extends LocalStorageChecker {
+
+    private final List<MockNoSpaceStorageInfo> mockNoSpaceStorageInfos = Lists.newArrayList();
+
+    MockNoSpaceStorageChecker(ShuffleServerConf conf, List<LocalStorage> storages) {
+      super(conf, storages);
+      for (LocalStorage storage : storages) {
+        mockNoSpaceStorageInfos.add(new MockNoSpaceStorageInfo(storage));
+      }
+    }
+
+    @Override
+    public boolean checkIsHealthy() {
+      for (StorageInfo storageInfo : mockNoSpaceStorageInfos) {
+        if (!storageInfo.checkStorageReadAndWrite()) {
+          return false;
+        }
+      }
+      return true;
+    }
+
+    private class MockNoSpaceStorageInfo extends StorageInfo {
+
+      private final File storageDir;
+      private final LocalStorage storage;
+
+      MockNoSpaceStorageInfo(LocalStorage storage) {
+        super(storage);
+        this.storageDir = new File(storage.getBasePath());
+        this.storage = storage;
+      }
+
+      @Override
+      boolean checkStorageReadAndWrite() {
+        if (storage.isCorrupted()) {
+          return false;
+        }
+        File checkDir = new File(storageDir, CHECKER_DIR_NAME);
+        try {
+          if (storage.getBasePath().contains("st2")) {
+            throw new IOException("No space left on device");
+          }
+          if (storage.getBasePath().contains("st3")) {
+            throw new IOException("mock");
+          }
+        } catch (Exception e) {
+          if (e.getMessage() != null && DEVICE_NO_SPACE_ERROR_MESSAGE.equals(e.getMessage())) {
+            return true;
+          }
+          return false;
+        } finally {
+          try {
+            FileUtils.deleteDirectory(checkDir);
+          } catch (IOException ioe) {
+            return false;
+          }
+        }
+        return true;
+      }
+    }
   }
 }
