@@ -23,17 +23,14 @@ import java.nio.file.FileStore;
 import java.nio.file.Files;
 import java.util.HashSet;
 import java.util.List;
-import java.util.Queue;
 import java.util.Set;
-import java.util.concurrent.locks.ReadWriteLock;
 
 import com.google.common.annotations.VisibleForTesting;
-import com.google.common.collect.Queues;
 import org.apache.commons.io.FileUtils;
-import org.roaringbitmap.RoaringBitmap;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import org.apache.uniffle.common.exception.RssException;
 import org.apache.uniffle.common.storage.StorageMedia;
 import org.apache.uniffle.common.util.RssUtils;
 import org.apache.uniffle.storage.handler.api.ServerReadHandler;
@@ -51,27 +48,18 @@ public class LocalStorage extends AbstractStorage {
   private long capacity;
   private final String basePath;
   private final String mountPoint;
-  private final double cleanupThreshold;
-  private final long cleanIntervalMs;
   private final double highWaterMarkOfWrite;
   private final double lowWaterMarkOfWrite;
-  private final long shuffleExpiredTimeoutMs;
-  private final Queue<String> expiredShuffleKeys = Queues.newLinkedBlockingQueue();
-
-  private LocalStorageMeta metaData = new LocalStorageMeta();
+  private final LocalStorageMeta metaData = new LocalStorageMeta();
   private final StorageMedia media;
   private boolean isSpaceEnough = true;
   private volatile boolean isCorrupted = false;
 
-
   private LocalStorage(Builder builder) {
     this.basePath = builder.basePath;
-    this.cleanupThreshold = builder.cleanupThreshold;
-    this.cleanIntervalMs = builder.cleanIntervalMs;
     this.highWaterMarkOfWrite = builder.highWaterMarkOfWrite;
     this.lowWaterMarkOfWrite = builder.lowWaterMarkOfWrite;
     this.capacity = builder.capacity;
-    this.shuffleExpiredTimeoutMs = builder.shuffleExpiredTimeoutMs;
     this.media = builder.media;
 
     File baseFolder = new File(basePath);
@@ -81,20 +69,28 @@ public class LocalStorage extends AbstractStorage {
       // clean the directory if it's data left from previous ran.
       FileUtils.cleanDirectory(baseFolder);
       FileStore store = Files.getFileStore(baseFolder.toPath());
-      this.mountPoint =  store.name();
+      this.mountPoint = store.name();
     } catch (IOException ioe) {
       LOG.warn("Init base directory " + basePath + " fail, the disk should be corrupted", ioe);
-      throw new RuntimeException(ioe);
+      throw new RssException(ioe);
     }
     if (capacity < 0L) {
-      this.capacity = baseFolder.getTotalSpace();
-      LOG.info("Make the disk capacity the total space when \"rss.server.disk.capacity\" is not specified "
-          + "or less than 0");
+      long totalSpace = baseFolder.getTotalSpace();
+      this.capacity = (long) (totalSpace * builder.ratio);
+      LOG.info(
+          "The `rss.server.disk.capacity` is not specified nor negative, the "
+              + "ratio(`rss.server.disk.capacity.ratio`:{}) * disk space({}) is used, ",
+          builder.ratio,
+          totalSpace);
     } else {
       long freeSpace = baseFolder.getFreeSpace();
       if (freeSpace < capacity) {
-        throw new IllegalArgumentException("The Disk of " + basePath + " Available Capacity " + freeSpace
-            + " is smaller than configuration");
+        throw new IllegalArgumentException(
+            "The Disk of "
+                + basePath
+                + " Available Capacity "
+                + freeSpace
+                + " is smaller than configuration");
       }
     }
   }
@@ -109,29 +105,10 @@ public class LocalStorage extends AbstractStorage {
     return STORAGE_HOST;
   }
 
-  @Override
-  public boolean lockShuffleShared(String shuffleKey) {
-    ReadWriteLock lock = getLock(shuffleKey);
-    if (lock == null) {
-      return false;
-    }
-    lock.readLock().lock();
-    return true;
-  }
-
-  @Override
-  public boolean unlockShuffleShared(String shuffleKey) {
-    ReadWriteLock lock = getLock(shuffleKey);
-    if (lock == null) {
-      return false;
-    }
-    lock.readLock().unlock();
-    return true;
-  }
-
   @Override
   public void updateWriteMetrics(StorageWriteMetrics metrics) {
-    updateWrite(RssUtils.generateShuffleKey(metrics.getAppId(), metrics.getShuffleId()),
+    updateWrite(
+        RssUtils.generateShuffleKey(metrics.getAppId(), metrics.getShuffleId()),
         metrics.getDataSize(),
         metrics.getPartitions());
   }
@@ -145,13 +122,13 @@ public class LocalStorage extends AbstractStorage {
 
   @Override
   ShuffleWriteHandler newWriteHandler(CreateShuffleWriteHandlerRequest request) {
-    return new LocalFileWriteHandler(request.getAppId(),
+    return new LocalFileWriteHandler(
+        request.getAppId(),
         request.getShuffleId(),
         request.getStartPartition(),
         request.getEndPartition(),
         basePath,
-        request.getFileNamePrefix()
-    );
+        request.getFileNamePrefix());
   }
 
   @Override
@@ -193,29 +170,10 @@ public class LocalStorage extends AbstractStorage {
     metaData.prepareStartRead(key);
   }
 
-  public boolean isShuffleLongTimeNotRead(String shuffleKey) {
-    if (metaData.getShuffleLastReadTs(shuffleKey) == -1) {
-      return false;
-    }
-    if (System.currentTimeMillis() - metaData.getShuffleLastReadTs(shuffleKey) > shuffleExpiredTimeoutMs) {
-      return true;
-    }
-    return false;
-  }
-
   public void updateShuffleLastReadTs(String shuffleKey) {
     metaData.updateShuffleLastReadTs(shuffleKey);
   }
 
-  public RoaringBitmap getNotUploadedPartitions(String key) {
-    return metaData.getNotUploadedPartitions(key);
-  }
-
-  public void updateUploadedShuffle(String shuffleKey, long size, List<Integer> partitions) {
-    metaData.updateUploadedShuffleSize(shuffleKey, size);
-    metaData.addUploadedShufflePartitionList(shuffleKey, partitions);
-  }
-
   public long getDiskSize() {
     return metaData.getDiskSize().longValue();
   }
@@ -237,18 +195,6 @@ public class LocalStorage extends AbstractStorage {
     return media;
   }
 
-  public double getHighWaterMarkOfWrite() {
-    return highWaterMarkOfWrite;
-  }
-
-  public double getLowWaterMarkOfWrite() {
-    return lowWaterMarkOfWrite;
-  }
-
-  public void addExpiredShuffleKey(String shuffleKey) {
-    expiredShuffleKeys.offer(shuffleKey);
-  }
-
   // This is the only place to remove shuffle metadata, clean and gc thread may remove
   // the shuffle metadata concurrently or serially. Force uploader thread may update the
   // shuffle size so gc thread must acquire write lock before updating disk size, and force
@@ -256,54 +202,17 @@ public class LocalStorage extends AbstractStorage {
   // add the shuffle key back to the expiredShuffleKeys if get lock but fail to acquire write lock.
   public void removeResources(String shuffleKey) {
     LOG.info("Start to remove resource of {}", shuffleKey);
-    ReadWriteLock lock = metaData.getLock(shuffleKey);
-    if (lock == null) {
-      LOG.info("Ignore shuffle {} for its resource was removed already", shuffleKey);
-      return;
+    try {
+      metaData.updateDiskSize(-metaData.getShuffleSize(shuffleKey));
+      metaData.remoteShuffle(shuffleKey);
+      LOG.info(
+          "Finish remove resource of {}, disk size is {} and {} shuffle metadata",
+          shuffleKey,
+          metaData.getDiskSize(),
+          metaData.getShuffleMetaSet().size());
+    } catch (Exception e) {
+      LOG.error("Fail to update disk size", e);
     }
-
-    if (lock.writeLock().tryLock()) {
-      try {
-        metaData.updateDiskSize(-metaData.getShuffleSize(shuffleKey));
-        metaData.remoteShuffle(shuffleKey);
-        LOG.info("Finish remove resource of {}, disk size is {} and {} shuffle metadata",
-            shuffleKey, metaData.getDiskSize(), metaData.getShuffleMetaSet().size());
-      } catch (Exception e) {
-        LOG.error("Fail to update disk size", e);
-        expiredShuffleKeys.offer(shuffleKey);
-      } finally {
-        lock.writeLock().unlock();
-      }
-    } else {
-      LOG.info("Fail to get write lock of {}, add it back to expired shuffle queue", shuffleKey);
-      expiredShuffleKeys.offer(shuffleKey);
-    }
-  }
-
-  public ReadWriteLock getLock(String shuffleKey) {
-    return metaData.getLock(shuffleKey);
-  }
-
-  public long getNotUploadedSize(String key) {
-    return metaData.getNotUploadedSize(key);
-  }
-
-  public List<String> getSortedShuffleKeys(boolean checkRead, int num) {
-    return metaData.getSortedShuffleKeys(checkRead, num);
-  }
-
-  public Set<String> getShuffleMetaSet() {
-    return metaData.getShuffleMetaSet();
-  }
-
-  public void removeShuffle(String shuffleKey, long size, List<Integer> partitions) {
-    metaData.removeShufflePartitionList(shuffleKey, partitions);
-    metaData.updateDiskSize(-size);
-    metaData.updateShuffleSize(shuffleKey, -size);
-  }
-
-  public Queue<String> getExpiredShuffleKeys() {
-    return expiredShuffleKeys;
   }
 
   public boolean isCorrupted() {
@@ -336,22 +245,24 @@ public class LocalStorage extends AbstractStorage {
 
   public static class Builder {
     private long capacity;
+    private double ratio;
     private double lowWaterMarkOfWrite;
     private double highWaterMarkOfWrite;
-    private double cleanupThreshold;
     private String basePath;
-    private long cleanIntervalMs;
-    private long shuffleExpiredTimeoutMs;
     private StorageMedia media;
 
-    private Builder() {
-    }
+    private Builder() {}
 
     public Builder capacity(long capacity) {
       this.capacity = capacity;
       return this;
     }
 
+    public Builder ratio(double ratio) {
+      this.ratio = ratio;
+      return this;
+    }
+
     public Builder lowWaterMarkOfWrite(double lowWaterMarkOfWrite) {
       this.lowWaterMarkOfWrite = lowWaterMarkOfWrite;
       return this;
@@ -362,26 +273,11 @@ public class LocalStorage extends AbstractStorage {
       return this;
     }
 
-    public Builder cleanupThreshold(double cleanupThreshold) {
-      this.cleanupThreshold = cleanupThreshold;
-      return this;
-    }
-
     public Builder highWaterMarkOfWrite(double highWaterMarkOfWrite) {
       this.highWaterMarkOfWrite = highWaterMarkOfWrite;
       return this;
     }
 
-    public Builder cleanIntervalMs(long cleanIntervalMs) {
-      this.cleanIntervalMs = cleanIntervalMs;
-      return this;
-    }
-
-    public Builder shuffleExpiredTimeoutMs(long shuffleExpiredTimeoutMs) {
-      this.shuffleExpiredTimeoutMs = shuffleExpiredTimeoutMs;
-      return this;
-    }
-
     public Builder localStorageMedia(StorageMedia media) {
       this.media = media;
       return this;
