@@ -34,8 +34,8 @@ import org.apache.uniffle.common.util.RssUtils;
 import org.apache.uniffle.storage.handler.api.ClientReadHandler;
 import org.apache.uniffle.storage.handler.api.ShuffleDeleteHandler;
 import org.apache.uniffle.storage.handler.impl.ComposedClientReadHandler;
-import org.apache.uniffle.storage.handler.impl.HdfsClientReadHandler;
-import org.apache.uniffle.storage.handler.impl.HdfsShuffleDeleteHandler;
+import org.apache.uniffle.storage.handler.impl.HadoopClientReadHandler;
+import org.apache.uniffle.storage.handler.impl.HadoopShuffleDeleteHandler;
 import org.apache.uniffle.storage.handler.impl.LocalFileClientReadHandler;
 import org.apache.uniffle.storage.handler.impl.LocalFileDeleteHandler;
 import org.apache.uniffle.storage.handler.impl.MemoryClientReadHandler;
@@ -48,8 +48,7 @@ public class ShuffleHandlerFactory {
 
   private static ShuffleHandlerFactory INSTANCE;
 
-  private ShuffleHandlerFactory() {
-  }
+  private ShuffleHandlerFactory() {}
 
   public static synchronized ShuffleHandlerFactory getInstance() {
     if (INSTANCE == null) {
@@ -58,26 +57,33 @@ public class ShuffleHandlerFactory {
     return INSTANCE;
   }
 
-
   public ClientReadHandler createShuffleReadHandler(CreateShuffleReadHandlerRequest request) {
     if (CollectionUtils.isEmpty(request.getShuffleServerInfoList())) {
-      throw new RuntimeException("Shuffle servers should not be empty!");
+      throw new RssException("Shuffle servers should not be empty!");
     }
     if (request.getShuffleServerInfoList().size() > 1) {
       List<ClientReadHandler> handlers = Lists.newArrayList();
-      request.getShuffleServerInfoList().forEach((ssi) -> {
-        handlers.add(ShuffleHandlerFactory.getInstance().createSingleReplicaClientReadHandler(request, ssi));
-      });
-      return new MultiReplicaClientReadHandler(handlers, request.getShuffleServerInfoList(),
-          request.getExpectBlockIds(), request.getProcessBlockIds());
+      request
+          .getShuffleServerInfoList()
+          .forEach(
+              (ssi) -> {
+                handlers.add(
+                    ShuffleHandlerFactory.getInstance()
+                        .createSingleReplicaClientReadHandler(request, ssi));
+              });
+      return new MultiReplicaClientReadHandler(
+          handlers,
+          request.getShuffleServerInfoList(),
+          request.getExpectBlockIds(),
+          request.getProcessBlockIds());
     } else {
       ShuffleServerInfo serverInfo = request.getShuffleServerInfoList().get(0);
       return createSingleReplicaClientReadHandler(request, serverInfo);
     }
   }
 
-  public ClientReadHandler createSingleReplicaClientReadHandler(CreateShuffleReadHandlerRequest request,
-                                                                ShuffleServerInfo serverInfo) {
+  public ClientReadHandler createSingleReplicaClientReadHandler(
+      CreateShuffleReadHandlerRequest request, ShuffleServerInfo serverInfo) {
     String storageType = request.getStorageType();
     StorageType type = StorageType.valueOf(storageType);
 
@@ -87,7 +93,7 @@ public class ShuffleHandlerFactory {
     }
 
     if (StorageType.HDFS == type) {
-      return getHdfsClientReadHandler(request, serverInfo);
+      return getHadoopClientReadHandler(request, serverInfo);
     }
     if (StorageType.LOCALFILE == type) {
       return getLocalfileClientReaderHandler(request, serverInfo);
@@ -95,61 +101,67 @@ public class ShuffleHandlerFactory {
 
     List<Supplier<ClientReadHandler>> handlers = new ArrayList<>();
     if (StorageType.withMemory(type)) {
-      handlers.add(
-          () -> getMemoryClientReadHandler(request, serverInfo)
-      );
+      handlers.add(() -> getMemoryClientReadHandler(request, serverInfo));
     }
     if (StorageType.withLocalfile(type)) {
-      handlers.add(
-          () -> getLocalfileClientReaderHandler(request, serverInfo)
-      );
+      handlers.add(() -> getLocalfileClientReaderHandler(request, serverInfo));
     }
-    if (StorageType.withHDFS(type)) {
-      handlers.add(
-          () -> getHdfsClientReadHandler(request, serverInfo)
-      );
+    if (StorageType.withHadoop(type)) {
+      handlers.add(() -> getHadoopClientReadHandler(request, serverInfo));
     }
     if (handlers.isEmpty()) {
-      throw new RssException("This should not happen due to the unknown storage type: " + storageType);
+      throw new RssException(
+          "This should not happen due to the unknown storage type: " + storageType);
     }
 
     return new ComposedClientReadHandler(serverInfo, handlers);
   }
 
-  private ClientReadHandler getMemoryClientReadHandler(CreateShuffleReadHandlerRequest request, ShuffleServerInfo ssi) {
-    ShuffleServerClient shuffleServerClient = ShuffleServerClientFactory.getInstance().getShuffleServerClient(
-        ClientType.GRPC.name(), ssi);
+  private ClientReadHandler getMemoryClientReadHandler(
+      CreateShuffleReadHandlerRequest request, ShuffleServerInfo ssi) {
+    ShuffleServerClient shuffleServerClient =
+        ShuffleServerClientFactory.getInstance()
+            .getShuffleServerClient(ClientType.GRPC.name(), ssi, request.getClientConf());
     Roaring64NavigableMap expectTaskIds = null;
     if (request.isExpectedTaskIdsBitmapFilterEnable()) {
       Roaring64NavigableMap realExceptBlockIds = RssUtils.cloneBitMap(request.getExpectBlockIds());
       realExceptBlockIds.xor(request.getProcessBlockIds());
       expectTaskIds = RssUtils.generateTaskIdBitMap(realExceptBlockIds, request.getIdHelper());
     }
-    ClientReadHandler memoryClientReadHandler = new MemoryClientReadHandler(
-        request.getAppId(),
-        request.getShuffleId(),
-        request.getPartitionId(),
-        request.getReadBufferSize(),
-        shuffleServerClient,
-        expectTaskIds
-    );
+    ClientReadHandler memoryClientReadHandler =
+        new MemoryClientReadHandler(
+            request.getAppId(),
+            request.getShuffleId(),
+            request.getPartitionId(),
+            request.getReadBufferSize(),
+            shuffleServerClient,
+            expectTaskIds);
     return memoryClientReadHandler;
   }
 
-  private ClientReadHandler getLocalfileClientReaderHandler(CreateShuffleReadHandlerRequest request,
-                                                            ShuffleServerInfo ssi) {
-    ShuffleServerClient shuffleServerClient = ShuffleServerClientFactory.getInstance().getShuffleServerClient(
-        ClientType.GRPC.name(), ssi);
+  private ClientReadHandler getLocalfileClientReaderHandler(
+      CreateShuffleReadHandlerRequest request, ShuffleServerInfo ssi) {
+    ShuffleServerClient shuffleServerClient =
+        ShuffleServerClientFactory.getInstance()
+            .getShuffleServerClient(ClientType.GRPC.name(), ssi, request.getClientConf());
     return new LocalFileClientReadHandler(
-        request.getAppId(), request.getShuffleId(), request.getPartitionId(),
-        request.getIndexReadLimit(), request.getPartitionNumPerRange(), request.getPartitionNum(),
-        request.getReadBufferSize(), request.getExpectBlockIds(), request.getProcessBlockIds(),
-        shuffleServerClient, request.getDistributionType(), request.getExpectTaskIds()
-    );
+        request.getAppId(),
+        request.getShuffleId(),
+        request.getPartitionId(),
+        request.getIndexReadLimit(),
+        request.getPartitionNumPerRange(),
+        request.getPartitionNum(),
+        request.getReadBufferSize(),
+        request.getExpectBlockIds(),
+        request.getProcessBlockIds(),
+        shuffleServerClient,
+        request.getDistributionType(),
+        request.getExpectTaskIds());
   }
 
-  private ClientReadHandler getHdfsClientReadHandler(CreateShuffleReadHandlerRequest request, ShuffleServerInfo ssi) {
-    return new HdfsClientReadHandler(
+  private ClientReadHandler getHadoopClientReadHandler(
+      CreateShuffleReadHandlerRequest request, ShuffleServerInfo ssi) {
+    return new HadoopClientReadHandler(
         request.getAppId(),
         request.getShuffleId(),
         request.getPartitionId(),
@@ -163,18 +175,19 @@ public class ShuffleHandlerFactory {
         request.getHadoopConf(),
         request.getDistributionType(),
         request.getExpectTaskIds(),
-        ssi.getId()
-    );
+        ssi.getId(),
+        request.isOffHeapEnabled());
   }
 
-  public ShuffleDeleteHandler createShuffleDeleteHandler(CreateShuffleDeleteHandlerRequest request) {
+  public ShuffleDeleteHandler createShuffleDeleteHandler(
+      CreateShuffleDeleteHandlerRequest request) {
     if (StorageType.HDFS.name().equals(request.getStorageType())) {
-      return new HdfsShuffleDeleteHandler(request.getConf());
+      return new HadoopShuffleDeleteHandler(request.getConf());
     } else if (StorageType.LOCALFILE.name().equals(request.getStorageType())) {
       return new LocalFileDeleteHandler();
     } else {
-      throw new UnsupportedOperationException("Doesn't support storage type for shuffle delete handler:"
-          + request.getStorageType());
+      throw new UnsupportedOperationException(
+          "Doesn't support storage type for shuffle delete handler:" + request.getStorageType());
     }
   }
 }
