@@ -28,6 +28,7 @@ import org.slf4j.LoggerFactory;
 
 import org.apache.uniffle.common.ShufflePartitionedBlock;
 import org.apache.uniffle.common.exception.RssException;
+import org.apache.uniffle.common.util.ByteBufUtils;
 import org.apache.uniffle.storage.common.FileBasedShuffleSegment;
 import org.apache.uniffle.storage.handler.api.ShuffleWriteHandler;
 import org.apache.uniffle.storage.util.ShuffleStorageUtils;
@@ -47,8 +48,10 @@ public class LocalFileWriteHandler implements ShuffleWriteHandler {
       String storageBasePath,
       String fileNamePrefix) {
     this.fileNamePrefix = fileNamePrefix;
-    this.basePath = ShuffleStorageUtils.getFullShuffleDataFolder(storageBasePath,
-        ShuffleStorageUtils.getShuffleDataPath(appId, shuffleId, startPartition, endPartition));
+    this.basePath =
+        ShuffleStorageUtils.getFullShuffleDataFolder(
+            storageBasePath,
+            ShuffleStorageUtils.getShuffleDataPath(appId, shuffleId, startPartition, endPartition));
     createBasePath();
   }
 
@@ -66,25 +69,19 @@ public class LocalFileWriteHandler implements ShuffleWriteHandler {
 
   // pick base path by hashcode
   private String pickBasePath(
-      String[] storageBasePaths,
-      String appId,
-      int shuffleId,
-      int startPartition) {
+      String[] storageBasePaths, String appId, int shuffleId, int startPartition) {
     if (storageBasePaths == null || storageBasePaths.length == 0) {
-      throw new RuntimeException("Base path can't be empty, please check rss.storage.localFile.basePaths");
+      throw new RssException(
+          "Base path can't be empty, please check rss.storage.localFile.basePaths");
     }
-    int index = ShuffleStorageUtils.getStorageIndex(
-        storageBasePaths.length,
-        appId,
-        shuffleId,
-        startPartition
-    );
+    int index =
+        ShuffleStorageUtils.getStorageIndex(
+            storageBasePaths.length, appId, shuffleId, startPartition);
     return storageBasePaths[index];
   }
 
   @Override
-  public synchronized void write(
-      List<ShufflePartitionedBlock> shuffleBlocks) throws Exception {
+  public synchronized void write(List<ShufflePartitionedBlock> shuffleBlocks) throws Exception {
 
     // Ignore this write, if the shuffle directory is deleted after being uploaded in multi mode
     // or after its app heartbeat times out.
@@ -106,10 +103,16 @@ public class LocalFileWriteHandler implements ShuffleWriteHandler {
         long blockId = block.getBlockId();
         long crc = block.getCrc();
         long startOffset = dataWriter.nextOffset();
-        dataWriter.writeData(block.getData());
+        dataWriter.writeData(ByteBufUtils.readBytes(block.getData()));
 
-        FileBasedShuffleSegment segment = new FileBasedShuffleSegment(
-            blockId, startOffset, block.getLength(), block.getUncompressLength(), crc, block.getTaskAttemptId());
+        FileBasedShuffleSegment segment =
+            new FileBasedShuffleSegment(
+                blockId,
+                startOffset,
+                block.getLength(),
+                block.getUncompressLength(),
+                crc,
+                block.getTaskAttemptId());
         indexWriter.writeIndex(segment);
       }
       LOG.debug(
@@ -132,5 +135,4 @@ public class LocalFileWriteHandler implements ShuffleWriteHandler {
   protected String getBasePath() {
     return basePath;
   }
-
 }
