@@ -28,17 +28,16 @@ import org.apache.uniffle.client.request.RssGetInMemoryShuffleDataRequest;
 import org.apache.uniffle.client.response.RssGetInMemoryShuffleDataResponse;
 import org.apache.uniffle.common.BufferSegment;
 import org.apache.uniffle.common.ShuffleDataResult;
-import org.apache.uniffle.common.exception.RssException;
+import org.apache.uniffle.common.exception.RssFetchFailedException;
 import org.apache.uniffle.common.util.Constants;
 
-
 public class MemoryClientReadHandler extends AbstractClientReadHandler {
 
   private static final Logger LOG = LoggerFactory.getLogger(MemoryClientReadHandler.class);
   private long lastBlockId = Constants.INVALID_BLOCK_ID;
   private ShuffleServerClient shuffleServerClient;
   private Roaring64NavigableMap expectTaskIds;
-  
+
   public MemoryClientReadHandler(
       String appId,
       int shuffleId,
@@ -58,23 +57,23 @@ public class MemoryClientReadHandler extends AbstractClientReadHandler {
   public ShuffleDataResult readShuffleData() {
     ShuffleDataResult result = null;
 
-    RssGetInMemoryShuffleDataRequest request = new RssGetInMemoryShuffleDataRequest(
-        appId,
-        shuffleId,
-        partitionId,
-        lastBlockId,
-        readBufferSize,
-        expectTaskIds
-    );
+    RssGetInMemoryShuffleDataRequest request =
+        new RssGetInMemoryShuffleDataRequest(
+            appId, shuffleId, partitionId, lastBlockId, readBufferSize, expectTaskIds);
 
     try {
       RssGetInMemoryShuffleDataResponse response =
           shuffleServerClient.getInMemoryShuffleData(request);
       result = new ShuffleDataResult(response.getData(), response.getBufferSegments());
+    } catch (RssFetchFailedException e) {
+      throw e;
     } catch (Exception e) {
       // todo: fault tolerance solution should be added
-      throw new RssException("Failed to read in memory shuffle data with "
-          + shuffleServerClient.getClientInfo() + " due to " + e);
+      throw new RssFetchFailedException(
+          "Failed to read in memory shuffle data with "
+              + shuffleServerClient.getClientInfo()
+              + " due to "
+              + e);
     }
 
     // update lastBlockId for next rpc call
