@@ -25,6 +25,7 @@ import org.roaringbitmap.longlong.Roaring64NavigableMap;
 import org.apache.uniffle.common.ShuffleDataDistributionType;
 import org.apache.uniffle.common.ShuffleServerInfo;
 import org.apache.uniffle.common.config.RssBaseConf;
+import org.apache.uniffle.common.config.RssConf;
 import org.apache.uniffle.common.util.IdHelper;
 
 public class CreateShuffleReadHandlerRequest {
@@ -46,11 +47,12 @@ public class CreateShuffleReadHandlerRequest {
   private ShuffleDataDistributionType distributionType;
   private Roaring64NavigableMap expectTaskIds;
   private boolean expectedTaskIdsBitmapFilterEnable;
+  private boolean offHeapEnabled;
+  private RssConf clientConf;
 
   private IdHelper idHelper;
 
-  public CreateShuffleReadHandlerRequest() {
-  }
+  public CreateShuffleReadHandlerRequest() {}
 
   public RssBaseConf getRssBaseConf() {
     return rssBaseConf;
@@ -195,4 +197,20 @@ public class CreateShuffleReadHandlerRequest {
   public void setIdHelper(IdHelper idHelper) {
     this.idHelper = idHelper;
   }
+
+  public void enableOffHeap() {
+    this.offHeapEnabled = true;
+  }
+
+  public boolean isOffHeapEnabled() {
+    return offHeapEnabled;
+  }
+
+  public RssConf getClientConf() {
+    return clientConf;
+  }
+
+  public void setClientConf(RssConf clientConf) {
+    this.clientConf = clientConf;
+  }
 }
